package Locales::DB::Territory::bez;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::bez::VERSION = '0.09';

$Locales::DB::Territory::bez::cldr_version = '2.0';

%Locales::DB::Territory::bez::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Huandola',
    'ae'  => "Hufalme\ dza\ Hihalabu",
    'af'  => 'Huafuganistani',
    'ag'  => "Huantigua\ na\ Hubarubuda",
    'ai'  => 'Huanguila',
    'al'  => 'Hualbania',
    'am'  => 'Huamenia',
    'an'  => "Huantili\ dza\ Huuholanzi",
    'ao'  => 'Huangola',
    'aq'  => 'Antarctica',
    'ar'  => 'Huajendina',
    'as'  => "Husamoa\ ya\ Humalekani",
    'at'  => 'Huastlia',
    'au'  => 'Huaustlalia',
    'aw'  => 'Hualuba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Huazabajani',
    'ba'  => "Hubosinia\ na\ Huhezegovina",
    'bb'  => 'Hubabadosi',
    'bd'  => 'Hubangaladeshi',
    'be'  => 'Huubelgiji',
    'bf'  => 'Hubukinafaso',
    'bg'  => 'Hubulgaria',
    'bh'  => 'Hubahaleni',
    'bi'  => 'Huburundi',
    'bj'  => 'Hubenini',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Hubelmuda',
    'bn'  => 'Hubrunei',
    'bo'  => 'Hubolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Hublazili',
    'bs'  => 'Hubahama',
    'bt'  => 'Hubutani',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Hubotiswana',
    'by'  => 'Hubelalusi',
    'bz'  => 'Hubelize',
    'ca'  => 'Hukanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Ijamhuri\ ya\ Hidemokrasi\ ya\ Hukongo",
    'cf'  => "Ijamhuri\ ya\ Afrika\ ya\ Pagati",
    'cg'  => 'Hukongo',
    'ch'  => 'Huuswisi',
    'ci'  => 'Hukodivaa',
    'ck'  => "Ifisima\ fya\ Kook",
    'cl'  => 'Huchile',
    'cm'  => 'Hukameruni',
    'cn'  => 'Huchina',
    'co'  => 'Hukolombia',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Hukostarika',
    'cs'  => "Huselbia\ na\ Humonteneglo",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Hukuba',
    'cv'  => 'Hukepuvede',
    'cx'  => "Christmas\ Island",
    'cy'  => 'Hukuprosi',
    'cz'  => "Ijamhuri\ ya\ Cheki",
    'dd'  => "East\ Germany",
    'de'  => 'Huujerumani',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Hujibuti',
    'dk'  => 'Hudenmaki',
    'dm'  => 'Hudominika',
    'do'  => "Ijamhuri\ ya\ Hudominika",
    'dz'  => 'Hualjelia',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Huekwado',
    'ee'  => 'Huestonia',
    'eg'  => 'Humisri',
    'eh'  => "Western\ Sahara",
    'er'  => 'Hueritrea',
    'es'  => 'Huhispania',
    'et'  => 'Huuhabeshi',
    'eu'  => "European\ Union",
    'fi'  => 'Huufini',
    'fj'  => 'Hufiji',
    'fk'  => "Ifisima\ fya\ Falkland",
    'fm'  => 'Humikronesia',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Huufaransa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Hugaboni',
    'gb'  => 'Huuingereza',
    'gd'  => 'Hugrenada',
    'ge'  => 'Hujojia',
    'gf'  => "Hugwiyana\ ya\ Huufaransa",
    'gg'  => 'Guernsey',
    'gh'  => 'Hughana',
    'gi'  => 'Hujiblalta',
    'gl'  => 'Hujinlandi',
    'gm'  => 'Hugambia',
    'gn'  => 'Hujine',
    'gp'  => 'Hugwadelupe',
    'gq'  => 'Huginekweta',
    'gr'  => 'Huugiliki',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Hugwatemala',
    'gu'  => 'Hugwam',
    'gw'  => 'Huginebisau',
    'gy'  => 'Huguyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Huhondulasi',
    'hr'  => 'Hukorasia',
    'ht'  => 'Huhaiti',
    'hu'  => 'Huhungalia',
    'ic'  => "Canary\ Islands",
    'id'  => 'Huindonesia',
    'ie'  => 'Huayalandi',
    'il'  => 'Huislaheli',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Huindia',
    'io'  => "Ulubali\ lwa\ Hubahari\ ya\ Hindi\ lwa\ Huingereza",
    'iq'  => 'Huilaki',
    'ir'  => 'Huuajemi',
    'is'  => 'Huaislandi',
    'it'  => 'Huitalia',
    'je'  => 'Jersey',
    'jm'  => 'Hujamaika',
    'jo'  => 'Huyolodani',
    'jp'  => 'Hujapani',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Hukenya',
    'kg'  => 'Hukiligizistani',
    'kh'  => 'Hukambodia',
    'ki'  => 'Hukilibati',
    'km'  => 'Hukomoro',
    'kn'  => "Husantakitzi\ na\ Hunevis",
    'kp'  => "Hukolea\ Kaskazini",
    'kr'  => "Hukolea\ Kusini",
    'kw'  => 'Hukuwaiti',
    'ky'  => "Ifisima\ fya\ Kayman",
    'kz'  => 'Hukazakistani',
    'la'  => 'Hulaosi',
    'lb'  => 'Hulebanoni',
    'lc'  => 'Husantalusia',
    'li'  => 'Hulishenteni',
    'lk'  => 'Husirilanka',
    'lr'  => 'Hulibelia',
    'ls'  => 'Hulesoto',
    'lt'  => 'Hulitwania',
    'lu'  => 'Hulasembagi',
    'lv'  => 'Hulativia',
    'ly'  => 'Hulibiya',
    'ma'  => 'Humoloko',
    'mc'  => 'Humonako',
    'md'  => 'Humoldova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Hubukini',
    'mh'  => "Ifisima\ fya\ Marshal",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Humasedonia',
    'ml'  => 'Humali',
    'mm'  => 'Humyama',
    'mn'  => 'Humongolia',
    'mo'  => 'Macau',
    'mp'  => "Ifisima\ fya\ Mariana\ fya\ Hukaskazini",
    'mq'  => 'Humartiniki',
    'mr'  => 'Humolitania',
    'ms'  => 'Humontserrati',
    'mt'  => 'Humalta',
    'mu'  => 'Humolisi',
    'mv'  => 'Humodivu',
    'mw'  => 'Humalawi',
    'mx'  => 'Humeksiko',
    'my'  => 'Humalesia',
    'mz'  => 'Humusumbiji',
    'na'  => 'Hunamibia',
    'nc'  => 'Hunyukaledonia',
    'ne'  => 'Hunijeli',
    'nf'  => "Ihisima\ sha\ Norfok",
    'ng'  => 'Hunijelia',
    'ni'  => 'Hunikaragwa',
    'nl'  => 'Huuholanzi',
    'no'  => 'Hunolwe',
    'np'  => 'Hunepali',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Hunauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Huniue',
    'nz'  => 'Hunyuzilandi',
    'om'  => 'Huomani',
    'pa'  => 'Hupanama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Hupelu',
    'pf'  => "Hupolinesia\ ya\ Huufaransa",
    'pg'  => 'Hupapua',
    'ph'  => 'Hufilipino',
    'pk'  => 'Hupakistani',
    'pl'  => 'Hupolandi',
    'pm'  => "Husantapieri\ na\ Humikeloni",
    'pn'  => 'Hupitkaini',
    'pr'  => 'Hupwetoriko',
    'ps'  => "Ulubali\ lwa\ Magharibi\ nu\ Gaza\ wa\ Hupalestina",
    'pt'  => 'Huuleno',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Hupalau',
    'py'  => 'Hupalagwai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Hukatali',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Huliyunioni',
    'ro'  => 'Hulomania',
    'rs'  => 'Serbia',
    'ru'  => 'Huulusi',
    'rw'  => 'Hulwanda',
    'sa'  => 'Husaudi',
    'sb'  => "Ifisima\ fya\ Solomon",
    'sc'  => 'Hushelisheli',
    'sd'  => 'Husudani',
    'se'  => 'Huuswidi',
    'sg'  => 'Husingapoo',
    'sh'  => 'Husantahelena',
    'si'  => 'Huslovenia',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Huslovakia',
    'sl'  => "Husiela\ Lioni",
    'sm'  => 'Husamalino',
    'sn'  => 'Husenegali',
    'so'  => 'Husomalia',
    'sr'  => 'Husurinamu',
    'st'  => "Husaotome\ na\ Huprinsipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Huelsavado',
    'sy'  => 'Husilia',
    'sz'  => 'Huuswazi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Ifisima\ fya\ Turki\ na\ Kaiko",
    'td'  => 'Huchadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Hutogo',
    'th'  => 'Hutailandi',
    'tj'  => 'Hutajikistani',
    'tk'  => 'Hutokelau',
    'tl'  => "Hutimori\ ya\ Mashariki",
    'tm'  => 'Huuturukimenistani',
    'tn'  => 'Hutunisia',
    'to'  => 'Hutonga',
    'tr'  => 'Huuturuki',
    'tt'  => "Hutrinad\ na\ Hutobago",
    'tv'  => 'Hutuvalu',
    'tw'  => 'Hutaiwani',
    'tz'  => 'Hutanzania',
    'ua'  => 'Huukraini',
    'ug'  => 'Huuganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Humalekani',
    'uy'  => 'Huulugwai',
    'uz'  => 'Huuzibekistani',
    'va'  => 'Huvatikani',
    'vc'  => "Husantavisenti\ na\ Hugrenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Huvenezuela',
    'vg'  => "Ifisima\ fya\ Virgin\ fya\ Huingereza",
    'vi'  => "Ifisima\ fya\ Virgin\ fya\ Humelekani",
    'vn'  => 'Huvietinamu',
    'vu'  => 'Huvanuatu',
    'wf'  => "Huwalis\ na\ Hufutuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Husamoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Huyemeni',
    'yt'  => 'Humayotte',
    'za'  => "Huafrika\ iya\ Hukusini",
    'zm'  => 'Huzambia',
    'zw'  => 'Huzimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::bez::name_to_code = (
    'africa'                                    => '002',
    'americas'                                  => '019',
    'antarctica'                                => 'aq',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'bouvetisland'                              => 'bv',
    'britishantarcticterritory'                 => 'bq',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'diegogarcia'                               => 'dg',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'guernsey'                                  => 'gg',
    'heardislandandmcdonaldislands'             => 'hm',
    'hongkong'                                  => 'hk',
    'huafrikaiyahukusini'                       => 'za',
    'huafuganistani'                            => 'af',
    'huaislandi'                                => 'is',
    'huajendina'                                => 'ar',
    'hualbania'                                 => 'al',
    'hualjelia'                                 => 'dz',
    'hualuba'                                   => 'aw',
    'huamenia'                                  => 'am',
    'huandola'                                  => 'ad',
    'huangola'                                  => 'ao',
    'huanguila'                                 => 'ai',
    'huantiguanahubarubuda'                     => 'ag',
    'huantilidzahuuholanzi'                     => 'an',
    'huastlia'                                  => 'at',
    'huaustlalia'                               => 'au',
    'huayalandi'                                => 'ie',
    'huazabajani'                               => 'az',
    'hubabadosi'                                => 'bb',
    'hubahaleni'                                => 'bh',
    'hubahama'                                  => 'bs',
    'hubangaladeshi'                            => 'bd',
    'hubelalusi'                                => 'by',
    'hubelize'                                  => 'bz',
    'hubelmuda'                                 => 'bm',
    'hubenini'                                  => 'bj',
    'hublazili'                                 => 'br',
    'hubolivia'                                 => 'bo',
    'hubosinianahuhezegovina'                   => 'ba',
    'hubotiswana'                               => 'bw',
    'hubrunei'                                  => 'bn',
    'hubukinafaso'                              => 'bf',
    'hubukini'                                  => 'mg',
    'hubulgaria'                                => 'bg',
    'huburundi'                                 => 'bi',
    'hubutani'                                  => 'bt',
    'huchadi'                                   => 'td',
    'huchile'                                   => 'cl',
    'huchina'                                   => 'cn',
    'hudenmaki'                                 => 'dk',
    'hudominika'                                => 'dm',
    'huekwado'                                  => 'ec',
    'huelsavado'                                => 'sv',
    'hueritrea'                                 => 'er',
    'huestonia'                                 => 'ee',
    'hufalmedzahihalabu'                        => 'ae',
    'hufiji'                                    => 'fj',
    'hufilipino'                                => 'ph',
    'hugaboni'                                  => 'ga',
    'hugambia'                                  => 'gm',
    'hughana'                                   => 'gh',
    'huginebisau'                               => 'gw',
    'huginekweta'                               => 'gq',
    'hugrenada'                                 => 'gd',
    'huguyana'                                  => 'gy',
    'hugwadelupe'                               => 'gp',
    'hugwam'                                    => 'gu',
    'hugwatemala'                               => 'gt',
    'hugwiyanayahuufaransa'                     => 'gf',
    'huhaiti'                                   => 'ht',
    'huhispania'                                => 'es',
    'huhondulasi'                               => 'hn',
    'huhungalia'                                => 'hu',
    'huilaki'                                   => 'iq',
    'huindia'                                   => 'in',
    'huindonesia'                               => 'id',
    'huislaheli'                                => 'il',
    'huitalia'                                  => 'it',
    'hujamaika'                                 => 'jm',
    'hujapani'                                  => 'jp',
    'hujiblalta'                                => 'gi',
    'hujibuti'                                  => 'dj',
    'hujine'                                    => 'gn',
    'hujinlandi'                                => 'gl',
    'hujojia'                                   => 'ge',
    'hukambodia'                                => 'kh',
    'hukameruni'                                => 'cm',
    'hukanada'                                  => 'ca',
    'hukatali'                                  => 'qa',
    'hukazakistani'                             => 'kz',
    'hukenya'                                   => 'ke',
    'hukepuvede'                                => 'cv',
    'hukilibati'                                => 'ki',
    'hukiligizistani'                           => 'kg',
    'hukodivaa'                                 => 'ci',
    'hukoleakaskazini'                          => 'kp',
    'hukoleakusini'                             => 'kr',
    'hukolombia'                                => 'co',
    'hukomoro'                                  => 'km',
    'hukongo'                                   => 'cg',
    'hukorasia'                                 => 'hr',
    'hukostarika'                               => 'cr',
    'hukuba'                                    => 'cu',
    'hukuprosi'                                 => 'cy',
    'hukuwaiti'                                 => 'kw',
    'hulaosi'                                   => 'la',
    'hulasembagi'                               => 'lu',
    'hulativia'                                 => 'lv',
    'hulebanoni'                                => 'lb',
    'hulesoto'                                  => 'ls',
    'hulibelia'                                 => 'lr',
    'hulibiya'                                  => 'ly',
    'hulishenteni'                              => 'li',
    'hulitwania'                                => 'lt',
    'huliyunioni'                               => 're',
    'hulomania'                                 => 'ro',
    'hulwanda'                                  => 'rw',
    'humalawi'                                  => 'mw',
    'humalekani'                                => 'us',
    'humalesia'                                 => 'my',
    'humali'                                    => 'ml',
    'humalta'                                   => 'mt',
    'humartiniki'                               => 'mq',
    'humasedonia'                               => 'mk',
    'humayotte'                                 => 'yt',
    'humeksiko'                                 => 'mx',
    'humikronesia'                              => 'fm',
    'humisri'                                   => 'eg',
    'humodivu'                                  => 'mv',
    'humoldova'                                 => 'md',
    'humolisi'                                  => 'mu',
    'humolitania'                               => 'mr',
    'humoloko'                                  => 'ma',
    'humonako'                                  => 'mc',
    'humongolia'                                => 'mn',
    'humontserrati'                             => 'ms',
    'humusumbiji'                               => 'mz',
    'humyama'                                   => 'mm',
    'hunamibia'                                 => 'na',
    'hunauru'                                   => 'nr',
    'hunepali'                                  => 'np',
    'hunijeli'                                  => 'ne',
    'hunijelia'                                 => 'ng',
    'hunikaragwa'                               => 'ni',
    'huniue'                                    => 'nu',
    'hunolwe'                                   => 'no',
    'hunyukaledonia'                            => 'nc',
    'hunyuzilandi'                              => 'nz',
    'huomani'                                   => 'om',
    'hupakistani'                               => 'pk',
    'hupalagwai'                                => 'py',
    'hupalau'                                   => 'pw',
    'hupanama'                                  => 'pa',
    'hupapua'                                   => 'pg',
    'hupelu'                                    => 'pe',
    'hupitkaini'                                => 'pn',
    'hupolandi'                                 => 'pl',
    'hupolinesiayahuufaransa'                   => 'pf',
    'hupwetoriko'                               => 'pr',
    'husamalino'                                => 'sm',
    'husamoa'                                   => 'ws',
    'husamoayahumalekani'                       => 'as',
    'husantahelena'                             => 'sh',
    'husantakitzinahunevis'                     => 'kn',
    'husantalusia'                              => 'lc',
    'husantapierinahumikeloni'                  => 'pm',
    'husantavisentinahugrenadini'               => 'vc',
    'husaotomenahuprinsipe'                     => 'st',
    'husaudi'                                   => 'sa',
    'huselbianahumonteneglo'                    => 'cs',
    'husenegali'                                => 'sn',
    'hushelisheli'                              => 'sc',
    'husielalioni'                              => 'sl',
    'husilia'                                   => 'sy',
    'husingapoo'                                => 'sg',
    'husirilanka'                               => 'lk',
    'huslovakia'                                => 'sk',
    'huslovenia'                                => 'si',
    'husomalia'                                 => 'so',
    'husudani'                                  => 'sd',
    'husurinamu'                                => 'sr',
    'hutailandi'                                => 'th',
    'hutaiwani'                                 => 'tw',
    'hutajikistani'                             => 'tj',
    'hutanzania'                                => 'tz',
    'hutimoriyamashariki'                       => 'tl',
    'hutogo'                                    => 'tg',
    'hutokelau'                                 => 'tk',
    'hutonga'                                   => 'to',
    'hutrinadnahutobago'                        => 'tt',
    'hutunisia'                                 => 'tn',
    'hutuvalu'                                  => 'tv',
    'huuajemi'                                  => 'ir',
    'huubelgiji'                                => 'be',
    'huufaransa'                                => 'fr',
    'huufini'                                   => 'fi',
    'huuganda'                                  => 'ug',
    'huugiliki'                                 => 'gr',
    'huuhabeshi'                                => 'et',
    'huuholanzi'                                => 'nl',
    'huuingereza'                               => 'gb',
    'huujerumani'                               => 'de',
    'huukraini'                                 => 'ua',
    'huuleno'                                   => 'pt',
    'huulugwai'                                 => 'uy',
    'huulusi'                                   => 'ru',
    'huuswazi'                                  => 'sz',
    'huuswidi'                                  => 'se',
    'huuswisi'                                  => 'ch',
    'huuturuki'                                 => 'tr',
    'huuturukimenistani'                        => 'tm',
    'huuzibekistani'                            => 'uz',
    'huvanuatu'                                 => 'vu',
    'huvatikani'                                => 'va',
    'huvenezuela'                               => 've',
    'huvietinamu'                               => 'vn',
    'huwalisnahufutuna'                         => 'wf',
    'huyemeni'                                  => 'ye',
    'huyolodani'                                => 'jo',
    'huzambia'                                  => 'zm',
    'huzimbabwe'                                => 'zw',
    'ifisimafyafalkland'                        => 'fk',
    'ifisimafyakayman'                          => 'ky',
    'ifisimafyakook'                            => 'ck',
    'ifisimafyamarianafyahukaskazini'           => 'mp',
    'ifisimafyamarshal'                         => 'mh',
    'ifisimafyasolomon'                         => 'sb',
    'ifisimafyaturkinakaiko'                    => 'tc',
    'ifisimafyavirginfyahuingereza'             => 'vg',
    'ifisimafyavirginfyahumelekani'             => 'vi',
    'ihisimashanorfok'                          => 'nf',
    'ijamhuriyaafrikayapagati'                  => 'cf',
    'ijamhuriyacheki'                           => 'cz',
    'ijamhuriyahidemokrasiyahukongo'            => 'cd',
    'ijamhuriyahudominika'                      => 'do',
    'isleofman'                                 => 'im',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'latinamerica'                              => 419,
    'macau'                                     => 'mo',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'montenegro'                                => 'me',
    'neutralzone'                               => 'nt',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'oceania'                                   => '009',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'panamacanalzone'                           => 'pz',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'polynesia'                                 => '061',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'serbia'                                    => 'rs',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'svalbardandjanmayen'                       => 'sj',
    'tristandacunha'                            => 'ta',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ulubalilwahubahariyahindilwahuingereza'    => 'io',
    'ulubalilwamagharibinugazawahupalestina'    => 'ps',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'wakeisland'                                => 'wk',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    "\Ã\landislands"                         => 'ax',
);

1;

