package Locales::DB::Territory::ur;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::ur::VERSION = '0.09';

$Locales::DB::Territory::ur::cldr_version = '2.0';

%Locales::DB::Territory::ur::code_to_name = (
    '001' => 'دنیا',
    '002' => 'افریقہ',
    '003' => "شمالی\ امریکہ",
    '005' => "جنوبی\ امریکہ",
    '009' => 'اوشیانیا',
    '011' => "مغربی\ افریقہ",
    '013' => "وسطی\ امریکہ",
    '014' => "مشرقی\ افریقہ",
    '015' => "شمالی\ افریقہ",
    '017' => "وسطی\ افریقہ",
    '018' => "جنوبی\ افریقہ\ کے\ علاقہ",
    '019' => 'امیریکاز',
    '021' => "شمالی\ امریکہ\ کا\ علاقہ",
    '029' => 'کریبیائی',
    '030' => "مشرقی\ ایشیا",
    '034' => "جنوبی\ ایشیا",
    '035' => "جنوب\ مشرقی\ ایشیا",
    '039' => "جنوبی\ یورپ",
    '053' => "آسٹریلیا\ اور\ نیوزی\ لینڈ",
    '054' => 'مالینیشیا',
    '057' => "مائکرونیشیائی\ علاقہ",
    '061' => 'پولینیشیا',
    '062' => "South\-Central\ Asia",
    142   => 'ایشیا',
    143   => "وسطی\ ایشیا",
    145   => "مغربی\ ایشیا",
    150   => 'یوروپ',
    151   => "مشرقی\ یورپ",
    154   => "شمالی\ یورپ",
    155   => "مغربی\ یورپ",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "لاطینی\ امریکہ",
    830   => "Channel\ Islands",
    'ac'  => "اسکینسیئن\ آئلینڈ",
    'ad'  => 'انڈورا',
    'ae'  => "متحدہ\ عرب\ امارات",
    'af'  => 'افغانستان',
    'ag'  => "انٹیگوا\ اور\ باربودا",
    'ai'  => 'انگوئیلا',
    'al'  => 'البانیہ',
    'am'  => 'آرمینیا',
    'an'  => "نیدرلینڈز\ انٹیلیز",
    'ao'  => 'انگولا',
    'aq'  => 'انٹارکٹیکا',
    'ar'  => 'ارجنٹینا',
    'as'  => "امریکی\ ساموآ",
    'at'  => 'آسٹریا',
    'au'  => 'آسٹریلیا',
    'aw'  => 'اروبا',
    'ax'  => "آلینڈ\ آئلینڈز",
    'az'  => 'آذربائجان',
    'ba'  => "بوسنیا\ اور\ ہرزیگووینا",
    'bb'  => 'باربادوس',
    'bd'  => "بنگلہ\ دیش",
    'be'  => 'بیلجیم',
    'bf'  => "برکینا\ فاسو",
    'bg'  => 'بلغاریہ',
    'bh'  => 'بحرین',
    'bi'  => 'برونڈی',
    'bj'  => 'بینن',
    'bl'  => "سینٹ\ برتھلیمی",
    'bm'  => 'برمودا',
    'bn'  => 'برونئی',
    'bo'  => 'بولیویا',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'برازیلی',
    'bs'  => 'بہاماس',
    'bt'  => 'بھوٹان',
    'bv'  => "بؤویٹ\ آئلینڈ",
    'bw'  => 'بوتسوانا',
    'by'  => 'بیلاروس',
    'bz'  => 'بیلائز',
    'ca'  => 'کینیڈا',
    'cc'  => "کوکوس\ \[کیلنگ\]\ جزائر",
    'cd'  => "کانگو\ \[DRC\]",
    'cf'  => "وسط\ افریقی\ جمہوریہ",
    'cg'  => "کانگو\ \[جمہوریہ\]",
    'ch'  => "سوئٹزر\ لینڈ",
    'ci'  => "آئیوری\ کوسٹ",
    'ck'  => "کک\ آئلینڈز",
    'cl'  => 'چلی',
    'cm'  => 'کیمرون',
    'cn'  => 'چین',
    'co'  => 'کولمبیا',
    'cp'  => "کلپّرٹن\ آئلینڈ",
    'cr'  => "کوسٹا\ ریکا",
    'cs'  => "سربیا\ اور\ مانٹینیگرو",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'کیوبا',
    'cv'  => "کیپ\ ورڈی",
    'cx'  => "کرسمس\ آئلینڈ",
    'cy'  => 'قبرص',
    'cz'  => "چیک\ جمہوریہ",
    'dd'  => "East\ Germany",
    'de'  => 'جرمنی',
    'dg'  => "ڈائجو\ گارسیا",
    'dj'  => 'جبوتی',
    'dk'  => 'ڈنمارک',
    'dm'  => 'ڈومنیکا',
    'do'  => "ڈومنیکن\ جمہوریہ",
    'dz'  => 'الجیریا',
    'ea'  => "سیئوٹا\ اور\ میلیلا",
    'ec'  => 'ایکواڈور',
    'ee'  => 'اسٹونیا',
    'eg'  => 'مصر',
    'eh'  => "مغربی\ صحارا",
    'er'  => 'اریٹیریا',
    'es'  => 'ہسپانیہ',
    'et'  => 'ایتھوپیا',
    'eu'  => "یوروپی\ یونین",
    'fi'  => "فن\ لینڈ",
    'fj'  => 'فجی',
    'fk'  => "فاکلینڈ\ آئلینڈز\ \[ازلاس\ مالوینس\]",
    'fm'  => 'مائکرونیشیا',
    'fo'  => "فروئی\ آئلینڈز",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'فرانس',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'گیبون',
    'gb'  => "سلطنت\ متحدہ",
    'gd'  => 'غرناطہ',
    'ge'  => 'جارجیا',
    'gf'  => "فرینچ\ گیانا",
    'gg'  => 'گوئرنسی',
    'gh'  => 'گھانا',
    'gi'  => "جبل\ الطارق",
    'gl'  => "گرین\ لینڈ",
    'gm'  => 'گامبیا',
    'gn'  => 'گنی',
    'gp'  => 'گواڈیلوپ',
    'gq'  => "استوائی\ گیانا",
    'gr'  => 'یونان',
    'gs'  => "جنوبی\ جارجیا\ اور\ جنوبی\ سینڈوچ\ جزائر",
    'gt'  => "گواٹے\ مالا",
    'gu'  => 'گوآم',
    'gw'  => "گنی\ بساؤ",
    'gy'  => 'گیانا',
    'hk'  => "ہانگ\ کانگ",
    'hm'  => "ہیئرڈ\ آئلینڈ\ اور\ میکڈونالڈ\ آئلینڈز",
    'hn'  => 'ہونڈاروس',
    'hr'  => 'کروشیا',
    'ht'  => 'ہیتی',
    'hu'  => 'ہنگری',
    'ic'  => "کینری\ آئلینڈز",
    'id'  => 'انڈونیشیا',
    'ie'  => 'آئرلینڈ',
    'il'  => 'اسرائیل',
    'im'  => "آئل\ آف\ مین",
    'in'  => 'بھارت',
    'io'  => "برطانوی\ ہندوستانی\ سمندری\ خطہ",
    'iq'  => 'عراق',
    'ir'  => 'ایران',
    'is'  => "آئس\ لینڈ",
    'it'  => 'اٹلی',
    'je'  => 'جرسی',
    'jm'  => 'جمائیکا',
    'jo'  => 'اردن',
    'jp'  => 'جاپان',
    'jt'  => "Johnston\ Island",
    'ke'  => 'کینیا',
    'kg'  => 'کرغزستان',
    'kh'  => 'کمبوڈیا',
    'ki'  => 'کریباتی',
    'km'  => 'کوموروس',
    'kn'  => "سینٹ\ کٹس\ اور\ نیویس",
    'kp'  => "شمالی\ کوریا",
    'kr'  => "جنوبی\ کوریا",
    'kw'  => 'کویت',
    'ky'  => "کیمین\ آئلینڈز",
    'kz'  => 'قزاخستان',
    'la'  => 'لاؤس',
    'lb'  => 'لبنان',
    'lc'  => "سینٹ\ لوسیا",
    'li'  => 'لیشٹنسٹائن',
    'lk'  => "سری\ لنکا",
    'lr'  => 'لائبیریا',
    'ls'  => 'لیسوتھو',
    'lt'  => 'لتھوانیا',
    'lu'  => 'لگژمبرگ',
    'lv'  => 'لٹویا',
    'ly'  => 'لیبیا',
    'ma'  => 'مراقش',
    'mc'  => 'موناکو',
    'md'  => 'مالدووا',
    'me'  => "مونٹے\ نیگرو",
    'mf'  => "سینٹ\ مارٹن",
    'mg'  => 'مڈغاسکر',
    'mh'  => "مارشل\ آئلینڈز",
    'mi'  => "Midway\ Islands",
    'mk'  => "مقدونیائی\ \[FYROM\]",
    'ml'  => 'مالی',
    'mm'  => "میانمار\ \[برما\]",
    'mn'  => 'منگولیا',
    'mo'  => 'مکاؤ',
    'mp'  => "شمالی\ ماریانا\ آئلینڈز",
    'mq'  => 'مارٹینک',
    'mr'  => 'موریطانیہ',
    'ms'  => 'مونٹسیراٹ',
    'mt'  => 'مالٹا',
    'mu'  => 'ماریشس',
    'mv'  => 'مالدیو',
    'mw'  => 'ملاوی',
    'mx'  => 'میکسیکو',
    'my'  => 'ملیشیا',
    'mz'  => 'موزمبیق',
    'na'  => 'نامیبیا',
    'nc'  => "نیو\ کلیڈونیا",
    'ne'  => 'نائجر',
    'nf'  => "نار\ فاک\ آئلینڈ",
    'ng'  => 'نائجیریا',
    'ni'  => 'نکاراگووا',
    'nl'  => "نیدر\ لینڈز",
    'no'  => 'ناروے',
    'np'  => 'نیپال',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'نؤرو',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'نیئو',
    'nz'  => "نیوزی\ ینڈ",
    'om'  => 'عمان',
    'pa'  => 'پنامہ',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'پیرو',
    'pf'  => "فرانسیسی\ پولینیشیا",
    'pg'  => "پاپوآ\ نیو\ گنی",
    'ph'  => 'فلپائنی',
    'pk'  => 'پاکستان',
    'pl'  => 'پولینڈ',
    'pm'  => "سینٹ\ پیئر\ اور\ میکلیئون",
    'pn'  => "پٹکائرن\ جزائر",
    'pr'  => "پیورٹو\ ریکو",
    'ps'  => "فلسطینی\ خطے",
    'pt'  => 'پرتگال',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'پلاؤ',
    'py'  => 'پیراگوئے',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'قطر',
    'qo'  => "بیرونی\ اوشیانیا",
    're'  => "ری\ یونین",
    'ro'  => 'رومانیا',
    'rs'  => 'سربیا',
    'ru'  => 'روسی',
    'rw'  => 'روانڈا',
    'sa'  => "سعودی\ عرب",
    'sb'  => "سولومن\ آئلینڈز",
    'sc'  => 'سشلیز',
    'sd'  => 'سوڈان',
    'se'  => 'سویڈن',
    'sg'  => 'سنگاپور',
    'sh'  => "سینٹ\ ہیلینا",
    'si'  => 'سلووینیا',
    'sj'  => "سوالبرڈ\ اور\ جان\ ماین",
    'sk'  => 'سلوواکیہ',
    'sl'  => "سیئر\ لیون",
    'sm'  => "سان\ مارینو",
    'sn'  => 'سینیگل',
    'so'  => 'صومالیہ',
    'sr'  => 'سورینام',
    'st'  => "ساؤ\ ٹوم\ اور\ پرنسپے",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "ال\ سلواڈور",
    'sy'  => 'شام',
    'sz'  => "سوازی\ لینڈ",
    'ta'  => "ٹرسٹن\ ڈا\ کیونہا",
    'tc'  => "ترکس\ اور\ کیکاؤس\ جزائر",
    'td'  => 'چاڈ',
    'tf'  => "فرانسیسی\ جنوبی\ خطے",
    'tg'  => 'ٹوگو',
    'th'  => "تھائی\ لینڈ",
    'tj'  => 'تاجکستان',
    'tk'  => 'ٹوکیلاؤ',
    'tl'  => "مشرقی\ تیمور",
    'tm'  => 'ترکمانستان',
    'tn'  => 'تیونیسیا',
    'to'  => 'ٹونگا',
    'tr'  => 'ترکی',
    'tt'  => "ترینیداد\ اور\ ٹوباگو",
    'tv'  => 'ٹووالو',
    'tw'  => 'تائیوان',
    'tz'  => 'تنزانیہ',
    'ua'  => 'یوکرین',
    'ug'  => 'یوگانڈا',
    'um'  => "امریکہ\ سے\ باہر\ کے\ چھوٹے\ جزائز",
    'us'  => "ریاستہائے\ متحدہ",
    'uy'  => 'یوروگوئے',
    'uz'  => 'ازبکستان',
    'va'  => "واٹیکن\ سٹی",
    'vc'  => "سینٹ\ ونسنٹ\ اور\ گرینیڈائنز",
    'vd'  => "North\ Vietnam",
    've'  => 'وینزوئیلا',
    'vg'  => "برٹش\ ورجن\ آئلینڈز",
    'vi'  => "امریکی\ ورجن\ آئلینڈز",
    'vn'  => 'ویتنام',
    'vu'  => 'وینوآٹو',
    'wf'  => "ویلیز\ اور\ فیوٹیونا",
    'wk'  => "Wake\ Island",
    'ws'  => 'ساموآ',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'یمن',
    'yt'  => 'مایوٹ',
    'za'  => "جنوبی\ افریقہ",
    'zm'  => 'زامبیا',
    'zw'  => 'زمبابوے',
    'zz'  => "نامعلوم\ علاقہ",
);

%Locales::DB::Territory::ur::name_to_code = (
    'britishantarcticterritory'                                    => 'bq',
    'cantonandenderburyislands'                                    => 'ct',
    'channelislands'                                               => 830,
    'commonwealthofindependentstates'                              => 172,
    'czechoslovakia'                                               => 200,
    'dronningmaudland'                                             => 'nq',
    'eastgermany'                                                  => 'dd',
    'frenchsouthernandantarcticterritories'                        => 'fq',
    'johnstonisland'                                               => 'jt',
    'metropolitanfrance'                                           => 'fx',
    'midwayislands'                                                => 'mi',
    'neutralzone'                                                  => 'nt',
    'northvietnam'                                                 => 'vd',
    'pacificislandstrustterritory'                                 => 'pc',
    'panamacanalzone'                                              => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                    => 'yd',
    'southcentralasia'                                             => '062',
    "u\.s\.miscellaneouspacificislands"                            => 'pu',
    'unionofsovietsocialistrepublics'                              => 'su',
    'wakeisland'                                                   => 'wk',
    'آئرلینڈ'                                               => 'ie',
    'آئسلینڈ'                                               => 'is',
    'آئلآفمین'                                             => 'im',
    'آئیوریکوسٹ'                                         => 'ci',
    'آذربائجان'                                           => 'az',
    'آرمینیا'                                               => 'am',
    'آسٹریا'                                                 => 'at',
    'آسٹریلیا'                                             => 'au',
    'آسٹریلیااورنیوزیلینڈ'                     => '053',
    'آلینڈآئلینڈز'                                     => 'ax',
    'ارجنٹینا'                                             => 'ar',
    'اردن'                                                     => 'jo',
    'اروبا'                                                   => 'aw',
    'اریٹیریا'                                             => 'er',
    'ازبکستان'                                             => 'uz',
    'استوائیگیانا'                                     => 'gq',
    'اسرائیل'                                               => 'il',
    'اسٹونیا'                                               => 'ee',
    'اسکینسیئنآئلینڈ'                               => 'ac',
    'افریقہ'                                                 => '002',
    'افغانستان'                                           => 'af',
    'البانیہ'                                               => 'al',
    'الجیریا'                                               => 'dz',
    'السلواڈور'                                           => 'sv',
    'امریکہسےباہرکےچھوٹےجزائز'             => 'um',
    'امریکیساموآ'                                       => 'as',
    'امریکیورجنآئلینڈز'                           => 'vi',
    'امیریکاز'                                             => '019',
    'انٹارکٹیکا'                                         => 'aq',
    'انٹیگوااورباربودا'                           => 'ag',
    'انڈورا'                                                 => 'ad',
    'انڈونیشیا'                                           => 'id',
    'انگوئیلا'                                             => 'ai',
    'انگولا'                                                 => 'ao',
    'اوشیانیا'                                             => '009',
    'اٹلی'                                                     => 'it',
    'ایتھوپیا'                                             => 'et',
    'ایران'                                                   => 'ir',
    'ایشیا'                                                   => 142,
    'ایکواڈور'                                             => 'ec',
    'بؤویٹآئلینڈ'                                       => 'bv',
    'باربادوس'                                             => 'bb',
    'بحرین'                                                   => 'bh',
    'برازیلی'                                               => 'br',
    'برطانویہندوستانیسمندریخطہ'           => 'io',
    'برمودا'                                                 => 'bm',
    'برونئی'                                                 => 'bn',
    'برونڈی'                                                 => 'bi',
    'برٹشورجنآئلینڈز'                               => 'vg',
    'برکینافاسو'                                         => 'bf',
    'بلغاریہ'                                               => 'bg',
    'بنگلہدیش'                                             => 'bd',
    'بوتسوانا'                                             => 'bw',
    'بوسنیااورہرزیگووینا'                       => 'ba',
    'بولیویا'                                               => 'bo',
    'بھارت'                                                   => 'in',
    'بھوٹان'                                                 => 'bt',
    'بہاماس'                                                 => 'bs',
    'بیرونیاوشیانیا'                                 => 'qo',
    'بیلائز'                                                 => 'bz',
    'بیلاروس'                                               => 'by',
    'بیلجیم'                                                 => 'be',
    'بینن'                                                     => 'bj',
    'تائیوان'                                               => 'tw',
    'تاجکستان'                                             => 'tj',
    'ترکساورکیکاؤسجزائر'                         => 'tc',
    'ترکمانستان'                                         => 'tm',
    'ترکی'                                                     => 'tr',
    'ترینیداداورٹوباگو'                           => 'tt',
    'تنزانیہ'                                               => 'tz',
    'تھائیلینڈ'                                           => 'th',
    'تیونیسیا'                                             => 'tn',
    'جارجیا'                                                 => 'ge',
    'جاپان'                                                   => 'jp',
    'جبلالطارق'                                           => 'gi',
    'جبوتی'                                                   => 'dj',
    'جرسی'                                                     => 'je',
    'جرمنی'                                                   => 'de',
    'جمائیکا'                                               => 'jm',
    'جنوبمشرقیایشیا'                                 => '035',
    'جنوبیافریقہ'                                       => 'za',
    'جنوبیافریقہکےعلاقہ'                         => '018',
    'جنوبیامریکہ'                                       => '005',
    'جنوبیایشیا'                                         => '034',
    'جنوبیجارجیااورجنوبیسینڈوچجزائر' => 'gs',
    'جنوبیکوریا'                                         => 'kr',
    'جنوبییورپ'                                           => '039',
    'دنیا'                                                     => '001',
    'روانڈا'                                                 => 'rw',
    'روسی'                                                     => 'ru',
    'رومانیا'                                               => 'ro',
    'ریاستہائےمتحدہ'                                 => 'us',
    'رییونین'                                               => 're',
    'زامبیا'                                                 => 'zm',
    'زمبابوے'                                               => 'zw',
    'ساؤٹوماورپرنسپے'                               => 'st',
    'ساموآ'                                                   => 'ws',
    'سانمارینو'                                           => 'sm',
    'سربیا'                                                   => 'rs',
    'سربیااورمانٹینیگرو'                         => 'cs',
    'سریلنکا'                                               => 'lk',
    'سشلیز'                                                   => 'sc',
    'سعودیعرب'                                             => 'sa',
    'سلطنتمتحدہ'                                         => 'gb',
    'سلوواکیہ'                                             => 'sk',
    'سلووینیا'                                             => 'si',
    'سنگاپور'                                               => 'sg',
    'سوئٹزرلینڈ'                                         => 'ch',
    'سوازیلینڈ'                                           => 'sz',
    'سوالبرڈاورجانماین'                           => 'sj',
    'سورینام'                                               => 'sr',
    'سولومنآئلینڈز'                                   => 'sb',
    'سوڈان'                                                   => 'sd',
    'سویڈن'                                                   => 'se',
    'سیئرلیون'                                             => 'sl',
    'سیئوٹااورمیلیلا'                               => 'ea',
    'سینٹبرتھلیمی'                                     => 'bl',
    'سینٹلوسیا'                                           => 'lc',
    'سینٹمارٹن'                                           => 'mf',
    'سینٹونسنٹاورگرینیڈائنز'                 => 'vc',
    'سینٹپیئراورمیکلیئون'                       => 'pm',
    'سینٹکٹساورنیویس'                               => 'kn',
    'سینٹہیلینا'                                         => 'sh',
    'سینیگل'                                                 => 'sn',
    'شام'                                                       => 'sy',
    'شمالیافریقہ'                                       => '015',
    'شمالیامریکہ'                                       => '003',
    'شمالیامریکہکاعلاقہ'                         => '021',
    'شمالیماریاناآئلینڈز'                       => 'mp',
    'شمالیکوریا'                                         => 'kp',
    'شمالییورپ'                                           => 154,
    'صومالیہ'                                               => 'so',
    'عراق'                                                     => 'iq',
    'عمان'                                                     => 'om',
    'غرناطہ'                                                 => 'gd',
    'فاکلینڈآئلینڈزازلاسمالوینس'         => 'fk',
    'فجی'                                                       => 'fj',
    'فرانس'                                                   => 'fr',
    'فرانسیسیجنوبیخطے'                             => 'tf',
    'فرانسیسیپولینیشیا'                           => 'pf',
    'فروئیآئلینڈز'                                     => 'fo',
    'فرینچگیانا'                                         => 'gf',
    'فلسطینیخطے'                                         => 'ps',
    'فلپائنی'                                               => 'ph',
    'فنلینڈ'                                                 => 'fi',
    'قبرص'                                                     => 'cy',
    'قزاخستان'                                             => 'kz',
    'قطر'                                                       => 'qa',
    'لاؤس'                                                     => 'la',
    'لائبیریا'                                             => 'lr',
    'لاطینیامریکہ'                                     => 419,
    'لبنان'                                                   => 'lb',
    'لتھوانیا'                                             => 'lt',
    'لٹویا'                                                   => 'lv',
    'لگژمبرگ'                                               => 'lu',
    'لیبیا'                                                   => 'ly',
    'لیسوتھو'                                               => 'ls',
    'لیشٹنسٹائن'                                         => 'li',
    'مائکرونیشیا'                                       => 'fm',
    'مائکرونیشیائیعلاقہ'                         => '057',
    'مارشلآئلینڈز'                                     => 'mh',
    'مارٹینک'                                               => 'mq',
    'ماریشس'                                                 => 'mu',
    'مالدووا'                                               => 'md',
    'مالدیو'                                                 => 'mv',
    'مالٹا'                                                   => 'mt',
    'مالی'                                                     => 'ml',
    'مالینیشیا'                                           => '054',
    'مایوٹ'                                                   => 'yt',
    'متحدہعربامارات'                                 => 'ae',
    'مراقش'                                                   => 'ma',
    'مشرقیافریقہ'                                       => '014',
    'مشرقیایشیا'                                         => '030',
    'مشرقیتیمور'                                         => 'tl',
    'مشرقییورپ'                                           => 151,
    'مصر'                                                       => 'eg',
    'مغربیافریقہ'                                       => '011',
    'مغربیایشیا'                                         => 145,
    'مغربیصحارا'                                         => 'eh',
    'مغربییورپ'                                           => 155,
    'مقدونیائیfyrom'                                      => 'mk',
    'ملاوی'                                                   => 'mw',
    'ملیشیا'                                                 => 'my',
    'منگولیا'                                               => 'mn',
    'موریطانیہ'                                           => 'mr',
    'موزمبیق'                                               => 'mz',
    'موناکو'                                                 => 'mc',
    'مونٹسیراٹ'                                           => 'ms',
    'مونٹےنیگرو'                                         => 'me',
    'مڈغاسکر'                                               => 'mg',
    'مکاؤ'                                                     => 'mo',
    'میانماربرما'                                       => 'mm',
    'میکسیکو'                                               => 'mx',
    'نؤرو'                                                     => 'nr',
    'نائجر'                                                   => 'ne',
    'نائجیریا'                                             => 'ng',
    'نارفاکآئلینڈ'                                     => 'nf',
    'ناروے'                                                   => 'no',
    'نامعلومعلاقہ'                                     => 'zz',
    'نامیبیا'                                               => 'na',
    'نکاراگووا'                                           => 'ni',
    'نیئو'                                                     => 'nu',
    'نیدرلینڈز'                                           => 'nl',
    'نیدرلینڈزانٹیلیز'                             => 'an',
    'نیوزیینڈ'                                             => 'nz',
    'نیوکلیڈونیا'                                       => 'nc',
    'نیپال'                                                   => 'np',
    'واٹیکنسٹی'                                           => 'va',
    'وسطافریقیجمہوریہ'                             => 'cf',
    'وسطیافریقہ'                                         => '017',
    'وسطیامریکہ'                                         => '013',
    'وسطیایشیا'                                           => 143,
    'ویتنام'                                                 => 'vn',
    'ویلیزاورفیوٹیونا'                             => 'wf',
    'وینزوئیلا'                                           => 've',
    'وینوآٹو'                                               => 'vu',
    'ٹرسٹنڈاکیونہا'                                   => 'ta',
    'ٹونگا'                                                   => 'to',
    'ٹووالو'                                                 => 'tv',
    'ٹوکیلاؤ'                                               => 'tk',
    'ٹوگو'                                                     => 'tg',
    'پاپوآنیوگنی'                                       => 'pg',
    'پاکستان'                                               => 'pk',
    'پرتگال'                                                 => 'pt',
    'پلاؤ'                                                     => 'pw',
    'پنامہ'                                                   => 'pa',
    'پولینڈ'                                                 => 'pl',
    'پولینیشیا'                                           => '061',
    'پٹکائرنجزائر'                                     => 'pn',
    'پیراگوئے'                                             => 'py',
    'پیرو'                                                     => 'pe',
    'پیورٹوریکو'                                         => 'pr',
    'چاڈ'                                                       => 'td',
    'چلی'                                                       => 'cl',
    'چین'                                                       => 'cn',
    'چیکجمہوریہ'                                         => 'cz',
    'ڈائجوگارسیا'                                       => 'dg',
    'ڈنمارک'                                                 => 'dk',
    'ڈومنیکا'                                               => 'dm',
    'ڈومنیکنجمہوریہ'                                 => 'do',
    'کانگوdrc'                                                => 'cd',
    'کانگوجمہوریہ'                                     => 'cg',
    'کرسمسآئلینڈ'                                       => 'cx',
    'کرغزستان'                                             => 'kg',
    'کروشیا'                                                 => 'hr',
    'کریباتی'                                               => 'ki',
    'کریبیائی'                                             => '029',
    'کلپّرٹنآئلینڈ'                                   => 'cp',
    'کمبوڈیا'                                               => 'kh',
    'کوسٹاریکا'                                           => 'cr',
    'کولمبیا'                                               => 'co',
    'کوموروس'                                               => 'km',
    'کوکوسکیلنگجزائر'                               => 'cc',
    'کویت'                                                     => 'kw',
    'ککآئلینڈز'                                           => 'ck',
    'کیمرون'                                                 => 'cm',
    'کیمینآئلینڈز'                                     => 'ky',
    'کینریآئلینڈز'                                     => 'ic',
    'کینیا'                                                   => 'ke',
    'کینیڈا'                                                 => 'ca',
    'کیوبا'                                                   => 'cu',
    'کیپورڈی'                                               => 'cv',
    'گامبیا'                                                 => 'gm',
    'گرینلینڈ'                                             => 'gl',
    'گنی'                                                       => 'gn',
    'گنیبساؤ'                                               => 'gw',
    'گوآم'                                                     => 'gu',
    'گوئرنسی'                                               => 'gg',
    'گواٹےمالا'                                           => 'gt',
    'گواڈیلوپ'                                             => 'gp',
    'گھانا'                                                   => 'gh',
    'گیانا'                                                   => 'gy',
    'گیبون'                                                   => 'ga',
    'ہانگکانگ'                                             => 'hk',
    'ہسپانیہ'                                               => 'es',
    'ہنگری'                                                   => 'hu',
    'ہونڈاروس'                                             => 'hn',
    'ہیئرڈآئلینڈاورمیکڈونالڈآئلینڈز' => 'hm',
    'ہیتی'                                                     => 'ht',
    'یمن'                                                       => 'ye',
    'یوروپ'                                                   => 150,
    'یوروپییونین'                                       => 'eu',
    'یوروگوئے'                                             => 'uy',
    'یونان'                                                   => 'gr',
    'یوکرین'                                                 => 'ua',
    'یوگانڈا'                                               => 'ug',
);

1;

