package Locales::DB::Territory::bs;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::bs::VERSION = '0.09';

$Locales::DB::Territory::bs::cldr_version = '2.0';

%Locales::DB::Territory::bs::code_to_name = (
    '001' => 'Svet',
    '002' => 'Afrika',
    '003' => "Severnoamerički\ kontinent",
    '005' => "Južna\ Amerika",
    '009' => 'Okeanija',
    '011' => "Zapadna\ Afrika",
    '013' => "Centralna\ Amerika",
    '014' => "Istočna\ Afrika",
    '015' => "Severna\ Afrika",
    '017' => "Centralna\ Afrika",
    '018' => "Južna\ Afrika",
    '019' => 'Amerike',
    '021' => "Severna\ Amerika",
    '029' => 'Karibi',
    '030' => "Istočna\ Azija",
    '034' => "Južna\ Azija",
    '035' => "Jugoistočna\ Azija",
    '039' => "Južna\ Evropa",
    '053' => "Australija\ i\ Novi\ Zeland",
    '054' => 'Melanezija',
    '057' => 'Micronezija',
    '061' => 'Polinezija',
    '062' => "Južno\-centralna\ Azija",
    142   => 'Azija',
    143   => "Centralna\ Azija",
    145   => "Zapadna\ Azija",
    150   => 'Evropa',
    151   => "Istočna\ Evropa",
    154   => "Severna\ Evropa",
    155   => "Zapadna\ Evropa",
    172   => "Komonvelt\ nezavisnih\ država",
    200   => 'Czechoslovakia',
    419   => "Latinska\ Amerika\ i\ Karibi",
    830   => "Kanalska\ ostrva",
    'ac'  => "Ostrvo\ Asension",
    'ad'  => 'Andora',
    'ae'  => "Ujedinjeni\ Arapski\ Emirati",
    'af'  => 'Avganistan',
    'ag'  => "Antigva\ i\ Barbuda",
    'ai'  => 'Angvila',
    'al'  => 'Albanija',
    'am'  => 'Armenija',
    'an'  => "Holandski\ Antili",
    'ao'  => 'Angola',
    'aq'  => 'Antarktika',
    'ar'  => 'Argentina',
    'as'  => "Američka\ Samoa",
    'at'  => 'Austrija',
    'au'  => 'Australija',
    'aw'  => 'Aruba',
    'ax'  => "Alandska\ ostrva",
    'az'  => 'Azerbejdžan',
    'ba'  => "Bosna\ i\ Hercegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladeš',
    'be'  => 'Belgija',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bugarska',
    'bh'  => 'Bahrein',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Sv\.\ Bartolomej",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunej',
    'bo'  => 'Bolivija',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazil',
    'bs'  => 'Bahami',
    'bt'  => 'Butan',
    'bv'  => "Buve\ Ostrva",
    'bw'  => 'Bocvana',
    'by'  => 'Belorusija',
    'bz'  => 'Belise',
    'ca'  => 'Kanada',
    'cc'  => "Kokos\ \(Keling\)\ Ostrva",
    'cd'  => "Kongo\ \[DRC\]",
    'cf'  => "Centralno\ Afrička\ Republika",
    'cg'  => "Republika\ Kongo",
    'ch'  => 'Švajcarska',
    'ci'  => "Obala\ Slonovače",
    'ck'  => "Kukova\ Ostrva",
    'cl'  => 'Čile',
    'cm'  => 'Kamerun',
    'cn'  => 'Kina',
    'co'  => 'Kolumbija',
    'cp'  => "Ostrvo\ Kliperton",
    'cr'  => 'Kostarika',
    'cs'  => "Srbija\ i\ Crna\ Gora",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Kape\ Verde",
    'cx'  => "Božićna\ Ostrva",
    'cy'  => 'Kipar',
    'cz'  => 'Češka',
    'dd'  => "East\ Germany",
    'de'  => 'Nemačka',
    'dg'  => "Dijego\ Garsija",
    'dj'  => 'Džibuti',
    'dk'  => 'Danska',
    'dm'  => 'Dominika',
    'do'  => "Dominikanska\ Republika",
    'dz'  => 'Alžir',
    'ea'  => "Seuta\ i\ Melilja",
    'ec'  => 'Ekvador',
    'ee'  => 'Estonija',
    'eg'  => 'Egipat',
    'eh'  => "Zapadna\ Sahara",
    'er'  => 'Eritreja',
    'es'  => 'Španija',
    'et'  => 'Etiopija',
    'eu'  => "Evropska\ unija",
    'fi'  => 'Finska',
    'fj'  => 'Fidži',
    'fk'  => "Folklandska\ ostrva\ \(Malvinska\ ostrva\)",
    'fm'  => 'Mikronezija',
    'fo'  => "Farska\ Ostrva",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Francuska',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => "Velika\ Britanija",
    'gd'  => 'Grenada',
    'ge'  => 'Gruzija',
    'gf'  => "Francuska\ Gvajana",
    'gg'  => 'Gurnsi',
    'gh'  => 'Gana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grenland',
    'gm'  => 'Gambija',
    'gn'  => 'Gvineja',
    'gp'  => 'Gvadelupe',
    'gq'  => "Ekvatorijalna\ Gvineja",
    'gr'  => 'Grčka',
    'gs'  => "Južna\ Džordžija\ i\ Južna\ Sendvič\ Ostrva",
    'gt'  => 'Gvatemala',
    'gu'  => 'Guam',
    'gw'  => "Gvineja\-Bisao",
    'gy'  => 'Gvajana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Herd\ i\ Mekdonald\ Ostrva",
    'hn'  => 'Honduras',
    'hr'  => 'Hrvatska',
    'ht'  => 'Haiti',
    'hu'  => 'Mađarska',
    'ic'  => "Kanarska\ ostrva",
    'id'  => 'Indonezija',
    'ie'  => 'Irska',
    'il'  => 'Izrael',
    'im'  => "Ostrvo\ Man",
    'in'  => 'Indija',
    'io'  => "Britansko\ Indijska\ Okeanska\ Teritorija",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Italija',
    'je'  => 'Džersi',
    'jm'  => 'Jamajka',
    'jo'  => 'Jordan',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenija',
    'kg'  => 'Kirgizstan',
    'kh'  => 'Kambodža',
    'ki'  => 'Kiribati',
    'km'  => "Komorska\ Ostrva",
    'kn'  => "Sent\ Kits\ i\ Nevis",
    'kp'  => "Severna\ Koreja",
    'kr'  => "Južna\ Koreja",
    'kw'  => 'Kuvajt',
    'ky'  => "Kajmanska\ Ostrva",
    'kz'  => 'Kazahstan',
    'la'  => 'Laos',
    'lb'  => 'Liban',
    'lc'  => "Sent\ Lucija",
    'li'  => 'Lihtenštajn',
    'lk'  => "Šri\ Lanka",
    'lr'  => 'Liberija',
    'ls'  => 'Lesoto',
    'lt'  => 'Litvanija',
    'lu'  => 'Luksemburg',
    'lv'  => 'Letonija',
    'ly'  => 'Libija',
    'ma'  => 'Maroko',
    'mc'  => 'Monako',
    'md'  => 'Moldavija',
    'me'  => "Crna\ Gora",
    'mf'  => "Sv\.\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Maršalska\ Ostrva",
    'mi'  => "Midway\ Islands",
    'mk'  => "Makedonija\ \(BJR\)",
    'ml'  => 'Mali',
    'mm'  => 'Mijanmar',
    'mn'  => 'Mongolija',
    'mo'  => 'Makao',
    'mp'  => "Severna\ Marijanska\ Ostrva",
    'mq'  => 'Martinik',
    'mr'  => 'Mauritanija',
    'ms'  => 'Monserat',
    'mt'  => 'Malta',
    'mu'  => 'Mauricius',
    'mv'  => 'Maldivi',
    'mw'  => 'Malavi',
    'mx'  => 'Meksiko',
    'my'  => 'Malezija',
    'mz'  => 'Mozambik',
    'na'  => 'Namibija',
    'nc'  => "Nova\ Kaledonija",
    'ne'  => 'Niger',
    'nf'  => "Norfolk\ Ostrvo",
    'ng'  => 'Nigerija',
    'ni'  => 'Nikaragva',
    'nl'  => 'Holandija',
    'no'  => 'Norveška',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Novi\ Zeland",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Francuska\ Polinezija",
    'pg'  => "Papua\ Nova\ Gvineja",
    'ph'  => 'Filipini',
    'pk'  => 'Pakistan',
    'pl'  => 'Poljska',
    'pm'  => "Sen\ Pjer\ i\ Mikelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Porto\ Riko",
    'ps'  => "Palestinska\ Teritorija",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paragvaj',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Ostala\ okeanija",
    're'  => 'Rejunion',
    'ro'  => 'Rumunija',
    'rs'  => 'Srbija',
    'ru'  => 'Rusija',
    'rw'  => 'Ruanda',
    'sa'  => "Saudijska\ Arabija",
    'sb'  => "Solomonska\ Ostrva",
    'sc'  => 'Sejšeli',
    'sd'  => 'Sudan',
    'se'  => 'Švedska',
    'sg'  => 'Singapur',
    'sh'  => "Sveta\ Jelena",
    'si'  => 'Slovenija',
    'sj'  => "Svalbard\ i\ Janmajen\ Ostrva",
    'sk'  => 'Slovačka',
    'sl'  => "Sijera\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalija',
    'sr'  => 'Surinam',
    'st'  => "Sao\ Tome\ i\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvador',
    'sy'  => 'Sirija',
    'sz'  => 'Svazilend',
    'ta'  => "Tristan\ da\ Kunja",
    'tc'  => "Turks\ i\ Kajkos\ Ostrva",
    'td'  => 'Čad',
    'tf'  => "Francuske\ Južne\ Teritorije",
    'tg'  => 'Togo',
    'th'  => 'Tajland',
    'tj'  => 'Tadžikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Istočni\ Timor",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunis',
    'to'  => 'Tonga',
    'tr'  => 'Turska',
    'tt'  => "Trinidad\ i\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Tajvan',
    'tz'  => 'Tanzanija',
    'ua'  => 'Ukrajina',
    'ug'  => 'Uganda',
    'um'  => "Manja\ Udaljena\ Ostrva\ SAD",
    'us'  => "Sjedinjene\ Američke\ Države",
    'uy'  => 'Urugvaj',
    'uz'  => 'Uzbekistan',
    'va'  => 'Vatikan',
    'vc'  => "Sent\ Vinsent\ i\ Grenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Venecuela',
    'vg'  => "Britanska\ Devičanska\ Ostrva",
    'vi'  => "S\.A\.D\.\ Devičanska\ Ostrva",
    'vn'  => 'Vijetnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Valis\ i\ Futuna\ Ostrva",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Majote',
    'za'  => "Južnoafrička\ Republika",
    'zm'  => 'Zambija',
    'zw'  => 'Zimbabve',
    'zz'  => "Nepoznata\ ili\ nevažeća\ oblast",
);

%Locales::DB::Territory::bs::name_to_code = (
    'afrika'                                    => '002',
    'alandskaostrva'                            => 'ax',
    'albanija'                                  => 'al',
    'alžir'                                    => 'dz',
    'amerike'                                   => '019',
    'američkasamoa'                            => 'as',
    'andora'                                    => 'ad',
    'angola'                                    => 'ao',
    'angvila'                                   => 'ai',
    'antarktika'                                => 'aq',
    'antigvaibarbuda'                           => 'ag',
    'argentina'                                 => 'ar',
    'armenija'                                  => 'am',
    'aruba'                                     => 'aw',
    'australija'                                => 'au',
    'australijainovizeland'                     => '053',
    'austrija'                                  => 'at',
    'avganistan'                                => 'af',
    'azerbejdžan'                              => 'az',
    'azija'                                     => 142,
    'bahami'                                    => 'bs',
    'bahrein'                                   => 'bh',
    'bangladeš'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgija'                                   => 'be',
    'belise'                                    => 'bz',
    'belorusija'                                => 'by',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bocvana'                                   => 'bw',
    'bolivija'                                  => 'bo',
    'bosnaihercegovina'                         => 'ba',
    'božićnaostrva'                           => 'cx',
    'brazil'                                    => 'br',
    'britanskadevičanskaostrva'                => 'vg',
    'britanskoindijskaokeanskateritorija'       => 'io',
    'britishantarcticterritory'                 => 'bq',
    'brunej'                                    => 'bn',
    'bugarska'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'butan'                                     => 'bt',
    'buveostrva'                                => 'bv',
    'cantonandenderburyislands'                 => 'ct',
    'centralnaafrika'                           => '017',
    'centralnaamerika'                          => '013',
    'centralnaazija'                            => 143,
    'centralnoafričkarepublika'                => 'cf',
    'crnagora'                                  => 'me',
    'czechoslovakia'                            => 200,
    'danska'                                    => 'dk',
    'dijegogarsija'                             => 'dg',
    'dominika'                                  => 'dm',
    'dominikanskarepublika'                     => 'do',
    'dronningmaudland'                          => 'nq',
    'džersi'                                   => 'je',
    'džibuti'                                  => 'dj',
    'eastgermany'                               => 'dd',
    'egipat'                                    => 'eg',
    'ekvador'                                   => 'ec',
    'ekvatorijalnagvineja'                      => 'gq',
    'eritreja'                                  => 'er',
    'estonija'                                  => 'ee',
    'etiopija'                                  => 'et',
    'evropa'                                    => 150,
    'evropskaunija'                             => 'eu',
    'farskaostrva'                              => 'fo',
    'fidži'                                    => 'fj',
    'filipini'                                  => 'ph',
    'finska'                                    => 'fi',
    'folklandskaostrvamalvinskaostrva'          => 'fk',
    'francuska'                                 => 'fr',
    'francuskagvajana'                          => 'gf',
    'francuskapolinezija'                       => 'pf',
    'francuskejužneteritorije'                 => 'tf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabon'                                     => 'ga',
    'gambija'                                   => 'gm',
    'gana'                                      => 'gh',
    'gibraltar'                                 => 'gi',
    'grenada'                                   => 'gd',
    'grenland'                                  => 'gl',
    'gruzija'                                   => 'ge',
    'grčka'                                    => 'gr',
    'guam'                                      => 'gu',
    'gurnsi'                                    => 'gg',
    'gvadelupe'                                 => 'gp',
    'gvajana'                                   => 'gy',
    'gvatemala'                                 => 'gt',
    'gvineja'                                   => 'gn',
    'gvinejabisao'                              => 'gw',
    'haiti'                                     => 'ht',
    'herdimekdonaldostrva'                      => 'hm',
    'holandija'                                 => 'nl',
    'holandskiantili'                           => 'an',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hrvatska'                                  => 'hr',
    'indija'                                    => 'in',
    'indonezija'                                => 'id',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'irska'                                     => 'ie',
    'island'                                    => 'is',
    'istočnaafrika'                            => '014',
    'istočnaazija'                             => '030',
    'istočnaevropa'                            => 151,
    'istočnitimor'                             => 'tl',
    'italija'                                   => 'it',
    'izrael'                                    => 'il',
    'jamajka'                                   => 'jm',
    'japan'                                     => 'jp',
    'jemen'                                     => 'ye',
    'johnstonisland'                            => 'jt',
    'jordan'                                    => 'jo',
    'jugoistočnaazija'                         => '035',
    'južnaafrika'                              => '018',
    'južnaamerika'                             => '005',
    'južnaazija'                               => '034',
    'južnadžordžijaijužnasendvičostrva'    => 'gs',
    'južnaevropa'                              => '039',
    'južnakoreja'                              => 'kr',
    'južnoafričkarepublika'                   => 'za',
    'južnocentralnaazija'                      => '062',
    'kajmanskaostrva'                           => 'ky',
    'kambodža'                                 => 'kh',
    'kamerun'                                   => 'cm',
    'kanada'                                    => 'ca',
    'kanalskaostrva'                            => 830,
    'kanarskaostrva'                            => 'ic',
    'kapeverde'                                 => 'cv',
    'karibi'                                    => '029',
    'katar'                                     => 'qa',
    'kazahstan'                                 => 'kz',
    'kenija'                                    => 'ke',
    'kina'                                      => 'cn',
    'kipar'                                     => 'cy',
    'kirgizstan'                                => 'kg',
    'kiribati'                                  => 'ki',
    'kokoskelingostrva'                         => 'cc',
    'kolumbija'                                 => 'co',
    'komonveltnezavisnihdržava'                => 172,
    'komorskaostrva'                            => 'km',
    'kongodrc'                                  => 'cd',
    'kostarika'                                 => 'cr',
    'kuba'                                      => 'cu',
    'kukovaostrva'                              => 'ck',
    'kuvajt'                                    => 'kw',
    'laos'                                      => 'la',
    'latinskaamerikaikaribi'                    => 419,
    'lesoto'                                    => 'ls',
    'letonija'                                  => 'lv',
    'liban'                                     => 'lb',
    'liberija'                                  => 'lr',
    'libija'                                    => 'ly',
    'lihtenštajn'                              => 'li',
    'litvanija'                                 => 'lt',
    'luksemburg'                                => 'lu',
    'madagaskar'                                => 'mg',
    'majote'                                    => 'yt',
    'makao'                                     => 'mo',
    'makedonijabjr'                             => 'mk',
    'malavi'                                    => 'mw',
    'maldivi'                                   => 'mv',
    'malezija'                                  => 'my',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'manjaudaljenaostrvasad'                    => 'um',
    'maroko'                                    => 'ma',
    'martinik'                                  => 'mq',
    'maršalskaostrva'                          => 'mh',
    'mauricius'                                 => 'mu',
    'mauritanija'                               => 'mr',
    'mađarska'                                 => 'hu',
    'meksiko'                                   => 'mx',
    'melanezija'                                => '054',
    'metropolitanfrance'                        => 'fx',
    'micronezija'                               => '057',
    'midwayislands'                             => 'mi',
    'mijanmar'                                  => 'mm',
    'mikronezija'                               => 'fm',
    'moldavija'                                 => 'md',
    'monako'                                    => 'mc',
    'mongolija'                                 => 'mn',
    'monserat'                                  => 'ms',
    'mozambik'                                  => 'mz',
    'namibija'                                  => 'na',
    'nauru'                                     => 'nr',
    'nemačka'                                  => 'de',
    'nepal'                                     => 'np',
    'nepoznatailinevažećaoblast'              => 'zz',
    'neutralzone'                               => 'nt',
    'niger'                                     => 'ne',
    'nigerija'                                  => 'ng',
    'nikaragva'                                 => 'ni',
    'niue'                                      => 'nu',
    'norfolkostrvo'                             => 'nf',
    'northvietnam'                              => 'vd',
    'norveška'                                 => 'no',
    'novakaledonija'                            => 'nc',
    'novizeland'                                => 'nz',
    'obalaslonovače'                           => 'ci',
    'okeanija'                                  => '009',
    'oman'                                      => 'om',
    'ostalaokeanija'                            => 'qo',
    'ostrvoasension'                            => 'ac',
    'ostrvokliperton'                           => 'cp',
    'ostrvoman'                                 => 'im',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'palestinskateritorija'                     => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanovagvineja'                          => 'pg',
    'paragvaj'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'polinezija'                                => '061',
    'poljska'                                   => 'pl',
    'portoriko'                                 => 'pr',
    'portugal'                                  => 'pt',
    'rejunion'                                  => 're',
    'republikakongo'                            => 'cg',
    'ruanda'                                    => 'rw',
    'rumunija'                                  => 'ro',
    'rusija'                                    => 'ru',
    "s\.a\.d\.devičanskaostrva"                => 'vi',
    'salvador'                                  => 'sv',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saotomeiprincipe'                          => 'st',
    'saudijskaarabija'                          => 'sa',
    'sejšeli'                                  => 'sc',
    'senegal'                                   => 'sn',
    'senpjerimikelon'                           => 'pm',
    'sentkitsinevis'                            => 'kn',
    'sentlucija'                                => 'lc',
    'sentvinsentigrenadini'                     => 'vc',
    'seutaimelilja'                             => 'ea',
    'severnaafrika'                             => '015',
    'severnaamerika'                            => '021',
    'severnaevropa'                             => 154,
    'severnakoreja'                             => 'kp',
    'severnamarijanskaostrva'                   => 'mp',
    'severnoameričkikontinent'                 => '003',
    'sijeraleone'                               => 'sl',
    'singapur'                                  => 'sg',
    'sirija'                                    => 'sy',
    'sjedinjeneameričkedržave'                => 'us',
    'slovačka'                                 => 'sk',
    'slovenija'                                 => 'si',
    'solomonskaostrva'                          => 'sb',
    'somalija'                                  => 'so',
    'srbija'                                    => 'rs',
    'srbijaicrnagora'                           => 'cs',
    'sudan'                                     => 'sd',
    'surinam'                                   => 'sr',
    "sv\.bartolomej"                            => 'bl',
    "sv\.martin"                                => 'mf',
    'svalbardijanmajenostrva'                   => 'sj',
    'svazilend'                                 => 'sz',
    'svet'                                      => '001',
    'svetajelena'                               => 'sh',
    'tadžikistan'                              => 'tj',
    'tajland'                                   => 'th',
    'tajvan'                                    => 'tw',
    'tanzanija'                                 => 'tz',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidaditobago'                           => 'tt',
    'tristandakunja'                            => 'ta',
    'tunis'                                     => 'tn',
    'turkmenistan'                              => 'tm',
    'turksikajkosostrva'                        => 'tc',
    'turska'                                    => 'tr',
    'tuvalu'                                    => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ujedinjeniarapskiemirati'                  => 'ae',
    'ukrajina'                                  => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'urugvaj'                                   => 'uy',
    'uzbekistan'                                => 'uz',
    'valisifutunaostrva'                        => 'wf',
    'vanuatu'                                   => 'vu',
    'vatikan'                                   => 'va',
    'velikabritanija'                           => 'gb',
    'venecuela'                                 => 've',
    'vijetnam'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'zambija'                                   => 'zm',
    'zapadnaafrika'                             => '011',
    'zapadnaazija'                              => 145,
    'zapadnaevropa'                             => 155,
    'zapadnasahara'                             => 'eh',
    'zimbabve'                                  => 'zw',
    'Čad'                                      => 'td',
    'Češka'                                   => 'cz',
    'Čile'                                     => 'cl',
    'Španija'                                  => 'es',
    'Šrilanka'                                 => 'lk',
    'Švajcarska'                               => 'ch',
    'Švedska'                                  => 'se',
);

1;

