package Locales::DB::Territory::hr;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::hr::VERSION = '0.09';

$Locales::DB::Territory::hr::cldr_version = '2.0';

%Locales::DB::Territory::hr::code_to_name = (
    '001' => 'Svijet',
    '002' => 'Afrika',
    '003' => "Sjevernoamerički\ kontinent",
    '005' => "Južna\ Amerika",
    '009' => 'Oceanija',
    '011' => "Zapadna\ Afrika",
    '013' => "Centralna\ Amerika",
    '014' => "Istočna\ Afrika",
    '015' => "Sjeverna\ Afrika",
    '017' => "Središnja\ Afrika",
    '018' => "Južna\ Afrika",
    '019' => 'Amerike',
    '021' => "Sjeverna\ Amerika",
    '029' => 'Karibi',
    '030' => "Istočna\ Azija",
    '034' => "Južna\ Azija",
    '035' => "Jugoistočna\ Azija",
    '039' => "Južna\ Europa",
    '053' => "Australija\ i\ Novi\ Zeland",
    '054' => 'Melanezija',
    '057' => "Mikronezki\ oblast",
    '061' => 'Polinezija',
    '062' => "Južno\-centralna\ Azija",
    142   => 'Azija',
    143   => "Srednja\ Azija",
    145   => "Zapadna\ Azija",
    150   => 'Europa',
    151   => "Istočna\ Europa",
    154   => "Sjeverna\ Europa",
    155   => "Zapadna\ Europa",
    172   => "Zajednica\ nezavisnih\ država",
    200   => 'Czechoslovakia',
    419   => "Latinska\ Amerika\ i\ Karibi",
    830   => "Kanalski\ otoci",
    'ac'  => "Otok\ Ascension",
    'ad'  => 'Andora',
    'ae'  => "Ujedinjeni\ Arapski\ Emirati",
    'af'  => 'Afganistan',
    'ag'  => "Antigua\ i\ Barbuda",
    'ai'  => 'Anguila',
    'al'  => 'Albanija',
    'am'  => 'Armenija',
    'an'  => "Nizozemski\ Antili",
    'ao'  => 'Angola',
    'aq'  => 'Antarktik',
    'ar'  => 'Argentina',
    'as'  => "Američka\ Samoa",
    'at'  => 'Austrija',
    'au'  => 'Australija',
    'aw'  => 'Aruba',
    'ax'  => "Alandski\ otoci",
    'az'  => 'Azerbajdžan',
    'ba'  => "Bosna\ i\ Hercegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladeš',
    'be'  => 'Belgija',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bugarska',
    'bh'  => 'Bahrein',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Sveti\ Bartolomej",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunej',
    'bo'  => 'Bolivija',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazil',
    'bs'  => 'Bahami',
    'bt'  => 'Butan',
    'bv'  => "Otok\ Bouvet",
    'bw'  => 'Bocvana',
    'by'  => 'Bjelorusija',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Kokosovi\ Otoci",
    'cd'  => "Demokratska\ Republika\ Kongo",
    'cf'  => "Srednjoafrička\ Republika",
    'cg'  => "Republika\ Kongo",
    'ch'  => 'Švicarska',
    'ci'  => "Bjelokosna\ Obala",
    'ck'  => "Kukovi\ Otoci",
    'cl'  => 'Čile',
    'cm'  => 'Kamerun',
    'cn'  => 'Kina',
    'co'  => 'Kolumbija',
    'cp'  => "Otok\ Clipperton",
    'cr'  => 'Kostarika',
    'cs'  => "Srbija\ i\ Crna\ Gora",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Zeleni\ Rt",
    'cx'  => "Božićni\ Otok",
    'cy'  => 'Cipar',
    'cz'  => "Češka\ Republika",
    'dd'  => "East\ Germany",
    'de'  => 'Njemačka',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Džibuti',
    'dk'  => 'Danska',
    'dm'  => 'Dominika',
    'do'  => "Dominikanska\ Republika",
    'dz'  => 'Alžir',
    'ea'  => "Ceuta\ i\ Melilla",
    'ec'  => 'Ekvador',
    'ee'  => 'Estonija',
    'eg'  => 'Egipat',
    'eh'  => "Zapadna\ Sahara",
    'er'  => 'Eritreja',
    'es'  => 'Španjolska',
    'et'  => 'Etiopija',
    'eu'  => "Europska\ Unija",
    'fi'  => 'Finska',
    'fj'  => 'Fidži',
    'fk'  => 'Falklandi',
    'fm'  => 'Mikronezija',
    'fo'  => "Farski\ Otoci",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Francuska',
    'fx'  => "Metropolitanska\ Francuska",
    'ga'  => 'Gabon',
    'gb'  => "Velika\ Britanija",
    'gd'  => 'Grenada',
    'ge'  => 'Gruzija',
    'gf'  => "Francuska\ Gvajana",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grenland',
    'gm'  => 'Gambija',
    'gn'  => 'Gvineja',
    'gp'  => 'Guadeloupe',
    'gq'  => "Ekvatorska\ Gvineja",
    'gr'  => 'Grčka',
    'gs'  => "Južna\ Gruzija\ i\ Južni\ Sendvič\ Otoci",
    'gt'  => 'Gvatemala',
    'gu'  => 'Guam',
    'gw'  => "Gvineja\ Bisau",
    'gy'  => 'Gvajana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Otok\ Heard\ i\ Otoci\ McDonald",
    'hn'  => 'Honduras',
    'hr'  => 'Hrvatska',
    'ht'  => 'Haiti',
    'hu'  => 'Mađarska',
    'ic'  => "Kanarski\ Otoci",
    'id'  => 'Indonezija',
    'ie'  => 'Irska',
    'il'  => 'Izrael',
    'im'  => "Otok\ Man",
    'in'  => 'Indija',
    'io'  => "Britanski\ Teritorij\ Indijskog\ Oceana",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Italija',
    'je'  => 'Jersey',
    'jm'  => 'Jamajka',
    'jo'  => 'Jordan',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenija',
    'kg'  => 'Kirgistan',
    'kh'  => 'Kambodža',
    'ki'  => 'Kiribati',
    'km'  => 'Komori',
    'kn'  => "Sveti\ Kristofor\ i\ Nevis",
    'kp'  => "Sjeverna\ Koreja",
    'kr'  => "Južna\ Koreja",
    'kw'  => 'Kuvajt',
    'ky'  => "Kajmanski\ Otoci",
    'kz'  => 'Kazakstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "Sveta\ Lucija",
    'li'  => 'Lihtenštajn',
    'lk'  => "Šri\ Lanka",
    'lr'  => 'Liberija',
    'ls'  => 'Lesoto',
    'lt'  => 'Litva',
    'lu'  => 'Luksemburg',
    'lv'  => 'Latvija',
    'ly'  => 'Libija',
    'ma'  => 'Maroko',
    'mc'  => 'Monako',
    'md'  => 'Moldavija',
    'me'  => "Crna\ Gora",
    'mf'  => "Sveti\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Maršalovi\ Otoci",
    'mi'  => "Midway\ Islands",
    'mk'  => "Makedonija\ \-\ BJRM",
    'ml'  => 'Mali',
    'mm'  => 'Mijanma',
    'mn'  => 'Mongolija',
    'mo'  => 'Makao',
    'mp'  => "Sjeverni\ Marijanski\ Otoci",
    'mq'  => 'Martinik',
    'mr'  => 'Mauritanija',
    'ms'  => 'Montserat',
    'mt'  => 'Malta',
    'mu'  => 'Mauricijus',
    'mv'  => 'Maldivi',
    'mw'  => 'Malavi',
    'mx'  => 'Meksiko',
    'my'  => 'Malezija',
    'mz'  => 'Mozambik',
    'na'  => 'Namibija',
    'nc'  => "Nova\ Kaledonija",
    'ne'  => 'Niger',
    'nf'  => "Otok\ Norfolk",
    'ng'  => 'Nigerija',
    'ni'  => 'Nikaragva',
    'nl'  => 'Nizozemska',
    'no'  => 'Norveška',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Novi\ Zeland",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Francuska\ Polinezija",
    'pg'  => "Papua\ Nova\ Gvineja",
    'ph'  => 'Filipini',
    'pk'  => 'Pakistan',
    'pl'  => 'Poljska',
    'pm'  => "Sveti\ Petar\ i\ Miguel",
    'pn'  => 'Pitcairn',
    'pr'  => 'Portoriko',
    'ps'  => "Palestinsko\ Područje",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paragvaj',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Ostala\ oceanija",
    're'  => 'Reunion',
    'ro'  => 'Rumunjska',
    'rs'  => 'Srbija',
    'ru'  => 'Rusija',
    'rw'  => 'Ruanda',
    'sa'  => "Saudijska\ Arabija",
    'sb'  => "Solomonski\ Otoci",
    'sc'  => 'Sejšeli',
    'sd'  => 'Sudan',
    'se'  => 'Švedska',
    'sg'  => 'Singapur',
    'sh'  => "Sveta\ Helena",
    'si'  => 'Slovenija',
    'sj'  => "Svalbard\ i\ Jan\ Mayen",
    'sk'  => 'Slovačka',
    'sl'  => "Sijera\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalija',
    'sr'  => 'Surinam',
    'st'  => "Sveti\ Toma\ i\ Prinsipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Sirija',
    'sz'  => 'Svazi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turkski\ i\ Kaikos\ Otoci",
    'td'  => 'Čad',
    'tf'  => "Francuski\ Južni\ Teritoriji",
    'tg'  => 'Togo',
    'th'  => 'Tajland',
    'tj'  => 'Tadžikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Istočni\ Timor",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunis',
    'to'  => 'Tonga',
    'tr'  => 'Turska',
    'tt'  => "Trinidad\ i\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Tajvan',
    'tz'  => 'Tanzanija',
    'ua'  => 'Ukrajina',
    'ug'  => 'Uganda',
    'um'  => "Ujedinjene\ Države\ Manjih\ Pacifičkih\ Otoka",
    'us'  => "Sjedinjene\ Države",
    'uy'  => 'Urugvaj',
    'uz'  => 'Uzbekistan',
    'va'  => "Grad\ Vatikan",
    'vc'  => "Sveti\ Vincent\ i\ Grenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Britanski\ Djevičanski\ Otoci",
    'vi'  => "Američki\ Djevičanski\ Otoci",
    'vn'  => 'Vijetnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ i\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Majote',
    'za'  => "Južnoafrička\ Republika",
    'zm'  => 'Zambija',
    'zw'  => 'Zimbabve',
    'zz'  => "nepoznata\ ili\ nevažeća\ oblast",
);

%Locales::DB::Territory::hr::name_to_code = (
    'afganistan'                                => 'af',
    'afrika'                                    => '002',
    'alandskiotoci'                             => 'ax',
    'albanija'                                  => 'al',
    'alžir'                                    => 'dz',
    'amerike'                                   => '019',
    'američkasamoa'                            => 'as',
    'američkidjevičanskiotoci'                => 'vi',
    'andora'                                    => 'ad',
    'angola'                                    => 'ao',
    'anguila'                                   => 'ai',
    'antarktik'                                 => 'aq',
    'antiguaibarbuda'                           => 'ag',
    'argentina'                                 => 'ar',
    'armenija'                                  => 'am',
    'aruba'                                     => 'aw',
    'australija'                                => 'au',
    'australijainovizeland'                     => '053',
    'austrija'                                  => 'at',
    'azerbajdžan'                              => 'az',
    'azija'                                     => 142,
    'bahami'                                    => 'bs',
    'bahrein'                                   => 'bh',
    'bangladeš'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgija'                                   => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bjelokosnaobala'                           => 'ci',
    'bjelorusija'                               => 'by',
    'bocvana'                                   => 'bw',
    'bolivija'                                  => 'bo',
    'bosnaihercegovina'                         => 'ba',
    'božićniotok'                             => 'cx',
    'brazil'                                    => 'br',
    'britanskidjevičanskiotoci'                => 'vg',
    'britanskiteritorijindijskogoceana'         => 'io',
    'britishantarcticterritory'                 => 'bq',
    'brunej'                                    => 'bn',
    'bugarska'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'butan'                                     => 'bt',
    'cantonandenderburyislands'                 => 'ct',
    'centralnaamerika'                          => '013',
    'ceutaimelilla'                             => 'ea',
    'cipar'                                     => 'cy',
    'crnagora'                                  => 'me',
    'czechoslovakia'                            => 200,
    'danska'                                    => 'dk',
    'demokratskarepublikakongo'                 => 'cd',
    'diegogarcia'                               => 'dg',
    'dominika'                                  => 'dm',
    'dominikanskarepublika'                     => 'do',
    'dronningmaudland'                          => 'nq',
    'džibuti'                                  => 'dj',
    'eastgermany'                               => 'dd',
    'egipat'                                    => 'eg',
    'ekvador'                                   => 'ec',
    'ekvatorskagvineja'                         => 'gq',
    'elsalvador'                                => 'sv',
    'eritreja'                                  => 'er',
    'estonija'                                  => 'ee',
    'etiopija'                                  => 'et',
    'europa'                                    => 150,
    'europskaunija'                             => 'eu',
    'falklandi'                                 => 'fk',
    'farskiotoci'                               => 'fo',
    'fidži'                                    => 'fj',
    'filipini'                                  => 'ph',
    'finska'                                    => 'fi',
    'francuska'                                 => 'fr',
    'francuskagvajana'                          => 'gf',
    'francuskapolinezija'                       => 'pf',
    'francuskijužniteritoriji'                 => 'tf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabon'                                     => 'ga',
    'gambija'                                   => 'gm',
    'gana'                                      => 'gh',
    'gibraltar'                                 => 'gi',
    'gradvatikan'                               => 'va',
    'grenada'                                   => 'gd',
    'grenland'                                  => 'gl',
    'gruzija'                                   => 'ge',
    'grčka'                                    => 'gr',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guernsey'                                  => 'gg',
    'gvajana'                                   => 'gy',
    'gvatemala'                                 => 'gt',
    'gvineja'                                   => 'gn',
    'gvinejabisau'                              => 'gw',
    'haiti'                                     => 'ht',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hrvatska'                                  => 'hr',
    'indija'                                    => 'in',
    'indonezija'                                => 'id',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'irska'                                     => 'ie',
    'island'                                    => 'is',
    'istočnaafrika'                            => '014',
    'istočnaazija'                             => '030',
    'istočnaeuropa'                            => 151,
    'istočnitimor'                             => 'tl',
    'italija'                                   => 'it',
    'izrael'                                    => 'il',
    'jamajka'                                   => 'jm',
    'japan'                                     => 'jp',
    'jemen'                                     => 'ye',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordan'                                    => 'jo',
    'jugoistočnaazija'                         => '035',
    'južnaafrika'                              => '018',
    'južnaamerika'                             => '005',
    'južnaazija'                               => '034',
    'južnaeuropa'                              => '039',
    'južnagruzijaijužnisendvičotoci'         => 'gs',
    'južnakoreja'                              => 'kr',
    'južnoafričkarepublika'                   => 'za',
    'južnocentralnaazija'                      => '062',
    'kajmanskiotoci'                            => 'ky',
    'kambodža'                                 => 'kh',
    'kamerun'                                   => 'cm',
    'kanada'                                    => 'ca',
    'kanalskiotoci'                             => 830,
    'kanarskiotoci'                             => 'ic',
    'karibi'                                    => '029',
    'katar'                                     => 'qa',
    'kazakstan'                                 => 'kz',
    'kenija'                                    => 'ke',
    'kina'                                      => 'cn',
    'kirgistan'                                 => 'kg',
    'kiribati'                                  => 'ki',
    'kokosoviotoci'                             => 'cc',
    'kolumbija'                                 => 'co',
    'komori'                                    => 'km',
    'kostarika'                                 => 'cr',
    'kuba'                                      => 'cu',
    'kukoviotoci'                               => 'ck',
    'kuvajt'                                    => 'kw',
    'laos'                                      => 'la',
    'latinskaamerikaikaribi'                    => 419,
    'latvija'                                   => 'lv',
    'lesoto'                                    => 'ls',
    'libanon'                                   => 'lb',
    'liberija'                                  => 'lr',
    'libija'                                    => 'ly',
    'lihtenštajn'                              => 'li',
    'litva'                                     => 'lt',
    'luksemburg'                                => 'lu',
    'madagaskar'                                => 'mg',
    'majote'                                    => 'yt',
    'makao'                                     => 'mo',
    'makedonijabjrm'                            => 'mk',
    'malavi'                                    => 'mw',
    'maldivi'                                   => 'mv',
    'malezija'                                  => 'my',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'maroko'                                    => 'ma',
    'martinik'                                  => 'mq',
    'maršaloviotoci'                           => 'mh',
    'mauricijus'                                => 'mu',
    'mauritanija'                               => 'mr',
    'mađarska'                                 => 'hu',
    'meksiko'                                   => 'mx',
    'melanezija'                                => '054',
    'metropolitanskafrancuska'                  => 'fx',
    'midwayislands'                             => 'mi',
    'mijanma'                                   => 'mm',
    'mikronezija'                               => 'fm',
    'mikronezkioblast'                          => '057',
    'moldavija'                                 => 'md',
    'monako'                                    => 'mc',
    'mongolija'                                 => 'mn',
    'montserat'                                 => 'ms',
    'mozambik'                                  => 'mz',
    'namibija'                                  => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'nepoznatailinevažećaoblast'              => 'zz',
    'neutralzone'                               => 'nt',
    'niger'                                     => 'ne',
    'nigerija'                                  => 'ng',
    'nikaragva'                                 => 'ni',
    'niue'                                      => 'nu',
    'nizozemska'                                => 'nl',
    'nizozemskiantili'                          => 'an',
    'njemačka'                                 => 'de',
    'northvietnam'                              => 'vd',
    'norveška'                                 => 'no',
    'novakaledonija'                            => 'nc',
    'novizeland'                                => 'nz',
    'oceanija'                                  => '009',
    'oman'                                      => 'om',
    'ostalaoceanija'                            => 'qo',
    'otokascension'                             => 'ac',
    'otokbouvet'                                => 'bv',
    'otokclipperton'                            => 'cp',
    'otokheardiotocimcdonald'                   => 'hm',
    'otokman'                                   => 'im',
    'otoknorfolk'                               => 'nf',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'palestinskopodručje'                      => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanovagvineja'                          => 'pg',
    'paragvaj'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'polinezija'                                => '061',
    'poljska'                                   => 'pl',
    'portoriko'                                 => 'pr',
    'portugal'                                  => 'pt',
    'republikakongo'                            => 'cg',
    'reunion'                                   => 're',
    'ruanda'                                    => 'rw',
    'rumunjska'                                 => 'ro',
    'rusija'                                    => 'ru',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saudijskaarabija'                          => 'sa',
    'sejšeli'                                  => 'sc',
    'senegal'                                   => 'sn',
    'sijeraleone'                               => 'sl',
    'singapur'                                  => 'sg',
    'sirija'                                    => 'sy',
    'sjedinjenedržave'                         => 'us',
    'sjevernaafrika'                            => '015',
    'sjevernaamerika'                           => '021',
    'sjevernaeuropa'                            => 154,
    'sjevernakoreja'                            => 'kp',
    'sjevernimarijanskiotoci'                   => 'mp',
    'sjevernoameričkikontinent'                => '003',
    'slovačka'                                 => 'sk',
    'slovenija'                                 => 'si',
    'solomonskiotoci'                           => 'sb',
    'somalija'                                  => 'so',
    'srbija'                                    => 'rs',
    'srbijaicrnagora'                           => 'cs',
    'središnjaafrika'                          => '017',
    'srednjaazija'                              => 143,
    'srednjoafričkarepublika'                  => 'cf',
    'sudan'                                     => 'sd',
    'surinam'                                   => 'sr',
    'svalbardijanmayen'                         => 'sj',
    'svazi'                                     => 'sz',
    'svetahelena'                               => 'sh',
    'svetalucija'                               => 'lc',
    'svetibartolomej'                           => 'bl',
    'svetikristoforinevis'                      => 'kn',
    'svetimartin'                               => 'mf',
    'svetipetarimiguel'                         => 'pm',
    'svetitomaiprinsipe'                        => 'st',
    'svetivincentigrenadini'                    => 'vc',
    'svijet'                                    => '001',
    'tadžikistan'                              => 'tj',
    'tajland'                                   => 'th',
    'tajvan'                                    => 'tw',
    'tanzanija'                                 => 'tz',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidaditobago'                           => 'tt',
    'tristandacunha'                            => 'ta',
    'tunis'                                     => 'tn',
    'turkmenistan'                              => 'tm',
    'turkskiikaikosotoci'                       => 'tc',
    'turska'                                    => 'tr',
    'tuvalu'                                    => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ujedinjenedržavemanjihpacifičkihotoka'   => 'um',
    'ujedinjeniarapskiemirati'                  => 'ae',
    'ukrajina'                                  => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'urugvaj'                                   => 'uy',
    'uzbekistan'                                => 'uz',
    'vanuatu'                                   => 'vu',
    'velikabritanija'                           => 'gb',
    'venezuela'                                 => 've',
    'vijetnam'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'wallisifutuna'                             => 'wf',
    'zajednicanezavisnihdržava'                => 172,
    'zambija'                                   => 'zm',
    'zapadnaafrika'                             => '011',
    'zapadnaazija'                              => 145,
    'zapadnaeuropa'                             => 155,
    'zapadnasahara'                             => 'eh',
    'zelenirt'                                  => 'cv',
    'zimbabve'                                  => 'zw',
    'Čad'                                      => 'td',
    'Češkarepublika'                          => 'cz',
    'Čile'                                     => 'cl',
    'Španjolska'                               => 'es',
    'Šrilanka'                                 => 'lk',
    'Švedska'                                  => 'se',
    'Švicarska'                                => 'ch',
);

1;

