package Locales::DB::Territory::bm;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::bm::VERSION = '0.09';

$Locales::DB::Territory::bm::cldr_version = '2.0';

%Locales::DB::Territory::bm::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andɔr',
    'ae'  => "Arabu\ mara\ kafoli",
    'af'  => 'Afiganistaŋ',
    'ag'  => "Antiga\-ni\-Barbuda",
    'ai'  => 'Angiya',
    'al'  => 'Alibani',
    'am'  => 'Arimeni',
    'an'  => "Peyiba\ ka\ Antiyi",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Arizantin',
    'as'  => "Samowa\ amerikani",
    'at'  => 'Otirisi',
    'au'  => 'Ositirali',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azɛrbayjaŋ',
    'ba'  => "Bozni\-Ɛrizigovini",
    'bb'  => 'Barbadi',
    'bd'  => 'Bɛngiladɛsi',
    'be'  => 'Bɛliziki',
    'bf'  => "Burukina\ Faso",
    'bg'  => 'Buligari',
    'bh'  => 'Bareyini',
    'bi'  => 'Burundi',
    'bj'  => 'Benɛn',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermudi',
    'bn'  => 'Burinɛyi',
    'bo'  => 'Bolivi',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Berezili',
    'bs'  => 'Bahamasi',
    'bt'  => 'Butaŋ',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Bɔtisiwana',
    'by'  => 'Belarusi',
    'bz'  => 'Belizi',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Kongo\ ka\ republiki\ demɔkratiki",
    'cf'  => 'Santarafiriki',
    'cg'  => 'Kongo',
    'ch'  => 'Suwisi',
    'ci'  => 'Kodiwari',
    'ck'  => "Kuki\ Gun",
    'cl'  => 'Sili',
    'cm'  => 'Kameruni',
    'cn'  => 'Siniwajamana',
    'co'  => 'Kolombi',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kɔsitarika',
    'cs'  => "Serbi\-ni\-Mɔntenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => 'Capivɛrdi',
    'cx'  => "Christmas\ Island",
    'cy'  => 'Cipri',
    'cz'  => "Ceki\ republiki",
    'dd'  => "East\ Germany",
    'de'  => 'Alimaɲi',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jibuti',
    'dk'  => 'Danemarki',
    'dm'  => 'Dɔminiki',
    'do'  => "Dɔmimiki\ republiki",
    'dz'  => 'Alizeri',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwatɔr',
    'ee'  => 'Esetoni',
    'eg'  => 'Eziputi',
    'eh'  => "Western\ Sahara",
    'er'  => 'Eritere',
    'es'  => 'Esipaɲi',
    'et'  => 'Etiopi',
    'eu'  => "European\ Union",
    'fi'  => 'Finilandi',
    'fj'  => 'Fiji',
    'fk'  => "Maluwini\ Gun",
    'fm'  => 'Mikironesi',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Faransi',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabɔŋ',
    'gb'  => 'Angilɛtɛri',
    'gd'  => 'Granadi',
    'ge'  => 'Zeyɔrzi',
    'gf'  => "Faransi\ ka\ gwiyani",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Zibralitari',
    'gl'  => 'Gɔrɔhenelandi',
    'gm'  => 'Ganbi',
    'gn'  => 'Gine',
    'gp'  => 'Gwadelup',
    'gq'  => "Gine\ ekwatɔri",
    'gr'  => 'Gɛrɛsi',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatemala',
    'gu'  => 'Gwam',
    'gw'  => "Gine\ Bisawo",
    'gy'  => 'Gwiyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hɔndirasi',
    'hr'  => 'Kroasi',
    'ht'  => 'Ayiti',
    'hu'  => 'Hɔngri',
    'ic'  => "Canary\ Islands",
    'id'  => 'Ɛndonezi',
    'ie'  => 'Irilandi',
    'il'  => 'Isirayeli',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Ɛndujamana',
    'io'  => "Angilɛ\ ka\ ɛndu\ dugukolo",
    'iq'  => 'Iraki',
    'ir'  => 'Iraŋ',
    'is'  => 'Isilandi',
    'it'  => 'Itali',
    'je'  => 'Jersey',
    'jm'  => 'Zamayiki',
    'jo'  => 'Zɔrdani',
    'jp'  => 'Zapɔn',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Keniya',
    'kg'  => 'Kirigizisitaŋ',
    'kh'  => 'Kamboji',
    'ki'  => 'Kiribati',
    'km'  => 'Komɔri',
    'kn'  => "Kristɔfo\-Senu\-ni\-Ɲevɛs",
    'kp'  => "Kɛɲɛka\ Kore",
    'kr'  => "Worodugu\ Kore",
    'kw'  => 'Kowɛti',
    'ky'  => "Bama\ Gun",
    'kz'  => 'Kazakistaŋ',
    'la'  => 'Layosi',
    'lb'  => 'Libaŋ',
    'lc'  => "Lusi\-Senu",
    'li'  => 'Lisɛnsitayini',
    'lk'  => 'Sirilanka',
    'lr'  => 'Liberiya',
    'ls'  => 'Lesoto',
    'lt'  => 'Lituyani',
    'lu'  => 'Likisanburu',
    'lv'  => 'Letoni',
    'ly'  => 'Libi',
    'ma'  => 'Marɔku',
    'mc'  => 'Monako',
    'md'  => 'Molidavi',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagasikari',
    'mh'  => "Marisali\ Gun",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Macedɔni',
    'ml'  => 'Mali',
    'mm'  => 'Myanimari',
    'mn'  => 'Moŋoli',
    'mo'  => 'Macau',
    'mp'  => "Kɛɲɛka\ Mariyani\ Gun",
    'mq'  => 'Maritiniki',
    'mr'  => 'Mɔritani',
    'ms'  => 'Moŋsera',
    'mt'  => 'Malti',
    'mu'  => 'Morisi',
    'mv'  => 'Maldivi',
    'mw'  => 'Malawi',
    'mx'  => 'Meksiki',
    'my'  => 'Malɛzi',
    'mz'  => 'Mozanbiki',
    'na'  => 'Namibi',
    'nc'  => "Kaledoni\ Koura",
    'ne'  => 'Nizɛri',
    'nf'  => "Nɔrofoliki\ Gun",
    'ng'  => 'Nizeriya',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Peyiba',
    'no'  => 'Nɔriwɛzi',
    'np'  => 'Nepali',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nawuru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Nyuwe',
    'nz'  => "Zelandi\ Koura",
    'om'  => 'Omaŋ',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Faransi\ ka\ polinezi",
    'pg'  => "Papuwasi\-Gine\-Koura",
    'ph'  => 'Filipini',
    'pk'  => 'Pakisitaŋ',
    'pl'  => 'Poloɲi',
    'pm'  => "Piyɛri\-Senu\-ni\-Mikelɔŋ",
    'pn'  => 'Pitikarini',
    'pr'  => 'Pɔrotoriko',
    'ps'  => 'Palesitini',
    'pt'  => 'Pɔritigali',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palawu',
    'py'  => 'Paraguwayi',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katari',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Reyuɲɔŋ',
    'ro'  => 'Rumani',
    'rs'  => 'Serbia',
    'ru'  => 'Irisi',
    'rw'  => 'Ruwanda',
    'sa'  => "Arabiya\ Sawudiya",
    'sb'  => "Salomo\ Gun",
    'sc'  => 'Sesɛli',
    'sd'  => 'Sudaŋ',
    'se'  => 'Suwɛdi',
    'sg'  => 'Sɛngapuri',
    'sh'  => "Ɛlɛni\ Senu",
    'si'  => 'Sloveni',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slowaki',
    'sl'  => "Siyera\ Lewɔni",
    'sm'  => "Marini\-Senu",
    'sn'  => 'Senegali',
    'so'  => 'Somali',
    'sr'  => 'Surinami',
    'st'  => "Sawo\ Tome\-ni\-Prinicipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salivadɔr',
    'sy'  => 'Siri',
    'sz'  => 'Swazilandi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turiki\ Gun\ ni\ Kayiki",
    'td'  => 'Cadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Tayilandi',
    'tj'  => 'Tajikisitani',
    'tk'  => 'Tokelo',
    'tl'  => "Kɔrɔn\ Timɔr",
    'tm'  => 'Turikimenisitani',
    'tn'  => 'Tunizi',
    'to'  => 'Tonga',
    'tr'  => 'Turiki',
    'tt'  => "Trinite\-ni\-Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Tayiwani',
    'tz'  => 'Tanzani',
    'ua'  => 'Ukɛrɛni',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Ameriki',
    'uy'  => 'Urugwayi',
    'uz'  => 'Uzebekisitani',
    'va'  => 'Vatikaŋ',
    'vc'  => "Vinisɛn\-Senu\-ni\-Grenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuwela',
    'vg'  => "Angilɛ\ ka\ Sungurunnin\ Gun",
    'vi'  => "Ameriki\ ka\ Sungurunnin\ Gun",
    'vn'  => 'Wiyɛtinamu',
    'vu'  => 'Vanuwatu',
    'wf'  => "Walisi\-ni\-Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samowa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemɛni',
    'yt'  => 'Mayoti',
    'za'  => "Worodugu\ Afriki",
    'zm'  => 'Zanbi',
    'zw'  => 'Zimbabuwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::bm::name_to_code = (
    'afiganistaŋ'                              => 'af',
    'africa'                                    => '002',
    'alibani'                                   => 'al',
    'alimaɲi'                                  => 'de',
    'alizeri'                                   => 'dz',
    'americas'                                  => '019',
    'ameriki'                                   => 'us',
    'amerikikasungurunningun'                   => 'vi',
    'andɔr'                                    => 'ad',
    'angilɛkasungurunningun'                   => 'vg',
    'angilɛkaɛndudugukolo'                    => 'io',
    'angilɛtɛri'                              => 'gb',
    'angiya'                                    => 'ai',
    'angola'                                    => 'ao',
    'antarctica'                                => 'aq',
    'antiganibarbuda'                           => 'ag',
    'arabiyasawudiya'                           => 'sa',
    'arabumarakafoli'                           => 'ae',
    'arimeni'                                   => 'am',
    'arizantin'                                 => 'ar',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'ayiti'                                     => 'ht',
    'azɛrbayjaŋ'                              => 'az',
    'bahamasi'                                  => 'bs',
    'bamagun'                                   => 'ky',
    'barbadi'                                   => 'bb',
    'bareyini'                                  => 'bh',
    'belarusi'                                  => 'by',
    'belizi'                                    => 'bz',
    'benɛn'                                    => 'bj',
    'berezili'                                  => 'br',
    'bermudi'                                   => 'bm',
    'bolivi'                                    => 'bo',
    'bouvetisland'                              => 'bv',
    'bozniƐrizigovini'                         => 'ba',
    'britishantarcticterritory'                 => 'bq',
    'buligari'                                  => 'bg',
    'burinɛyi'                                 => 'bn',
    'burukinafaso'                              => 'bf',
    'burundi'                                   => 'bi',
    'butaŋ'                                    => 'bt',
    'bɔtisiwana'                               => 'bw',
    'bɛliziki'                                 => 'be',
    'bɛngiladɛsi'                             => 'bd',
    'cadi'                                      => 'td',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'capivɛrdi'                                => 'cv',
    'caribbean'                                 => '029',
    'cekirepubliki'                             => 'cz',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'cipri'                                     => 'cy',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danemarki'                                 => 'dk',
    'diegogarcia'                               => 'dg',
    'dronningmaudland'                          => 'nq',
    'dɔmimikirepubliki'                        => 'do',
    'dɔminiki'                                 => 'dm',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekwatɔr'                                  => 'ec',
    'eritere'                                   => 'er',
    'esetoni'                                   => 'ee',
    'esipaɲi'                                  => 'es',
    'etiopi'                                    => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'eziputi'                                   => 'eg',
    'faransi'                                   => 'fr',
    'faransikagwiyani'                          => 'gf',
    'faransikapolinezi'                         => 'pf',
    'faroeislands'                              => 'fo',
    'fiji'                                      => 'fj',
    'filipini'                                  => 'ph',
    'finilandi'                                 => 'fi',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabɔŋ'                                   => 'ga',
    'gana'                                      => 'gh',
    'ganbi'                                     => 'gm',
    'gine'                                      => 'gn',
    'ginebisawo'                                => 'gw',
    'gineekwatɔri'                             => 'gq',
    'granadi'                                   => 'gd',
    'guernsey'                                  => 'gg',
    'gwadelup'                                  => 'gp',
    'gwam'                                      => 'gu',
    'gwatemala'                                 => 'gt',
    'gwiyana'                                   => 'gy',
    'gɔrɔhenelandi'                           => 'gl',
    'gɛrɛsi'                                  => 'gr',
    'heardislandandmcdonaldislands'             => 'hm',
    'hongkong'                                  => 'hk',
    'hɔndirasi'                                => 'hn',
    'hɔngri'                                   => 'hu',
    'iraki'                                     => 'iq',
    'iraŋ'                                     => 'ir',
    'irilandi'                                  => 'ie',
    'irisi'                                     => 'ru',
    'isilandi'                                  => 'is',
    'isirayeli'                                 => 'il',
    'isleofman'                                 => 'im',
    'itali'                                     => 'it',
    'jersey'                                    => 'je',
    'jibuti'                                    => 'dj',
    'johnstonisland'                            => 'jt',
    'kaledonikoura'                             => 'nc',
    'kamboji'                                   => 'kh',
    'kameruni'                                  => 'cm',
    'kanada'                                    => 'ca',
    'katari'                                    => 'qa',
    'kazakistaŋ'                               => 'kz',
    'keniya'                                    => 'ke',
    'kiribati'                                  => 'ki',
    'kirigizisitaŋ'                            => 'kg',
    'kodiwari'                                  => 'ci',
    'kolombi'                                   => 'co',
    'komɔri'                                   => 'km',
    'kongo'                                     => 'cg',
    'kongokarepublikidemɔkratiki'              => 'cd',
    'kowɛti'                                   => 'kw',
    'kristɔfosenuniƝevɛs'                    => 'kn',
    'kroasi'                                    => 'hr',
    'kuba'                                      => 'cu',
    'kukigun'                                   => 'ck',
    'kɔrɔntimɔr'                             => 'tl',
    'kɔsitarika'                               => 'cr',
    'kɛɲɛkakore'                             => 'kp',
    'kɛɲɛkamariyanigun'                      => 'mp',
    'latinamerica'                              => 419,
    'layosi'                                    => 'la',
    'lesoto'                                    => 'ls',
    'letoni'                                    => 'lv',
    'libaŋ'                                    => 'lb',
    'liberiya'                                  => 'lr',
    'libi'                                      => 'ly',
    'likisanburu'                               => 'lu',
    'lisɛnsitayini'                            => 'li',
    'lituyani'                                  => 'lt',
    'lusisenu'                                  => 'lc',
    'macau'                                     => 'mo',
    'macedɔni'                                 => 'mk',
    'madagasikari'                              => 'mg',
    'malawi'                                    => 'mw',
    'maldivi'                                   => 'mv',
    'mali'                                      => 'ml',
    'malti'                                     => 'mt',
    'maluwinigun'                               => 'fk',
    'malɛzi'                                   => 'my',
    'marinisenu'                                => 'sm',
    'marisaligun'                               => 'mh',
    'maritiniki'                                => 'mq',
    'marɔku'                                   => 'ma',
    'mayoti'                                    => 'yt',
    'meksiki'                                   => 'mx',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikironesi'                                => 'fm',
    'molidavi'                                  => 'md',
    'monako'                                    => 'mc',
    'montenegro'                                => 'me',
    'morisi'                                    => 'mu',
    'mozanbiki'                                 => 'mz',
    'moŋoli'                                   => 'mn',
    'moŋsera'                                  => 'ms',
    'myanimari'                                 => 'mm',
    'mɔritani'                                 => 'mr',
    'namibi'                                    => 'na',
    'nawuru'                                    => 'nr',
    'nepali'                                    => 'np',
    'neutralzone'                               => 'nt',
    'nikaragwa'                                 => 'ni',
    'nizeriya'                                  => 'ng',
    'nizɛri'                                   => 'ne',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'nyuwe'                                     => 'nu',
    'nɔriwɛzi'                                => 'no',
    'nɔrofolikigun'                            => 'nf',
    'oceania'                                   => '009',
    'omaŋ'                                     => 'om',
    'ositirali'                                 => 'au',
    'otirisi'                                   => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakisitaŋ'                                => 'pk',
    'palawu'                                    => 'pw',
    'palesitini'                                => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuwasiginekoura'                         => 'pg',
    'paraguwayi'                                => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'peyiba'                                    => 'nl',
    'peyibakaantiyi'                            => 'an',
    'pitikarini'                                => 'pn',
    'piyɛrisenunimikelɔŋ'                    => 'pm',
    'poloɲi'                                   => 'pl',
    'polynesia'                                 => '061',
    'pɔritigali'                               => 'pt',
    'pɔrotoriko'                               => 'pr',
    'reyuɲɔŋ'                                => 're',
    'rumani'                                    => 'ro',
    'ruwanda'                                   => 'rw',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'salivadɔr'                                => 'sv',
    'salomogun'                                 => 'sb',
    'samowa'                                    => 'ws',
    'samowaamerikani'                           => 'as',
    'santarafiriki'                             => 'cf',
    'sawotomeniprinicipe'                       => 'st',
    'senegali'                                  => 'sn',
    'serbia'                                    => 'rs',
    'serbinimɔntenegro'                        => 'cs',
    'sesɛli'                                   => 'sc',
    'sili'                                      => 'cl',
    'siniwajamana'                              => 'cn',
    'siri'                                      => 'sy',
    'sirilanka'                                 => 'lk',
    'siyeralewɔni'                             => 'sl',
    'sloveni'                                   => 'si',
    'slowaki'                                   => 'sk',
    'somali'                                    => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'sudaŋ'                                    => 'sd',
    'surinami'                                  => 'sr',
    'suwisi'                                    => 'ch',
    'suwɛdi'                                   => 'se',
    'svalbardandjanmayen'                       => 'sj',
    'swazilandi'                                => 'sz',
    'sɛngapuri'                                => 'sg',
    'tajikisitani'                              => 'tj',
    'tanzani'                                   => 'tz',
    'tayilandi'                                 => 'th',
    'tayiwani'                                  => 'tw',
    'togo'                                      => 'tg',
    'tokelo'                                    => 'tk',
    'tonga'                                     => 'to',
    'trinitenitobago'                           => 'tt',
    'tristandacunha'                            => 'ta',
    'tunizi'                                    => 'tn',
    'turiki'                                    => 'tr',
    'turikigunnikayiki'                         => 'tc',
    'turikimenisitani'                          => 'tm',
    'tuvalu'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukɛrɛni'                                 => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'urugwayi'                                  => 'uy',
    'uzebekisitani'                             => 'uz',
    'vanuwatu'                                  => 'vu',
    'vatikaŋ'                                  => 'va',
    'venezuwela'                                => 've',
    'vinisɛnsenunigrenadini'                   => 'vc',
    'wakeisland'                                => 'wk',
    'walisinifutuna'                            => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'wiyɛtinamu'                               => 'vn',
    'world'                                     => '001',
    'woroduguafriki'                            => 'za',
    'worodugukore'                              => 'kr',
    'yemɛni'                                   => 'ye',
    'zamayiki'                                  => 'jm',
    'zanbi'                                     => 'zm',
    'zapɔn'                                    => 'jp',
    'zelandikoura'                              => 'nz',
    'zeyɔrzi'                                  => 'ge',
    'zibralitari'                               => 'gi',
    'zimbabuwe'                                 => 'zw',
    'zɔrdani'                                  => 'jo',
    "\Ã\landislands"                         => 'ax',
    'Ɛlɛnisenu'                               => 'sh',
    'Ɛndonezi'                                 => 'id',
    'Ɛndujamana'                               => 'in',
);

1;

