package Locales::DB::Territory::sbp;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::sbp::VERSION = '0.09';

$Locales::DB::Territory::sbp::cldr_version = '2.0';

%Locales::DB::Territory::sbp::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andola',
    'ae'  => "Wutwa\ wa\ shiyalabu",
    'af'  => 'Afuganisitani',
    'ag'  => "Anitiguya\ ni\ Balubuda",
    'ai'  => 'Anguilla',
    'al'  => 'Alubaniya',
    'am'  => 'Alimeniya',
    'an'  => "Anitili\ sa\ Uholansi",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Ajentina',
    'as'  => "Samoya\ ya\ Malekani",
    'at'  => 'Awusitiliya',
    'au'  => 'Awusitilaliya',
    'aw'  => 'Aluba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Asabajani',
    'ba'  => "Bosiniya\ ni\ Hesegovina",
    'bb'  => 'Babadosi',
    'bd'  => 'Bangiladeshi',
    'be'  => 'Ubeligiji',
    'bf'  => 'Bukinafaso',
    'bg'  => 'Buligaliya',
    'bh'  => 'Bahaleni',
    'bi'  => 'Bulundi',
    'bj'  => 'Benini',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Belimuda',
    'bn'  => 'Buluneyi',
    'bo'  => 'Boliviya',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Bulasili',
    'bs'  => 'Bahama',
    'bt'  => 'Butani',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botiswana',
    'by'  => 'Belalusi',
    'bz'  => 'Belise',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Jamuhuli\ ya\ Kidemokilasiya\ ya\ Kongo",
    'cf'  => "Jamuhuli\ ya\ Afilika\ ya\ Pakhati",
    'cg'  => 'Kongo',
    'ch'  => 'Uswisi',
    'ci'  => 'Kodivaya',
    'ck'  => "Figunguli\ fya\ Kooki",
    'cl'  => 'Shile',
    'cm'  => 'Kameruni',
    'cn'  => 'Shina',
    'co'  => 'Kolombiya',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kositalika',
    'cs'  => "Selibiya\ ni\ Montenegilo",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => 'Kepuvede',
    'cx'  => "Christmas\ Island",
    'cy'  => 'Kupilosi',
    'cz'  => "Jamuhuli\ ya\ Sheki",
    'dd'  => "East\ Germany",
    'de'  => 'Wujelumani',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jibuti',
    'dk'  => 'Denimaki',
    'dm'  => 'Dominika',
    'do'  => "Jamuhuli\ ya\ Dominika",
    'dz'  => 'Alijeliya',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwado',
    'ee'  => 'Esitoniya',
    'eg'  => 'Misili',
    'eh'  => "Western\ Sahara",
    'er'  => 'Elitileya',
    'es'  => 'Hisipaniya',
    'et'  => 'Uhabeshi',
    'eu'  => "European\ Union",
    'fi'  => 'Wufini',
    'fj'  => 'Fiji',
    'fk'  => "Figunguli\ fya\ Fokolendi",
    'fm'  => 'Mikilonesiya',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Wufalansa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gaboni',
    'gb'  => 'Uwingelesa',
    'gd'  => 'Gilenada',
    'ge'  => 'Jojiya',
    'gf'  => "Gwiyana\ ya\ Wufalansa",
    'gg'  => 'Guernsey',
    'gh'  => 'Khana',
    'gi'  => 'Jibulalita',
    'gl'  => 'Gilinilandi',
    'gm'  => 'Gambiya',
    'gn'  => 'Gine',
    'gp'  => 'Gwadelupe',
    'gq'  => 'Ginekweta',
    'gr'  => 'Wugiliki',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatemala',
    'gu'  => 'Gwamu',
    'gw'  => 'Ginebisawu',
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hondulasi',
    'hr'  => 'Kolasiya',
    'ht'  => 'Hayiti',
    'hu'  => 'Hungaliya',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonesiya',
    'ie'  => 'Ayalandi',
    'il'  => 'Isilaeli',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Indiya',
    'io'  => "Uluvala\ lwa\ Uwingelesa\ ku\ Bahali\ ya\ Hindi",
    'iq'  => 'Ilaki',
    'ir'  => 'Uwajemi',
    'is'  => 'Ayisilendi',
    'it'  => 'Italiya',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Yolodani',
    'jp'  => 'Japani',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kiligisisitani',
    'kh'  => 'Kambodiya',
    'ki'  => 'Kilibati',
    'km'  => 'Komolo',
    'kn'  => "Santakitisi\ ni\ Nevisi",
    'kp'  => "Koleya\ ya\ luvala\ lwa\ Kunyamande",
    'kr'  => "Koleya\ ya\ Kusini",
    'kw'  => 'Kuwaiti',
    'ky'  => "Figunguli\ ifya\ Kayimayi",
    'kz'  => 'Kasakisitani',
    'la'  => 'Layosi',
    'lb'  => 'Lebanoni',
    'lc'  => 'Santalusiya',
    'li'  => 'Lisheniteni',
    'lk'  => 'Sililanka',
    'lr'  => 'Libeliya',
    'ls'  => 'Lesoto',
    'lt'  => 'Litwaniya',
    'lu'  => 'Lasembagi',
    'lv'  => 'Lativiya',
    'ly'  => 'Libiya',
    'ma'  => 'Moloko',
    'mc'  => 'Monako',
    'md'  => 'Molidova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Bukini',
    'mh'  => "Figunguli\ ifya\ Malishali",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedoniya',
    'ml'  => 'Mali',
    'mm'  => 'Muyama',
    'mn'  => 'Mongoliya',
    'mo'  => 'Macau',
    'mp'  => "Figunguli\ fya\ Maliyana\ ifya\ luvala\ lwa\ Kunyamande",
    'mq'  => 'Malitiniki',
    'mr'  => 'Molitaniya',
    'ms'  => 'Monitiselati',
    'mt'  => 'Malita',
    'mu'  => 'Molisi',
    'mv'  => 'Modivu',
    'mw'  => 'Malawi',
    'mx'  => 'Mekisiko',
    'my'  => 'Malesiya',
    'mz'  => 'Musumbiji',
    'na'  => 'Namibiya',
    'nc'  => 'Nyukaledoniya',
    'ne'  => 'Nijeli',
    'nf'  => "Shigunguli\ sha\ Nolifoki",
    'ng'  => 'Nijeliya',
    'ni'  => 'Nikalagwa',
    'nl'  => 'Wuholansi',
    'no'  => 'Nolwe',
    'np'  => 'Nepali',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nawulu',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niwue',
    'nz'  => 'Nyusilendi',
    'om'  => 'Omani',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Pelu',
    'pf'  => "Polinesiya\ ya\ Wufalansa",
    'pg'  => 'Papuwa',
    'ph'  => 'Filipino',
    'pk'  => 'Pakisitani',
    'pl'  => 'Polandi',
    'pm'  => "Santapieli\ ni\ Mikeloni",
    'pn'  => 'Pitikailini',
    'pr'  => 'Pwetoliko',
    'ps'  => "Munjema\ gwa\ Kusikha\ nu\ Luvala\ lwa\ Gasa\ lwa\ Palesit",
    'pt'  => 'Wuleno',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palawu',
    'py'  => 'Palagwayi',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katali',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Liyunioni',
    'ro'  => 'Lomaniya',
    'rs'  => 'Serbia',
    'ru'  => 'Wulusi',
    'rw'  => 'Lwanda',
    'sa'  => 'Sawudi',
    'sb'  => "Figunguli\ fya\ Solomoni",
    'sc'  => 'Shelisheli',
    'sd'  => 'Sudani',
    'se'  => 'Uswidi',
    'sg'  => 'Singapoo',
    'sh'  => 'Santahelena',
    'si'  => 'Siloveniya',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Silovakiya',
    'sl'  => "Siela\ Liyoni",
    'sm'  => 'Samalino',
    'sn'  => 'Senegali',
    'so'  => 'Somaliya',
    'sr'  => 'Sulinamu',
    'st'  => "Sayo\ Tome\ ni\ Pilinikipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Elisavado',
    'sy'  => 'Siliya',
    'sz'  => 'Uswasi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Figunguli\ fya\ Tuliki\ ni\ Kaiko",
    'td'  => 'Shadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Tailandi',
    'tj'  => 'Tajikisitani',
    'tk'  => 'Tokelawu',
    'tl'  => "Timoli\ ya\ kunena",
    'tm'  => 'Tulukimenisitani',
    'tn'  => 'Tunisiya',
    'to'  => 'Tonga',
    'tr'  => 'Utuluki',
    'tt'  => "Tilinidadi\ ni\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwani',
    'tz'  => 'Tansaniya',
    'ua'  => 'Yukileini',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Malekani',
    'uy'  => 'Ulugwayi',
    'uz'  => 'Usibekisitani',
    'va'  => 'Vatikani',
    'vc'  => "Santavisenti\ na\ Gilenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Venesuela',
    'vg'  => "Figunguli\ ifya\ Viliginiya\ ifya\ Uwingelesa",
    'vi'  => "Figunguli\ fya\ Viliginiya\ ifya\ Malekani",
    'vn'  => 'Vietinamu',
    'vu'  => 'Vanuatu',
    'wf'  => "Walisi\ ni\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoya',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemeni',
    'yt'  => 'Mayote',
    'za'  => "Afilika\ Kusini",
    'zm'  => 'Sambiya',
    'zw'  => 'Simbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::sbp::name_to_code = (
    'afilikakusini'                               => 'za',
    'africa'                                      => '002',
    'afuganisitani'                               => 'af',
    'ajentina'                                    => 'ar',
    'alijeliya'                                   => 'dz',
    'alimeniya'                                   => 'am',
    'aluba'                                       => 'aw',
    'alubaniya'                                   => 'al',
    'americas'                                    => '019',
    'andola'                                      => 'ad',
    'angola'                                      => 'ao',
    'anguilla'                                    => 'ai',
    'anitiguyanibalubuda'                         => 'ag',
    'anitilisauholansi'                           => 'an',
    'antarctica'                                  => 'aq',
    'asabajani'                                   => 'az',
    'ascensionisland'                             => 'ac',
    'asia'                                        => 142,
    'australiaandnewzealand'                      => '053',
    'awusitilaliya'                               => 'au',
    'awusitiliya'                                 => 'at',
    'ayalandi'                                    => 'ie',
    'ayisilendi'                                  => 'is',
    'babadosi'                                    => 'bb',
    'bahaleni'                                    => 'bh',
    'bahama'                                      => 'bs',
    'bangiladeshi'                                => 'bd',
    'belalusi'                                    => 'by',
    'belimuda'                                    => 'bm',
    'belise'                                      => 'bz',
    'benini'                                      => 'bj',
    'boliviya'                                    => 'bo',
    'bosiniyanihesegovina'                        => 'ba',
    'botiswana'                                   => 'bw',
    'bouvetisland'                                => 'bv',
    'britishantarcticterritory'                   => 'bq',
    'bukinafaso'                                  => 'bf',
    'bukini'                                      => 'mg',
    'bulasili'                                    => 'br',
    'buligaliya'                                  => 'bg',
    'bulundi'                                     => 'bi',
    'buluneyi'                                    => 'bn',
    'butani'                                      => 'bt',
    'canaryislands'                               => 'ic',
    'cantonandenderburyislands'                   => 'ct',
    'caribbean'                                   => '029',
    'centralamerica'                              => '013',
    'centralasia'                                 => 143,
    'ceutaandmelilla'                             => 'ea',
    'channelislands'                              => 830,
    'christmasisland'                             => 'cx',
    'clippertonisland'                            => 'cp',
    'cocoskeelingislands'                         => 'cc',
    'commonwealthofindependentstates'             => 172,
    'czechoslovakia'                              => 200,
    'denimaki'                                    => 'dk',
    'diegogarcia'                                 => 'dg',
    'dominika'                                    => 'dm',
    'dronningmaudland'                            => 'nq',
    'easternafrica'                               => '014',
    'easternasia'                                 => '030',
    'easterneurope'                               => 151,
    'eastgermany'                                 => 'dd',
    'ekwado'                                      => 'ec',
    'elisavado'                                   => 'sv',
    'elitileya'                                   => 'er',
    'esitoniya'                                   => 'ee',
    'europe'                                      => 150,
    'europeanunion'                               => 'eu',
    'faroeislands'                                => 'fo',
    'figungulifyafokolendi'                       => 'fk',
    'figungulifyakooki'                           => 'ck',
    'figungulifyamaliyanaifyaluvalalwakunyamande' => 'mp',
    'figungulifyasolomoni'                        => 'sb',
    'figungulifyatulikinikaiko'                   => 'tc',
    'figungulifyaviliginiyaifyamalekani'          => 'vi',
    'figunguliifyakayimayi'                       => 'ky',
    'figunguliifyamalishali'                      => 'mh',
    'figunguliifyaviliginiyaifyauwingelesa'       => 'vg',
    'fiji'                                        => 'fj',
    'filipino'                                    => 'ph',
    'frenchsouthernandantarcticterritories'       => 'fq',
    'frenchsouthernterritories'                   => 'tf',
    'gaboni'                                      => 'ga',
    'gambiya'                                     => 'gm',
    'gilenada'                                    => 'gd',
    'gilinilandi'                                 => 'gl',
    'gine'                                        => 'gn',
    'ginebisawu'                                  => 'gw',
    'ginekweta'                                   => 'gq',
    'guernsey'                                    => 'gg',
    'guyana'                                      => 'gy',
    'gwadelupe'                                   => 'gp',
    'gwamu'                                       => 'gu',
    'gwatemala'                                   => 'gt',
    'gwiyanayawufalansa'                          => 'gf',
    'hayiti'                                      => 'ht',
    'heardislandandmcdonaldislands'               => 'hm',
    'hisipaniya'                                  => 'es',
    'hondulasi'                                   => 'hn',
    'hongkong'                                    => 'hk',
    'hungaliya'                                   => 'hu',
    'ilaki'                                       => 'iq',
    'indiya'                                      => 'in',
    'indonesiya'                                  => 'id',
    'isilaeli'                                    => 'il',
    'isleofman'                                   => 'im',
    'italiya'                                     => 'it',
    'jamaika'                                     => 'jm',
    'jamuhuliyaafilikayapakhati'                  => 'cf',
    'jamuhuliyadominika'                          => 'do',
    'jamuhuliyakidemokilasiyayakongo'             => 'cd',
    'jamuhuliyasheki'                             => 'cz',
    'japani'                                      => 'jp',
    'jersey'                                      => 'je',
    'jibulalita'                                  => 'gi',
    'jibuti'                                      => 'dj',
    'johnstonisland'                              => 'jt',
    'jojiya'                                      => 'ge',
    'kambodiya'                                   => 'kh',
    'kameruni'                                    => 'cm',
    'kanada'                                      => 'ca',
    'kasakisitani'                                => 'kz',
    'katali'                                      => 'qa',
    'kenya'                                       => 'ke',
    'kepuvede'                                    => 'cv',
    'khana'                                       => 'gh',
    'kilibati'                                    => 'ki',
    'kiligisisitani'                              => 'kg',
    'kodivaya'                                    => 'ci',
    'kolasiya'                                    => 'hr',
    'koleyayakusini'                              => 'kr',
    'koleyayaluvalalwakunyamande'                 => 'kp',
    'kolombiya'                                   => 'co',
    'komolo'                                      => 'km',
    'kongo'                                       => 'cg',
    'kositalika'                                  => 'cr',
    'kuba'                                        => 'cu',
    'kupilosi'                                    => 'cy',
    'kuwaiti'                                     => 'kw',
    'lasembagi'                                   => 'lu',
    'latinamerica'                                => 419,
    'lativiya'                                    => 'lv',
    'layosi'                                      => 'la',
    'lebanoni'                                    => 'lb',
    'lesoto'                                      => 'ls',
    'libeliya'                                    => 'lr',
    'libiya'                                      => 'ly',
    'lisheniteni'                                 => 'li',
    'litwaniya'                                   => 'lt',
    'liyunioni'                                   => 're',
    'lomaniya'                                    => 'ro',
    'lwanda'                                      => 'rw',
    'macau'                                       => 'mo',
    'malawi'                                      => 'mw',
    'malekani'                                    => 'us',
    'malesiya'                                    => 'my',
    'mali'                                        => 'ml',
    'malita'                                      => 'mt',
    'malitiniki'                                  => 'mq',
    'masedoniya'                                  => 'mk',
    'mayote'                                      => 'yt',
    'mekisiko'                                    => 'mx',
    'melanesia'                                   => '054',
    'metropolitanfrance'                          => 'fx',
    'micronesianregion'                           => '057',
    'middleafrica'                                => '017',
    'midwayislands'                               => 'mi',
    'mikilonesiya'                                => 'fm',
    'misili'                                      => 'eg',
    'modivu'                                      => 'mv',
    'molidova'                                    => 'md',
    'molisi'                                      => 'mu',
    'molitaniya'                                  => 'mr',
    'moloko'                                      => 'ma',
    'monako'                                      => 'mc',
    'mongoliya'                                   => 'mn',
    'monitiselati'                                => 'ms',
    'montenegro'                                  => 'me',
    'munjemagwakusikhanuluvalalwagasalwapalesit'  => 'ps',
    'musumbiji'                                   => 'mz',
    'muyama'                                      => 'mm',
    'namibiya'                                    => 'na',
    'nawulu'                                      => 'nr',
    'nepali'                                      => 'np',
    'neutralzone'                                 => 'nt',
    'nijeli'                                      => 'ne',
    'nijeliya'                                    => 'ng',
    'nikalagwa'                                   => 'ni',
    'niwue'                                       => 'nu',
    'nolwe'                                       => 'no',
    'northamerica'                                => '003',
    'northernafrica'                              => '015',
    'northernamerica'                             => '021',
    'northerneurope'                              => 154,
    'northvietnam'                                => 'vd',
    'nyukaledoniya'                               => 'nc',
    'nyusilendi'                                  => 'nz',
    'oceania'                                     => '009',
    'omani'                                       => 'om',
    'outlyingoceania'                             => 'qo',
    'pacificislandstrustterritory'                => 'pc',
    'pakisitani'                                  => 'pk',
    'palagwayi'                                   => 'py',
    'palawu'                                      => 'pw',
    'panama'                                      => 'pa',
    'panamacanalzone'                             => 'pz',
    'papuwa'                                      => 'pg',
    'pelu'                                        => 'pe',
    "people\â\\sdemocraticrepublicofyemen"   => 'yd',
    'pitikailini'                                 => 'pn',
    'polandi'                                     => 'pl',
    'polinesiyayawufalansa'                       => 'pf',
    'polynesia'                                   => '061',
    'pwetoliko'                                   => 'pr',
    "saintbarth\Ã\©lemy"                        => 'bl',
    'saintmartin'                                 => 'mf',
    'samalino'                                    => 'sm',
    'sambiya'                                     => 'zm',
    'samoya'                                      => 'ws',
    'samoyayamalekani'                            => 'as',
    'santahelena'                                 => 'sh',
    'santakitisininevisi'                         => 'kn',
    'santalusiya'                                 => 'lc',
    'santapielinimikeloni'                        => 'pm',
    'santavisentinagilenadini'                    => 'vc',
    'sawudi'                                      => 'sa',
    'sayotomenipilinikipe'                        => 'st',
    'selibiyanimontenegilo'                       => 'cs',
    'senegali'                                    => 'sn',
    'serbia'                                      => 'rs',
    'shadi'                                       => 'td',
    'shelisheli'                                  => 'sc',
    'shigungulishanolifoki'                       => 'nf',
    'shile'                                       => 'cl',
    'shina'                                       => 'cn',
    'sielaliyoni'                                 => 'sl',
    'sililanka'                                   => 'lk',
    'siliya'                                      => 'sy',
    'silovakiya'                                  => 'sk',
    'siloveniya'                                  => 'si',
    'simbabwe'                                    => 'zw',
    'singapoo'                                    => 'sg',
    'somaliya'                                    => 'so',
    'southamerica'                                => '005',
    'southcentralasia'                            => '062',
    'southeasternasia'                            => '035',
    'southernafrica'                              => '018',
    'southernasia'                                => '034',
    'southerneurope'                              => '039',
    'southgeorgiaandthesouthsandwichislands'      => 'gs',
    'sudani'                                      => 'sd',
    'sulinamu'                                    => 'sr',
    'svalbardandjanmayen'                         => 'sj',
    'tailandi'                                    => 'th',
    'taiwani'                                     => 'tw',
    'tajikisitani'                                => 'tj',
    'tansaniya'                                   => 'tz',
    'tilinidadinitobago'                          => 'tt',
    'timoliyakunena'                              => 'tl',
    'togo'                                        => 'tg',
    'tokelawu'                                    => 'tk',
    'tonga'                                       => 'to',
    'tristandacunha'                              => 'ta',
    'tulukimenisitani'                            => 'tm',
    'tunisiya'                                    => 'tn',
    'tuvalu'                                      => 'tv',
    "u\.s\.minoroutlyingislands"                  => 'um',
    "u\.s\.miscellaneouspacificislands"           => 'pu',
    'ubeligiji'                                   => 'be',
    'uganda'                                      => 'ug',
    'uhabeshi'                                    => 'et',
    'ulugwayi'                                    => 'uy',
    'uluvalalwauwingelesakubahaliyahindi'         => 'io',
    'unionofsovietsocialistrepublics'             => 'su',
    'unknownregion'                               => 'zz',
    'usibekisitani'                               => 'uz',
    'uswasi'                                      => 'sz',
    'uswidi'                                      => 'se',
    'uswisi'                                      => 'ch',
    'utuluki'                                     => 'tr',
    'uwajemi'                                     => 'ir',
    'uwingelesa'                                  => 'gb',
    'vanuatu'                                     => 'vu',
    'vatikani'                                    => 'va',
    'venesuela'                                   => 've',
    'vietinamu'                                   => 'vn',
    'wakeisland'                                  => 'wk',
    'walisinifutuna'                              => 'wf',
    'westernafrica'                               => '011',
    'westernasia'                                 => 145,
    'westerneurope'                               => 155,
    'westernsahara'                               => 'eh',
    'world'                                       => '001',
    'wufalansa'                                   => 'fr',
    'wufini'                                      => 'fi',
    'wugiliki'                                    => 'gr',
    'wuholansi'                                   => 'nl',
    'wujelumani'                                  => 'de',
    'wuleno'                                      => 'pt',
    'wulusi'                                      => 'ru',
    'wutwawashiyalabu'                            => 'ae',
    'yemeni'                                      => 'ye',
    'yolodani'                                    => 'jo',
    'yukileini'                                   => 'ua',
    "\Ã\landislands"                           => 'ax',
);

1;

