{"delimiters":{"quotation_start":"“","quotation_end":"”","alternate_quotation_start":"‘","alternate_quotation_end":"’"},"orientation":{"lines":"top-to-bottom","characters":"right-to-left"},"posix":{"nostr":"لا:ل","yesstr":"نعم:ن"},"plural_forms":{"category_list":["one","two","few","many","zero","other"],"category_rules_function":null,"category_rules":{"one":"n is 1","few":"n mod 100 in 3..10","zero":"n is 0","two":"n is 2","many":"n mod 100 in 11..99"},"category_rules_compiled":{"one":function (n) {if ( (( n == 1))) { return 'one'; } return;},"few":function (n) {if ( (( parseInt(n) == n && (n % 100) >= 3 && (n % 100) <= 10 ))) { return 'few'; } return;},"zero":function (n) {if ( (( n == 0))) { return 'zero'; } return;},"two":function (n) {if ( (( n == 2))) { return 'two'; } return;},"many":function (n) {if ( (( parseInt(n) == n && (n % 100) >= 11 && (n % 100) <= 99 ))) { return 'many'; } return;}}},"cldr_formats":{"territory":"المنطقة: {0}","_decimal_format_decimal":"٫","language":"اللغة: {0}","percent":"#,##0%","locale":"{0} ({1})","_decimal_format_group":"٬","_percent_format_percent":"٪","decimal":"#,##0.###;#,##0.###-","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}، {1}","2":"{0} و {1}","start":"{0}، {1}","end":"{0}، و {1}"}},"fallback":[],"characters":{"more_information":"?"}}