package Locales::DB::Territory::de_ch;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::de_ch::VERSION = '0.09';

$Locales::DB::Territory::de_ch::cldr_version = '2.0';

%Locales::DB::Territory::de_ch::code_to_name = (
    '001' => 'Welt',
    '002' => 'Afrika',
    '003' => 'Nordamerika',
    '005' => 'Südamerika',
    '009' => 'Ozeanien',
    '011' => 'Westafrika',
    '013' => 'Mittelamerika',
    '014' => 'Ostafrika',
    '015' => 'Nordafrika',
    '017' => 'Zentralafrika',
    '018' => "Südliches\ Afrika",
    '019' => 'Amerika',
    '021' => "Nördliches\ Amerika",
    '029' => 'Karibik',
    '030' => 'Ostasien',
    '034' => 'Südasien',
    '035' => 'Südostasien',
    '039' => 'Südeuropa',
    '053' => "Australien\ und\ Neuseeland",
    '054' => 'Melanesien',
    '057' => "Mikronesisches\ Inselgebiet",
    '061' => 'Polynesien',
    '062' => "Süd\-Zentralasien",
    142   => 'Asien',
    143   => 'Zentralasien',
    145   => 'Westasien',
    150   => 'Europa',
    151   => 'Osteuropa',
    154   => 'Nordeuropa',
    155   => 'Westeuropa',
    172   => "Gemeinschaft\ Unabhängiger\ Staaten",
    200   => 'Czechoslovakia',
    419   => 'Lateinamerika',
    830   => 'Kanalinseln',
    'ac'  => 'Ascension',
    'ad'  => 'Andorra',
    'ae'  => "Vereinigte\ Arabische\ Emirate",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ und\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albanien',
    'am'  => 'Armenien',
    'an'  => "Niederländische\ Antillen",
    'ao'  => 'Angola',
    'aq'  => 'Antarktis',
    'ar'  => 'Argentinien',
    'as'  => "Amerikanisch\-Samoa",
    'at'  => 'Österreich',
    'au'  => 'Australien',
    'aw'  => 'Aruba',
    'ax'  => 'Alandinseln',
    'az'  => 'Aserbaidschan',
    'ba'  => "Bosnien\ und\ Herzegowina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgien',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgarien',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "St\.\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivien',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasilien',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhutan',
    'bv'  => 'Bouvetinsel',
    'bw'  => 'Botswana',
    'by'  => 'Weissrussland',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => 'Kokosinseln',
    'cd'  => "Kongo\ \[Demokratische\ Republik\]",
    'cf'  => "Zentralafrikanische\ Republik",
    'cg'  => "Kongo\ \[Republik\]",
    'ch'  => 'Schweiz',
    'ci'  => 'Elfenbeinküste',
    'ck'  => 'Cookinseln',
    'cl'  => 'Chile',
    'cm'  => 'Kamerun',
    'cn'  => 'China',
    'co'  => 'Kolumbien',
    'cp'  => "Clipperton\-Insel",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbien\ und\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => 'Kapverden',
    'cx'  => 'Weihnachtsinsel',
    'cy'  => 'Zypern',
    'cz'  => "Tschechische\ Republik",
    'dd'  => "East\ Germany",
    'de'  => 'Deutschland',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Dänemark',
    'dm'  => 'Dominica',
    'do'  => "Dominikanische\ Republik",
    'dz'  => 'Algerien',
    'ea'  => "Ceuta\ und\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estland',
    'eg'  => 'Ägypten',
    'eh'  => 'Westsahara',
    'er'  => 'Eritrea',
    'es'  => 'Spanien',
    'et'  => 'Äthiopien',
    'eu'  => "Europäische\ Union",
    'fi'  => 'Finnland',
    'fj'  => 'Fidschi',
    'fk'  => 'Falklandinseln',
    'fm'  => 'Mikronesien',
    'fo'  => 'Färöer',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frankreich',
    'fx'  => "Metropolitan\-Frankreich",
    'ga'  => 'Gabun',
    'gb'  => 'Grossbritannien',
    'gd'  => 'Grenada',
    'ge'  => 'Georgien',
    'gf'  => "Französisch\-Guayana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grönland',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => 'Äquatorialguinea',
    'gr'  => 'Griechenland',
    'gs'  => "Südgeorgien\ und\ die\ Südlichen\ Sandwichinseln",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\-\ und\ McDonald\-Inseln",
    'hn'  => 'Honduras',
    'hr'  => 'Kroatien',
    'ht'  => 'Haiti',
    'hu'  => 'Ungarn',
    'ic'  => "Kanarische\ Inseln",
    'id'  => 'Indonesien',
    'ie'  => 'Irland',
    'il'  => 'Israel',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Indien',
    'io'  => "Britisches\ Territorium\ im\ Indischen\ Ozean",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Italien',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordanien',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirgisistan',
    'kh'  => 'Kambodscha',
    'ki'  => 'Kiribati',
    'km'  => 'Komoren',
    'kn'  => "St\.\ Kitts\ und\ Nevis",
    'kp'  => "Demokratische\ Volksrepublik\ Korea",
    'kr'  => "Republik\ Korea",
    'kw'  => 'Kuwait',
    'ky'  => 'Kaimaninseln',
    'kz'  => 'Kasachstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "St\.\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Litauen',
    'lu'  => 'Luxemburg',
    'lv'  => 'Lettland',
    'ly'  => 'Libyen',
    'ma'  => 'Marokko',
    'mc'  => 'Monaco',
    'md'  => "Republik\ Moldau",
    'me'  => 'Montenegro',
    'mf'  => "St\.\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Marshall\-Inseln",
    'mi'  => "Midway\ Islands",
    'mk'  => "Mazedonien\ \[EJR\]",
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongolei',
    'mo'  => 'Macao',
    'mp'  => "Nördliche\ Marianen",
    'mq'  => 'Martinique',
    'mr'  => 'Mauretanien',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Malediven',
    'mw'  => 'Malawi',
    'mx'  => 'Mexiko',
    'my'  => 'Malaysia',
    'mz'  => 'Mosambik',
    'na'  => 'Namibia',
    'nc'  => 'Neukaledonien',
    'ne'  => 'Niger',
    'nf'  => 'Norfolkinsel',
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Niederlande',
    'no'  => 'Norwegen',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => 'Neuseeland',
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Französisch\-Polynesien",
    'pg'  => "Papua\-Neuguinea",
    'ph'  => 'Philippinen',
    'pk'  => 'Pakistan',
    'pl'  => 'Polen',
    'pm'  => "St\.\ Pierre\ und\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Palästinensische\ Autonomiegebiete",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Äusseres\ Ozeanien",
    're'  => 'Réunion',
    'ro'  => 'Rumänien',
    'rs'  => 'Serbien',
    'ru'  => "Russische\ Föderation",
    'rw'  => 'Rwanda',
    'sa'  => "Saudi\-Arabien",
    'sb'  => "Salomon\-Inseln",
    'sc'  => 'Seychellen',
    'sd'  => 'Sudan',
    'se'  => 'Schweden',
    'sg'  => 'Singapur',
    'sh'  => "St\.\ Helena",
    'si'  => 'Slowenien',
    'sj'  => "Svalbard\ und\ Jan\ Mayen",
    'sk'  => 'Slowakei',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Suriname',
    'st'  => "Sao\ Tomé\ und\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Syrien',
    'sz'  => 'Swasiland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\-\ und\ Caicosinseln",
    'td'  => 'Tschad',
    'tf'  => "Französische\ Süd\-\ und\ Antarktisgebiete",
    'tg'  => 'Togo',
    'th'  => 'Thailand',
    'tj'  => 'Tadschikistan',
    'tk'  => 'Tokelau',
    'tl'  => 'Osttimor',
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunesien',
    'to'  => 'Tonga',
    'tr'  => 'Türkei',
    'tt'  => "Trinidad\ und\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tansania',
    'ua'  => 'Ukraine',
    'ug'  => 'Uganda',
    'um'  => "Amerikanisch\-Ozeanien",
    'us'  => "Vereinigte\ Staaten",
    'uy'  => 'Uruguay',
    'uz'  => 'Usbekistan',
    'va'  => 'Vatikanstadt',
    'vc'  => "St\.\ Vincent\ und\ die\ Grenadinen",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Britische\ Jungferninseln",
    'vi'  => "Amerikanische\ Jungferninseln",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ und\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => 'Südafrika',
    'zm'  => 'Sambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unbekannte\ Region",
);

%Locales::DB::Territory::de_ch::name_to_code = (
    'afghanistan'                                => 'af',
    'afrika'                                     => '002',
    'alandinseln'                                => 'ax',
    'albanien'                                   => 'al',
    'algerien'                                   => 'dz',
    'amerika'                                    => '019',
    'amerikanischejungferninseln'                => 'vi',
    'amerikanischozeanien'                       => 'um',
    'amerikanischsamoa'                          => 'as',
    'andorra'                                    => 'ad',
    'angola'                                     => 'ao',
    'anguilla'                                   => 'ai',
    'antarktis'                                  => 'aq',
    'antiguaundbarbuda'                          => 'ag',
    'argentinien'                                => 'ar',
    'armenien'                                   => 'am',
    'aruba'                                      => 'aw',
    'ascension'                                  => 'ac',
    'aserbaidschan'                              => 'az',
    'asien'                                      => 142,
    'australien'                                 => 'au',
    'australienundneuseeland'                    => '053',
    'bahamas'                                    => 'bs',
    'bahrain'                                    => 'bh',
    'bangladesh'                                 => 'bd',
    'barbados'                                   => 'bb',
    'belgien'                                    => 'be',
    'belize'                                     => 'bz',
    'benin'                                      => 'bj',
    'bermuda'                                    => 'bm',
    'bhutan'                                     => 'bt',
    'bolivien'                                   => 'bo',
    'bosnienundherzegowina'                      => 'ba',
    'botswana'                                   => 'bw',
    'bouvetinsel'                                => 'bv',
    'brasilien'                                  => 'br',
    'britischejungferninseln'                    => 'vg',
    'britischesterritoriumimindischenozean'      => 'io',
    'britishantarcticterritory'                  => 'bq',
    'brunei'                                     => 'bn',
    'bulgarien'                                  => 'bg',
    'burkinafaso'                                => 'bf',
    'burundi'                                    => 'bi',
    'cantonandenderburyislands'                  => 'ct',
    'ceutaundmelilla'                            => 'ea',
    'chile'                                      => 'cl',
    'china'                                      => 'cn',
    'clippertoninsel'                            => 'cp',
    'cookinseln'                                 => 'ck',
    'costarica'                                  => 'cr',
    'czechoslovakia'                             => 200,
    'demokratischevolksrepublikkorea'            => 'kp',
    'deutschland'                                => 'de',
    'diegogarcia'                                => 'dg',
    'djibouti'                                   => 'dj',
    'dominica'                                   => 'dm',
    'dominikanischerepublik'                     => 'do',
    'dronningmaudland'                           => 'nq',
    'dänemark'                                  => 'dk',
    'eastgermany'                                => 'dd',
    'ecuador'                                    => 'ec',
    'elfenbeinküste'                            => 'ci',
    'elsalvador'                                 => 'sv',
    'eritrea'                                    => 'er',
    'estland'                                    => 'ee',
    'europa'                                     => 150,
    'europäischeunion'                          => 'eu',
    'falklandinseln'                             => 'fk',
    'fidschi'                                    => 'fj',
    'finnland'                                   => 'fi',
    'frankreich'                                 => 'fr',
    'französischesüdundantarktisgebiete'       => 'tf',
    'französischguayana'                        => 'gf',
    'französischpolynesien'                     => 'pf',
    'frenchsouthernandantarcticterritories'      => 'fq',
    'färöer'                                   => 'fo',
    'gabun'                                      => 'ga',
    'gambia'                                     => 'gm',
    'gemeinschaftunabhängigerstaaten'           => 172,
    'georgien'                                   => 'ge',
    'ghana'                                      => 'gh',
    'gibraltar'                                  => 'gi',
    'grenada'                                    => 'gd',
    'griechenland'                               => 'gr',
    'grossbritannien'                            => 'gb',
    'grönland'                                  => 'gl',
    'guadeloupe'                                 => 'gp',
    'guam'                                       => 'gu',
    'guatemala'                                  => 'gt',
    'guernsey'                                   => 'gg',
    'guinea'                                     => 'gn',
    'guineabissau'                               => 'gw',
    'guyana'                                     => 'gy',
    'haiti'                                      => 'ht',
    'heardundmcdonaldinseln'                     => 'hm',
    'honduras'                                   => 'hn',
    'hongkong'                                   => 'hk',
    'indien'                                     => 'in',
    'indonesien'                                 => 'id',
    'irak'                                       => 'iq',
    'iran'                                       => 'ir',
    'irland'                                     => 'ie',
    'island'                                     => 'is',
    'isleofman'                                  => 'im',
    'israel'                                     => 'il',
    'italien'                                    => 'it',
    'jamaika'                                    => 'jm',
    'japan'                                      => 'jp',
    'jemen'                                      => 'ye',
    'jersey'                                     => 'je',
    'johnstonisland'                             => 'jt',
    'jordanien'                                  => 'jo',
    'kaimaninseln'                               => 'ky',
    'kambodscha'                                 => 'kh',
    'kamerun'                                    => 'cm',
    'kanada'                                     => 'ca',
    'kanalinseln'                                => 830,
    'kanarischeinseln'                           => 'ic',
    'kapverden'                                  => 'cv',
    'karibik'                                    => '029',
    'kasachstan'                                 => 'kz',
    'katar'                                      => 'qa',
    'kenia'                                      => 'ke',
    'kirgisistan'                                => 'kg',
    'kiribati'                                   => 'ki',
    'kokosinseln'                                => 'cc',
    'kolumbien'                                  => 'co',
    'komoren'                                    => 'km',
    'kongodemokratischerepublik'                 => 'cd',
    'kongorepublik'                              => 'cg',
    'kroatien'                                   => 'hr',
    'kuba'                                       => 'cu',
    'kuwait'                                     => 'kw',
    'laos'                                       => 'la',
    'lateinamerika'                              => 419,
    'lesotho'                                    => 'ls',
    'lettland'                                   => 'lv',
    'libanon'                                    => 'lb',
    'liberia'                                    => 'lr',
    'libyen'                                     => 'ly',
    'liechtenstein'                              => 'li',
    'litauen'                                    => 'lt',
    'luxemburg'                                  => 'lu',
    'macao'                                      => 'mo',
    'madagaskar'                                 => 'mg',
    'malawi'                                     => 'mw',
    'malaysia'                                   => 'my',
    'malediven'                                  => 'mv',
    'mali'                                       => 'ml',
    'malta'                                      => 'mt',
    'marokko'                                    => 'ma',
    'marshallinseln'                             => 'mh',
    'martinique'                                 => 'mq',
    'mauretanien'                                => 'mr',
    'mauritius'                                  => 'mu',
    'mayotte'                                    => 'yt',
    'mazedonienejr'                              => 'mk',
    'melanesien'                                 => '054',
    'metropolitanfrankreich'                     => 'fx',
    'mexiko'                                     => 'mx',
    'midwayislands'                              => 'mi',
    'mikronesien'                                => 'fm',
    'mikronesischesinselgebiet'                  => '057',
    'mittelamerika'                              => '013',
    'monaco'                                     => 'mc',
    'mongolei'                                   => 'mn',
    'montenegro'                                 => 'me',
    'montserrat'                                 => 'ms',
    'mosambik'                                   => 'mz',
    'myanmar'                                    => 'mm',
    'namibia'                                    => 'na',
    'nauru'                                      => 'nr',
    'nepal'                                      => 'np',
    'neukaledonien'                              => 'nc',
    'neuseeland'                                 => 'nz',
    'neutralzone'                                => 'nt',
    'nicaragua'                                  => 'ni',
    'niederlande'                                => 'nl',
    'niederländischeantillen'                   => 'an',
    'niger'                                      => 'ne',
    'nigeria'                                    => 'ng',
    'niue'                                       => 'nu',
    'nordafrika'                                 => '015',
    'nordamerika'                                => '003',
    'nordeuropa'                                 => 154,
    'norfolkinsel'                               => 'nf',
    'northvietnam'                               => 'vd',
    'norwegen'                                   => 'no',
    'nördlichemarianen'                         => 'mp',
    'nördlichesamerika'                         => '021',
    'oman'                                       => 'om',
    'ostafrika'                                  => '014',
    'ostasien'                                   => '030',
    'osteuropa'                                  => 151,
    'osttimor'                                   => 'tl',
    'ozeanien'                                   => '009',
    'pacificislandstrustterritory'               => 'pc',
    'pakistan'                                   => 'pk',
    'palau'                                      => 'pw',
    'palästinensischeautonomiegebiete'          => 'ps',
    'panama'                                     => 'pa',
    'panamacanalzone'                            => 'pz',
    'papuaneuguinea'                             => 'pg',
    'paraguay'                                   => 'py',
    "people\â\\sdemocraticrepublicofyemen"  => 'yd',
    'peru'                                       => 'pe',
    'philippinen'                                => 'ph',
    'pitcairn'                                   => 'pn',
    'polen'                                      => 'pl',
    'polynesien'                                 => '061',
    'portugal'                                   => 'pt',
    'puertorico'                                 => 'pr',
    'republikkorea'                              => 'kr',
    'republikmoldau'                             => 'md',
    'rumänien'                                  => 'ro',
    'russischeföderation'                       => 'ru',
    'rwanda'                                     => 'rw',
    'réunion'                                   => 're',
    'salomoninseln'                              => 'sb',
    'sambia'                                     => 'zm',
    'samoa'                                      => 'ws',
    'sanmarino'                                  => 'sm',
    'saotoméundprincipe'                        => 'st',
    'saudiarabien'                               => 'sa',
    'schweden'                                   => 'se',
    'schweiz'                                    => 'ch',
    'senegal'                                    => 'sn',
    'serbien'                                    => 'rs',
    'serbienundmontenegro'                       => 'cs',
    'seychellen'                                 => 'sc',
    'sierraleone'                                => 'sl',
    'singapur'                                   => 'sg',
    'slowakei'                                   => 'sk',
    'slowenien'                                  => 'si',
    'somalia'                                    => 'so',
    'spanien'                                    => 'es',
    'srilanka'                                   => 'lk',
    "st\.barthélemy"                            => 'bl',
    "st\.helena"                                 => 'sh',
    "st\.kittsundnevis"                          => 'kn',
    "st\.lucia"                                  => 'lc',
    "st\.martin"                                 => 'mf',
    "st\.pierreundmiquelon"                      => 'pm',
    "st\.vincentunddiegrenadinen"                => 'vc',
    'sudan'                                      => 'sd',
    'suriname'                                   => 'sr',
    'svalbardundjanmayen'                        => 'sj',
    'swasiland'                                  => 'sz',
    'syrien'                                     => 'sy',
    'südafrika'                                 => 'za',
    'südamerika'                                => '005',
    'südasien'                                  => '034',
    'südeuropa'                                 => '039',
    'südgeorgienunddiesüdlichensandwichinseln' => 'gs',
    'südlichesafrika'                           => '018',
    'südostasien'                               => '035',
    'südzentralasien'                           => '062',
    'tadschikistan'                              => 'tj',
    'taiwan'                                     => 'tw',
    'tansania'                                   => 'tz',
    'thailand'                                   => 'th',
    'togo'                                       => 'tg',
    'tokelau'                                    => 'tk',
    'tonga'                                      => 'to',
    'trinidadundtobago'                          => 'tt',
    'tristandacunha'                             => 'ta',
    'tschad'                                     => 'td',
    'tschechischerepublik'                       => 'cz',
    'tunesien'                                   => 'tn',
    'turkmenistan'                               => 'tm',
    'turksundcaicosinseln'                       => 'tc',
    'tuvalu'                                     => 'tv',
    'türkei'                                    => 'tr',
    "u\.s\.miscellaneouspacificislands"          => 'pu',
    'uganda'                                     => 'ug',
    'ukraine'                                    => 'ua',
    'unbekannteregion'                           => 'zz',
    'ungarn'                                     => 'hu',
    'unionofsovietsocialistrepublics'            => 'su',
    'uruguay'                                    => 'uy',
    'usbekistan'                                 => 'uz',
    'vanuatu'                                    => 'vu',
    'vatikanstadt'                               => 'va',
    'venezuela'                                  => 've',
    'vereinigtearabischeemirate'                 => 'ae',
    'vereinigtestaaten'                          => 'us',
    'vietnam'                                    => 'vn',
    'wakeisland'                                 => 'wk',
    'wallisundfutuna'                            => 'wf',
    'weihnachtsinsel'                            => 'cx',
    'weissrussland'                              => 'by',
    'welt'                                       => '001',
    'westafrika'                                 => '011',
    'westasien'                                  => 145,
    'westeuropa'                                 => 155,
    'westsahara'                                 => 'eh',
    'zentralafrika'                              => '017',
    'zentralafrikanischerepublik'                => 'cf',
    'zentralasien'                               => 143,
    'zimbabwe'                                   => 'zw',
    'zypern'                                     => 'cy',
    'Ägypten'                                   => 'eg',
    'Äquatorialguinea'                          => 'gq',
    'Äthiopien'                                 => 'et',
    'Äusseresozeanien'                          => 'qo',
    'Österreich'                                => 'at',
);

1;

