{"delimiters":{"quotation_start":"“","quotation_end":"”","alternate_quotation_start":"‘","alternate_quotation_end":"’"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":"le:l","yesstr":"iva:i"},"plural_forms":{"category_list":["one","few","many","other"],"category_rules_function":null,"category_rules":{"one":"n is 1","few":"n is 0 or n mod 100 in 2..10","many":"n mod 100 in 11..19"},"category_rules_compiled":{"one":function (n) {if ( (( n == 1))) { return 'one'; } return;},"few":function (n) {if ( (( n == 0)) ||  (( parseInt(n) == n && (n % 100) >= 2 && (n % 100) <= 10 ))) { return 'few'; } return;},"many":function (n) {if ( (( parseInt(n) == n && (n % 100) >= 11 && (n % 100) <= 19 ))) { return 'many'; } return;}}},"cldr_formats":{"territory":"Reġjun: {0}","_decimal_format_decimal":".","language":"Lingwa: {0}","percent":"#,##0%","locale":"{0} ({1})","_decimal_format_group":",","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} and {1}","start":"{0}, {1}","end":"{0}, and {1}"}},"fallback":[],"characters":{"more_information":"?"}}