package Locales::DB::Territory::ca;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::ca::VERSION = '0.09';

$Locales::DB::Territory::ca::cldr_version = '2.0';

%Locales::DB::Territory::ca::code_to_name = (
    '001' => 'Món',
    '002' => 'Àfrica',
    '003' => "Amèrica\ del\ Nord",
    '005' => "Amèrica\ del\ Sud",
    '009' => 'Oceania',
    '011' => "Àfrica\ Occidental",
    '013' => "Amèrica\ Central",
    '014' => "Àfrica\ Oriental",
    '015' => "Àfrica\ septentrional",
    '017' => "Àfrica\ Central",
    '018' => "Àfrica\ meridional",
    '019' => 'Amèrica',
    '021' => "Amèrica\ septentrional",
    '029' => 'Carib',
    '030' => "Àsia\ Oriental",
    '034' => "Àsia\ meridional",
    '035' => "Àsia\ Sud\-oriental",
    '039' => "Europa\ meridional",
    '053' => "Austràlia\ i\ Nova\ Zelanda",
    '054' => 'Melanèsia',
    '057' => "Regió\ de\ la\ Micronèsia",
    '061' => 'Polinèsia',
    '062' => "Àsia\ Sud\-central",
    142   => 'Àsia',
    143   => "Àsia\ Central",
    145   => "Àsia\ Occidental",
    150   => 'Europa',
    151   => "Europa\ Oriental",
    154   => "Europa\ septentrional",
    155   => "Europa\ Occidental",
    172   => "Comunitat\ d\'Estats\ Independents",
    200   => 'Czechoslovakia',
    419   => "Amèrica\ Llatina\ i\ Carib",
    830   => "Channel\ Islands",
    'ac'  => "Illa\ de\ l\'Ascensió",
    'ad'  => 'Andorra',
    'ae'  => "Unió\ dels\ Emirats\ Àrabs",
    'af'  => 'Afganistan',
    'ag'  => "Antigua\ i\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albània',
    'am'  => 'Armènia',
    'an'  => "Antilles\ Neerlandeses",
    'ao'  => 'Angola',
    'aq'  => 'Antàrtida',
    'ar'  => 'Argentina',
    'as'  => "Samoa\ Americana",
    'at'  => 'Àustria',
    'au'  => 'Austràlia',
    'aw'  => 'Aruba',
    'ax'  => "Illes\ Åland",
    'az'  => 'Azerbaidjan',
    'ba'  => "Bòsnia\ i\ Hercegovina",
    'bb'  => 'Barbados',
    'bd'  => "Bangla\ Desh",
    'be'  => 'Bèlgica',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgària',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benín',
    'bl'  => "Saint\ Barthélemy",
    'bm'  => 'Bermudes',
    'bn'  => 'Brunei',
    'bo'  => 'Bolívia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasil',
    'bs'  => 'Bahames',
    'bt'  => 'Bhutan',
    'bv'  => "Illa\ Bouvet",
    'bw'  => 'Botswana',
    'by'  => 'Bielorússia',
    'bz'  => 'Belize',
    'ca'  => 'Canadà',
    'cc'  => "Illes\ Cocos",
    'cd'  => "Congo\ \[República\ Democràtica\ del\ Congo\]",
    'cf'  => "República\ Centreafricana",
    'cg'  => "Congo\ \[República\ del\ Congo\]",
    'ch'  => 'Suïssa',
    'ci'  => "Costa\ d’Ivori",
    'ck'  => "Illes\ Cook",
    'cl'  => 'Xile',
    'cm'  => 'Camerun',
    'cn'  => 'Xina',
    'co'  => 'Colòmbia',
    'cp'  => "Illa\ Clipperton",
    'cr'  => "Costa\ Rica",
    'cs'  => "Sèrbia\ i\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Cap\ Verd",
    'cx'  => "Illa\ Christmas",
    'cy'  => 'Xipre',
    'cz'  => "República\ Txeca",
    'dd'  => "East\ Germany",
    'de'  => 'Alemanya',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Dinamarca',
    'dm'  => 'Dominica',
    'do'  => "República\ Dominicana",
    'dz'  => 'Algèria',
    'ea'  => "Ceuta\ i\ Melilla",
    'ec'  => 'Equador',
    'ee'  => 'Estònia',
    'eg'  => 'Egipte',
    'eh'  => "Sàhara\ Occidental",
    'er'  => 'Eritrea',
    'es'  => 'Espanya',
    'et'  => 'Etiòpia',
    'eu'  => "Unió\ Europea",
    'fi'  => 'Finlàndia',
    'fj'  => 'Fiji',
    'fk'  => "Illes\ Malvines\ \[Illes\ Falkland\]",
    'fm'  => 'Micronèsia',
    'fo'  => "Illes\ Fèroe",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'França',
    'fx'  => "França\ metropolitana",
    'ga'  => 'Gabon',
    'gb'  => "Regne\ Unit",
    'gd'  => 'Grenada',
    'ge'  => 'Geòrgia',
    'gf'  => "Guaiana\ Francesa",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grenlàndia',
    'gm'  => 'Gàmbia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => "Guinea\ Equatorial",
    'gr'  => 'Grècia',
    'gs'  => "Illes\ Geòrgia\ del\ Sud\ i\ Sandwich\ del\ Sud",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\ Bissau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Illa\ Heard\ i\ Illes\ McDonald",
    'hn'  => 'Hondures',
    'hr'  => 'Croàcia',
    'ht'  => 'Haití',
    'hu'  => 'Hongria',
    'ic'  => "Illes\ Canàries",
    'id'  => 'Indonèsia',
    'ie'  => 'Irlanda',
    'il'  => 'Israel',
    'im'  => "Illa\ de\ Man",
    'in'  => 'Índia',
    'io'  => "Territori\ Britànic\ de\ l\'Oceà\ Índic",
    'iq'  => 'Iraq',
    'ir'  => 'Iran',
    'is'  => 'Islàndia',
    'it'  => 'Itàlia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordània',
    'jp'  => 'Japó',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirguizistan',
    'kh'  => 'Cambodja',
    'ki'  => 'Kiribati',
    'km'  => 'Comores',
    'kn'  => "Saint\ Christopher\ i\ Nevis",
    'kp'  => "Corea\ del\ Nord",
    'kr'  => "Corea\ del\ Sud",
    'kw'  => 'Kuwait',
    'ky'  => "Illes\ Caiman",
    'kz'  => 'Kazakhstan',
    'la'  => 'Laos',
    'lb'  => 'Líban',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Libèria',
    'ls'  => 'Lesotho',
    'lt'  => 'Lituània',
    'lu'  => 'Luxemburg',
    'lv'  => 'Letònia',
    'ly'  => 'Líbia',
    'ma'  => 'Marroc',
    'mc'  => 'Mònaco',
    'md'  => 'Moldàvia',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagascar',
    'mh'  => "Illes\ Marshall",
    'mi'  => "Midway\ Islands",
    'mk'  => "Macedònia\ \[Exrepública\ Iugoslava\ de\ Macedònia\]",
    'ml'  => 'Mali',
    'mm'  => "Myanmar\ \[Birmània\]",
    'mn'  => 'Mongòlia',
    'mo'  => 'Macau',
    'mp'  => "Illes\ Mariannes\ del\ Nord",
    'mq'  => 'Martinica',
    'mr'  => 'Mauritània',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Maurici',
    'mv'  => 'Maldives',
    'mw'  => 'Malawi',
    'mx'  => 'Mèxic',
    'my'  => 'Malàisia',
    'mz'  => 'Moçambic',
    'na'  => 'Namíbia',
    'nc'  => "Nova\ Caledònia",
    'ne'  => 'Níger',
    'nf'  => "Illa\ Norfolk",
    'ng'  => 'Nigèria',
    'ni'  => 'Nicaragua',
    'nl'  => "Països\ Baixos",
    'no'  => 'Noruega',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nova\ Zelanda",
    'om'  => 'Oman',
    'pa'  => 'Panamà',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Perú',
    'pf'  => "Polinèsia\ Francesa",
    'pg'  => "Papua\ Nova\ Guinea",
    'ph'  => 'Filipines',
    'pk'  => 'Pakistan',
    'pl'  => 'Polònia',
    'pm'  => "Saint\ Pierre\ i\ Miquelon",
    'pn'  => "Illes\ Pitcairn",
    'pr'  => "Puerto\ Rico",
    'ps'  => 'Palestina',
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Territoris\ allunyats\ d\'Oceania",
    're'  => "Illa\ de\ la\ Reunió",
    'ro'  => 'Romania',
    'rs'  => 'Sèrbia',
    'ru'  => 'Rússia',
    'rw'  => 'Rwanda',
    'sa'  => "Aràbia\ Saudita",
    'sb'  => "Illes\ Salomó",
    'sc'  => 'Seychelles',
    'sd'  => 'Sudan',
    'se'  => 'Suècia',
    'sg'  => 'Singapur',
    'sh'  => "Saint\ Helena",
    'si'  => 'Eslovènia',
    'sj'  => "Svalbard\ i\ Jan\ Mayen",
    'sk'  => 'Eslovàquia',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somàlia',
    'sr'  => 'Surinam',
    'st'  => "São\ Tomé\ i\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Síria',
    'sz'  => 'Swazilàndia',
    'ta'  => "Tristão\ da\ Cunha",
    'tc'  => "Illes\ Turks\ i\ Caicos",
    'td'  => 'Txad',
    'tf'  => "Territoris\ Francesos\ del\ Sud",
    'tg'  => 'Togo',
    'th'  => 'Tailàndia',
    'tj'  => 'Tadjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ Oriental",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunísia',
    'to'  => 'Tonga',
    'tr'  => 'Turquia',
    'tt'  => "Trinitat\ i\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzània',
    'ua'  => 'Ucraïna',
    'ug'  => 'Uganda',
    'um'  => "Illes\ Perifèriques\ Menors\ dels\ EUA",
    'us'  => "Estats\ Units",
    'uy'  => 'Uruguai',
    'uz'  => 'Uzbekistan',
    'va'  => 'Vaticà',
    'vc'  => "Saint\ Vincent\ i\ les\ Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => 'Veneçuela',
    'vg'  => "Illes\ Verges\ Britàniques",
    'vi'  => "Illes\ Verges\ Nord\-americanes",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ i\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Iemen',
    'yt'  => 'Mayotte',
    'za'  => "República\ de\ Sud\-àfrica",
    'zm'  => 'Zàmbia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Regió\ desconeguda\ o\ no\ vàlida",
);

%Locales::DB::Territory::ca::name_to_code = (
    'afganistan'                                  => 'af',
    'albània'                                    => 'al',
    'alemanya'                                    => 'de',
    'algèria'                                    => 'dz',
    'amèrica'                                    => '019',
    'amèricacentral'                             => '013',
    'amèricadelnord'                             => '003',
    'amèricadelsud'                              => '005',
    'amèricallatinaicarib'                       => 419,
    'amèricaseptentrional'                       => '021',
    'andorra'                                     => 'ad',
    'angola'                                      => 'ao',
    'anguilla'                                    => 'ai',
    'antiguaibarbuda'                             => 'ag',
    'antillesneerlandeses'                        => 'an',
    'antàrtida'                                  => 'aq',
    'argentina'                                   => 'ar',
    'armènia'                                    => 'am',
    'aruba'                                       => 'aw',
    'aràbiasaudita'                              => 'sa',
    'austràlia'                                  => 'au',
    'austràliainovazelanda'                      => '053',
    'azerbaidjan'                                 => 'az',
    'bahames'                                     => 'bs',
    'bahrain'                                     => 'bh',
    'bangladesh'                                  => 'bd',
    'barbados'                                    => 'bb',
    'belize'                                      => 'bz',
    'benín'                                      => 'bj',
    'bermudes'                                    => 'bm',
    'bhutan'                                      => 'bt',
    'bielorússia'                                => 'by',
    'bolívia'                                    => 'bo',
    'botswana'                                    => 'bw',
    'brasil'                                      => 'br',
    'britishantarcticterritory'                   => 'bq',
    'brunei'                                      => 'bn',
    'bulgària'                                   => 'bg',
    'burkinafaso'                                 => 'bf',
    'burundi'                                     => 'bi',
    'bèlgica'                                    => 'be',
    'bòsniaihercegovina'                         => 'ba',
    'cambodja'                                    => 'kh',
    'camerun'                                     => 'cm',
    'canadà'                                     => 'ca',
    'cantonandenderburyislands'                   => 'ct',
    'capverd'                                     => 'cv',
    'carib'                                       => '029',
    'ceutaimelilla'                               => 'ea',
    'channelislands'                              => 830,
    'colòmbia'                                   => 'co',
    'comores'                                     => 'km',
    'comunitatdestatsindependents'                => 172,
    'congorepúblicadelcongo'                     => 'cg',
    'congorepúblicademocràticadelcongo'         => 'cd',
    'coreadelnord'                                => 'kp',
    'coreadelsud'                                 => 'kr',
    'costad’ivori'                              => 'ci',
    'costarica'                                   => 'cr',
    'croàcia'                                    => 'hr',
    'cuba'                                        => 'cu',
    'czechoslovakia'                              => 200,
    'diegogarcia'                                 => 'dg',
    'dinamarca'                                   => 'dk',
    'djibouti'                                    => 'dj',
    'dominica'                                    => 'dm',
    'dronningmaudland'                            => 'nq',
    'eastgermany'                                 => 'dd',
    'egipte'                                      => 'eg',
    'elsalvador'                                  => 'sv',
    'equador'                                     => 'ec',
    'eritrea'                                     => 'er',
    'eslovàquia'                                 => 'sk',
    'eslovènia'                                  => 'si',
    'espanya'                                     => 'es',
    'estatsunits'                                 => 'us',
    'estònia'                                    => 'ee',
    'etiòpia'                                    => 'et',
    'europa'                                      => 150,
    'europameridional'                            => '039',
    'europaoccidental'                            => 155,
    'europaoriental'                              => 151,
    'europaseptentrional'                         => 154,
    'fiji'                                        => 'fj',
    'filipines'                                   => 'ph',
    'finlàndia'                                  => 'fi',
    'frança'                                     => 'fr',
    'françametropolitana'                        => 'fx',
    'frenchsouthernandantarcticterritories'       => 'fq',
    'gabon'                                       => 'ga',
    'geòrgia'                                    => 'ge',
    'ghana'                                       => 'gh',
    'gibraltar'                                   => 'gi',
    'grenada'                                     => 'gd',
    'grenlàndia'                                 => 'gl',
    'grècia'                                     => 'gr',
    'guadeloupe'                                  => 'gp',
    'guaianafrancesa'                             => 'gf',
    'guam'                                        => 'gu',
    'guatemala'                                   => 'gt',
    'guernsey'                                    => 'gg',
    'guinea'                                      => 'gn',
    'guineabissau'                                => 'gw',
    'guineaequatorial'                            => 'gq',
    'guyana'                                      => 'gy',
    'gàmbia'                                     => 'gm',
    'haití'                                      => 'ht',
    'hondures'                                    => 'hn',
    'hongkong'                                    => 'hk',
    'hongria'                                     => 'hu',
    'iemen'                                       => 'ye',
    'illabouvet'                                  => 'bv',
    'illachristmas'                               => 'cx',
    'illaclipperton'                              => 'cp',
    'illadelareunió'                             => 're',
    'illadelascensió'                            => 'ac',
    'illademan'                                   => 'im',
    'illaheardiillesmcdonald'                     => 'hm',
    'illanorfolk'                                 => 'nf',
    'illescaiman'                                 => 'ky',
    'illescanàries'                              => 'ic',
    'illescocos'                                  => 'cc',
    'illescook'                                   => 'ck',
    'illesfèroe'                                 => 'fo',
    'illesgeòrgiadelsudisandwichdelsud'          => 'gs',
    'illesmalvinesillesfalkland'                  => 'fk',
    'illesmariannesdelnord'                       => 'mp',
    'illesmarshall'                               => 'mh',
    'illesperifèriquesmenorsdelseua'             => 'um',
    'illespitcairn'                               => 'pn',
    'illessalomó'                                => 'sb',
    'illesturksicaicos'                           => 'tc',
    'illesvergesbritàniques'                     => 'vg',
    'illesvergesnordamericanes'                   => 'vi',
    'illesÅland'                                 => 'ax',
    'indonèsia'                                  => 'id',
    'iran'                                        => 'ir',
    'iraq'                                        => 'iq',
    'irlanda'                                     => 'ie',
    'islàndia'                                   => 'is',
    'israel'                                      => 'il',
    'itàlia'                                     => 'it',
    'jamaica'                                     => 'jm',
    'japó'                                       => 'jp',
    'jersey'                                      => 'je',
    'johnstonisland'                              => 'jt',
    'jordània'                                   => 'jo',
    'kazakhstan'                                  => 'kz',
    'kenya'                                       => 'ke',
    'kirguizistan'                                => 'kg',
    'kiribati'                                    => 'ki',
    'kuwait'                                      => 'kw',
    'laos'                                        => 'la',
    'lesotho'                                     => 'ls',
    'letònia'                                    => 'lv',
    'libèria'                                    => 'lr',
    'liechtenstein'                               => 'li',
    'lituània'                                   => 'lt',
    'luxemburg'                                   => 'lu',
    'líban'                                      => 'lb',
    'líbia'                                      => 'ly',
    'macau'                                       => 'mo',
    'macedòniaexrepúblicaiugoslavademacedònia' => 'mk',
    'madagascar'                                  => 'mg',
    'malawi'                                      => 'mw',
    'maldives'                                    => 'mv',
    'mali'                                        => 'ml',
    'malta'                                       => 'mt',
    'malàisia'                                   => 'my',
    'marroc'                                      => 'ma',
    'martinica'                                   => 'mq',
    'maurici'                                     => 'mu',
    'mauritània'                                 => 'mr',
    'mayotte'                                     => 'yt',
    'melanèsia'                                  => '054',
    'micronèsia'                                 => 'fm',
    'midwayislands'                               => 'mi',
    'moldàvia'                                   => 'md',
    'mongòlia'                                   => 'mn',
    'montenegro'                                  => 'me',
    'montserrat'                                  => 'ms',
    'moçambic'                                   => 'mz',
    'myanmarbirmània'                            => 'mm',
    'mèxic'                                      => 'mx',
    'mònaco'                                     => 'mc',
    'món'                                        => '001',
    'namíbia'                                    => 'na',
    'nauru'                                       => 'nr',
    'nepal'                                       => 'np',
    'neutralzone'                                 => 'nt',
    'nicaragua'                                   => 'ni',
    'nigèria'                                    => 'ng',
    'niue'                                        => 'nu',
    'northvietnam'                                => 'vd',
    'noruega'                                     => 'no',
    'novacaledònia'                              => 'nc',
    'novazelanda'                                 => 'nz',
    'níger'                                      => 'ne',
    'oceania'                                     => '009',
    'oman'                                        => 'om',
    'pacificislandstrustterritory'                => 'pc',
    'pakistan'                                    => 'pk',
    'palau'                                       => 'pw',
    'palestina'                                   => 'ps',
    'panamacanalzone'                             => 'pz',
    'panamà'                                     => 'pa',
    'papuanovaguinea'                             => 'pg',
    'paraguai'                                    => 'py',
    'païsosbaixos'                               => 'nl',
    "people\â\\sdemocraticrepublicofyemen"   => 'yd',
    'perú'                                       => 'pe',
    'polinèsia'                                  => '061',
    'polinèsiafrancesa'                          => 'pf',
    'polònia'                                    => 'pl',
    'portugal'                                    => 'pt',
    'puertorico'                                  => 'pr',
    'qatar'                                       => 'qa',
    'regiódelamicronèsia'                       => '057',
    'regiódesconegudaonovàlida'                 => 'zz',
    'regneunit'                                   => 'gb',
    'repúblicacentreafricana'                    => 'cf',
    'repúblicadesudàfrica'                      => 'za',
    'repúblicadominicana'                        => 'do',
    'repúblicatxeca'                             => 'cz',
    'romania'                                     => 'ro',
    'rwanda'                                      => 'rw',
    'rússia'                                     => 'ru',
    'saintbarthélemy'                            => 'bl',
    'saintchristopherinevis'                      => 'kn',
    'sainthelena'                                 => 'sh',
    'saintlucia'                                  => 'lc',
    'saintmartin'                                 => 'mf',
    'saintpierreimiquelon'                        => 'pm',
    'saintvincentilesgrenadines'                  => 'vc',
    'samoa'                                       => 'ws',
    'samoaamericana'                              => 'as',
    'sanmarino'                                   => 'sm',
    'senegal'                                     => 'sn',
    'seychelles'                                  => 'sc',
    'sierraleone'                                 => 'sl',
    'singapur'                                    => 'sg',
    'somàlia'                                    => 'so',
    'srilanka'                                    => 'lk',
    'sudan'                                       => 'sd',
    'surinam'                                     => 'sr',
    'suècia'                                     => 'se',
    'suïssa'                                     => 'ch',
    'svalbardijanmayen'                           => 'sj',
    'swazilàndia'                                => 'sz',
    'sàharaoccidental'                           => 'eh',
    'sãotoméipríncipe'                         => 'st',
    'sèrbia'                                     => 'rs',
    'sèrbiaimontenegro'                          => 'cs',
    'síria'                                      => 'sy',
    'tadjikistan'                                 => 'tj',
    'tailàndia'                                  => 'th',
    'taiwan'                                      => 'tw',
    'tanzània'                                   => 'tz',
    'territoribritànicdeloceàÍndic'            => 'io',
    'territorisallunyatsdoceania'                 => 'qo',
    'territorisfrancesosdelsud'                   => 'tf',
    'timororiental'                               => 'tl',
    'togo'                                        => 'tg',
    'tokelau'                                     => 'tk',
    'tonga'                                       => 'to',
    'trinitatitobago'                             => 'tt',
    'tristãodacunha'                             => 'ta',
    'tunísia'                                    => 'tn',
    'turkmenistan'                                => 'tm',
    'turquia'                                     => 'tr',
    'tuvalu'                                      => 'tv',
    'txad'                                        => 'td',
    "u\.s\.miscellaneouspacificislands"           => 'pu',
    'ucraïna'                                    => 'ua',
    'uganda'                                      => 'ug',
    'unionofsovietsocialistrepublics'             => 'su',
    'uniódelsemiratsÀrabs'                      => 'ae',
    'unióeuropea'                                => 'eu',
    'uruguai'                                     => 'uy',
    'uzbekistan'                                  => 'uz',
    'vanuatu'                                     => 'vu',
    'vaticà'                                     => 'va',
    'veneçuela'                                  => 've',
    'vietnam'                                     => 'vn',
    'wakeisland'                                  => 'wk',
    'wallisifutuna'                               => 'wf',
    'xile'                                        => 'cl',
    'xina'                                        => 'cn',
    'xipre'                                       => 'cy',
    'zimbabwe'                                    => 'zw',
    'zàmbia'                                     => 'zm',
    'Àfrica'                                     => '002',
    'Àfricacentral'                              => '017',
    'Àfricameridional'                           => '018',
    'Àfricaoccidental'                           => '011',
    'Àfricaoriental'                             => '014',
    'Àfricaseptentrional'                        => '015',
    'Àsia'                                       => 142,
    'Àsiacentral'                                => 143,
    'Àsiameridional'                             => '034',
    'Àsiaoccidental'                             => 145,
    'Àsiaoriental'                               => '030',
    'Àsiasudcentral'                             => '062',
    'Àsiasudoriental'                            => '035',
    'Àustria'                                    => 'at',
    'Índia'                                      => 'in',
);

1;

