package Locales::DB::Territory::pt_br;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::pt_br::VERSION = '0.09';

$Locales::DB::Territory::pt_br::cldr_version = '2.0';

%Locales::DB::Territory::pt_br::code_to_name = (
    '001' => 'Mundo',
    '002' => 'África',
    '003' => "América\ do\ Norte",
    '005' => "América\ do\ Sul",
    '009' => 'Oceania',
    '011' => "África\ Ocidental",
    '013' => "América\ Central",
    '014' => "África\ Oriental",
    '015' => "África\ do\ Norte",
    '017' => "África\ Central",
    '018' => "África\ Austral",
    '019' => 'Américas',
    '021' => "América\ Setentrional",
    '029' => 'Caribe',
    '030' => "Ásia\ Oriental",
    '034' => "Ásia\ do\ Sul",
    '035' => "Ásia\ Centro\-Oriental",
    '039' => "Europa\ do\ Sul",
    '053' => "Austrália\ e\ Nova\ Zelândia",
    '054' => 'Melanésia',
    '057' => "Região\ da\ Micronésia",
    '061' => 'Polinésia',
    '062' => "Ásia\ Centro\-Meridional",
    142   => 'Ásia',
    143   => "Ásia\ Central",
    145   => "Ásia\ Ocidental",
    150   => 'Europa',
    151   => "Europa\ Oriental",
    154   => "Europa\ Setentrional",
    155   => "Europa\ Ocidental",
    172   => "Comunidade\ dos\ Estados\ Independentes",
    200   => 'Czechoslovakia',
    419   => "América\ Latina\ e\ Caribe",
    830   => "Channel\ Islands",
    'ac'  => "Ilha\ de\ Ascensão",
    'ad'  => 'Andorra',
    'ae'  => "Emirados\ Árabes\ Unidos",
    'af'  => 'Afeganistão',
    'ag'  => "Antígua\ e\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albânia',
    'am'  => 'Armênia',
    'an'  => "Antilhas\ Holandesas",
    'ao'  => 'Angola',
    'aq'  => 'Antártida',
    'ar'  => 'Argentina',
    'as'  => "Samoa\ Americana",
    'at'  => 'Áustria',
    'au'  => 'Austrália',
    'aw'  => 'Aruba',
    'ax'  => "Ilhas\ Aland",
    'az'  => 'Azerbaijão',
    'ba'  => "Bósnia\-Herzegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Bélgica',
    'bf'  => "Burquina\ Faso",
    'bg'  => 'Bulgária',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "São\ Bartolomeu",
    'bm'  => 'Bermudas',
    'bn'  => 'Brunei',
    'bo'  => 'Bolívia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasil',
    'bs'  => 'Bahamas',
    'bt'  => 'Butão',
    'bv'  => "Ilha\ Bouvet",
    'bw'  => 'Botsuana',
    'by'  => 'Belarus',
    'bz'  => 'Belize',
    'ca'  => 'Canadá',
    'cc'  => "Ilhas\ Coco",
    'cd'  => "República\ Democrática\ do\ Congo",
    'cf'  => "República\ Centro\-Africana",
    'cg'  => 'Congo',
    'ch'  => 'Suíça',
    'ci'  => "Costa\ do\ Marfim",
    'ck'  => "Ilhas\ Cook",
    'cl'  => 'Chile',
    'cm'  => "República\ dos\ Camarões",
    'cn'  => 'China',
    'co'  => 'Colômbia',
    'cp'  => "Ilha\ de\ Clipperton",
    'cr'  => "Costa\ Rica",
    'cs'  => "Sérvia\ e\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Cabo\ Verde",
    'cx'  => "Ilhas\ Natal",
    'cy'  => 'Chipre',
    'cz'  => "República\ Tcheca",
    'dd'  => "East\ Germany",
    'de'  => 'Alemanha',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibuti',
    'dk'  => 'Dinamarca',
    'dm'  => 'Dominica',
    'do'  => "República\ Dominicana",
    'dz'  => 'Argélia',
    'ea'  => "Ceuta\ e\ Melilha",
    'ec'  => 'Equador',
    'ee'  => 'Estônia',
    'eg'  => 'Egito',
    'eh'  => "Saara\ Ocidental",
    'er'  => 'Eritreia',
    'es'  => 'Espanha',
    'et'  => 'Etiópia',
    'eu'  => "União\ Europeia",
    'fi'  => 'Finlândia',
    'fj'  => 'Fiji',
    'fk'  => "Ilhas\ Malvinas",
    'fm'  => 'Micronésia',
    'fo'  => "Ilhas\ Faroe",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'França',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabão',
    'gb'  => "Reino\ Unido",
    'gd'  => 'Granada',
    'ge'  => 'Geórgia',
    'gf'  => "Guiana\ Francesa",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Groênlandia',
    'gm'  => 'Gâmbia',
    'gn'  => 'Guiné',
    'gp'  => 'Guadalupe',
    'gq'  => "Guiné\ Equatorial",
    'gr'  => 'Grécia',
    'gs'  => "Geórgia\ do\ Sul\ e\ Ilhas\ Sandwich\ do\ Sul",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guiné\ Bissau",
    'gy'  => 'Guiana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Ilha\ Heard\ e\ Ilhas\ McDonald",
    'hn'  => 'Honduras',
    'hr'  => 'Croácia',
    'ht'  => 'Haiti',
    'hu'  => 'Hungria',
    'ic'  => "Ilhas\ Canárias",
    'id'  => 'Indonésia',
    'ie'  => 'Irlanda',
    'il'  => 'Israel',
    'im'  => "Ilha\ de\ Man",
    'in'  => 'Índia',
    'io'  => "Território\ Britânico\ do\ Oceano\ Índico",
    'iq'  => 'Iraque',
    'ir'  => 'Irã',
    'is'  => 'Islândia',
    'it'  => 'Itália',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordânia',
    'jp'  => 'Japão',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Quênia',
    'kg'  => 'Quirguistão',
    'kh'  => 'Camboja',
    'ki'  => 'Quiribati',
    'km'  => 'Comores',
    'kn'  => "São\ Cristovão\ e\ Nevis",
    'kp'  => "Coreia\ do\ Norte",
    'kr'  => "Coreia\ do\ Sul",
    'kw'  => 'Kuwait',
    'ky'  => "Ilhas\ Caiman",
    'kz'  => 'Casaquistão',
    'la'  => "República\ Popular\ Democrática\ do\ Laos",
    'lb'  => 'Líbano',
    'lc'  => "Santa\ Lúcia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Libéria',
    'ls'  => 'Lesoto',
    'lt'  => 'Lituânia',
    'lu'  => 'Luxemburgo',
    'lv'  => 'Letônia',
    'ly'  => 'Líbia',
    'ma'  => 'Marrocos',
    'mc'  => 'Mônaco',
    'md'  => 'Moldávia',
    'me'  => 'Montenegro',
    'mf'  => "São\ Martinho",
    'mg'  => 'Madagascar',
    'mh'  => "Ilhas\ Marshall",
    'mi'  => "Midway\ Islands",
    'mk'  => "Macedônia\ \[Antiga\ República\ Iugoslava\ da\ Macedônia\ \-\ ARIM\]",
    'ml'  => 'Mali',
    'mm'  => "Mianmar\ \[Birmânia\]",
    'mn'  => 'Mongólia',
    'mo'  => 'Macau',
    'mp'  => "Ilhas\ Marianas\ do\ Norte",
    'mq'  => 'Martinica',
    'mr'  => 'Mauritânia',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Maurício',
    'mv'  => 'Maldivas',
    'mw'  => 'Malawi',
    'mx'  => 'México',
    'my'  => 'Malásia',
    'mz'  => 'Moçambique',
    'na'  => 'Namíbia',
    'nc'  => "Nova\ Caledônia",
    'ne'  => 'Níger',
    'nf'  => "Ilha\ Norfolk",
    'ng'  => 'Nigéria',
    'ni'  => 'Nicarágua',
    'nl'  => 'Holanda',
    'no'  => 'Noruega',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nova\ Zelândia",
    'om'  => 'Omã',
    'pa'  => 'Panamá',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polinésia\ Francesa",
    'pg'  => "Papua\-Nova\ Guiné",
    'ph'  => 'Filipinas',
    'pk'  => 'Paquistão',
    'pl'  => 'Polônia',
    'pm'  => "Saint\ Pierre\ e\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Porto\ Rico",
    'ps'  => "Territórios\ palestinos",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Catar',
    'qo'  => "Oceania\ Remota",
    're'  => 'Reunião',
    'ro'  => 'Romênia',
    'rs'  => 'Sérvia',
    'ru'  => 'Rússia',
    'rw'  => 'Ruanda',
    'sa'  => "Arábia\ Saudita",
    'sb'  => "Ilhas\ Salomão",
    'sc'  => 'Seychelles',
    'sd'  => 'Sudão',
    'se'  => 'Suécia',
    'sg'  => 'Cingapura',
    'sh'  => "Santa\ Helena",
    'si'  => 'Eslovênia',
    'sj'  => "Svalbard\ e\ Jan\ Mayen",
    'sk'  => 'Eslováquia',
    'sl'  => "Serra\ Leoa",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somália',
    'sr'  => 'Suriname',
    'st'  => "São\ Tomé\ e\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Síria',
    'sz'  => 'Suazilândia',
    'ta'  => "Tristão\ da\ Cunha",
    'tc'  => "Ilhas\ Turks\ e\ Caicos",
    'td'  => 'Chade',
    'tf'  => "Territórios\ Franceses\ do\ Sul",
    'tg'  => 'Togo',
    'th'  => 'Tailândia',
    'tj'  => 'Tadjiquistão',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\-Leste",
    'tm'  => 'Turcomenistão',
    'tn'  => 'Tunísia',
    'to'  => 'Tonga',
    'tr'  => 'Turquia',
    'tt'  => "Trinidad\ e\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzânia',
    'ua'  => 'Ucrânia',
    'ug'  => 'Uganda',
    'um'  => "Ilhas\ Menores\ Distantes\ dos\ Estados\ Unidos",
    'us'  => "Estados\ Unidos",
    'uy'  => 'Uruguai',
    'uz'  => 'Uzbequistão',
    'va'  => 'Vaticano',
    'vc'  => "São\ Vicente\ e\ Granadinas",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Ilhas\ Virgens\ Britânicas",
    'vi'  => "Ilhas\ Virgens\ dos\ EUA",
    'vn'  => 'Vietnã',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ e\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Iêmen',
    'yt'  => 'Mayotte',
    'za'  => "África\ do\ Sul",
    'zm'  => 'Zâmbia',
    'zw'  => 'Zimbábue',
    'zz'  => "Região\ desconhecida\ ou\ inválida",
);

%Locales::DB::Territory::pt_br::name_to_code = (
    'afeganistão'                                        => 'af',
    'albânia'                                            => 'al',
    'alemanha'                                            => 'de',
    'américacentral'                                     => '013',
    'américadonorte'                                     => '003',
    'américadosul'                                       => '005',
    'américalatinaecaribe'                               => 419,
    'américas'                                           => '019',
    'américasetentrional'                                => '021',
    'andorra'                                             => 'ad',
    'angola'                                              => 'ao',
    'anguilla'                                            => 'ai',
    'antilhasholandesas'                                  => 'an',
    'antártida'                                          => 'aq',
    'antíguaebarbuda'                                    => 'ag',
    'argentina'                                           => 'ar',
    'argélia'                                            => 'dz',
    'armênia'                                            => 'am',
    'aruba'                                               => 'aw',
    'arábiasaudita'                                      => 'sa',
    'austrália'                                          => 'au',
    'austráliaenovazelândia'                            => '053',
    'azerbaijão'                                         => 'az',
    'bahamas'                                             => 'bs',
    'bahrain'                                             => 'bh',
    'bangladesh'                                          => 'bd',
    'barbados'                                            => 'bb',
    'belarus'                                             => 'by',
    'belize'                                              => 'bz',
    'benin'                                               => 'bj',
    'bermudas'                                            => 'bm',
    'bolívia'                                            => 'bo',
    'botsuana'                                            => 'bw',
    'brasil'                                              => 'br',
    'britishantarcticterritory'                           => 'bq',
    'brunei'                                              => 'bn',
    'bulgária'                                           => 'bg',
    'burquinafaso'                                        => 'bf',
    'burundi'                                             => 'bi',
    'butão'                                              => 'bt',
    'bélgica'                                            => 'be',
    'bósniaherzegovina'                                  => 'ba',
    'caboverde'                                           => 'cv',
    'camboja'                                             => 'kh',
    'canadá'                                             => 'ca',
    'cantonandenderburyislands'                           => 'ct',
    'caribe'                                              => '029',
    'casaquistão'                                        => 'kz',
    'catar'                                               => 'qa',
    'ceutaemelilha'                                       => 'ea',
    'chade'                                               => 'td',
    'channelislands'                                      => 830,
    'chile'                                               => 'cl',
    'china'                                               => 'cn',
    'chipre'                                              => 'cy',
    'cingapura'                                           => 'sg',
    'colômbia'                                           => 'co',
    'comores'                                             => 'km',
    'comunidadedosestadosindependentes'                   => 172,
    'congo'                                               => 'cg',
    'coreiadonorte'                                       => 'kp',
    'coreiadosul'                                         => 'kr',
    'costadomarfim'                                       => 'ci',
    'costarica'                                           => 'cr',
    'croácia'                                            => 'hr',
    'cuba'                                                => 'cu',
    'czechoslovakia'                                      => 200,
    'diegogarcia'                                         => 'dg',
    'dinamarca'                                           => 'dk',
    'djibuti'                                             => 'dj',
    'dominica'                                            => 'dm',
    'dronningmaudland'                                    => 'nq',
    'eastgermany'                                         => 'dd',
    'egito'                                               => 'eg',
    'elsalvador'                                          => 'sv',
    'emiradosÁrabesunidos'                               => 'ae',
    'equador'                                             => 'ec',
    'eritreia'                                            => 'er',
    'eslováquia'                                         => 'sk',
    'eslovênia'                                          => 'si',
    'espanha'                                             => 'es',
    'estadosunidos'                                       => 'us',
    'estônia'                                            => 'ee',
    'etiópia'                                            => 'et',
    'europa'                                              => 150,
    'europadosul'                                         => '039',
    'europaocidental'                                     => 155,
    'europaoriental'                                      => 151,
    'europasetentrional'                                  => 154,
    'fiji'                                                => 'fj',
    'filipinas'                                           => 'ph',
    'finlândia'                                          => 'fi',
    'frança'                                             => 'fr',
    'frenchsouthernandantarcticterritories'               => 'fq',
    'gabão'                                              => 'ga',
    'gana'                                                => 'gh',
    'geórgia'                                            => 'ge',
    'geórgiadosuleilhassandwichdosul'                    => 'gs',
    'gibraltar'                                           => 'gi',
    'granada'                                             => 'gd',
    'groênlandia'                                        => 'gl',
    'grécia'                                             => 'gr',
    'guadalupe'                                           => 'gp',
    'guam'                                                => 'gu',
    'guatemala'                                           => 'gt',
    'guernsey'                                            => 'gg',
    'guiana'                                              => 'gy',
    'guianafrancesa'                                      => 'gf',
    'guiné'                                              => 'gn',
    'guinébissau'                                        => 'gw',
    'guinéequatorial'                                    => 'gq',
    'gâmbia'                                             => 'gm',
    'haiti'                                               => 'ht',
    'holanda'                                             => 'nl',
    'honduras'                                            => 'hn',
    'hongkong'                                            => 'hk',
    'hungria'                                             => 'hu',
    'ilhabouvet'                                          => 'bv',
    'ilhadeascensão'                                     => 'ac',
    'ilhadeclipperton'                                    => 'cp',
    'ilhademan'                                           => 'im',
    'ilhaheardeilhasmcdonald'                             => 'hm',
    'ilhanorfolk'                                         => 'nf',
    'ilhasaland'                                          => 'ax',
    'ilhascaiman'                                         => 'ky',
    'ilhascanárias'                                      => 'ic',
    'ilhascoco'                                           => 'cc',
    'ilhascook'                                           => 'ck',
    'ilhasfaroe'                                          => 'fo',
    'ilhasmalvinas'                                       => 'fk',
    'ilhasmarianasdonorte'                                => 'mp',
    'ilhasmarshall'                                       => 'mh',
    'ilhasmenoresdistantesdosestadosunidos'               => 'um',
    'ilhasnatal'                                          => 'cx',
    'ilhassalomão'                                       => 'sb',
    'ilhasturksecaicos'                                   => 'tc',
    'ilhasvirgensbritânicas'                             => 'vg',
    'ilhasvirgensdoseua'                                  => 'vi',
    'indonésia'                                          => 'id',
    'iraque'                                              => 'iq',
    'irlanda'                                             => 'ie',
    'irã'                                                => 'ir',
    'islândia'                                           => 'is',
    'israel'                                              => 'il',
    'itália'                                             => 'it',
    'iêmen'                                              => 'ye',
    'jamaica'                                             => 'jm',
    'japão'                                              => 'jp',
    'jersey'                                              => 'je',
    'johnstonisland'                                      => 'jt',
    'jordânia'                                           => 'jo',
    'kuwait'                                              => 'kw',
    'lesoto'                                              => 'ls',
    'letônia'                                            => 'lv',
    'libéria'                                            => 'lr',
    'liechtenstein'                                       => 'li',
    'lituânia'                                           => 'lt',
    'luxemburgo'                                          => 'lu',
    'líbano'                                             => 'lb',
    'líbia'                                              => 'ly',
    'macau'                                               => 'mo',
    'macedôniaantigarepúblicaiugoslavadamacedôniaarim' => 'mk',
    'madagascar'                                          => 'mg',
    'malawi'                                              => 'mw',
    'maldivas'                                            => 'mv',
    'mali'                                                => 'ml',
    'malta'                                               => 'mt',
    'malásia'                                            => 'my',
    'marrocos'                                            => 'ma',
    'martinica'                                           => 'mq',
    'mauritânia'                                         => 'mr',
    'maurício'                                           => 'mu',
    'mayotte'                                             => 'yt',
    'melanésia'                                          => '054',
    'metropolitanfrance'                                  => 'fx',
    'mianmarbirmânia'                                    => 'mm',
    'micronésia'                                         => 'fm',
    'midwayislands'                                       => 'mi',
    'moldávia'                                           => 'md',
    'mongólia'                                           => 'mn',
    'montenegro'                                          => 'me',
    'montserrat'                                          => 'ms',
    'moçambique'                                         => 'mz',
    'mundo'                                               => '001',
    'méxico'                                             => 'mx',
    'mônaco'                                             => 'mc',
    'namíbia'                                            => 'na',
    'nauru'                                               => 'nr',
    'nepal'                                               => 'np',
    'neutralzone'                                         => 'nt',
    'nicarágua'                                          => 'ni',
    'nigéria'                                            => 'ng',
    'niue'                                                => 'nu',
    'northvietnam'                                        => 'vd',
    'noruega'                                             => 'no',
    'novacaledônia'                                      => 'nc',
    'novazelândia'                                       => 'nz',
    'níger'                                              => 'ne',
    'oceania'                                             => '009',
    'oceaniaremota'                                       => 'qo',
    'omã'                                                => 'om',
    'pacificislandstrustterritory'                        => 'pc',
    'palau'                                               => 'pw',
    'panamacanalzone'                                     => 'pz',
    'panamá'                                             => 'pa',
    'papuanovaguiné'                                     => 'pg',
    'paquistão'                                          => 'pk',
    'paraguai'                                            => 'py',
    "people\â\\sdemocraticrepublicofyemen"           => 'yd',
    'peru'                                                => 'pe',
    'pitcairn'                                            => 'pn',
    'polinésia'                                          => '061',
    'polinésiafrancesa'                                  => 'pf',
    'polônia'                                            => 'pl',
    'portorico'                                           => 'pr',
    'portugal'                                            => 'pt',
    'quirguistão'                                        => 'kg',
    'quiribati'                                           => 'ki',
    'quênia'                                             => 'ke',
    'regiãodamicronésia'                                => '057',
    'regiãodesconhecidaouinválida'                      => 'zz',
    'reinounido'                                          => 'gb',
    'repúblicacentroafricana'                            => 'cf',
    'repúblicademocráticadocongo'                       => 'cd',
    'repúblicadominicana'                                => 'do',
    'repúblicadoscamarões'                              => 'cm',
    'repúblicapopulardemocráticadolaos'                 => 'la',
    'repúblicatcheca'                                    => 'cz',
    'reunião'                                            => 're',
    'romênia'                                            => 'ro',
    'ruanda'                                              => 'rw',
    'rússia'                                             => 'ru',
    'saaraocidental'                                      => 'eh',
    'saintpierreemiquelon'                                => 'pm',
    'samoa'                                               => 'ws',
    'samoaamericana'                                      => 'as',
    'sanmarino'                                           => 'sm',
    'santahelena'                                         => 'sh',
    'santalúcia'                                         => 'lc',
    'senegal'                                             => 'sn',
    'serraleoa'                                           => 'sl',
    'seychelles'                                          => 'sc',
    'somália'                                            => 'so',
    'srilanka'                                            => 'lk',
    'suazilândia'                                        => 'sz',
    'sudão'                                              => 'sd',
    'suriname'                                            => 'sr',
    'suécia'                                             => 'se',
    'suíça'                                             => 'ch',
    'svalbardejanmayen'                                   => 'sj',
    'sãobartolomeu'                                      => 'bl',
    'sãocristovãoenevis'                                => 'kn',
    'sãomartinho'                                        => 'mf',
    'sãotoméepríncipe'                                 => 'st',
    'sãovicenteegranadinas'                              => 'vc',
    'sérvia'                                             => 'rs',
    'sérviaemontenegro'                                  => 'cs',
    'síria'                                              => 'sy',
    'tadjiquistão'                                       => 'tj',
    'tailândia'                                          => 'th',
    'taiwan'                                              => 'tw',
    'tanzânia'                                           => 'tz',
    'territóriobritânicodooceanoÍndico'                => 'io',
    'territóriosfrancesesdosul'                          => 'tf',
    'territóriospalestinos'                              => 'ps',
    'timorleste'                                          => 'tl',
    'togo'                                                => 'tg',
    'tokelau'                                             => 'tk',
    'tonga'                                               => 'to',
    'trinidadetobago'                                     => 'tt',
    'tristãodacunha'                                     => 'ta',
    'tunísia'                                            => 'tn',
    'turcomenistão'                                      => 'tm',
    'turquia'                                             => 'tr',
    'tuvalu'                                              => 'tv',
    "u\.s\.miscellaneouspacificislands"                   => 'pu',
    'ucrânia'                                            => 'ua',
    'uganda'                                              => 'ug',
    'unionofsovietsocialistrepublics'                     => 'su',
    'uniãoeuropeia'                                      => 'eu',
    'uruguai'                                             => 'uy',
    'uzbequistão'                                        => 'uz',
    'vanuatu'                                             => 'vu',
    'vaticano'                                            => 'va',
    'venezuela'                                           => 've',
    'vietnã'                                             => 'vn',
    'wakeisland'                                          => 'wk',
    'wallisefutuna'                                       => 'wf',
    'zimbábue'                                           => 'zw',
    'zâmbia'                                             => 'zm',
    'África'                                             => '002',
    'Áfricaaustral'                                      => '018',
    'Áfricacentral'                                      => '017',
    'Áfricadonorte'                                      => '015',
    'Áfricadosul'                                        => 'za',
    'Áfricaocidental'                                    => '011',
    'Áfricaoriental'                                     => '014',
    'Ásia'                                               => 142,
    'Ásiacentral'                                        => 143,
    'Ásiacentromeridional'                               => '062',
    'Ásiacentrooriental'                                 => '035',
    'Ásiadosul'                                          => '034',
    'Ásiaocidental'                                      => 145,
    'Ásiaoriental'                                       => '030',
    'Áustria'                                            => 'at',
    'Índia'                                              => 'in',
);

1;

