package Locales::DB::Territory::km;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::km::VERSION = '0.09';

$Locales::DB::Territory::km::cldr_version = '2.0';

%Locales::DB::Territory::km::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'អានដូរ៉ា',
    'ae'  => 'អេមីរ៉ែទអារ៉ាប់រួម',
    'af'  => 'អាហ្វហ្គានីស្ថាន',
    'ag'  => "Antigua\ and\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'អាល់បានី',
    'am'  => 'អារមេនី',
    'an'  => "Netherlands\ Antilles",
    'ao'  => 'អង់ហ្គោឡា',
    'aq'  => 'Antarctica',
    'ar'  => 'អាហ្សង់ទីន',
    'as'  => "American\ Samoa",
    'at'  => 'អូទ្រីស',
    'au'  => 'អូស្ត្រាលី',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'អាហ៊្សែរបែហ្សង់',
    'ba'  => 'បូស្ន៉ី',
    'bb'  => 'បារបាដូស',
    'bd'  => 'បង់ក្លាដេស្ហ',
    'be'  => 'បែលហ្ស៉ិក',
    'bf'  => 'ប៊ូរគីណាហ្វាសូ',
    'bg'  => 'ប៊ុលហ្គារី',
    'bh'  => 'បារ៉ែន',
    'bi'  => 'ប៊ូរុនឌី',
    'bj'  => 'បេណាំង',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermuda',
    'bn'  => 'ប៊្រុយណេ',
    'bo'  => 'បូលីវី',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'ប្រេស៊ីល',
    'bs'  => 'បាហាម៉ា',
    'bt'  => 'ប៊ូតាន',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'បុតស្វាណា',
    'by'  => 'បេឡារុស្ស',
    'bz'  => 'បេលីហ្ស',
    'ca'  => 'កាណាដា',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Congo\ \[DRC\]",
    'cf'  => 'សាធារណរដ្ឋអាហ្វ្រិកកណ្ដាល',
    'cg'  => 'កុងហ្គោ',
    'ch'  => 'ស្វីស',
    'ci'  => 'កូដឌីវ័រ',
    'ck'  => "Cook\ Islands",
    'cl'  => 'ឈីលី',
    'cm'  => 'កាមេរូន',
    'cn'  => 'ចិន',
    'co'  => 'កូឡុំប៊ី',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'កូស្តារីកា',
    'cs'  => "Serbia\ and\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'គុយបា',
    'cv'  => 'កាបវែរ',
    'cx'  => "Christmas\ Island",
    'cy'  => 'ស៉ីពរ៍',
    'cz'  => 'សាធារណរដ្ឋឆេក',
    'dd'  => "East\ Germany",
    'de'  => 'អាល្លឺម៉ង់',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'ហ្ស៉ីបូទី',
    'dk'  => 'ដាណឺម៉ាក',
    'dm'  => 'ដូមីនីកា',
    'do'  => 'សាធារណរដ្ឋដូមីនីកែន',
    'dz'  => 'អាល់ហ្សេរី',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'អេក្វាឌ័រ',
    'ee'  => 'អេស្តូនី',
    'eg'  => 'អេហ្ស៉ីប',
    'eh'  => 'សាហារ៉ាខាងលិច',
    'er'  => 'អេរីទ្រា',
    'es'  => 'អេស្ប៉ាញ',
    'et'  => 'អេត្យូពី',
    'eu'  => "European\ Union",
    'fi'  => 'ហ្វាំងឡង់',
    'fj'  => 'ហ្វ៉ីហ្ស៉ី',
    'fk'  => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm'  => 'មិក្រូនេស៊ី',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'បារាំង',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'ហ្គាបុង',
    'gb'  => "United\ Kingdom",
    'gd'  => 'Grenada',
    'ge'  => 'ហ្សកហ្ស៉ី',
    'gf'  => "French\ Guiana",
    'gg'  => 'Guernsey',
    'gh'  => 'ហ្កាណា',
    'gi'  => 'Gibraltar',
    'gl'  => 'Greenland',
    'gm'  => 'ហ្គាំប៊ី',
    'gn'  => 'ហ្គីណេ',
    'gp'  => 'Guadeloupe',
    'gq'  => 'ហ្គីណេអេក្វាទ័រ',
    'gr'  => 'ក្រិច',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'ហ្គាតេម៉ាឡា',
    'gu'  => 'Guam',
    'gw'  => 'ហ្គីណេប៊ីសូ',
    'gy'  => 'ហ្គីយ៉ាណា',
    'hk'  => 'ហុងកុង',
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'ហុងឌួរ៉ាស់',
    'hr'  => 'ក្រូអាស៊ី',
    'ht'  => 'ហៃទី',
    'hu'  => 'ហុងគ្រី',
    'ic'  => "Canary\ Islands",
    'id'  => 'ឥណ្ឌូនេស៊ី',
    'ie'  => 'អៀរឡង់',
    'il'  => 'អ៊ីស្រាអែល',
    'im'  => "Isle\ of\ Man",
    'in'  => 'ឥណ្ឌា',
    'io'  => "British\ Indian\ Ocean\ Territory",
    'iq'  => 'អ៊ីរ៉ាក់',
    'ir'  => 'អ៊ីរ៉ង់',
    'is'  => 'អ៉ីស្លង់',
    'it'  => 'អ៊ីតាលី',
    'je'  => 'Jersey',
    'jm'  => 'ហ្សាម៉ាអ៉ិគ',
    'jo'  => 'ហ៊្សកដានី',
    'jp'  => 'ជប៉ុន',
    'jt'  => "Johnston\ Island",
    'ke'  => 'កេនយ៉ា',
    'kg'  => 'គៀរហ្គីស្តង់',
    'kh'  => 'កម្ពុជា',
    'ki'  => 'គិរិបាទី',
    'km'  => 'កុំម៉ូរ៉ូស',
    'kn'  => "Saint\ Kitts\ and\ Nevis",
    'kp'  => 'សាធារណរដ្ឋប្រជាធិបតេយ្យប្រជាមានិតកូរ៉េ',
    'kr'  => 'សាធារណរដ្ឋកូរ៉េ',
    'kw'  => 'គុយវ៉ែត',
    'ky'  => "Cayman\ Islands",
    'kz'  => 'កាហ្សាក់ស្តាង់់',
    'la'  => 'ឡាវ',
    'lb'  => 'លីបង់',
    'lc'  => "Saint\ Lucia",
    'li'  => 'លិចទេនស្តែន',
    'lk'  => 'ស្រីលង្កា',
    'lr'  => 'លីបេរីយ៉ា',
    'ls'  => 'លើសូតូ',
    'lt'  => 'លីទុយអានី',
    'lu'  => 'លុចហ្សំបួរ',
    'lv'  => 'ឡាតវីយ៉ា',
    'ly'  => 'លីប៊ី',
    'ma'  => 'ម៉ារ៉ុក',
    'mc'  => 'ម៉ូណាកូ',
    'md'  => 'សាធារណរដ្ឋម៉ុលដាវី',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'ម៉ាដាហ្កាស្ការ',
    'mh'  => "Marshall\ Islands",
    'mi'  => "Midway\ Islands",
    'mk'  => 'ម៉ាសេដន',
    'ml'  => 'ម៉ាលី',
    'mm'  => 'មីយ៉ាន់ម៉ា',
    'mn'  => 'ម៉ុងហ្គោលី',
    'mo'  => 'Macau',
    'mp'  => "Northern\ Mariana\ Islands",
    'mq'  => 'Martinique',
    'mr'  => 'ម៉ូរីតានី',
    'ms'  => 'Montserrat',
    'mt'  => 'ម៉ាល់តា',
    'mu'  => 'ម៉ូរីទុស',
    'mv'  => 'Maldives',
    'mw'  => 'Malawi',
    'mx'  => 'ម៉ិចសិក',
    'my'  => 'ម៉ាលេស៉ី',
    'mz'  => 'ម៉ូហ្សាំប៊ិក',
    'na'  => 'ណាមីប៊ី',
    'nc'  => "New\ Caledonia",
    'ne'  => 'នីហ្សេរ',
    'nf'  => "Norfolk\ Island",
    'ng'  => 'នីហ្សេរីយ៉ា',
    'ni'  => 'នីការ៉ាហ្គ័រ',
    'nl'  => 'ហូល្លង់',
    'no'  => 'ន័រវែស',
    'np'  => 'នេប៉ាល់',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => 'នូវែលហ្សេឡង់',
    'om'  => 'អូម៉ង់',
    'pa'  => 'ប៉ាណាម៉ា',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'ប៉េរូ',
    'pf'  => "French\ Polynesia",
    'pg'  => 'ប៉ាពូអានូវែលហ្គីណេ',
    'ph'  => 'ហ្វ៉ីលីពីន',
    'pk'  => 'ប៉ាគីស្ថាន',
    'pl'  => 'ប៉ូលូញ',
    'pm'  => "Saint\ Pierre\ and\ Miquelon",
    'pn'  => "Pitcairn\ Islands",
    'pr'  => 'ព័រតូរីកូ',
    'ps'  => 'ប៉ាលេស្ទីន',
    'pt'  => 'ព័រទុយហ្កាល់',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'ប៉ារ៉ាហ្គាយ',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'កាតារ',
    'qo'  => "Outlying\ Oceania",
    're'  => "R\Ã\©union",
    'ro'  => 'រូម៉ានី',
    'rs'  => 'Serbia',
    'ru'  => 'រូស្ស៊ី',
    'rw'  => 'រវ៉ាន់ដា',
    'sa'  => 'អារ៉ាប៊ីសាអ៊ូឌីត',
    'sb'  => "Solomon\ Islands",
    'sc'  => 'សីសែល',
    'sd'  => 'ស៊ូដង់',
    'se'  => 'ស៊ុយអែដ',
    'sg'  => 'សិង្ហបុរី',
    'sh'  => "Saint\ Helena",
    'si'  => 'ស្លូវេនី',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'ស្លូវ៉ាគី',
    'sl'  => 'សេរ៉ាឡេអូន',
    'sm'  => "San\ Marino",
    'sn'  => 'សេនេហ្កាល់',
    'so'  => 'សូម៉ាលី',
    'sr'  => 'សូរីណាម',
    'st'  => "S\Ã\£o\ Tom\Ã\©\ and\ Pr\Ã\­ncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'អែលសាល់វ៉ាឌ័រ',
    'sy'  => 'ស៊ីរី',
    'sz'  => 'សូហ្ស៉ីឡង់',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ and\ Caicos\ Islands",
    'td'  => 'ឆាដ',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'តូហ្គូ',
    'th'  => 'ថៃ',
    'tj'  => 'តាដហ្ស៉ីគីស្តង់',
    'tk'  => 'Tokelau',
    'tl'  => 'ទីម័រខាងកើត',
    'tm'  => 'ទួគមេនីស្តង់',
    'tn'  => 'ទុយនេស៊ី',
    'to'  => 'តុងហ្គា',
    'tr'  => 'ទួរគី',
    'tt'  => 'ទ្រីនីដាដនឹងតូបាហ្គោ',
    'tv'  => 'Tuvalu',
    'tw'  => 'តៃវ៉ាន់',
    'tz'  => 'តង់ហ្សានី',
    'ua'  => 'អ៊ុយក្រែន',
    'ug'  => 'អ៊ូហ្កង់ដា',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'សហរដ្ឋអាមេរិក',
    'uy'  => 'អ៊ុយរុយហ្គាយ',
    'uz'  => 'អ៊ូហ្សបេគីស្តង់',
    'va'  => 'វ៉ាទីកង់',
    'vc'  => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => 'វេនេហ្ស៊ុយឡា',
    'vg'  => "British\ Virgin\ Islands",
    'vi'  => "U\.S\.\ Virgin\ Islands",
    'vn'  => 'វៀតណាម',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ and\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'សាមូអា',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'យេមែន',
    'yt'  => 'Mayotte',
    'za'  => 'អាហ្វ្រិកខាងត្បូង',
    'zm'  => 'ហ្សាំប៊ី',
    'zw'  => 'ហ្ស៊ីមបាបវ៉េ',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::km::name_to_code = (
    'africa'                                                                                                             => '002',
    'americansamoa'                                                                                                      => 'as',
    'americas'                                                                                                           => '019',
    'anguilla'                                                                                                           => 'ai',
    'antarctica'                                                                                                         => 'aq',
    'antiguaandbarbuda'                                                                                                  => 'ag',
    'aruba'                                                                                                              => 'aw',
    'ascensionisland'                                                                                                    => 'ac',
    'asia'                                                                                                               => 142,
    'australiaandnewzealand'                                                                                             => '053',
    'bermuda'                                                                                                            => 'bm',
    'bouvetisland'                                                                                                       => 'bv',
    'britishantarcticterritory'                                                                                          => 'bq',
    'britishindianoceanterritory'                                                                                        => 'io',
    'britishvirginislands'                                                                                               => 'vg',
    'canaryislands'                                                                                                      => 'ic',
    'cantonandenderburyislands'                                                                                          => 'ct',
    'caribbean'                                                                                                          => '029',
    'caymanislands'                                                                                                      => 'ky',
    'centralamerica'                                                                                                     => '013',
    'centralasia'                                                                                                        => 143,
    'ceutaandmelilla'                                                                                                    => 'ea',
    'channelislands'                                                                                                     => 830,
    'christmasisland'                                                                                                    => 'cx',
    'clippertonisland'                                                                                                   => 'cp',
    'cocoskeelingislands'                                                                                                => 'cc',
    'commonwealthofindependentstates'                                                                                    => 172,
    'congodrc'                                                                                                           => 'cd',
    'cookislands'                                                                                                        => 'ck',
    'czechoslovakia'                                                                                                     => 200,
    'diegogarcia'                                                                                                        => 'dg',
    'dronningmaudland'                                                                                                   => 'nq',
    'easternafrica'                                                                                                      => '014',
    'easternasia'                                                                                                        => '030',
    'easterneurope'                                                                                                      => 151,
    'eastgermany'                                                                                                        => 'dd',
    'europe'                                                                                                             => 150,
    'europeanunion'                                                                                                      => 'eu',
    'falklandislandsislasmalvinas'                                                                                       => 'fk',
    'faroeislands'                                                                                                       => 'fo',
    'frenchguiana'                                                                                                       => 'gf',
    'frenchpolynesia'                                                                                                    => 'pf',
    'frenchsouthernandantarcticterritories'                                                                              => 'fq',
    'frenchsouthernterritories'                                                                                          => 'tf',
    'gibraltar'                                                                                                          => 'gi',
    'greenland'                                                                                                          => 'gl',
    'grenada'                                                                                                            => 'gd',
    'guadeloupe'                                                                                                         => 'gp',
    'guam'                                                                                                               => 'gu',
    'guernsey'                                                                                                           => 'gg',
    'heardislandandmcdonaldislands'                                                                                      => 'hm',
    'isleofman'                                                                                                          => 'im',
    'jersey'                                                                                                             => 'je',
    'johnstonisland'                                                                                                     => 'jt',
    'latinamerica'                                                                                                       => 419,
    'macau'                                                                                                              => 'mo',
    'malawi'                                                                                                             => 'mw',
    'maldives'                                                                                                           => 'mv',
    'marshallislands'                                                                                                    => 'mh',
    'martinique'                                                                                                         => 'mq',
    'mayotte'                                                                                                            => 'yt',
    'melanesia'                                                                                                          => '054',
    'metropolitanfrance'                                                                                                 => 'fx',
    'micronesianregion'                                                                                                  => '057',
    'middleafrica'                                                                                                       => '017',
    'midwayislands'                                                                                                      => 'mi',
    'montenegro'                                                                                                         => 'me',
    'montserrat'                                                                                                         => 'ms',
    'nauru'                                                                                                              => 'nr',
    'netherlandsantilles'                                                                                                => 'an',
    'neutralzone'                                                                                                        => 'nt',
    'newcaledonia'                                                                                                       => 'nc',
    'niue'                                                                                                               => 'nu',
    'norfolkisland'                                                                                                      => 'nf',
    'northamerica'                                                                                                       => '003',
    'northernafrica'                                                                                                     => '015',
    'northernamerica'                                                                                                    => '021',
    'northerneurope'                                                                                                     => 154,
    'northernmarianaislands'                                                                                             => 'mp',
    'northvietnam'                                                                                                       => 'vd',
    'oceania'                                                                                                            => '009',
    'outlyingoceania'                                                                                                    => 'qo',
    'pacificislandstrustterritory'                                                                                       => 'pc',
    'palau'                                                                                                              => 'pw',
    'panamacanalzone'                                                                                                    => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                                                                          => 'yd',
    'pitcairnislands'                                                                                                    => 'pn',
    'polynesia'                                                                                                          => '061',
    "r\Ã\©union"                                                                                                       => 're',
    "saintbarth\Ã\©lemy"                                                                                               => 'bl',
    'sainthelena'                                                                                                        => 'sh',
    'saintkittsandnevis'                                                                                                 => 'kn',
    'saintlucia'                                                                                                         => 'lc',
    'saintmartin'                                                                                                        => 'mf',
    'saintpierreandmiquelon'                                                                                             => 'pm',
    'saintvincentandthegrenadines'                                                                                       => 'vc',
    'sanmarino'                                                                                                          => 'sm',
    'serbia'                                                                                                             => 'rs',
    'serbiaandmontenegro'                                                                                                => 'cs',
    'solomonislands'                                                                                                     => 'sb',
    'southamerica'                                                                                                       => '005',
    'southcentralasia'                                                                                                   => '062',
    'southeasternasia'                                                                                                   => '035',
    'southernafrica'                                                                                                     => '018',
    'southernasia'                                                                                                       => '034',
    'southerneurope'                                                                                                     => '039',
    'southgeorgiaandthesouthsandwichislands'                                                                             => 'gs',
    'svalbardandjanmayen'                                                                                                => 'sj',
    "s\Ã\£otom\Ã\©andpr\Ã\­ncipe"                                                                                  => 'st',
    'tokelau'                                                                                                            => 'tk',
    'tristandacunha'                                                                                                     => 'ta',
    'turksandcaicosislands'                                                                                              => 'tc',
    'tuvalu'                                                                                                             => 'tv',
    "u\.s\.minoroutlyingislands"                                                                                         => 'um',
    "u\.s\.miscellaneouspacificislands"                                                                                  => 'pu',
    "u\.s\.virginislands"                                                                                                => 'vi',
    'unionofsovietsocialistrepublics'                                                                                    => 'su',
    'unitedkingdom'                                                                                                      => 'gb',
    'unknownregion'                                                                                                      => 'zz',
    'vanuatu'                                                                                                            => 'vu',
    'wakeisland'                                                                                                         => 'wk',
    'wallisandfutuna'                                                                                                    => 'wf',
    'westernafrica'                                                                                                      => '011',
    'westernasia'                                                                                                        => 145,
    'westerneurope'                                                                                                      => 155,
    'world'                                                                                                              => '001',
    "\Ã\landislands"                                                                                                  => 'ax',
    'កម្ពុជា'                                                                                              => 'kh',
    'កាណាដា'                                                                                                 => 'ca',
    'កាតារ'                                                                                                    => 'qa',
    'កាបវែរ'                                                                                                 => 'cv',
    'កាមេរូន'                                                                                              => 'cm',
    'កាហ្សាក់ស្តាង់់'                                                                      => 'kz',
    'កុងហ្គោ'                                                                                              => 'cg',
    'កុំម៉ូរ៉ូស'                                                                                     => 'km',
    'កូដឌីវ័រ'                                                                                           => 'ci',
    'កូស្តារីកា'                                                                                     => 'cr',
    'កូឡុំប៊ី'                                                                                           => 'co',
    'កេនយ៉ា'                                                                                                 => 'ke',
    'ក្រិច'                                                                                                    => 'gr',
    'ក្រូអាស៊ី'                                                                                        => 'hr',
    'គិរិបាទី'                                                                                           => 'ki',
    'គុយបា'                                                                                                    => 'cu',
    'គុយវ៉ែត'                                                                                              => 'kw',
    'គៀរហ្គីស្តង់'                                                                               => 'kg',
    'ចិន'                                                                                                          => 'cn',
    'ឆាដ'                                                                                                          => 'td',
    'ជប៉ុន'                                                                                                    => 'jp',
    'ឈីលី'                                                                                                       => 'cl',
    'ដាណឺម៉ាក'                                                                                           => 'dk',
    'ដូមីនីកា'                                                                                           => 'dm',
    'ណាមីប៊ី'                                                                                              => 'na',
    'តង់ហ្សានី'                                                                                        => 'tz',
    'តាដហ្ស៉ីគីស្តង់'                                                                      => 'tj',
    'តុងហ្គា'                                                                                              => 'to',
    'តូហ្គូ'                                                                                                 => 'tg',
    'តៃវ៉ាន់'                                                                                              => 'tw',
    'ថៃ'                                                                                                             => 'th',
    'ទីម័រខាងកើត'                                                                                  => 'tl',
    'ទុយនេស៊ី'                                                                                           => 'tn',
    'ទួគមេនីស្តង់'                                                                               => 'tm',
    'ទួរគី'                                                                                                    => 'tr',
    'ទ្រីនីដាដនឹងតូបាហ្គោ'                                                       => 'tt',
    'នីការ៉ាហ្គ័រ'                                                                               => 'ni',
    'នីហ្សេរ'                                                                                              => 'ne',
    'នីហ្សេរីយ៉ា'                                                                                  => 'ng',
    'នូវែលហ្សេឡង់'                                                                               => 'nz',
    'នេប៉ាល់'                                                                                              => 'np',
    'ន័រវែស'                                                                                                 => 'no',
    'បង់ក្លាដេស្ហ'                                                                               => 'bd',
    'បារបាដូស'                                                                                           => 'bb',
    'បារាំង'                                                                                                 => 'fr',
    'បារ៉ែន'                                                                                                 => 'bh',
    'បាហាម៉ា'                                                                                              => 'bs',
    'បុតស្វាណា'                                                                                        => 'bw',
    'បូលីវី'                                                                                                 => 'bo',
    'បូស្ន៉ី'                                                                                              => 'ba',
    'បេណាំង'                                                                                                 => 'bj',
    'បេលីហ្ស'                                                                                              => 'bz',
    'បេឡារុស្ស'                                                                                        => 'by',
    'បែលហ្ស៉ិក'                                                                                        => 'be',
    'ប៉ាគីស្ថាន'                                                                                     => 'pk',
    'ប៉ាណាម៉ា'                                                                                           => 'pa',
    'ប៉ាពូអានូវែលហ្គីណេ'                                                             => 'pg',
    'ប៉ារ៉ាហ្គាយ'                                                                                  => 'py',
    'ប៉ាលេស្ទីន'                                                                                     => 'ps',
    'ប៉ូលូញ'                                                                                                 => 'pl',
    'ប៉េរូ'                                                                                                    => 'pe',
    'ប៊ុលហ្គារី'                                                                                     => 'bg',
    'ប៊ូតាន'                                                                                                 => 'bt',
    'ប៊ូរគីណាហ្វាសូ'                                                                         => 'bf',
    'ប៊ូរុនឌី'                                                                                           => 'bi',
    'ប៊្រុយណេ'                                                                                           => 'bn',
    'ប្រេស៊ីល'                                                                                           => 'br',
    'ព័រតូរីកូ'                                                                                        => 'pr',
    'ព័រទុយហ្កាល់'                                                                               => 'pt',
    'មិក្រូនេស៊ី'                                                                                  => 'fm',
    'មីយ៉ាន់ម៉ា'                                                                                     => 'mm',
    'ម៉ាដាហ្កាស្ការ'                                                                         => 'mg',
    'ម៉ារ៉ុក'                                                                                              => 'ma',
    'ម៉ាលី'                                                                                                    => 'ml',
    'ម៉ាលេស៉ី'                                                                                           => 'my',
    'ម៉ាល់តា'                                                                                              => 'mt',
    'ម៉ាសេដន'                                                                                              => 'mk',
    'ម៉ិចសិក'                                                                                              => 'mx',
    'ម៉ុងហ្គោលី'                                                                                     => 'mn',
    'ម៉ូណាកូ'                                                                                              => 'mc',
    'ម៉ូរីតានី'                                                                                        => 'mr',
    'ម៉ូរីទុស'                                                                                           => 'mu',
    'ម៉ូហ្សាំប៊ិក'                                                                               => 'mz',
    'យេមែន'                                                                                                    => 'ye',
    'រវ៉ាន់ដា'                                                                                           => 'rw',
    'រូម៉ានី'                                                                                              => 'ro',
    'រូស្ស៊ី'                                                                                              => 'ru',
    'លិចទេនស្តែន'                                                                                  => 'li',
    'លីទុយអានី'                                                                                        => 'lt',
    'លីបង់'                                                                                                    => 'lb',
    'លីបេរីយ៉ា'                                                                                        => 'lr',
    'លីប៊ី'                                                                                                    => 'ly',
    'លុចហ្សំបួរ'                                                                                     => 'lu',
    'លើសូតូ'                                                                                                 => 'ls',
    'វៀតណាម'                                                                                                 => 'vn',
    'វេនេហ្ស៊ុយឡា'                                                                               => 've',
    'វ៉ាទីកង់'                                                                                           => 'va',
    'សហរដ្ឋអាមេរិក'                                                                            => 'us',
    'សាធារណរដ្ឋកូរ៉េ'                                                                      => 'kr',
    'សាធារណរដ្ឋឆេក'                                                                            => 'cz',
    'សាធារណរដ្ឋដូមីនីកែន'                                                          => 'do',
    'សាធារណរដ្ឋប្រជាធិបតេយ្យប្រជាមានិតកូរ៉េ' => 'kp',
    'សាធារណរដ្ឋម៉ុលដាវី'                                                             => 'md',
    'សាធារណរដ្ឋអាហ្វ្រិកកណ្ដាល'                                        => 'cf',
    'សាមូអា'                                                                                                 => 'ws',
    'សាហារ៉ាខាងលិច'                                                                            => 'eh',
    'សិង្ហបុរី'                                                                                        => 'sg',
    'សីសែល'                                                                                                    => 'sc',
    'សូម៉ាលី'                                                                                              => 'so',
    'សូរីណាម'                                                                                              => 'sr',
    'សូហ្ស៉ីឡង់'                                                                                     => 'sz',
    'សេនេហ្កាល់'                                                                                     => 'sn',
    'សេរ៉ាឡេអូន'                                                                                     => 'sl',
    'ស៉ីពរ៍'                                                                                                 => 'cy',
    'ស៊ីរី'                                                                                                    => 'sy',
    'ស៊ុយអែដ'                                                                                              => 'se',
    'ស៊ូដង់'                                                                                                 => 'sd',
    'ស្រីលង្កា'                                                                                        => 'lk',
    'ស្លូវេនី'                                                                                           => 'si',
    'ស្លូវ៉ាគី'                                                                                        => 'sk',
    'ស្វីស'                                                                                                    => 'ch',
    'ហុងកុង'                                                                                                 => 'hk',
    'ហុងគ្រី'                                                                                              => 'hu',
    'ហុងឌួរ៉ាស់'                                                                                     => 'hn',
    'ហូល្លង់'                                                                                              => 'nl',
    'ហៃទី'                                                                                                       => 'ht',
    'ហ៊្សកដានី'                                                                                        => 'jo',
    'ហ្កាណា'                                                                                                 => 'gh',
    'ហ្គាតេម៉ាឡា'                                                                                  => 'gt',
    'ហ្គាបុង'                                                                                              => 'ga',
    'ហ្គាំប៊ី'                                                                                           => 'gm',
    'ហ្គីណេ'                                                                                                 => 'gn',
    'ហ្គីណេប៊ីសូ'                                                                                  => 'gw',
    'ហ្គីណេអេក្វាទ័រ'                                                                      => 'gq',
    'ហ្គីយ៉ាណា'                                                                                        => 'gy',
    'ហ្វាំងឡង់'                                                                                        => 'fi',
    'ហ្វ៉ីលីពីន'                                                                                     => 'ph',
    'ហ្វ៉ីហ្ស៉ី'                                                                                     => 'fj',
    'ហ្សកហ្ស៉ី'                                                                                        => 'ge',
    'ហ្សាម៉ាអ៉ិគ'                                                                                  => 'jm',
    'ហ្សាំប៊ី'                                                                                           => 'zm',
    'ហ្ស៉ីបូទី'                                                                                        => 'dj',
    'ហ្ស៊ីមបាបវ៉េ'                                                                               => 'zw',
    'ឡាតវីយ៉ា'                                                                                           => 'lv',
    'ឡាវ'                                                                                                          => 'la',
    'អង់ហ្គោឡា'                                                                                        => 'ao',
    'អានដូរ៉ា'                                                                                           => 'ad',
    'អារមេនី'                                                                                              => 'am',
    'អារ៉ាប៊ីសាអ៊ូឌីត'                                                                   => 'sa',
    'អាល់បានី'                                                                                           => 'al',
    'អាល់ហ្សេរី'                                                                                     => 'dz',
    'អាល្លឺម៉ង់'                                                                                     => 'de',
    'អាហ៊្សែរបែហ្សង់'                                                                      => 'az',
    'អាហ្វហ្គានីស្ថាន'                                                                   => 'af',
    'អាហ្វ្រិកខាងត្បូង'                                                                => 'za',
    'អាហ្សង់ទីន'                                                                                     => 'ar',
    'អូទ្រីស'                                                                                              => 'at',
    'អូម៉ង់'                                                                                                 => 'om',
    'អូស្ត្រាលី'                                                                                     => 'au',
    'អៀរឡង់'                                                                                                 => 'ie',
    'អេក្វាឌ័រ'                                                                                        => 'ec',
    'អេត្យូពី'                                                                                           => 'et',
    'អេមីរ៉ែទអារ៉ាប់រួម'                                                             => 'ae',
    'អេរីទ្រា'                                                                                           => 'er',
    'អេស្តូនី'                                                                                           => 'ee',
    'អេស្ប៉ាញ'                                                                                           => 'es',
    'អេហ្ស៉ីប'                                                                                           => 'eg',
    'អែលសាល់វ៉ាឌ័រ'                                                                            => 'sv',
    'អ៉ីស្លង់'                                                                                           => 'is',
    'អ៊ីតាលី'                                                                                              => 'it',
    'អ៊ីរ៉ង់'                                                                                              => 'ir',
    'អ៊ីរ៉ាក់'                                                                                           => 'iq',
    'អ៊ីស្រាអែល'                                                                                     => 'il',
    'អ៊ុយក្រែន'                                                                                        => 'ua',
    'អ៊ុយរុយហ្គាយ'                                                                               => 'uy',
    'អ៊ូហ្កង់ដា'                                                                                     => 'ug',
    'អ៊ូហ្សបេគីស្តង់'                                                                      => 'uz',
    'ឥណ្ឌា'                                                                                                    => 'in',
    'ឥណ្ឌូនេស៊ី'                                                                                     => 'id',
);

1;

