package Locales::DB::Territory::agq;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::agq::VERSION = '0.09';

$Locales::DB::Territory::agq::cldr_version = '2.0';

%Locales::DB::Territory::agq::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Àndolà',
    'ae'  => "Yùnaetɛ\ Alab\ ɛmelɛ̀",
    'af'  => 'Àfɨ̀ganìsɨ̀tân',
    'ag'  => "Àntigwà\ à\ Bàbudà",
    'ai'  => 'Àŋgwilà',
    'al'  => 'Àabɛnìa',
    'am'  => 'Àmɛnyìa',
    'an'  => "Nedàlân\ Antàe",
    'ao'  => 'Àŋgolà',
    'aq'  => 'Antarctica',
    'ar'  => 'Àdzɛ̀ntinà',
    'as'  => "Àmɛlekan\ Samwà",
    'at'  => 'Usɨtɨ̀là',
    'au'  => 'Ùsɨ̀tɛ̀lɛlìa',
    'aw'  => 'Àlubà',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Àzɨbɛ̀dzân',
    'ba'  => "Bosɨnyìa\ à\ Hɛ̀zɛ̀gòvinà",
    'bb'  => 'Bàbadòs',
    'bd'  => 'Baŋgɨ̀làdɛ̂',
    'be'  => 'Bɛɛdzwùm',
    'bf'  => "Bùkinà\ Fasò",
    'bg'  => 'Bùugɛlìa',
    'bh'  => 'Bàlaen',
    'bi'  => 'Bùlundì',
    'bj'  => 'Bɛ̀nɨ̂ŋ',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bɛ̀mudà',
    'bn'  => 'Bɨ̀lunè',
    'bo'  => 'Bòlevà',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Bɨ̀làzîi',
    'bs'  => 'Bàhamàs',
    'bt'  => 'Mbutàn',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Bòtɨ̀swǎnà',
    'by'  => 'Bɛlàlûs',
    'bz'  => 'Bɛ̀lezɨ̀',
    'ca'  => 'Kanadà',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Dɛ̀mùkàlatì\ Lèkpubèlè\ è\ Kuŋgù",
    'cf'  => "Sɛnta\ Afɨlekan\ Lèkpobèlè",
    'cg'  => 'Kuŋgù',
    'ch'  => 'Suezàlân',
    'ci'  => "Ku\ Dɨ̀vûa",
    'ck'  => "Chwɨla\ ŋ̀\ Kûʔ",
    'cl'  => 'Chilè',
    'cm'  => 'Kàmàlûŋ',
    'cn'  => 'Chaenà',
    'co'  => 'Kòlombìa',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kòsɨ̀tà\ Lekà",
    'cs'  => "Sɛɛbìa\ à\ Mùŋtànegùlù",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuuwbà',
    'cv'  => "Chwɨla\ ŋ̀\ Kɛ̀b\ Vɛ̂ɛ",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Saekpùlù',
    'cz'  => "Chɛ̂\ Lèkpubèlè",
    'dd'  => "East\ Germany",
    'de'  => 'Dzamanè',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Dzìbuwtì',
    'dk'  => 'Dɛnɨmà',
    'dm'  => 'Dòmenekà',
    'do'  => "Dòmenekà\ Lèkpubèlè",
    'dz'  => 'Àadzɛlìa',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwadò',
    'ee'  => 'Èsɨ̀tonyìa',
    'eg'  => 'Edzì',
    'eh'  => "Western\ Sahara",
    'er'  => 'Èletɨ̀là',
    'es'  => 'Sɨ̀kpɛ̂n',
    'et'  => 'Ètyǒpìa',
    'eu'  => "European\ Union",
    'fi'  => 'Fɨnlàn',
    'fj'  => 'Fidzi',
    'fk'  => "Chwɨlà\ fɨ\ Fakɨlàn",
    'fm'  => 'Maekòlòneshìa',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Fàlâŋnsì',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gàbûn',
    'gb'  => "Yùnaetɛ\ Kiŋdɔ̀m",
    'gd'  => 'Gɨ̀lɛnadà',
    'ge'  => 'Dzɔɔdzìa',
    'gf'  => "Gàyanà\ è\ Fàlâŋnsì",
    'gg'  => 'Guernsey',
    'gh'  => 'Gaanà',
    'gi'  => 'Dzibɨ̀latà',
    'gl'  => 'Gɨ̀lenlân',
    'gm'  => 'Gambìa',
    'gn'  => 'Ginè',
    'gp'  => 'Gwadalukpɛ̀',
    'gq'  => "Èkwɛ̀tolia\ Ginè",
    'gr'  => 'Gɨ̀lês',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwàtɨ̀malà',
    'gu'  => 'Gwam',
    'gw'  => "Ginè\ Bìsawù",
    'gy'  => 'Gùyanà',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hɔndulàs',
    'hr'  => 'Kòwɛshìa',
    'ht'  => 'Hǎetì',
    'hu'  => 'Hɔŋgàlè',
    'ic'  => "Canary\ Islands",
    'id'  => 'Èndòneshìa',
    'ie'  => 'Aelɨ̀lân',
    'il'  => 'Ezɨ̀lɛ̂',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Endìa',
    'io'  => "Dɨŋò\ kɨ\ dzughùnstòʔ\ kɨ\ Endìa\ kɨ\ Bɨ̀letì\ kò",
    'iq'  => 'Èlâkɨ̀',
    'ir'  => 'Èlân',
    'is'  => 'Aesɨ̀lân',
    'it'  => 'Etalè',
    'je'  => 'Jersey',
    'jm'  => 'Dzàmɛkà',
    'jo'  => 'Dzodàn',
    'jp'  => 'Dzàkpân',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kɨnyà',
    'kg'  => 'Kìdzisɨ̀tân',
    'kh'  => 'Kàmbodìa',
    'ki'  => 'Kèlèbati',
    'km'  => 'Komolòs',
    'kn'  => "Sɛ̀n\ Kî\ à\ Nevì",
    'kp'  => "Kùulîa\,\ Ekùw",
    'kr'  => "Kùulîa\,\ Emàm",
    'kw'  => 'Kùwɛ̂',
    'ky'  => "Chwɨlà\ ŋ̀\ Kaemàn",
    'kz'  => 'Kàzasɨ̀tân',
    'la'  => 'Làwos',
    'lb'  => 'Lɛbanè',
    'lc'  => "Sɛ̀n\ Lushìa",
    'li'  => 'Letɨnshɨ̀n',
    'lk'  => "Sɨ̀le\ Laŋkà",
    'lr'  => 'Làebɛlìa',
    'ls'  => 'Lɛ̀sotù',
    'lt'  => 'Lètwǎnyìa',
    'lu'  => 'Luzɨmbùʔ',
    'lv'  => 'Làtɨva',
    'ly'  => 'Lebìa',
    'ma'  => 'Mòlokò',
    'mc'  => 'Mùnaku',
    'md'  => 'Mòodovà',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Màdàgasɨkà',
    'mh'  => "Chwɨlà\ fɨ\ Mashà",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Mɨ̀sɨ̀donyìa',
    'ml'  => 'Malè',
    'mm'  => 'Mǐanmà',
    'mn'  => 'Mùŋgolìa',
    'mo'  => 'Macau',
    'mp'  => "Chwɨlà\ m̀\ Màlǐanà\ mɨ̀\ Ekùw\ mò",
    'mq'  => 'Màtìnekì',
    'mr'  => 'Mùlètanyìa',
    'ms'  => 'Mùŋtselà',
    'mt'  => 'Maatà',
    'mu'  => 'Mùleshwɨ̀s',
    'mv'  => 'Màdivè',
    'mw'  => 'Màlawì',
    'mx'  => 'Mɛkɨzikù',
    'my'  => 'Màlɛshìa',
    'mz'  => 'Mùzàmbî',
    'na'  => 'Nàmibìa',
    'nc'  => "Kàlèdonyìa\ È\ fūghū",
    'ne'  => 'Naedzà',
    'nf'  => "Chwɨlà\ fɨ\ Nufòʔ",
    'ng'  => 'Gɨ̀anyɨ',
    'ni'  => 'Nikàlagwà',
    'nl'  => 'Nedàlân',
    'no'  => 'Noowɛ̂ɛ',
    'np'  => 'Nɛkpâa',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nàwulù',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niyu',
    'nz'  => "Zìlân\ È\ fūghū",
    'om'  => 'Umàn',
    'pa'  => 'Kpanàma',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Kpɛlû',
    'pf'  => "Kpoleneshìa\ è\ Fàlâŋnsì",
    'pg'  => "Kpakpua\ Ginè\ È\ fūghū",
    'ph'  => 'Felèkpî',
    'pk'  => 'Kpakìsɨ̀tân',
    'pl'  => 'Kpulàn',
    'pm'  => "Sɛ̀n\ Kpiyɛ̀\ à\ Mikelɔŋ",
    'pn'  => 'Kpitɨ̀kalè',
    'pr'  => "Kpǒto\ Leko",
    'ps'  => "Adzɨmā\ kɨ\ ŋgùŋ\ kɨ\ Palɛsɨtɨnyia\ à\ kɨ\ Gazà\ kò",
    'pt'  => 'Kputuwgà',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Kpàlawù',
    'py'  => 'Kpalàgwɛ̂',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katà',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Lèyunyɔ̀ŋ',
    'ro'  => 'Lùmanyìa',
    'rs'  => 'Serbia',
    'ru'  => 'Loshìa',
    'rw'  => 'Lùwandà',
    'sa'  => "Sawudi\ Alabi",
    'sb'  => "Chwɨlà\ fɨ\ Solomwɨ̀n",
    'sc'  => 'Sɛchɛ̀lɛ̀s',
    'sd'  => 'Sùdân',
    'se'  => 'Suedɨ̀n',
    'sg'  => 'Siŋgàkpôo',
    'sh'  => "Sɛ̀n\ Èlenà",
    'si'  => 'Sɨ̀lòvɨnyìa',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Sɨ̀lòvɨkɨ̀a',
    'sl'  => "Silìa\ lûŋ",
    'sm'  => "Sàn\ Màlenù",
    'sn'  => 'Sɛ̀nɛ̀gâa',
    'so'  => 'Sòmalìa',
    'sr'  => 'Sulènamè',
    'st'  => "Sawo\ Tɔ̀me\ à\ Kpèlènsikpɛ̀",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Esàvadò',
    'sy'  => 'Silîa',
    'sz'  => 'Shǔazìlân',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Chwɨla\ n\ Tɨtê\ à\ Kaekùs",
    'td'  => 'Châ',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Tugù',
    'th'  => 'Taelàn',
    'tj'  => 'Tàdzikìsɨ̀tân',
    'tk'  => 'Tuwkelawù',
    'tl'  => "Ês\ Taemò",
    'tm'  => 'Tekɨmènèsɨ̀tân',
    'tn'  => 'Tùneshìa',
    'to'  => 'Tuŋgà',
    'tr'  => 'Teekì',
    'tt'  => "Tèlenedà\ à\ Tòbagù",
    'tv'  => 'Tuwvalùw',
    'tw'  => 'Taewàn',
    'tz'  => 'Tàanzanyìa',
    'ua'  => 'Yùkɛ̀lɛ̂',
    'ug'  => 'Yùgandà',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'USA',
    'uy'  => 'Yulùgwɛ̂',
    'uz'  => 'Yùzɨ̀bɛkìsɨ̀tân',
    'va'  => "Vatikàn\ Sɨ̀tɛ̂",
    'vc'  => "Sɛ̀n\ Vinsɨ̀n\ à\ Gɨlenadi\ Ù\ tē",
    'vd'  => "North\ Vietnam",
    've'  => 'Vɛ̀nɛ̀zǔɛɛlà',
    'vg'  => "Chwɨlà\ m̀\ Vidzinyìa\ m̀\ Bɨ̀letì\ mò",
    'vi'  => "U\.\ S\.\ Chwɨlà\ fɨ\ Mbuʔmbu",
    'vn'  => 'Vìyɛnàm',
    'vu'  => 'Vànǔatùw',
    'wf'  => "Wales\ à\ Fùwtuwnà",
    'wk'  => "Wake\ Island",
    'ws'  => 'Sàmowà',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yɛmɛ̀n',
    'yt'  => 'Màyotì',
    'za'  => "Afɨlekà\ ghɨ\ Emàm\ ghò",
    'zm'  => 'Zambìa',
    'zw'  => 'Zìmbagbɛ̀',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::agq::name_to_code = (
    'adzɨmākɨŋgùŋkɨpalɛsɨtɨnyiaàkɨgazàkò' => 'ps',
    'aelɨ̀lân'                                       => 'ie',
    'aesɨ̀lân'                                       => 'is',
    'africa'                                            => '002',
    'afɨlekàghɨemàmghò'                            => 'za',
    'americas'                                          => '019',
    'antarctica'                                        => 'aq',
    'ascensionisland'                                   => 'ac',
    'asia'                                              => 142,
    'australiaandnewzealand'                            => '053',
    'baŋgɨ̀làdɛ̂'                                 => 'bd',
    'bosɨnyìaàhɛ̀zɛ̀gòvinà'                    => 'ba',
    'bouvetisland'                                      => 'bv',
    'britishantarcticterritory'                         => 'bq',
    'bàbadòs'                                         => 'bb',
    'bàhamàs'                                         => 'bs',
    'bàlaen'                                           => 'bh',
    'bòlevà'                                          => 'bo',
    'bòtɨ̀swǎnà'                                   => 'bw',
    'bùkinàfasò'                                     => 'bf',
    'bùlundì'                                         => 'bi',
    'bùugɛlìa'                                       => 'bg',
    'bɛlàlûs'                                        => 'by',
    'bɛɛdzwùm'                                       => 'be',
    'bɛ̀lezɨ̀'                                      => 'bz',
    'bɛ̀mudà'                                        => 'bm',
    'bɛ̀nɨ̂ŋ'                                      => 'bj',
    'bɨ̀lunè'                                        => 'bn',
    'bɨ̀làzîi'                                      => 'br',
    'canaryislands'                                     => 'ic',
    'cantonandenderburyislands'                         => 'ct',
    'caribbean'                                         => '029',
    'centralamerica'                                    => '013',
    'centralasia'                                       => 143,
    'ceutaandmelilla'                                   => 'ea',
    'chaenà'                                           => 'cn',
    'channelislands'                                    => 830,
    'chilè'                                            => 'cl',
    'christmasisland'                                   => 'cx',
    'chwɨlantɨtêàkaekùs'                           => 'tc',
    'chwɨlaŋ̀kûʔ'                                  => 'ck',
    'chwɨlaŋ̀kɛ̀bvɛ̂ɛ'                          => 'cv',
    'chwɨlàfɨfakɨlàn'                              => 'fk',
    'chwɨlàfɨmashà'                                 => 'mh',
    'chwɨlàfɨnufòʔ'                                => 'nf',
    'chwɨlàfɨsolomwɨ̀n'                            => 'sb',
    'chwɨlàm̀màlǐanàmɨ̀ekùwmò'                => 'mp',
    'chwɨlàm̀vidzinyìam̀bɨ̀letìmò'             => 'vg',
    'chwɨlàŋ̀kaemàn'                               => 'ky',
    'châ'                                              => 'td',
    'chɛ̂lèkpubèlè'                                => 'cz',
    'clippertonisland'                                  => 'cp',
    'cocoskeelingislands'                               => 'cc',
    'commonwealthofindependentstates'                   => 172,
    'czechoslovakia'                                    => 200,
    'diegogarcia'                                       => 'dg',
    'dronningmaudland'                                  => 'nq',
    'dzamanè'                                          => 'de',
    'dzibɨ̀latà'                                     => 'gi',
    'dzodàn'                                           => 'jo',
    'dzàkpân'                                         => 'jp',
    'dzàmɛkà'                                        => 'jm',
    'dzìbuwtì'                                        => 'dj',
    'dzɔɔdzìa'                                       => 'ge',
    'dòmenekà'                                        => 'dm',
    'dòmenekàlèkpubèlè'                            => 'do',
    'dɛnɨmà'                                         => 'dk',
    'dɛ̀mùkàlatìlèkpubèlèèkuŋgù'             => 'cd',
    'dɨŋòkɨdzughùnstòʔkɨendìakɨbɨ̀letìkò' => 'io',
    'easternafrica'                                     => '014',
    'easternasia'                                       => '030',
    'easterneurope'                                     => 151,
    'eastgermany'                                       => 'dd',
    'edzì'                                             => 'eg',
    'ekwadò'                                           => 'ec',
    'endìa'                                            => 'in',
    'esàvadò'                                         => 'sv',
    'etalè'                                            => 'it',
    'europe'                                            => 150,
    'europeanunion'                                     => 'eu',
    'ezɨ̀lɛ̂'                                       => 'il',
    'faroeislands'                                      => 'fo',
    'felèkpî'                                         => 'ph',
    'fidzi'                                             => 'fj',
    'frenchsouthernandantarcticterritories'             => 'fq',
    'frenchsouthernterritories'                         => 'tf',
    'fàlâŋnsì'                                      => 'fr',
    'fɨnlàn'                                          => 'fi',
    'gaanà'                                            => 'gh',
    'gambìa'                                           => 'gm',
    'ginè'                                             => 'gn',
    'ginèbìsawù'                                     => 'gw',
    'guernsey'                                          => 'gg',
    'gwadalukpɛ̀'                                     => 'gp',
    'gwam'                                              => 'gu',
    'gwàtɨ̀malà'                                    => 'gt',
    'gàbûn'                                           => 'ga',
    'gàyanàèfàlâŋnsì'                            => 'gf',
    'gùyanà'                                          => 'gy',
    'gɨ̀anyɨ'                                        => 'ng',
    'gɨ̀lenlân'                                      => 'gl',
    'gɨ̀lês'                                         => 'gr',
    'gɨ̀lɛnadà'                                     => 'gd',
    'heardislandandmcdonaldislands'                     => 'hm',
    'hongkong'                                          => 'hk',
    'hǎetì'                                           => 'ht',
    'hɔndulàs'                                        => 'hn',
    'hɔŋgàlè'                                       => 'hu',
    'isleofman'                                         => 'im',
    'jersey'                                            => 'je',
    'johnstonisland'                                    => 'jt',
    'kanadà'                                           => 'ca',
    'katà'                                             => 'qa',
    'komolòs'                                          => 'km',
    'kpakpuaginèÈfūghū'                             => 'pg',
    'kpakìsɨ̀tân'                                   => 'pk',
    'kpalàgwɛ̂'                                      => 'py',
    'kpanàma'                                          => 'pa',
    'kpitɨ̀kalè'                                     => 'pn',
    'kpoleneshìaèfàlâŋnsì'                        => 'pf',
    'kpulàn'                                           => 'pl',
    'kputuwgà'                                         => 'pt',
    'kpàlawù'                                         => 'pw',
    'kpǒtoleko'                                        => 'pr',
    'kpɛlû'                                           => 'pe',
    'kudɨ̀vûa'                                       => 'ci',
    'kuuwbà'                                           => 'cu',
    'kuŋgù'                                           => 'cg',
    'kàlèdonyìaÈfūghū'                            => 'nc',
    'kàmbodìa'                                        => 'kh',
    'kàmàlûŋ'                                       => 'cm',
    'kàzasɨ̀tân'                                    => 'kz',
    'kèlèbati'                                        => 'ki',
    'kìdzisɨ̀tân'                                   => 'kg',
    'kòlombìa'                                        => 'co',
    'kòsɨ̀tàlekà'                                  => 'cr',
    'kòwɛshìa'                                       => 'hr',
    "kùulîa\,ekùw"                                   => 'kp',
    "kùulîa\,emàm"                                   => 'kr',
    'kùwɛ̂'                                          => 'kw',
    'kɨnyà'                                           => 'ke',
    'latinamerica'                                      => 419,
    'lebìa'                                            => 'ly',
    'letɨnshɨ̀n'                                     => 'li',
    'loshìa'                                           => 'ru',
    'luzɨmbùʔ'                                       => 'lu',
    'làebɛlìa'                                       => 'lr',
    'làtɨva'                                          => 'lv',
    'làwos'                                            => 'la',
    'lètwǎnyìa'                                      => 'lt',
    'lèyunyɔ̀ŋ'                                     => 're',
    'lùmanyìa'                                        => 'ro',
    'lùwandà'                                         => 'rw',
    'lɛbanè'                                          => 'lb',
    'lɛ̀sotù'                                        => 'ls',
    'maatà'                                            => 'mt',
    'macau'                                             => 'mo',
    'maekòlòneshìa'                                  => 'fm',
    'malè'                                             => 'ml',
    'mbutàn'                                           => 'bt',
    'melanesia'                                         => '054',
    'metropolitanfrance'                                => 'fx',
    'micronesianregion'                                 => '057',
    'middleafrica'                                      => '017',
    'midwayislands'                                     => 'mi',
    'montenegro'                                        => 'me',
    'màdivè'                                          => 'mv',
    'màdàgasɨkà'                                    => 'mg',
    'màlawì'                                          => 'mw',
    'màlɛshìa'                                       => 'my',
    'màtìnekì'                                       => 'mq',
    'màyotì'                                          => 'yt',
    'mòlokò'                                          => 'ma',
    'mòodovà'                                         => 'md',
    'mùleshwɨ̀s'                                     => 'mu',
    'mùlètanyìa'                                     => 'mr',
    'mùnaku'                                           => 'mc',
    'mùzàmbî'                                        => 'mz',
    'mùŋgolìa'                                       => 'mn',
    'mùŋtselà'                                       => 'ms',
    'mǐanmà'                                          => 'mm',
    'mɛkɨzikù'                                       => 'mx',
    'mɨ̀sɨ̀donyìa'                                 => 'mk',
    'naedzà'                                           => 'ne',
    'nedàlân'                                         => 'nl',
    'nedàlânantàe'                                   => 'an',
    'neutralzone'                                       => 'nt',
    'nikàlagwà'                                       => 'ni',
    'niyu'                                              => 'nu',
    'noowɛ̂ɛ'                                        => 'no',
    'northamerica'                                      => '003',
    'northernafrica'                                    => '015',
    'northernamerica'                                   => '021',
    'northerneurope'                                    => 154,
    'northvietnam'                                      => 'vd',
    'nàmibìa'                                         => 'na',
    'nàwulù'                                          => 'nr',
    'nɛkpâa'                                          => 'np',
    'oceania'                                           => '009',
    'outlyingoceania'                                   => 'qo',
    'pacificislandstrustterritory'                      => 'pc',
    'panamacanalzone'                                   => 'pz',
    "people\â\\sdemocraticrepublicofyemen"         => 'yd',
    'polynesia'                                         => '061',
    'saekpùlù'                                        => 'cy',
    "saintbarth\Ã\©lemy"                              => 'bl',
    'saintmartin'                                       => 'mf',
    'sawotɔ̀meàkpèlènsikpɛ̀'                     => 'st',
    'sawudialabi'                                       => 'sa',
    'serbia'                                            => 'rs',
    'shǔazìlân'                                      => 'sz',
    'silìalûŋ'                                       => 'sl',
    'silîa'                                            => 'sy',
    'siŋgàkpôo'                                      => 'sg',
    'southamerica'                                      => '005',
    'southcentralasia'                                  => '062',
    'southeasternasia'                                  => '035',
    'southernafrica'                                    => '018',
    'southernasia'                                      => '034',
    'southerneurope'                                    => '039',
    'southgeorgiaandthesouthsandwichislands'            => 'gs',
    'suedɨ̀n'                                         => 'se',
    'suezàlân'                                        => 'ch',
    'sulènamè'                                        => 'sr',
    'svalbardandjanmayen'                               => 'sj',
    'sàmowà'                                          => 'ws',
    'sànmàlenù'                                      => 'sm',
    'sòmalìa'                                         => 'so',
    'sùdân'                                           => 'sd',
    'sɛchɛ̀lɛ̀s'                                   => 'sc',
    'sɛntaafɨlekanlèkpobèlè'                       => 'cf',
    'sɛɛbìaàmùŋtànegùlù'                       => 'cs',
    'sɛ̀nkpiyɛ̀àmikelɔŋ'                         => 'pm',
    'sɛ̀nkîànevì'                                  => 'kn',
    'sɛ̀nlushìa'                                     => 'lc',
    'sɛ̀nvinsɨ̀nàgɨlenadiÙtē'                   => 'vc',
    'sɛ̀nÈlenà'                                     => 'sh',
    'sɛ̀nɛ̀gâa'                                    => 'sn',
    'sɨ̀kpɛ̂n'                                      => 'es',
    'sɨ̀lelaŋkà'                                    => 'lk',
    'sɨ̀lòvɨkɨ̀a'                                 => 'sk',
    'sɨ̀lòvɨnyìa'                                  => 'si',
    'taelàn'                                           => 'th',
    'taewàn'                                           => 'tw',
    'teekì'                                            => 'tr',
    'tekɨmènèsɨ̀tân'                              => 'tm',
    'tristandacunha'                                    => 'ta',
    'tugù'                                             => 'tg',
    'tuwkelawù'                                        => 'tk',
    'tuwvalùw'                                         => 'tv',
    'tuŋgà'                                           => 'to',
    'tàanzanyìa'                                      => 'tz',
    'tàdzikìsɨ̀tân'                                => 'tj',
    'tèlenedààtòbagù'                              => 'tt',
    'tùneshìa'                                        => 'tn',
    "u\.s\.chwɨlàfɨmbuʔmbu"                         => 'vi',
    "u\.s\.minoroutlyingislands"                        => 'um',
    "u\.s\.miscellaneouspacificislands"                 => 'pu',
    'umàn'                                             => 'om',
    'unionofsovietsocialistrepublics'                   => 'su',
    'unknownregion'                                     => 'zz',
    'usa'                                               => 'us',
    'usɨtɨ̀là'                                      => 'at',
    'vatikànsɨ̀tɛ̂'                                => 'va',
    'vànǔatùw'                                       => 'vu',
    'vìyɛnàm'                                        => 'vn',
    'vɛ̀nɛ̀zǔɛɛlà'                              => 've',
    'wakeisland'                                        => 'wk',
    'walesàfùwtuwnà'                                 => 'wf',
    'westernafrica'                                     => '011',
    'westernasia'                                       => 145,
    'westerneurope'                                     => 155,
    'westernsahara'                                     => 'eh',
    'world'                                             => '001',
    'yulùgwɛ̂'                                       => 'uy',
    'yùgandà'                                         => 'ug',
    'yùkɛ̀lɛ̂'                                     => 'ua',
    'yùnaetɛalabɛmelɛ̀'                            => 'ae',
    'yùnaetɛkiŋdɔ̀m'                               => 'gb',
    'yùzɨ̀bɛkìsɨ̀tân'                           => 'uz',
    'yɛmɛ̀n'                                         => 'ye',
    'zambìa'                                           => 'zm',
    'zìlânÈfūghū'                                  => 'nz',
    'zìmbagbɛ̀'                                      => 'zw',
    'Àabɛnìa'                                        => 'al',
    'Àadzɛlìa'                                       => 'dz',
    'Àdzɛ̀ntinà'                                    => 'ar',
    'Àfɨ̀ganìsɨ̀tân'                             => 'af',
    'Àlubà'                                           => 'aw',
    'Àmɛlekansamwà'                                  => 'as',
    'Àmɛnyìa'                                        => 'am',
    'Àndolà'                                          => 'ad',
    'Àntigwààbàbudà'                               => 'ag',
    'Àzɨbɛ̀dzân'                                   => 'az',
    'Àŋgolà'                                         => 'ao',
    'Àŋgwilà'                                        => 'ai',
    "\Ã\landislands"                                 => 'ax',
    'Èkwɛ̀toliaginè'                                => 'gq',
    'Èletɨ̀là'                                      => 'er',
    'Èlâkɨ̀'                                        => 'iq',
    'Èlân'                                            => 'ir',
    'Èndòneshìa'                                     => 'id',
    'Èsɨ̀tonyìa'                                    => 'ee',
    'Ètyǒpìa'                                        => 'et',
    'Êstaemò'                                         => 'tl',
    'Ùsɨ̀tɛ̀lɛlìa'                               => 'au',
);

1;

