package Locales::DB::Territory::af;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::af::VERSION = '0.09';

$Locales::DB::Territory::af::cldr_version = '2.0';

%Locales::DB::Territory::af::code_to_name = (
    '001' => 'Wêreld',
    '002' => 'Afrika',
    '003' => "Noord\-Amerika",
    '005' => "Suid\-Amerika",
    '009' => 'Oseanië',
    '011' => "Wes\-Afrika",
    '013' => "Sentraal\-Amerika",
    '014' => "Oos\-Afrika",
    '015' => "Noord\-Afrika",
    '017' => "Midde\-Afrika",
    '018' => "Suider\-Afrika",
    '019' => 'Amerikas',
    '021' => "Noordelike\ Amerika",
    '029' => 'Karibbies',
    '030' => "Oos\-Asië",
    '034' => "Suid\-Asië",
    '035' => "Suidoos\-Asië",
    '039' => "Suid\-Europa",
    '053' => "Australië\ en\ Nieu\-Seeland",
    '054' => 'Melanesië',
    '057' => "Mikronesiese\ streek",
    '061' => 'Polinesië',
    '062' => "South\-Central\ Asia",
    142   => 'Asië',
    143   => "Sentraal\-Asië",
    145   => "Wes\-Asië",
    150   => 'Europa',
    151   => "Oos\-Europa",
    154   => "Noord\-Europa",
    155   => "Wes\-Europa",
    172   => "Gemenebes\ van\ Onafhanklike\ State",
    200   => 'Czechoslovakia',
    419   => "Latyns\ Amerika",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\-eiland",
    'ad'  => 'Andorra',
    'ae'  => "Verenigde\ Arabiese\ Emirate",
    'af'  => 'Afganistan',
    'ag'  => "Antigua\ en\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albanië',
    'am'  => 'Armenië',
    'an'  => "Nederlands\-Antille",
    'ao'  => 'Angola',
    'aq'  => 'Antarktika',
    'ar'  => 'Argentinië',
    'as'  => "Amerikaans\ Samoa",
    'at'  => 'Oostenryk',
    'au'  => 'Australië',
    'aw'  => 'Aruba',
    'ax'  => "Åland\-eilande",
    'az'  => 'Aserbeidjan',
    'ba'  => "Bosnië\ en\ Herzegowina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesj',
    'be'  => 'België',
    'bf'  => "Boerkina\ Fasso",
    'bg'  => 'Bulgarye',
    'bh'  => 'Bahrein',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Sint\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Broenei',
    'bo'  => 'Bolivië',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasilië',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhoetan',
    'bv'  => 'Bouveteiland',
    'bw'  => 'Botswana',
    'by'  => "Wit\-Rusland",
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\-\ \[Keeling\]\ eilande",
    'cd'  => "Kongo\ \(DRK\)",
    'cf'  => "Sentraal\-Afrikaanse\ Republiek",
    'cg'  => "Kongo\ \[Republiek\]",
    'ch'  => 'Switserland',
    'ci'  => 'Ivoorkus',
    'ck'  => 'Cookeilande',
    'cl'  => 'Chili',
    'cm'  => 'Kameroen',
    'cn'  => 'Sjina',
    'co'  => 'Kolombië',
    'cp'  => "Clipperton\-eiland",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serwië\ en\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Kaap\ Verde",
    'cx'  => 'Kerseiland',
    'cy'  => 'Ciprus',
    'cz'  => "Tjeggiese\ Republiek",
    'dd'  => "East\ Germany",
    'de'  => 'Duitsland',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djiboeti',
    'dk'  => 'Denemarke',
    'dm'  => 'Dominika',
    'do'  => "Dominikaanse\ Republiek",
    'dz'  => 'Algerië',
    'ea'  => "Ceuta\ en\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estland',
    'eg'  => 'Egipte',
    'eh'  => "Wes\-Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Spanje',
    'et'  => 'Ethiopië',
    'eu'  => "Europese\ Unie",
    'fi'  => 'Finland',
    'fj'  => 'Fidji',
    'fk'  => "Falkland\-eilande\ \[Malvinas\]",
    'fm'  => 'Mikronesië',
    'fo'  => 'Faroëreilande',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frankryk',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gaboen',
    'gb'  => "Groot\-Brittanje",
    'gd'  => 'Grenada',
    'ge'  => 'Georgië',
    'gf'  => "Frans\-Guyana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Groenland',
    'gm'  => 'Gambië',
    'gn'  => 'Guinee',
    'gp'  => 'Guadeloupe',
    'gq'  => "Ekwatoriaal\-Guinee",
    'gr'  => 'Griekeland',
    'gs'  => "Suid\-Georgië\ en\ die\ Suid\-Sandwich\-eilande",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinee\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\-eiland\ en\ McDonald\-eilande",
    'hn'  => 'Honduras',
    'hr'  => 'Kroasië',
    'ht'  => 'Haïti',
    'hu'  => 'Hongarye',
    'ic'  => "Kanarie\-eilande",
    'id'  => 'Indonesië',
    'ie'  => 'Ierland',
    'il'  => 'Israel',
    'im'  => "Eiland\ Man",
    'in'  => 'Indië',
    'io'  => "Britse\ Indiese\ Oseaan\ Gebied",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Ysland',
    'it'  => 'Italië',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordanië',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirgisië',
    'kh'  => 'Kambodja',
    'ki'  => 'Kiribati',
    'km'  => 'Comore',
    'kn'  => "Saint\ Kitts\ en\ Nevis",
    'kp'  => "Noord\-Korea",
    'kr'  => "Suid\-Korea",
    'kw'  => 'Koeweit',
    'ky'  => 'Kaaimanseilande',
    'kz'  => 'Kasakstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "Sint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberië',
    'ls'  => 'Lesotho',
    'lt'  => 'Litaue',
    'lu'  => 'Luxemburg',
    'lv'  => 'Letland',
    'ly'  => 'Libië',
    'ma'  => 'Marokko',
    'mc'  => 'Monaco',
    'md'  => 'Moldova',
    'me'  => 'Montenegro',
    'mf'  => "Sint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Marshall\-eilande",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Macedonië',
    'ml'  => 'Mali',
    'mm'  => 'Mianmar',
    'mn'  => 'Mongolië',
    'mo'  => 'Macau',
    'mp'  => "Noordelike\ Marianaeilande",
    'mq'  => 'Martinique',
    'mr'  => 'Mouritanië',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Maledive',
    'mw'  => 'Malawi',
    'mx'  => 'Meksiko',
    'my'  => 'Maleisië',
    'mz'  => 'Mosambiek',
    'na'  => 'Namibië',
    'nc'  => "Nieu\-Kaledonië",
    'ne'  => 'Niger',
    'nf'  => "Norfolk\-eiland",
    'ng'  => 'Nigerië',
    'ni'  => 'Nicaragua',
    'nl'  => 'Nederland',
    'no'  => 'Noorweë',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Naoeroe',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nieu\-Seeland",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Frans\-Polinesië",
    'pg'  => "Papoea\ Nieu\-Guinee",
    'ph'  => 'Filippyne',
    'pk'  => 'Pakistan',
    'pl'  => 'Pole',
    'pm'  => "Sint\-Pierre\ en\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => 'Palestina',
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Omliggende\ Oseanië",
    're'  => 'Réunion',
    'ro'  => 'Roemenië',
    'rs'  => 'Serwië',
    'ru'  => 'Rusland',
    'rw'  => 'Rwanda',
    'sa'  => "Saoedi\-Arabië",
    'sb'  => "Solomon\ Eilande",
    'sc'  => 'Seychelle',
    'sd'  => 'Soedan',
    'se'  => 'Swede',
    'sg'  => 'Singapoer',
    'sh'  => "Sint\ Helena",
    'si'  => 'Slowenië',
    'sj'  => "Svalbard\ en\ Jan\ Mayen",
    'sk'  => 'Slowakye',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalië',
    'sr'  => 'Suriname',
    'st'  => "Sao\ Tome\ en\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvador',
    'sy'  => 'Sirië',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ en\ Caicos\ Eilande",
    'td'  => 'Tsjaad',
    'tf'  => "Franse\ Suidelike\ Gebiede",
    'tg'  => 'Togo',
    'th'  => 'Thailand',
    'tj'  => 'Tadjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Oos\-Timor",
    'tm'  => 'Turkmenië',
    'tn'  => 'Tunisië',
    'to'  => 'Tonga',
    'tr'  => 'Turkye',
    'tt'  => "Trinidad\ en\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzanië',
    'ua'  => 'Oekraine',
    'ug'  => 'Uganda',
    'um'  => "VS\ klein\ omliggende\ eilande",
    'us'  => "Verenigde\ State\ van\ Amerika",
    'uy'  => 'Uruguay',
    'uz'  => 'Oesbekistan',
    'va'  => 'Vatikaan',
    'vc'  => "Saint\ Vincent\ en\ die\ Grenadine",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Britse\ Maagde\-eilande",
    'vi'  => "V\.S\.\ Maagde\-eilande",
    'vn'  => 'Viëtnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ en\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => "Suid\-Afrika",
    'zm'  => 'Zambië',
    'zw'  => 'Zimbabwe',
    'zz'  => "Onbekend\ gebied",
);

%Locales::DB::Territory::af::name_to_code = (
    'afganistan'                                => 'af',
    'afrika'                                    => '002',
    'albanië'                                  => 'al',
    'algerië'                                  => 'dz',
    'amerikaanssamoa'                           => 'as',
    'amerikas'                                  => '019',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarktika'                                => 'aq',
    'antiguaenbarbuda'                          => 'ag',
    'argentinië'                               => 'ar',
    'armenië'                                  => 'am',
    'aruba'                                     => 'aw',
    'ascensioneiland'                           => 'ac',
    'aserbeidjan'                               => 'az',
    'asië'                                     => 142,
    'australië'                                => 'au',
    'australiëennieuseeland'                   => '053',
    'bahamas'                                   => 'bs',
    'bahrein'                                   => 'bh',
    'bangladesj'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgië'                                   => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhoetan'                                   => 'bt',
    'boerkinafasso'                             => 'bf',
    'bolivië'                                  => 'bo',
    'bosniëenherzegowina'                      => 'ba',
    'botswana'                                  => 'bw',
    'bouveteiland'                              => 'bv',
    'brasilië'                                 => 'br',
    'britishantarcticterritory'                 => 'bq',
    'britseindieseoseaangebied'                 => 'io',
    'britsemaagdeeilande'                       => 'vg',
    'broenei'                                   => 'bn',
    'bulgarye'                                  => 'bg',
    'burundi'                                   => 'bi',
    'cantonandenderburyislands'                 => 'ct',
    'ceutaenmelilla'                            => 'ea',
    'channelislands'                            => 830,
    'chili'                                     => 'cl',
    'ciprus'                                    => 'cy',
    'clippertoneiland'                          => 'cp',
    'cocoskeelingeilande'                       => 'cc',
    'comore'                                    => 'km',
    'cookeilande'                               => 'ck',
    'costarica'                                 => 'cr',
    'czechoslovakia'                            => 200,
    'denemarke'                                 => 'dk',
    'diegogarcia'                               => 'dg',
    'djiboeti'                                  => 'dj',
    'dominika'                                  => 'dm',
    'dominikaanserepubliek'                     => 'do',
    'dronningmaudland'                          => 'nq',
    'duitsland'                                 => 'de',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egipte'                                    => 'eg',
    'eilandman'                                 => 'im',
    'ekwatoriaalguinee'                         => 'gq',
    'eritrea'                                   => 'er',
    'estland'                                   => 'ee',
    'ethiopië'                                 => 'et',
    'europa'                                    => 150,
    'europeseunie'                              => 'eu',
    'falklandeilandemalvinas'                   => 'fk',
    'faroëreilande'                            => 'fo',
    'fidji'                                     => 'fj',
    'filippyne'                                 => 'ph',
    'finland'                                   => 'fi',
    'frankryk'                                  => 'fr',
    'fransesuidelikegebiede'                    => 'tf',
    'fransguyana'                               => 'gf',
    'franspolinesië'                           => 'pf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gaboen'                                    => 'ga',
    'gambië'                                   => 'gm',
    'gemenebesvanonafhanklikestate'             => 172,
    'georgië'                                  => 'ge',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'grenada'                                   => 'gd',
    'griekeland'                                => 'gr',
    'groenland'                                 => 'gl',
    'grootbrittanje'                            => 'gb',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guinee'                                    => 'gn',
    'guineebissau'                              => 'gw',
    'guyana'                                    => 'gy',
    'haïti'                                    => 'ht',
    'heardeilandenmcdonaldeilande'              => 'hm',
    'honduras'                                  => 'hn',
    'hongarye'                                  => 'hu',
    'hongkong'                                  => 'hk',
    'ierland'                                   => 'ie',
    'indië'                                    => 'in',
    'indonesië'                                => 'id',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'israel'                                    => 'il',
    'italië'                                   => 'it',
    'ivoorkus'                                  => 'ci',
    'jamaika'                                   => 'jm',
    'japan'                                     => 'jp',
    'jemen'                                     => 'ye',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordanië'                                 => 'jo',
    'kaaimanseilande'                           => 'ky',
    'kaapverde'                                 => 'cv',
    'kambodja'                                  => 'kh',
    'kameroen'                                  => 'cm',
    'kanada'                                    => 'ca',
    'kanarieeilande'                            => 'ic',
    'karibbies'                                 => '029',
    'kasakstan'                                 => 'kz',
    'katar'                                     => 'qa',
    'kenia'                                     => 'ke',
    'kerseiland'                                => 'cx',
    'kirgisië'                                 => 'kg',
    'kiribati'                                  => 'ki',
    'koeweit'                                   => 'kw',
    'kolombië'                                 => 'co',
    'kongodrk'                                  => 'cd',
    'kongorepubliek'                            => 'cg',
    'kroasië'                                  => 'hr',
    'kuba'                                      => 'cu',
    'laos'                                      => 'la',
    'latynsamerika'                             => 419,
    'lesotho'                                   => 'ls',
    'letland'                                   => 'lv',
    'libanon'                                   => 'lb',
    'liberië'                                  => 'lr',
    'libië'                                    => 'ly',
    'liechtenstein'                             => 'li',
    'litaue'                                    => 'lt',
    'luxemburg'                                 => 'lu',
    'macau'                                     => 'mo',
    'macedonië'                                => 'mk',
    'madagaskar'                                => 'mg',
    'malawi'                                    => 'mw',
    'maledive'                                  => 'mv',
    'maleisië'                                 => 'my',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'marokko'                                   => 'ma',
    'marshalleilande'                           => 'mh',
    'martinique'                                => 'mq',
    'mauritius'                                 => 'mu',
    'mayotte'                                   => 'yt',
    'meksiko'                                   => 'mx',
    'melanesië'                                => '054',
    'metropolitanfrance'                        => 'fx',
    'mianmar'                                   => 'mm',
    'middeafrika'                               => '017',
    'midwayislands'                             => 'mi',
    'mikronesiesestreek'                        => '057',
    'mikronesië'                               => 'fm',
    'moldova'                                   => 'md',
    'monaco'                                    => 'mc',
    'mongolië'                                 => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mosambiek'                                 => 'mz',
    'mouritanië'                               => 'mr',
    'namibië'                                  => 'na',
    'naoeroe'                                   => 'nr',
    'nederland'                                 => 'nl',
    'nederlandsantille'                         => 'an',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'nieukaledonië'                            => 'nc',
    'nieuseeland'                               => 'nz',
    'niger'                                     => 'ne',
    'nigerië'                                  => 'ng',
    'niue'                                      => 'nu',
    'noordafrika'                               => '015',
    'noordamerika'                              => '003',
    'noordelikeamerika'                         => '021',
    'noordelikemarianaeilande'                  => 'mp',
    'noordeuropa'                               => 154,
    'noordkorea'                                => 'kp',
    'noorweë'                                  => 'no',
    'norfolkeiland'                             => 'nf',
    'northvietnam'                              => 'vd',
    'oekraine'                                  => 'ua',
    'oesbekistan'                               => 'uz',
    'oman'                                      => 'om',
    'omliggendeoseanië'                        => 'qo',
    'onbekendgebied'                            => 'zz',
    'oosafrika'                                 => '014',
    'oosasië'                                  => '030',
    'ooseuropa'                                 => 151,
    'oostenryk'                                 => 'at',
    'oostimor'                                  => 'tl',
    'oseanië'                                  => '009',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'palestina'                                 => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papoeanieuguinee'                          => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'pole'                                      => 'pl',
    'polinesië'                                => '061',
    'portugal'                                  => 'pt',
    'puertorico'                                => 'pr',
    'roemenië'                                 => 'ro',
    'rusland'                                   => 'ru',
    'rwanda'                                    => 'rw',
    'réunion'                                  => 're',
    'saintkittsennevis'                         => 'kn',
    'saintvincentendiegrenadine'                => 'vc',
    'salvador'                                  => 'sv',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saoediarabië'                             => 'sa',
    'saotomeenprincipe'                         => 'st',
    'senegal'                                   => 'sn',
    'sentraalafrikaanserepubliek'               => 'cf',
    'sentraalamerika'                           => '013',
    'sentraalasië'                             => 143,
    'serwië'                                   => 'rs',
    'serwiëenmontenegro'                       => 'cs',
    'seychelle'                                 => 'sc',
    'sierraleone'                               => 'sl',
    'singapoer'                                 => 'sg',
    'sintbarthélemy'                           => 'bl',
    'sinthelena'                                => 'sh',
    'sintlucia'                                 => 'lc',
    'sintmartin'                                => 'mf',
    'sintpierreenmiquelon'                      => 'pm',
    'sirië'                                    => 'sy',
    'sjina'                                     => 'cn',
    'slowakye'                                  => 'sk',
    'slowenië'                                 => 'si',
    'soedan'                                    => 'sd',
    'solomoneilande'                            => 'sb',
    'somalië'                                  => 'so',
    'southcentralasia'                          => '062',
    'spanje'                                    => 'es',
    'srilanka'                                  => 'lk',
    'suidafrika'                                => 'za',
    'suidamerika'                               => '005',
    'suidasië'                                 => '034',
    'suiderafrika'                              => '018',
    'suideuropa'                                => '039',
    'suidgeorgiëendiesuidsandwicheilande'      => 'gs',
    'suidkorea'                                 => 'kr',
    'suidoosasië'                              => '035',
    'suriname'                                  => 'sr',
    'svalbardenjanmayen'                        => 'sj',
    'swaziland'                                 => 'sz',
    'swede'                                     => 'se',
    'switserland'                               => 'ch',
    'tadjikistan'                               => 'tj',
    'taiwan'                                    => 'tw',
    'tanzanië'                                 => 'tz',
    'thailand'                                  => 'th',
    'tjeggieserepubliek'                        => 'cz',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadentobago'                          => 'tt',
    'tristandacunha'                            => 'ta',
    'tsjaad'                                    => 'td',
    'tunisië'                                  => 'tn',
    'turkmenië'                                => 'tm',
    'turksencaicoseilande'                      => 'tc',
    'turkye'                                    => 'tr',
    'tuvalu'                                    => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    "v\.s\.maagdeeilande"                       => 'vi',
    'vanuatu'                                   => 'vu',
    'vatikaan'                                  => 'va',
    'venezuela'                                 => 've',
    'verenigdearabieseemirate'                  => 'ae',
    'verenigdestatevanamerika'                  => 'us',
    'viëtnam'                                  => 'vn',
    'vskleinomliggendeeilande'                  => 'um',
    'wakeisland'                                => 'wk',
    'wallisenfutuna'                            => 'wf',
    'wesafrika'                                 => '011',
    'wesasië'                                  => 145,
    'weseuropa'                                 => 155,
    'wessahara'                                 => 'eh',
    'witrusland'                                => 'by',
    'wêreld'                                   => '001',
    'ysland'                                    => 'is',
    'zambië'                                   => 'zm',
    'zimbabwe'                                  => 'zw',
    'Ålandeilande'                             => 'ax',
);

1;

