{"delimiters":{"quotation_start":"»","quotation_end":"«","alternate_quotation_start":"„","alternate_quotation_end":"“"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":"ne:n","yesstr":"da:d"},"plural_forms":{"category_list":["one","two","few","other"],"category_rules_function":null,"category_rules":{"one":"n mod 100 is 1","few":"n mod 100 in 3..4","two":"n mod 100 is 2"},"category_rules_compiled":{"one":function (n) {if ( (( (n % 100) == 1))) { return 'one'; } return;},"few":function (n) {if ( (( parseInt(n) == n && (n % 100) >= 3 && (n % 100) <= 4 ))) { return 'few'; } return;},"two":function (n) {if ( (( (n % 100) == 2))) { return 'two'; } return;}}},"cldr_formats":{"territory":"Regija: {0}","_decimal_format_decimal":",","language":"Jezik: {0}","percent":"#,##0%","locale":"{0} ({1})","_decimal_format_group":".","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} in {1}","start":"{0}, {1}","end":"{0} in {1}"}},"fallback":[],"characters":{"more_information":"?"}}