package Locales::DB::Territory::ru;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::ru::VERSION = '0.09';

$Locales::DB::Territory::ru::cldr_version = '2.0';

%Locales::DB::Territory::ru::code_to_name = (
    '001' => 'Мир',
    '002' => 'Африка',
    '003' => "Северная\ Америка",
    '005' => "Южная\ Америка",
    '009' => 'Океания',
    '011' => "Западная\ Африка",
    '013' => "Центральная\ Америка",
    '014' => "Восточная\ Африка",
    '015' => "Северная\ Африка",
    '017' => "Центральная\ Африка",
    '018' => "Южная\ Африка",
    '019' => "Центральная\ и\ Южная\ Америка",
    '021' => "Северная\ Америка\ \-\ США\ и\ Канада",
    '029' => 'Карибы',
    '030' => "Восточная\ Азия",
    '034' => "Южная\ Азия",
    '035' => "Юго\-Восточная\ Азия",
    '039' => "Южная\ Европа",
    '053' => "Австралия\ и\ Новая\ Зеландия",
    '054' => 'Меланезия',
    '057' => 'Микронезия',
    '061' => 'Полинезия',
    '062' => "Юг\ Средней\ Азии",
    142   => 'Азия',
    143   => "Средняя\ Азия",
    145   => "Ближний\ и\ Средний\ Восток",
    150   => 'Европа',
    151   => "Восточная\ Европа",
    154   => "Северная\ Европа",
    155   => "Западная\ Европа",
    172   => 'СНГ',
    200   => 'Czechoslovakia',
    419   => "Латинская\ Америка\ и\ Карибские\ о\-ва",
    830   => "Нормандские\ о\-ва",
    'ac'  => "Остров\ Вознесения",
    'ad'  => 'Андорра',
    'ae'  => 'ОАЭ',
    'af'  => 'Афганистан',
    'ag'  => "Антигуа\ и\ Барбуда",
    'ai'  => 'Ангилья',
    'al'  => 'Албания',
    'am'  => 'Армения',
    'an'  => "Нидерландские\ Антильские\ о\-ва",
    'ao'  => 'Ангола',
    'aq'  => 'Антарктида',
    'ar'  => 'Аргентина',
    'as'  => "Американское\ Самоа",
    'at'  => 'Австрия',
    'au'  => 'Австралия',
    'aw'  => 'Аруба',
    'ax'  => "Аландские\ о\-ва",
    'az'  => 'Азербайджан',
    'ba'  => "Босния\ и\ Герцеговина",
    'bb'  => 'Барбадос',
    'bd'  => 'Бангладеш',
    'be'  => 'Бельгия',
    'bf'  => "Буркина\ Фасо",
    'bg'  => 'Болгария',
    'bh'  => 'Бахрейн',
    'bi'  => 'Бурунди',
    'bj'  => 'Бенин',
    'bl'  => "Остров\ Святого\ Бартоломея",
    'bm'  => "Бермудские\ о\-ва",
    'bn'  => "Бруней\ Даруссалам",
    'bo'  => 'Боливия',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Бразилия',
    'bs'  => "Багамские\ о\-ва",
    'bt'  => 'Бутан',
    'bv'  => "Остров\ Буве",
    'bw'  => 'Ботсвана',
    'by'  => 'Беларусь',
    'bz'  => 'Белиз',
    'ca'  => 'Канада',
    'cc'  => "Кокосовые\ о\-ва",
    'cd'  => "Конго\ \(ДРК\)",
    'cf'  => 'ЦАР',
    'cg'  => 'Конго',
    'ch'  => 'Швейцария',
    'ci'  => "Берег\ Слоновой\ Кости",
    'ck'  => "Острова\ Кука",
    'cl'  => 'Чили',
    'cm'  => 'Камерун',
    'cn'  => 'Китай',
    'co'  => 'Колумбия',
    'cp'  => "Остров\ Клиппертон",
    'cr'  => "Коста\-Рика",
    'cs'  => "Сербия\ и\ Черногория",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Куба',
    'cv'  => "Острова\ Зеленого\ Мыса",
    'cx'  => "Остров\ Рождества",
    'cy'  => 'Кипр',
    'cz'  => 'Чехия',
    'dd'  => "East\ Germany",
    'de'  => 'Германия',
    'dg'  => "Диего\-Гарсия",
    'dj'  => 'Джибути',
    'dk'  => 'Дания',
    'dm'  => 'Доминика',
    'do'  => "Доминиканская\ Республика",
    'dz'  => 'Алжир',
    'ea'  => "Сеута\ и\ Мелилья",
    'ec'  => 'Эквадор',
    'ee'  => 'Эстония',
    'eg'  => 'Египет',
    'eh'  => "Западная\ Сахара",
    'er'  => 'Эритрея',
    'es'  => 'Испания',
    'et'  => 'Эфиопия',
    'eu'  => "Европейский\ союз",
    'fi'  => 'Финляндия',
    'fj'  => 'Фиджи',
    'fk'  => "Фолклендские\ \(Мальвинские\)\ о\-ва",
    'fm'  => "Федеративные\ Штаты\ Микронезии",
    'fo'  => "Фарерские\ о\-ва",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Франция',
    'fx'  => "Французская\ метрополия",
    'ga'  => 'Габон',
    'gb'  => 'Великобритания',
    'gd'  => 'Гренада',
    'ge'  => 'Грузия',
    'gf'  => "Французская\ Гвиана",
    'gg'  => 'Гернси',
    'gh'  => 'Гана',
    'gi'  => 'Гибралтар',
    'gl'  => 'Гренландия',
    'gm'  => 'Гамбия',
    'gn'  => 'Гвинея',
    'gp'  => 'Гваделупа',
    'gq'  => "Экваториальная\ Гвинея",
    'gr'  => 'Греция',
    'gs'  => "Южная\ Джорджия\ и\ Южные\ Сандвичевы\ Острова",
    'gt'  => 'Гватемала',
    'gu'  => 'Гуам',
    'gw'  => "Гвинея\-Бисау",
    'gy'  => 'Гайана',
    'hk'  => 'Гонконг',
    'hm'  => "Острова\ Херд\ и\ Макдональд",
    'hn'  => 'Гондурас',
    'hr'  => 'Хорватия',
    'ht'  => 'Гаити',
    'hu'  => 'Венгрия',
    'ic'  => "Канарские\ о\-ва",
    'id'  => 'Индонезия',
    'ie'  => 'Ирландия',
    'il'  => 'Израиль',
    'im'  => "Остров\ Мэн",
    'in'  => 'Индия',
    'io'  => "Британская\ территория\ в\ Индийском\ океане",
    'iq'  => 'Ирак',
    'ir'  => 'Иран',
    'is'  => 'Исландия',
    'it'  => 'Италия',
    'je'  => 'Джерси',
    'jm'  => 'Ямайка',
    'jo'  => 'Иордания',
    'jp'  => 'Япония',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Кения',
    'kg'  => 'Киргизия',
    'kh'  => 'Камбоджа',
    'ki'  => 'Кирибати',
    'km'  => "Коморские\ о\-ва",
    'kn'  => "Сент\-Киттс\ и\ Невис",
    'kp'  => "Северная\ Корея",
    'kr'  => "Республика\ Корея",
    'kw'  => 'Кувейт',
    'ky'  => "Каймановы\ острова",
    'kz'  => 'Казахстан',
    'la'  => 'Лаос',
    'lb'  => 'Ливан',
    'lc'  => "Сент\-Люсия",
    'li'  => 'Лихтенштейн',
    'lk'  => "Шри\-Ланка",
    'lr'  => 'Либерия',
    'ls'  => 'Лесото',
    'lt'  => 'Литва',
    'lu'  => 'Люксембург',
    'lv'  => 'Латвия',
    'ly'  => 'Ливия',
    'ma'  => 'Марокко',
    'mc'  => 'Монако',
    'md'  => 'Молдова',
    'me'  => 'Черногория',
    'mf'  => "Остров\ Святого\ Мартина",
    'mg'  => 'Мадагаскар',
    'mh'  => "Маршалловы\ о\-ва",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Македония',
    'ml'  => 'Мали',
    'mm'  => 'Мьянма',
    'mn'  => 'Монголия',
    'mo'  => 'Макао',
    'mp'  => "Северные\ Марианские\ о\-ва",
    'mq'  => 'Мартиника',
    'mr'  => 'Мавритания',
    'ms'  => 'Монтсеррат',
    'mt'  => 'Мальта',
    'mu'  => 'Маврикий',
    'mv'  => "Мальдивские\ о\-ва",
    'mw'  => 'Малави',
    'mx'  => 'Мексика',
    'my'  => 'Малайзия',
    'mz'  => 'Мозамбик',
    'na'  => 'Намибия',
    'nc'  => "Новая\ Каледония",
    'ne'  => 'Нигер',
    'nf'  => "Остров\ Норфолк",
    'ng'  => 'Нигерия',
    'ni'  => 'Никарагуа',
    'nl'  => 'Нидерланды',
    'no'  => 'Норвегия',
    'np'  => 'Непал',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Науру',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Ниуе',
    'nz'  => "Новая\ Зеландия",
    'om'  => 'Оман',
    'pa'  => 'Панама',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Перу',
    'pf'  => "Французская\ Полинезия",
    'pg'  => "Папуа\ –\ Новая\ Гвинея",
    'ph'  => 'Филиппины',
    'pk'  => 'Пакистан',
    'pl'  => 'Польша',
    'pm'  => "Сен\-Пьер\ и\ Микелон",
    'pn'  => 'Питкэрн',
    'pr'  => "Пуэрто\-Рико",
    'ps'  => "Палестинские\ территории",
    'pt'  => 'Португалия',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Палау',
    'py'  => 'Парагвай',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Катар',
    'qo'  => "Внешняя\ Океания",
    're'  => 'Реюньон',
    'ro'  => 'Румыния',
    'rs'  => 'Сербия',
    'ru'  => 'Россия',
    'rw'  => 'Руанда',
    'sa'  => "Саудовская\ Аравия",
    'sb'  => "Соломоновы\ о\-ва",
    'sc'  => "Сейшельские\ о\-ва",
    'sd'  => 'Судан',
    'se'  => 'Швеция',
    'sg'  => 'Сингапур',
    'sh'  => "Остров\ Святой\ Елены",
    'si'  => 'Словения',
    'sj'  => "Свальбард\ и\ Ян\-Майен",
    'sk'  => 'Словакия',
    'sl'  => "Сьерра\-Леоне",
    'sm'  => "Сан\-Марино",
    'sn'  => 'Сенегал',
    'so'  => 'Сомали',
    'sr'  => 'Суринам',
    'st'  => "Сан\-Томе\ и\ Принсипи",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Сальвадор',
    'sy'  => 'Сирия',
    'sz'  => 'Свазиленд',
    'ta'  => "Тристан\-да\-Кунья",
    'tc'  => "Острова\ Тёркс\ и\ Кайкос",
    'td'  => 'Чад',
    'tf'  => "Французские\ Южные\ Территории",
    'tg'  => 'Того',
    'th'  => 'Таиланд',
    'tj'  => 'Таджикистан',
    'tk'  => 'Токелау',
    'tl'  => "Восточный\ Тимор",
    'tm'  => 'Туркменистан',
    'tn'  => 'Тунис',
    'to'  => 'Тонга',
    'tr'  => 'Турция',
    'tt'  => "Тринидад\ и\ Тобаго",
    'tv'  => 'Тувалу',
    'tw'  => 'Тайвань',
    'tz'  => 'Танзания',
    'ua'  => 'Украина',
    'ug'  => 'Уганда',
    'um'  => "Внешние\ малые\ острова\ \(США\)",
    'us'  => 'США',
    'uy'  => 'Уругвай',
    'uz'  => 'Узбекистан',
    'va'  => 'Ватикан',
    'vc'  => "Сент\-Винсент\ и\ Гренадины",
    'vd'  => "North\ Vietnam",
    've'  => 'Венесуэла',
    'vg'  => "Британские\ Виргинские\ о\-ва",
    'vi'  => "Виргинские\ о\-ва\ \(США\)",
    'vn'  => 'Вьетнам',
    'vu'  => 'Вануату',
    'wf'  => "Уоллис\ и\ Футуна",
    'wk'  => "Wake\ Island",
    'ws'  => 'Самоа',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Йемен',
    'yt'  => 'Майотта',
    'za'  => 'ЮАР',
    'zm'  => 'Замбия',
    'zw'  => 'Зимбабве',
    'zz'  => "Неизвестный\ или\ недействительный\ регион",
);

%Locales::DB::Territory::ru::name_to_code = (
    'britishantarcticterritory'                                                => 'bq',
    'cantonandenderburyislands'                                                => 'ct',
    'czechoslovakia'                                                           => 200,
    'dronningmaudland'                                                         => 'nq',
    'eastgermany'                                                              => 'dd',
    'frenchsouthernandantarcticterritories'                                    => 'fq',
    'johnstonisland'                                                           => 'jt',
    'midwayislands'                                                            => 'mi',
    'neutralzone'                                                              => 'nt',
    'northvietnam'                                                             => 'vd',
    'pacificislandstrustterritory'                                             => 'pc',
    'panamacanalzone'                                                          => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                                => 'yd',
    "u\.s\.miscellaneouspacificislands"                                        => 'pu',
    'unionofsovietsocialistrepublics'                                          => 'su',
    'wakeisland'                                                               => 'wk',
    'Австралия'                                                       => 'au',
    'АвстралияиНоваяЗеландия'                           => '053',
    'Австрия'                                                           => 'at',
    'Азербайджан'                                                   => 'az',
    'Азия'                                                                 => 142,
    'Аландскиеова'                                                 => 'ax',
    'Албания'                                                           => 'al',
    'Алжир'                                                               => 'dz',
    'АмериканскоеСамоа'                                       => 'as',
    'Ангилья'                                                           => 'ai',
    'Ангола'                                                             => 'ao',
    'Андорра'                                                           => 'ad',
    'Антарктида'                                                     => 'aq',
    'АнтигуаиБарбуда'                                           => 'ag',
    'Аргентина'                                                       => 'ar',
    'Армения'                                                           => 'am',
    'Аруба'                                                               => 'aw',
    'Афганистан'                                                     => 'af',
    'Африка'                                                             => '002',
    'Багамскиеова'                                                 => 'bs',
    'Бангладеш'                                                       => 'bd',
    'Барбадос'                                                         => 'bb',
    'Бахрейн'                                                           => 'bh',
    'Беларусь'                                                         => 'by',
    'Белиз'                                                               => 'bz',
    'Бельгия'                                                           => 'be',
    'Бенин'                                                               => 'bj',
    'БерегСлоновойКости'                                     => 'ci',
    'Бермудскиеова'                                               => 'bm',
    'БлижнийиСреднийВосток'                               => 145,
    'Болгария'                                                         => 'bg',
    'Боливия'                                                           => 'bo',
    'БоснияиГерцеговина'                                     => 'ba',
    'Ботсвана'                                                         => 'bw',
    'Бразилия'                                                         => 'br',
    'БританскаятерриториявИндийскомокеане' => 'io',
    'БританскиеВиргинскиеова'                           => 'vg',
    'БрунейДаруссалам'                                         => 'bn',
    'БуркинаФасо'                                                   => 'bf',
    'Бурунди'                                                           => 'bi',
    'Бутан'                                                               => 'bt',
    'Вануату'                                                           => 'vu',
    'Ватикан'                                                           => 'va',
    'Великобритания'                                             => 'gb',
    'Венгрия'                                                           => 'hu',
    'Венесуэла'                                                       => 've',
    'ВиргинскиеоваСША'                                         => 'vi',
    'ВнешниемалыеостроваСША'                             => 'um',
    'ВнешняяОкеания'                                             => 'qo',
    'ВосточнаяАзия'                                               => '030',
    'ВосточнаяАфрика'                                           => '014',
    'ВосточнаяЕвропа'                                           => 151,
    'ВосточныйТимор'                                             => 'tl',
    'Вьетнам'                                                           => 'vn',
    'Габон'                                                               => 'ga',
    'Гаити'                                                               => 'ht',
    'Гайана'                                                             => 'gy',
    'Гамбия'                                                             => 'gm',
    'Гана'                                                                 => 'gh',
    'Гваделупа'                                                       => 'gp',
    'Гватемала'                                                       => 'gt',
    'Гвинея'                                                             => 'gn',
    'ГвинеяБисау'                                                   => 'gw',
    'Германия'                                                         => 'de',
    'Гернси'                                                             => 'gg',
    'Гибралтар'                                                       => 'gi',
    'Гондурас'                                                         => 'hn',
    'Гонконг'                                                           => 'hk',
    'Гренада'                                                           => 'gd',
    'Гренландия'                                                     => 'gl',
    'Греция'                                                             => 'gr',
    'Грузия'                                                             => 'ge',
    'Гуам'                                                                 => 'gu',
    'Дания'                                                               => 'dk',
    'Джерси'                                                             => 'je',
    'Джибути'                                                           => 'dj',
    'ДиегоГарсия'                                                   => 'dg',
    'Доминика'                                                         => 'dm',
    'ДоминиканскаяРеспублика'                           => 'do',
    'Европа'                                                             => 150,
    'Европейскийсоюз'                                           => 'eu',
    'Египет'                                                             => 'eg',
    'Замбия'                                                             => 'zm',
    'ЗападнаяАфрика'                                             => '011',
    'ЗападнаяЕвропа'                                             => 155,
    'ЗападнаяСахара'                                             => 'eh',
    'Зимбабве'                                                         => 'zw',
    'Израиль'                                                           => 'il',
    'Индия'                                                               => 'in',
    'Индонезия'                                                       => 'id',
    'Иордания'                                                         => 'jo',
    'Ирак'                                                                 => 'iq',
    'Иран'                                                                 => 'ir',
    'Ирландия'                                                         => 'ie',
    'Исландия'                                                         => 'is',
    'Испания'                                                           => 'es',
    'Италия'                                                             => 'it',
    'Йемен'                                                               => 'ye',
    'Казахстан'                                                       => 'kz',
    'Каймановыострова'                                         => 'ky',
    'Камбоджа'                                                         => 'kh',
    'Камерун'                                                           => 'cm',
    'Канада'                                                             => 'ca',
    'Канарскиеова'                                                 => 'ic',
    'Карибы'                                                             => '029',
    'Катар'                                                               => 'qa',
    'Кения'                                                               => 'ke',
    'Кипр'                                                                 => 'cy',
    'Киргизия'                                                         => 'kg',
    'Кирибати'                                                         => 'ki',
    'Китай'                                                               => 'cn',
    'Кокосовыеова'                                                 => 'cc',
    'Колумбия'                                                         => 'co',
    'Коморскиеова'                                                 => 'km',
    'Конго'                                                               => 'cg',
    'КонгоДРК'                                                         => 'cd',
    'КостаРика'                                                       => 'cr',
    'Куба'                                                                 => 'cu',
    'Кувейт'                                                             => 'kw',
    'Лаос'                                                                 => 'la',
    'Латвия'                                                             => 'lv',
    'ЛатинскаяАмерикаиКарибскиеова'               => 419,
    'Лесото'                                                             => 'ls',
    'Либерия'                                                           => 'lr',
    'Ливан'                                                               => 'lb',
    'Ливия'                                                               => 'ly',
    'Литва'                                                               => 'lt',
    'Лихтенштейн'                                                   => 'li',
    'Люксембург'                                                     => 'lu',
    'Маврикий'                                                         => 'mu',
    'Мавритания'                                                     => 'mr',
    'Мадагаскар'                                                     => 'mg',
    'Майотта'                                                           => 'yt',
    'Макао'                                                               => 'mo',
    'Македония'                                                       => 'mk',
    'Малави'                                                             => 'mw',
    'Малайзия'                                                         => 'my',
    'Мали'                                                                 => 'ml',
    'Мальдивскиеова'                                             => 'mv',
    'Мальта'                                                             => 'mt',
    'Марокко'                                                           => 'ma',
    'Мартиника'                                                       => 'mq',
    'Маршалловыова'                                               => 'mh',
    'Мексика'                                                           => 'mx',
    'Меланезия'                                                       => '054',
    'Микронезия'                                                     => '057',
    'Мир'                                                                   => '001',
    'Мозамбик'                                                         => 'mz',
    'Молдова'                                                           => 'md',
    'Монако'                                                             => 'mc',
    'Монголия'                                                         => 'mn',
    'Монтсеррат'                                                     => 'ms',
    'Мьянма'                                                             => 'mm',
    'Намибия'                                                           => 'na',
    'Науру'                                                               => 'nr',
    'Неизвестныйилинедействительныйрегион' => 'zz',
    'Непал'                                                               => 'np',
    'Нигер'                                                               => 'ne',
    'Нигерия'                                                           => 'ng',
    'НидерландскиеАнтильскиеова'                     => 'an',
    'Нидерланды'                                                     => 'nl',
    'Никарагуа'                                                       => 'ni',
    'Ниуе'                                                                 => 'nu',
    'НоваяЗеландия'                                               => 'nz',
    'НоваяКаледония'                                             => 'nc',
    'Норвегия'                                                         => 'no',
    'Нормандскиеова'                                             => 830,
    'ОАЭ'                                                                   => 'ae',
    'Океания'                                                           => '009',
    'Оман'                                                                 => 'om',
    'ОстровБуве'                                                     => 'bv',
    'ОстровВознесения'                                         => 'ac',
    'ОстровКлиппертон'                                         => 'cp',
    'ОстровМэн'                                                       => 'im',
    'ОстровНорфолк'                                               => 'nf',
    'ОстровРождества'                                           => 'cx',
    'ОстровСвятогоБартоломея'                           => 'bl',
    'ОстровСвятогоМартина'                                 => 'mf',
    'ОстровСвятойЕлены'                                       => 'sh',
    'ОстроваЗеленогоМыса'                                   => 'cv',
    'ОстроваКука'                                                   => 'ck',
    'ОстроваТёрксиКайкос'                                   => 'tc',
    'ОстроваХердиМакдональд'                             => 'hm',
    'Пакистан'                                                         => 'pk',
    'Палау'                                                               => 'pw',
    'Палестинскиетерритории'                             => 'ps',
    'Панама'                                                             => 'pa',
    'Папуа–НоваяГвинея'                                      => 'pg',
    'Парагвай'                                                         => 'py',
    'Перу'                                                                 => 'pe',
    'Питкэрн'                                                           => 'pn',
    'Полинезия'                                                       => '061',
    'Польша'                                                             => 'pl',
    'Португалия'                                                     => 'pt',
    'ПуэртоРико'                                                     => 'pr',
    'РеспубликаКорея'                                           => 'kr',
    'Реюньон'                                                           => 're',
    'Россия'                                                             => 'ru',
    'Руанда'                                                             => 'rw',
    'Румыния'                                                           => 'ro',
    'СНГ'                                                                   => 172,
    'США'                                                                   => 'us',
    'Сальвадор'                                                       => 'sv',
    'Самоа'                                                               => 'ws',
    'СанМарино'                                                       => 'sm',
    'СанТомеиПринсипи'                                         => 'st',
    'СаудовскаяАравия'                                         => 'sa',
    'Свазиленд'                                                       => 'sz',
    'СвальбардиЯнМайен'                                       => 'sj',
    'СевернаяАмерика'                                           => '003',
    'СевернаяАмерикаСШАиКанада'                       => '021',
    'СевернаяАфрика'                                             => '015',
    'СевернаяЕвропа'                                             => 154,
    'СевернаяКорея'                                               => 'kp',
    'СеверныеМарианскиеова'                               => 'mp',
    'Сейшельскиеова'                                             => 'sc',
    'СенПьериМикелон'                                           => 'pm',
    'Сенегал'                                                           => 'sn',
    'СентВинсентиГренадины'                               => 'vc',
    'СентКиттсиНевис'                                           => 'kn',
    'СентЛюсия'                                                       => 'lc',
    'Сербия'                                                             => 'rs',
    'СербияиЧерногория'                                       => 'cs',
    'СеутаиМелилья'                                               => 'ea',
    'Сингапур'                                                         => 'sg',
    'Сирия'                                                               => 'sy',
    'Словакия'                                                         => 'sk',
    'Словения'                                                         => 'si',
    'Соломоновыова'                                               => 'sb',
    'Сомали'                                                             => 'so',
    'СредняяАзия'                                                   => 143,
    'Судан'                                                               => 'sd',
    'Суринам'                                                           => 'sr',
    'СьерраЛеоне'                                                   => 'sl',
    'Таджикистан'                                                   => 'tj',
    'Таиланд'                                                           => 'th',
    'Тайвань'                                                           => 'tw',
    'Танзания'                                                         => 'tz',
    'Того'                                                                 => 'tg',
    'Токелау'                                                           => 'tk',
    'Тонга'                                                               => 'to',
    'ТринидадиТобаго'                                           => 'tt',
    'ТристандаКунья'                                             => 'ta',
    'Тувалу'                                                             => 'tv',
    'Тунис'                                                               => 'tn',
    'Туркменистан'                                                 => 'tm',
    'Турция'                                                             => 'tr',
    'Уганда'                                                             => 'ug',
    'Узбекистан'                                                     => 'uz',
    'Украина'                                                           => 'ua',
    'УоллисиФутуна'                                               => 'wf',
    'Уругвай'                                                           => 'uy',
    'Фарерскиеова'                                                 => 'fo',
    'ФедеративныеШтатыМикронезии'                   => 'fm',
    'Фиджи'                                                               => 'fj',
    'Филиппины'                                                       => 'ph',
    'Финляндия'                                                       => 'fi',
    'ФолклендскиеМальвинскиеова'                     => 'fk',
    'Франция'                                                           => 'fr',
    'ФранцузскаяГвиана'                                       => 'gf',
    'ФранцузскаяПолинезия'                                 => 'pf',
    'Французскаяметрополия'                               => 'fx',
    'ФранцузскиеЮжныеТерритории'                     => 'tf',
    'Хорватия'                                                         => 'hr',
    'ЦАР'                                                                   => 'cf',
    'ЦентральнаяАмерика'                                     => '013',
    'ЦентральнаяАфрика'                                       => '017',
    'ЦентральнаяиЮжнаяАмерика'                         => '019',
    'Чад'                                                                   => 'td',
    'Черногория'                                                     => 'me',
    'Чехия'                                                               => 'cz',
    'Чили'                                                                 => 'cl',
    'Швейцария'                                                       => 'ch',
    'Швеция'                                                             => 'se',
    'ШриЛанка'                                                         => 'lk',
    'Эквадор'                                                           => 'ec',
    'ЭкваториальнаяГвинея'                                 => 'gq',
    'Эритрея'                                                           => 'er',
    'Эстония'                                                           => 'ee',
    'Эфиопия'                                                           => 'et',
    'ЮАР'                                                                   => 'za',
    'ЮгСреднейАзии'                                               => '062',
    'ЮгоВосточнаяАзия'                                         => '035',
    'ЮжнаяАзия'                                                       => '034',
    'ЮжнаяАмерика'                                                 => '005',
    'ЮжнаяАфрика'                                                   => '018',
    'ЮжнаяДжорджияиЮжныеСандвичевыОстрова' => 'gs',
    'ЮжнаяЕвропа'                                                   => '039',
    'Ямайка'                                                             => 'jm',
    'Япония'                                                             => 'jp',
);

1;

