package Locales::DB::Territory::cs;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::cs::VERSION = '0.09';

$Locales::DB::Territory::cs::cldr_version = '2.0';

%Locales::DB::Territory::cs::code_to_name = (
    '001' => 'Svět',
    '002' => 'Afrika',
    '003' => '003',
    '005' => "Jižní\ Amerika",
    '009' => 'Oceánie',
    '011' => "Západní\ Afrika",
    '013' => "Střední\ Amerika",
    '014' => "Východní\ Afrika",
    '015' => "Severní\ Afrika",
    '017' => "Střední\ Afrika",
    '018' => "Jižní\ Afrika",
    '019' => 'Amerika',
    '021' => "Severní\ Amerika",
    '029' => 'Karibik',
    '030' => "Východní\ Asie",
    '034' => "Jižní\ Asie",
    '035' => "Jihovýchodní\ Asie",
    '039' => "Jižní\ Evropa",
    '053' => "Austrálie\ a\ Nový\ Zéland",
    '054' => 'Melanésie',
    '057' => 'Mikronésie',
    '061' => 'Polynésie',
    '062' => "Jižní\ a\ centrální\ Asie",
    142   => 'Asie',
    143   => "Střední\ Asie",
    145   => "Západní\ Asie",
    150   => 'Evropa',
    151   => "Východní\ Evropa",
    154   => "Severní\ Evropa",
    155   => "Západní\ Evropa",
    172   => "Společenství\ nezávislých\ států",
    200   => 'Československo',
    419   => "Latinská\ Amerika\ a\ Karibské\ moře",
    830   => "Normanské\ ostrovy",
    'ac'  => "Ostrov\ Ascension",
    'ad'  => 'Andorra',
    'ae'  => "Spojené\ arabské\ emiráty",
    'af'  => 'Afghánistán',
    'ag'  => "Antigua\ a\ Barbuda",
    'ai'  => 'Anguila',
    'al'  => 'Albánie',
    'am'  => 'Arménie',
    'an'  => "Nizozemské\ Antily",
    'ao'  => 'Angola',
    'aq'  => 'Antarktida',
    'ar'  => 'Argentina',
    'as'  => "Americká\ Samoa",
    'at'  => 'Rakousko',
    'au'  => 'Austrálie',
    'aw'  => 'Aruba',
    'ax'  => 'Alandy',
    'az'  => 'Ázerbájdžán',
    'ba'  => "Bosna\ a\ Hercegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladéš',
    'be'  => 'Belgie',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulharsko',
    'bh'  => 'Bahrajn',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Svatý\ Bartoloměj",
    'bm'  => 'Bermudy',
    'bn'  => "Brunej\ Darussalam",
    'bo'  => 'Bolívie',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazílie',
    'bs'  => 'Bahamy',
    'bt'  => 'Bhútán',
    'bv'  => "Ostrov\ Bouvet",
    'bw'  => 'Botswana',
    'by'  => 'Bělorusko',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Kokosové\ ostrovy",
    'cd'  => "Kongo\ \-\ DRK",
    'cf'  => "Středoafrická\ republika",
    'cg'  => "Kongo\ \[Republika\]",
    'ch'  => 'Švýcarsko',
    'ci'  => "Pobřeží\ slonoviny",
    'ck'  => "Cookovy\ ostrovy",
    'cl'  => 'Chile',
    'cm'  => 'Kamerun',
    'cn'  => 'Čína',
    'co'  => 'Kolumbie',
    'cp'  => "Clippertonův\ ostrov",
    'cr'  => 'Kostarika',
    'cs'  => "Srbsko\ a\ Černá\ Hora",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => 'Kapverdy',
    'cx'  => "Vánoční\ ostrovy",
    'cy'  => 'Kypr',
    'cz'  => "Česká\ republika",
    'dd'  => "East\ Germany",
    'de'  => 'Německo',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Džibuti',
    'dk'  => 'Dánsko',
    'dm'  => 'Dominika',
    'do'  => "Dominikánská\ republika",
    'dz'  => 'Alžírsko',
    'ea'  => "Ceuta\ a\ Melilla",
    'ec'  => 'Ekvádor',
    'ee'  => 'Estonsko',
    'eg'  => 'Egypt',
    'eh'  => "Západní\ Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Španělsko',
    'et'  => 'Etiopie',
    'eu'  => "Evropská\ unie",
    'fi'  => 'Finsko',
    'fj'  => 'Fidži',
    'fk'  => "Falklandské\ ostrovy\ \[Malvíny\]",
    'fm'  => 'Mikronézie',
    'fo'  => "Faerské\ ostrovy",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Francie',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => "Velká\ Británie",
    'gd'  => 'Grenada',
    'ge'  => 'Gruzie',
    'gf'  => "Francouzská\ Guyana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grónsko',
    'gm'  => 'Gambie',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => "Rovníková\ Guinea",
    'gr'  => 'Řecko',
    'gs'  => "Jižní\ Georgie\ a\ Jižní\ Sandwichovy\ ostrovy",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Ostrovy\ Heard\ a\ McDonald",
    'hn'  => 'Honduras',
    'hr'  => 'Chorvatsko',
    'ht'  => 'Haiti',
    'hu'  => 'Maďarsko',
    'ic'  => "Kanárské\ ostrovy",
    'id'  => 'Indonésie',
    'ie'  => 'Irsko',
    'il'  => 'Izrael',
    'im'  => "Ostrov\ Man",
    'in'  => 'Indie',
    'io'  => "Britské\ území\ v\ Indickém\ oceánu",
    'iq'  => 'Irák',
    'ir'  => 'Írán',
    'is'  => 'Island',
    'it'  => 'Itálie',
    'je'  => 'Jersey',
    'jm'  => 'Jamajka',
    'jo'  => 'Jordánsko',
    'jp'  => 'Japonsko',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Keňa',
    'kg'  => 'Kyrgyzstán',
    'kh'  => 'Kambodža',
    'ki'  => 'Kiribati',
    'km'  => 'Komory',
    'kn'  => "Svatý\ Kitts\ a\ Nevis",
    'kp'  => "Severní\ Korea",
    'kr'  => "Jižní\ Korea",
    'kw'  => 'Kuvajt',
    'ky'  => "Kajmanské\ ostrovy",
    'kz'  => 'Kazachstán',
    'la'  => "Lidově\ demokratická\ republika\ Laos",
    'lb'  => 'Libanon',
    'lc'  => "Svatá\ Lucie",
    'li'  => 'Lichtenštejnsko',
    'lk'  => "Srí\ Lanka",
    'lr'  => 'Libérie',
    'ls'  => 'Lesotho',
    'lt'  => 'Litva',
    'lu'  => 'Lucembursko',
    'lv'  => 'Lotyšsko',
    'ly'  => 'Libye',
    'ma'  => 'Maroko',
    'mc'  => 'Monako',
    'md'  => 'Moldavsko',
    'me'  => "Černá\ Hora",
    'mf'  => "Svatý\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Marshallovy\ ostrovy",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Makedonie',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongolsko',
    'mo'  => 'Macao',
    'mp'  => "Severní\ Mariany",
    'mq'  => 'Martinik',
    'mr'  => 'Mauritánie',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauricius',
    'mv'  => 'Maladivy',
    'mw'  => 'Malawi',
    'mx'  => 'Mexiko',
    'my'  => 'Malajsie',
    'mz'  => 'Mosambik',
    'na'  => 'Namibie',
    'nc'  => "Nová\ Kaledonie",
    'ne'  => 'Niger',
    'nf'  => 'Norfolk',
    'ng'  => 'Nigérie',
    'ni'  => 'Nikaragua',
    'nl'  => 'Nizozemsko',
    'no'  => 'Norsko',
    'np'  => 'Nepál',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nový\ Zéland",
    'om'  => 'Omán',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Francouzská\ Polynésie",
    'pg'  => "Papua\-Nová\ Guinea",
    'ph'  => 'Filipíny',
    'pk'  => 'Pákistán',
    'pl'  => 'Polsko',
    'pm'  => "Svatý\ Pierre\ a\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => 'Portoriko',
    'ps'  => "Palestinian\ Territory",
    'pt'  => 'Portugalsko',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Vnější\ Oceánie",
    're'  => 'Réunion',
    'ro'  => 'Rumunsko',
    'rs'  => 'Srbsko',
    'ru'  => 'Rusko',
    'rw'  => 'Rwanda',
    'sa'  => "Saúdská\ Arábie",
    'sb'  => "Šalamounovy\ ostrovy",
    'sc'  => 'Seychely',
    'sd'  => 'Súdán',
    'se'  => 'Švédsko',
    'sg'  => 'Singapur',
    'sh'  => "Svatá\ Helena",
    'si'  => 'Slovinsko',
    'sj'  => "Svalbard\ a\ Jan\ Mayen",
    'sk'  => 'Slovensko',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somálsko',
    'sr'  => 'Surinam',
    'st'  => "Svatý\ Tomáš",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Sýrie',
    'sz'  => 'Svazijsko',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Ostrovy\ Caicos\ a\ Turks",
    'td'  => 'Čad',
    'tf'  => "Francouzská\ jižní\ teritoria",
    'tg'  => 'Togo',
    'th'  => 'Thajsko',
    'tj'  => 'Tádžikistán',
    'tk'  => 'Tokelau',
    'tl'  => "Východní\ Timor",
    'tm'  => 'Turkmenistán',
    'tn'  => 'Tunisko',
    'to'  => 'Tonga',
    'tr'  => 'Turecko',
    'tt'  => "Trinidad\ a\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => "Tchaj\-wan",
    'tz'  => 'Tanzanie',
    'ua'  => 'Ukrajina',
    'ug'  => 'Uganda',
    'um'  => "Menší\ odlehlé\ ostrovy\ USA",
    'us'  => "Spojené\ státy",
    'uy'  => 'Uruguay',
    'uz'  => 'Uzbekistán',
    'va'  => "Svatý\ stolec",
    'vc'  => "Svatý\ Vincent\ a\ Grenadiny",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Britské\ Panenské\ ostrovy",
    'vi'  => "Americké\ Panenské\ ostrovy",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ a\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => "Jihoafrická\ republika",
    'zm'  => 'Zambie',
    'zw'  => 'Zimbabwe',
    'zz'  => "Neznámá\ nebo\ neplatná\ oblast",
);

%Locales::DB::Territory::cs::name_to_code = (
    '003'                                       => '003',
    'afghánistán'                             => 'af',
    'afrika'                                    => '002',
    'alandy'                                    => 'ax',
    'albánie'                                  => 'al',
    'alžírsko'                                => 'dz',
    'americkásamoa'                            => 'as',
    'americképanenskéostrovy'                 => 'vi',
    'amerika'                                   => '019',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguila'                                   => 'ai',
    'antarktida'                                => 'aq',
    'antiguaabarbuda'                           => 'ag',
    'argentina'                                 => 'ar',
    'arménie'                                  => 'am',
    'aruba'                                     => 'aw',
    'asie'                                      => 142,
    'austrálie'                                => 'au',
    'austrálieanovýzéland'                   => '053',
    'bahamy'                                    => 'bs',
    'bahrajn'                                   => 'bh',
    'bangladéš'                               => 'bd',
    'barbados'                                  => 'bb',
    'belgie'                                    => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermudy'                                   => 'bm',
    'bhútán'                                  => 'bt',
    'bolívie'                                  => 'bo',
    'bosnaahercegovina'                         => 'ba',
    'botswana'                                  => 'bw',
    'brazílie'                                 => 'br',
    'britishantarcticterritory'                 => 'bq',
    'britsképanenskéostrovy'                  => 'vg',
    'britskéúzemívindickémoceánu'          => 'io',
    'brunejdarussalam'                          => 'bn',
    'bulharsko'                                 => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'bělorusko'                                => 'by',
    'cantonandenderburyislands'                 => 'ct',
    'ceutaamelilla'                             => 'ea',
    'chile'                                     => 'cl',
    'chorvatsko'                                => 'hr',
    'clippertonůvostrov'                       => 'cp',
    'cookovyostrovy'                            => 'ck',
    'diegogarcia'                               => 'dg',
    'dominika'                                  => 'dm',
    'dominikánskárepublika'                   => 'do',
    'dronningmaudland'                          => 'nq',
    'dánsko'                                   => 'dk',
    'džibuti'                                  => 'dj',
    'eastgermany'                               => 'dd',
    'egypt'                                     => 'eg',
    'ekvádor'                                  => 'ec',
    'elsalvador'                                => 'sv',
    'eritrea'                                   => 'er',
    'estonsko'                                  => 'ee',
    'etiopie'                                   => 'et',
    'evropa'                                    => 150,
    'evropskáunie'                             => 'eu',
    'faerskéostrovy'                           => 'fo',
    'falklandskéostrovymalvíny'               => 'fk',
    'fidži'                                    => 'fj',
    'filipíny'                                 => 'ph',
    'finsko'                                    => 'fi',
    'francie'                                   => 'fr',
    'francouzskáguyana'                        => 'gf',
    'francouzskájižníteritoria'              => 'tf',
    'francouzskápolynésie'                    => 'pf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabon'                                     => 'ga',
    'gambie'                                    => 'gm',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'grenada'                                   => 'gd',
    'gruzie'                                    => 'ge',
    'grónsko'                                  => 'gl',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guinea'                                    => 'gn',
    'guineabissau'                              => 'gw',
    'guyana'                                    => 'gy',
    'haiti'                                     => 'ht',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'indie'                                     => 'in',
    'indonésie'                                => 'id',
    'irsko'                                     => 'ie',
    'irák'                                     => 'iq',
    'island'                                    => 'is',
    'itálie'                                   => 'it',
    'izrael'                                    => 'il',
    'jamajka'                                   => 'jm',
    'japonsko'                                  => 'jp',
    'jemen'                                     => 'ye',
    'jersey'                                    => 'je',
    'jihoafrickárepublika'                     => 'za',
    'jihovýchodníasie'                        => '035',
    'jižníacentrálníasie'                   => '062',
    'jižníafrika'                             => '018',
    'jižníamerika'                            => '005',
    'jižníasie'                               => '034',
    'jižníevropa'                             => '039',
    'jižnígeorgieajižnísandwichovyostrovy'  => 'gs',
    'jižníkorea'                              => 'kr',
    'johnstonisland'                            => 'jt',
    'jordánsko'                                => 'jo',
    'kajmanskéostrovy'                         => 'ky',
    'kambodža'                                 => 'kh',
    'kamerun'                                   => 'cm',
    'kanada'                                    => 'ca',
    'kanárskéostrovy'                         => 'ic',
    'kapverdy'                                  => 'cv',
    'karibik'                                   => '029',
    'katar'                                     => 'qa',
    'kazachstán'                               => 'kz',
    'keňa'                                     => 'ke',
    'kiribati'                                  => 'ki',
    'kokosovéostrovy'                          => 'cc',
    'kolumbie'                                  => 'co',
    'komory'                                    => 'km',
    'kongodrk'                                  => 'cd',
    'kongorepublika'                            => 'cg',
    'kostarika'                                 => 'cr',
    'kuba'                                      => 'cu',
    'kuvajt'                                    => 'kw',
    'kypr'                                      => 'cy',
    'kyrgyzstán'                               => 'kg',
    'latinskáamerikaakaribskémoře'           => 419,
    'lesotho'                                   => 'ls',
    'libanon'                                   => 'lb',
    'libye'                                     => 'ly',
    'libérie'                                  => 'lr',
    'lichtenštejnsko'                          => 'li',
    'lidovědemokratickárepublikalaos'         => 'la',
    'litva'                                     => 'lt',
    'lotyšsko'                                 => 'lv',
    'lucembursko'                               => 'lu',
    'macao'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'makedonie'                                 => 'mk',
    'maladivy'                                  => 'mv',
    'malajsie'                                  => 'my',
    'malawi'                                    => 'mw',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'maroko'                                    => 'ma',
    'marshallovyostrovy'                        => 'mh',
    'martinik'                                  => 'mq',
    'mauricius'                                 => 'mu',
    'mauritánie'                               => 'mr',
    'mayotte'                                   => 'yt',
    'maďarsko'                                 => 'hu',
    'melanésie'                                => '054',
    'menšíodlehléostrovyusa'                 => 'um',
    'metropolitanfrance'                        => 'fx',
    'mexiko'                                    => 'mx',
    'midwayislands'                             => 'mi',
    'mikronésie'                               => '057',
    'mikronézie'                               => 'fm',
    'moldavsko'                                 => 'md',
    'monako'                                    => 'mc',
    'mongolsko'                                 => 'mn',
    'montserrat'                                => 'ms',
    'mosambik'                                  => 'mz',
    'myanmar'                                   => 'mm',
    'namibie'                                   => 'na',
    'nauru'                                     => 'nr',
    'nepál'                                    => 'np',
    'neutralzone'                               => 'nt',
    'neznámáneboneplatnáoblast'              => 'zz',
    'niger'                                     => 'ne',
    'nigérie'                                  => 'ng',
    'nikaragua'                                 => 'ni',
    'niue'                                      => 'nu',
    'nizozemsko'                                => 'nl',
    'nizozemskéantily'                         => 'an',
    'norfolk'                                   => 'nf',
    'normanskéostrovy'                         => 830,
    'norsko'                                    => 'no',
    'northvietnam'                              => 'vd',
    'novákaledonie'                            => 'nc',
    'novýzéland'                              => 'nz',
    'německo'                                  => 'de',
    'oceánie'                                  => '009',
    'omán'                                     => 'om',
    'ostrovascension'                           => 'ac',
    'ostrovbouvet'                              => 'bv',
    'ostrovman'                                 => 'im',
    'ostrovycaicosaturks'                       => 'tc',
    'ostrovyheardamcdonald'                     => 'hm',
    'pacificislandstrustterritory'              => 'pc',
    'palau'                                     => 'pw',
    'palestinianterritory'                      => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanováguinea'                          => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'pobřežíslonoviny'                       => 'ci',
    'polsko'                                    => 'pl',
    'polynésie'                                => '061',
    'portoriko'                                 => 'pr',
    'portugalsko'                               => 'pt',
    'pákistán'                                => 'pk',
    'rakousko'                                  => 'at',
    'rovníkováguinea'                         => 'gq',
    'rumunsko'                                  => 'ro',
    'rusko'                                     => 'ru',
    'rwanda'                                    => 'rw',
    'réunion'                                  => 're',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saúdskáarábie'                          => 'sa',
    'senegal'                                   => 'sn',
    'severníafrika'                            => '015',
    'severníamerika'                           => '021',
    'severníevropa'                            => 154,
    'severníkorea'                             => 'kp',
    'severnímariany'                           => 'mp',
    'seychely'                                  => 'sc',
    'sierraleone'                               => 'sl',
    'singapur'                                  => 'sg',
    'slovensko'                                 => 'sk',
    'slovinsko'                                 => 'si',
    'somálsko'                                 => 'so',
    'spojenéarabskéemiráty'                  => 'ae',
    'spojenéstáty'                            => 'us',
    'společenstvínezávislýchstátů'        => 172,
    'srbsko'                                    => 'rs',
    'srbskoaČernáhora'                        => 'cs',
    'srílanka'                                 => 'lk',
    'středníafrika'                           => '017',
    'středníamerika'                          => '013',
    'středníasie'                             => 143,
    'středoafrickárepublika'                  => 'cf',
    'surinam'                                   => 'sr',
    'svalbardajanmayen'                         => 'sj',
    'svatáhelena'                              => 'sh',
    'svatálucie'                               => 'lc',
    'svatýbartoloměj'                         => 'bl',
    'svatýkittsanevis'                         => 'kn',
    'svatýmartin'                              => 'mf',
    'svatýpierreamiquelon'                     => 'pm',
    'svatýstolec'                              => 'va',
    'svatýtomáš'                             => 'st',
    'svatývincentagrenadiny'                   => 'vc',
    'svazijsko'                                 => 'sz',
    'svět'                                     => '001',
    'súdán'                                   => 'sd',
    'sýrie'                                    => 'sy',
    'tanzanie'                                  => 'tz',
    'tchajwan'                                  => 'tw',
    'thajsko'                                   => 'th',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadatobago'                           => 'tt',
    'tristandacunha'                            => 'ta',
    'tunisko'                                   => 'tn',
    'turecko'                                   => 'tr',
    'turkmenistán'                             => 'tm',
    'tuvalu'                                    => 'tv',
    'tádžikistán'                            => 'tj',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukrajina'                                  => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    'uzbekistán'                               => 'uz',
    'vanuatu'                                   => 'vu',
    'velkábritánie'                           => 'gb',
    'venezuela'                                 => 've',
    'vietnam'                                   => 'vn',
    'vnějšíoceánie'                         => 'qo',
    'vánočníostrovy'                         => 'cx',
    'východníafrika'                          => '014',
    'východníasie'                            => '030',
    'východníevropa'                          => 151,
    'východnítimor'                           => 'tl',
    'wakeisland'                                => 'wk',
    'wallisafutuna'                             => 'wf',
    'zambie'                                    => 'zm',
    'zimbabwe'                                  => 'zw',
    'západníafrika'                           => '011',
    'západníasie'                             => 145,
    'západníevropa'                           => 155,
    'západnísahara'                           => 'eh',
    'Ázerbájdžán'                           => 'az',
    'Írán'                                    => 'ir',
    'Čad'                                      => 'td',
    'Černáhora'                               => 'me',
    'Československo'                           => 200,
    'Českárepublika'                          => 'cz',
    'Čína'                                    => 'cn',
    'Řecko'                                    => 'gr',
    'Šalamounovyostrovy'                       => 'sb',
    'Španělsko'                               => 'es',
    'Švédsko'                                 => 'se',
    'Švýcarsko'                               => 'ch',
);

1;

