package Locales::DB::Territory::yo;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::yo::VERSION = '0.09';

$Locales::DB::Territory::yo::cldr_version = '2.0';

%Locales::DB::Territory::yo::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => "Orílẹ́ède\ Ààndórà",
    'ae'  => "Orílẹ́ède\ Ẹmirate\ ti\ Awọn\ Arabu",
    'af'  => "Orílẹ́ède\ Àfùgànístánì",
    'ag'  => "Orílẹ́ède\ Ààntígúà\ àti\ Báríbúdà",
    'ai'  => "Orílẹ́ède\ Ààngúlílà",
    'al'  => "Orílẹ́ède\ Àlùbàníánì",
    'am'  => "Orílẹ́ède\ Améníà",
    'an'  => "Orílẹ́ède\ Nedalandi\ ti\ Antelisi",
    'ao'  => "Orílẹ́ède\ Ààngólà",
    'aq'  => 'Antarctica',
    'ar'  => "Orílẹ́ède\ Agentínà",
    'as'  => "Sámóánì\ ti\ Orílẹ́ède\ Àméríkà",
    'at'  => "Orílẹ́ède\ Asítíríà",
    'au'  => "Orílẹ́ède\ Ástràlìá",
    'aw'  => "Orílẹ́ède\ Árúbà",
    'ax'  => "\Ã\land\ Islands",
    'az'  => "Orílẹ́ède\ Asẹ́bájánì",
    'ba'  => "Orílẹ́ède\ Bọ̀síníà\ àti\ Ẹtisẹgófínà",
    'bb'  => "Orílẹ́ède\ Bábádósì",
    'bd'  => "Orílẹ́ède\ Bángáládésì",
    'be'  => "Orílẹ́ède\ Bégíọ́mù",
    'bf'  => "Orílẹ́ède\ Bùùkíná\ Fasò",
    'bg'  => "Orílẹ́ède\ Bùùgáríà",
    'bh'  => "Orílẹ́ède\ Báránì",
    'bi'  => "Orílẹ́ède\ Bùùrúndì",
    'bj'  => "Orílẹ́ède\ Bẹ̀nẹ̀",
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => "Orílẹ́ède\ Bémúdà",
    'bn'  => "Orílẹ́ède\ Búrúnẹ́lì",
    'bo'  => "Orílẹ́ède\ Bọ̀lífíyà",
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => "Orílẹ́ède\ Bàràsílì",
    'bs'  => "Orílẹ́ède\ Bàhámásì",
    'bt'  => "Orílẹ́ède\ Bútánì",
    'bv'  => "Bouvet\ Island",
    'bw'  => "Orílẹ́ède\ Bọ̀tìsúwánà",
    'by'  => "Orílẹ́ède\ Bélárúsì",
    'bz'  => "Orílẹ́ède\ Bèlísẹ̀",
    'ca'  => "Orílẹ́ède\ Kánádà",
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Orilẹ́ède\ Kóngò",
    'cf'  => "Orílẹ́ède\ Àrin\ gùngun\ Áfíríkà",
    'cg'  => "Orílẹ́ède\ Kóngò",
    'ch'  => "Orílẹ́ède\ switiṣilandi",
    'ci'  => "Orílẹ́ède\ Kóútè\ forà",
    'ck'  => "Orílẹ́ède\ Etíokun\ Kùúkù",
    'cl'  => "Orílẹ́ède\ ṣílè",
    'cm'  => "Orílẹ́ède\ Kamerúúnì",
    'cn'  => "Orílẹ́ède\ ṣáínà",
    'co'  => "Orílẹ́ède\ Kòlómíbìa",
    'cp'  => "Clipperton\ Island",
    'cr'  => "Orílẹ́ède\ Kuusita\ Ríkà",
    'cs'  => "Orílẹ́ède\ sẹbia\ ati\ Mọtinegoro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => "Orílẹ́ède\ Kúbà",
    'cv'  => "Orílẹ́ède\ Etíokun\ Kápé\ féndè",
    'cx'  => "Christmas\ Island",
    'cy'  => "Orílẹ́ède\ Kúrúsì",
    'cz'  => "Orílẹ́ède\ ṣẹ́ẹ́kì",
    'dd'  => "East\ Germany",
    'de'  => "Orílẹ́ède\ Gemani",
    'dg'  => "Diego\ Garcia",
    'dj'  => "Orílẹ́ède\ Díbọ́ótì",
    'dk'  => "Orílẹ́ède\ Dẹ́mákì",
    'dm'  => "Orílẹ́ède\ Dòmíníkà",
    'do'  => "Orilẹ́ède\ Dòmíníkánì",
    'dz'  => "Orílẹ́ède\ Àlùgèríánì",
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => "Orílẹ́ède\ Ekuádò",
    'ee'  => "Orílẹ́ède\ Esitonia",
    'eg'  => "Orílẹ́ède\ Égípítì",
    'eh'  => "Western\ Sahara",
    'er'  => "Orílẹ́ède\ Eritira",
    'es'  => "Orílẹ́ède\ Sipani",
    'et'  => "Orílẹ́ède\ Etopia",
    'eu'  => "European\ Union",
    'fi'  => "Orílẹ́ède\ Filandi",
    'fj'  => "Orílẹ́ède\ Fiji",
    'fk'  => "Orílẹ́ède\ Etikun\ Fakalandi",
    'fm'  => "Orílẹ́ède\ Makoronesia",
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => "Orílẹ́ède\ Faranse",
    'fx'  => "Metropolitan\ France",
    'ga'  => "Orílẹ́ède\ Gabon",
    'gb'  => "Orílẹ́ède\ Omobabirin",
    'gd'  => "Orílẹ́ède\ Genada",
    'ge'  => "Orílẹ́ède\ Gọgia",
    'gf'  => "Orílẹ́ède\ Firenṣi\ Guana",
    'gg'  => 'Guernsey',
    'gh'  => "Orílẹ́ède\ Gana",
    'gi'  => "Orílẹ́ède\ Gibaratara",
    'gl'  => "Orílẹ́ède\ Gerelandi",
    'gm'  => "Orílẹ́ède\ Gambia",
    'gn'  => "Orílẹ́ède\ Gene",
    'gp'  => "Orílẹ́ède\ Gadelope",
    'gq'  => "Orílẹ́ède\ Ekutoria\ Gini",
    'gr'  => "Orílẹ́ède\ Geriisi",
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => "Orílẹ́ède\ Guatemala",
    'gu'  => "Orílẹ́ède\ Guamu",
    'gw'  => "Orílẹ́ède\ Gene\-Busau",
    'gy'  => "Orílẹ́ède\ Guyana",
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => "Orílẹ́ède\ Hondurasi",
    'hr'  => "Orílẹ́ède\ Kòróátíà",
    'ht'  => "Orílẹ́ède\ Haati",
    'hu'  => "Orílẹ́ède\ Hungari",
    'ic'  => "Canary\ Islands",
    'id'  => "Orílẹ́ède\ Indonesia",
    'ie'  => "Orílẹ́ède\ Ailandi",
    'il'  => "Orílẹ́ède\ Iserẹli",
    'im'  => "Isle\ of\ Man",
    'in'  => "Orílẹ́ède\ India",
    'io'  => "Orílẹ́ède\ Etíkun\ Índíánì\ ti\ Ìlú\ Bírítísì",
    'iq'  => "Orílẹ́ède\ Iraki",
    'ir'  => "Orílẹ́ède\ Irani",
    'is'  => "Orílẹ́ède\ Aṣilandi",
    'it'  => "Orílẹ́ède\ Italiyi",
    'je'  => 'Jersey',
    'jm'  => "Orílẹ́ède\ Jamaika",
    'jo'  => "Orílẹ́ède\ Jọdani",
    'jp'  => "Orílẹ́ède\ Japani",
    'jt'  => "Johnston\ Island",
    'ke'  => "Orílẹ́ède\ Kenya",
    'kg'  => "Orílẹ́ède\ Kuriṣisitani",
    'kh'  => "Orílẹ́ède\ Kàmùbódíà",
    'ki'  => "Orílẹ́ède\ Kiribati",
    'km'  => "Orílẹ́ède\ Kòmòrósì",
    'kn'  => "Orílẹ́ède\ Kiiti\ ati\ Neefi",
    'kp'  => "Orílẹ́ède\ Guusu\ Kọria",
    'kr'  => "Orílẹ́ède\ Ariwa\ Kọria",
    'kw'  => "Orílẹ́ède\ Kuweti",
    'ky'  => "Orílẹ́ède\ Etíokun\ Kámánì",
    'kz'  => "Orílẹ́ède\ Kaṣaṣatani",
    'la'  => "Orílẹ́ède\ Laosi",
    'lb'  => "Orílẹ́ède\ Lebanoni",
    'lc'  => "Orílẹ́ède\ Luṣia",
    'li'  => "Orílẹ́ède\ Lẹṣitẹnisiteni",
    'lk'  => "Orílẹ́ède\ Siri\ Lanka",
    'lr'  => "Orílẹ́ède\ Laberia",
    'ls'  => "Orílẹ́ède\ Lesoto",
    'lt'  => "Orílẹ́ède\ Lituania",
    'lu'  => "Orílẹ́ède\ Lusemogi",
    'lv'  => "Orílẹ́ède\ Latifia",
    'ly'  => "Orílẹ́ède\ Libiya",
    'ma'  => "Orílẹ́ède\ Moroko",
    'mc'  => "Orílẹ́ède\ Monako",
    'md'  => "Orílẹ́ède\ Modofia",
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => "Orílẹ́ède\ Madasika",
    'mh'  => "Orílẹ́ède\ Etikun\ Máṣali",
    'mi'  => "Midway\ Islands",
    'mk'  => "Orílẹ́ède\ Masidonia",
    'ml'  => "Orílẹ́ède\ Mali",
    'mm'  => "Orílẹ́ède\ Manamari",
    'mn'  => "Orílẹ́ède\ Mogolia",
    'mo'  => 'Macau',
    'mp'  => "Orílẹ́ède\ Etikun\ Guusu\ Mariana",
    'mq'  => "Orílẹ́ède\ Matinikuwi",
    'mr'  => "Orílẹ́ède\ Maritania",
    'ms'  => "Orílẹ́ède\ Motserati",
    'mt'  => "Orílẹ́ède\ Malata",
    'mu'  => "Orílẹ́ède\ Maritiusi",
    'mv'  => "Orílẹ́ède\ Maladifi",
    'mw'  => "Orílẹ́ède\ Malawi",
    'mx'  => "Orílẹ́ède\ Mesiko",
    'my'  => "Orílẹ́ède\ Malasia",
    'mz'  => "Orílẹ́ède\ Moṣamibiku",
    'na'  => "Orílẹ́ède\ Namibia",
    'nc'  => "Orílẹ́ède\ Kaledonia\ Titun",
    'ne'  => "Orílẹ́ède\ Nàìjá",
    'nf'  => "Orílẹ́ède\ Etikun\ Nọ́úfókì",
    'ng'  => "Orílẹ́ède\ Nàìjíríà",
    'ni'  => "Orílẹ́ède\ NIkaragua",
    'nl'  => "Orílẹ́ède\ Nedalandi",
    'no'  => "Orílẹ́ède\ Nọọwii",
    'np'  => "Orílẹ́ède\ Nepa",
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => "Orílẹ́ède\ Nauru",
    'nt'  => "Neutral\ Zone",
    'nu'  => "Orílẹ́ède\ Niue",
    'nz'  => "Orílẹ́ède\ ṣilandi\ Titun",
    'om'  => "Orílẹ́ède\ Ọọma",
    'pa'  => "Orílẹ́ède\ Panama",
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => "Orílẹ́ède\ Peru",
    'pf'  => "Orílẹ́ède\ Firenṣi\ Polinesia",
    'pg'  => "Orílẹ́ède\ Paapu\ ti\ Giini",
    'ph'  => "Orílẹ́ède\ filipini",
    'pk'  => "Orílẹ́ède\ Pakisitan",
    'pl'  => "Orílẹ́ède\ Polandi",
    'pm'  => "Orílẹ́ède\ Pẹẹri\ ati\ mikuloni",
    'pn'  => "Orílẹ́ède\ Pikarini",
    'pr'  => "Orílẹ́ède\ Pọto\ Riko",
    'ps'  => "Orílẹ́ède\ Iwọorun\ Pakisitian\ ati\ Gaṣa",
    'pt'  => "Orílẹ́ède\ Pọtugi",
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => "Orílẹ́ède\ Paalu",
    'py'  => "Orílẹ́ède\ Paraguye",
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => "Orílẹ́ède\ Kota",
    'qo'  => "Outlying\ Oceania",
    're'  => "Orílẹ́ède\ Riuniyan",
    'ro'  => "Orílẹ́ède\ Romaniya",
    'rs'  => 'Serbia',
    'ru'  => "Orílẹ́ède\ Rọṣia",
    'rw'  => "Orílẹ́ède\ Ruwanda",
    'sa'  => "Orílẹ́ède\ Saudi\ Arabia",
    'sb'  => "Orílẹ́ède\ Etikun\ Solomoni",
    'sc'  => "Orílẹ́ède\ seṣẹlẹsi",
    'sd'  => "Orílẹ́ède\ Sudani",
    'se'  => "Orílẹ́ède\ Swidini",
    'sg'  => "Orílẹ́ède\ Singapo",
    'sh'  => "Orílẹ́ède\ Hẹlena",
    'si'  => "Orílẹ́ède\ Silofania",
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => "Orílẹ́ède\ Silofakia",
    'sl'  => "Orílẹ́ède\ Siria\ looni",
    'sm'  => "Orílẹ́ède\ Sani\ Marino",
    'sn'  => "Orílẹ́ède\ Sẹnẹga",
    'so'  => "Orílẹ́ède\ Somalia",
    'sr'  => "Orílẹ́ède\ Surinami",
    'st'  => "Orílẹ́ède\ Sao\ tomi\ ati\ piriiṣipi",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "Orílẹ́ède\ Ẹẹsáfádò",
    'sy'  => "Orílẹ́ède\ Siria",
    'sz'  => "Orílẹ́ède\ Saṣiland",
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Orílẹ́ède\ Tọọki\ ati\ Etikun\ Kakọsi",
    'td'  => "Orílẹ́ède\ ṣààdì",
    'tf'  => "French\ Southern\ Territories",
    'tg'  => "Orílẹ́ède\ Togo",
    'th'  => "Orílẹ́ède\ Tailandi",
    'tj'  => "Orílẹ́ède\ Takisitani",
    'tk'  => "Orílẹ́ède\ Tokelau",
    'tl'  => "Orílẹ́ède\ ÌlàOòrùn\ Tímọ̀",
    'tm'  => "Orílẹ́ède\ Tọọkimenisita",
    'tn'  => "Orílẹ́ède\ Tuniṣia",
    'to'  => "Orílẹ́ède\ Tonga",
    'tr'  => "Orílẹ́ède\ Tọọki",
    'tt'  => "Orílẹ́ède\ Tirinida\ ati\ Tobaga",
    'tv'  => "Orílẹ́ède\ Tufalu",
    'tw'  => "Orílẹ́ède\ Taiwani",
    'tz'  => "Orílẹ́ède\ Tanṣania",
    'ua'  => "Orílẹ́ède\ Ukarini",
    'ug'  => "Orílẹ́ède\ Uganda",
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Orílẹ́ède\ Orilẹede\ Amerika",
    'uy'  => "Orílẹ́ède\ Nruguayi",
    'uz'  => "Orílẹ́ède\ Nṣibẹkisitani",
    'va'  => "Orílẹ́ède\ Fatikani",
    'vc'  => "Orílẹ́ède\ Fisẹnnti\ ati\ Genadina",
    'vd'  => "North\ Vietnam",
    've'  => "Orílẹ́ède\ Fẹnẹṣuẹla",
    'vg'  => "Orílẹ́ède\ Etíkun\ Fágínì\ ti\ ìlú\ Bírítísì",
    'vi'  => "Orílẹ́ède\ Etikun\ Fagini\ ti\ Amẹrika",
    'vn'  => "Orílẹ́ède\ Fẹtinami",
    'vu'  => "Orílẹ́ède\ Faniatu",
    'wf'  => "Orílẹ́ède\ Wali\ ati\ futuna",
    'wk'  => "Wake\ Island",
    'ws'  => "Orílẹ́ède\ Samọ",
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => "Orílẹ́ède\ yemeni",
    'yt'  => "Orílẹ́ède\ Mayote",
    'za'  => "Orílẹ́ède\ Ariwa\ Afirika",
    'zm'  => "Orílẹ́ède\ ṣamibia",
    'zw'  => "Orílẹ́ède\ ṣimibabe",
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::yo::name_to_code = (
    'africa'                                              => '002',
    'americas'                                            => '019',
    'antarctica'                                          => 'aq',
    'ascensionisland'                                     => 'ac',
    'asia'                                                => 142,
    'australiaandnewzealand'                              => '053',
    'bouvetisland'                                        => 'bv',
    'britishantarcticterritory'                           => 'bq',
    'canaryislands'                                       => 'ic',
    'cantonandenderburyislands'                           => 'ct',
    'caribbean'                                           => '029',
    'centralamerica'                                      => '013',
    'centralasia'                                         => 143,
    'ceutaandmelilla'                                     => 'ea',
    'channelislands'                                      => 830,
    'christmasisland'                                     => 'cx',
    'clippertonisland'                                    => 'cp',
    'cocoskeelingislands'                                 => 'cc',
    'commonwealthofindependentstates'                     => 172,
    'czechoslovakia'                                      => 200,
    'diegogarcia'                                         => 'dg',
    'dronningmaudland'                                    => 'nq',
    'easternafrica'                                       => '014',
    'easternasia'                                         => '030',
    'easterneurope'                                       => 151,
    'eastgermany'                                         => 'dd',
    'europe'                                              => 150,
    'europeanunion'                                       => 'eu',
    'faroeislands'                                        => 'fo',
    'frenchsouthernandantarcticterritories'               => 'fq',
    'frenchsouthernterritories'                           => 'tf',
    'guernsey'                                            => 'gg',
    'heardislandandmcdonaldislands'                       => 'hm',
    'hongkong'                                            => 'hk',
    'isleofman'                                           => 'im',
    'jersey'                                              => 'je',
    'johnstonisland'                                      => 'jt',
    'latinamerica'                                        => 419,
    'macau'                                               => 'mo',
    'melanesia'                                           => '054',
    'metropolitanfrance'                                  => 'fx',
    'micronesianregion'                                   => '057',
    'middleafrica'                                        => '017',
    'midwayislands'                                       => 'mi',
    'montenegro'                                          => 'me',
    'neutralzone'                                         => 'nt',
    'northamerica'                                        => '003',
    'northernafrica'                                      => '015',
    'northernamerica'                                     => '021',
    'northerneurope'                                      => 154,
    'northvietnam'                                        => 'vd',
    'oceania'                                             => '009',
    'orilẹ́èdedòmíníkánì'                        => 'do',
    'orilẹ́èdekóngò'                                => 'cd',
    'orílẹ́èdeagentínà'                            => 'ar',
    'orílẹ́èdeailandi'                               => 'ie',
    'orílẹ́èdeaméníà'                             => 'am',
    'orílẹ́èdeariwaafirika'                          => 'za',
    'orílẹ́èdeariwakọria'                          => 'kr',
    'orílẹ́èdeasítíríà'                          => 'at',
    'orílẹ́èdeasẹ́bájánì'                      => 'az',
    'orílẹ́èdeaṣilandi'                            => 'is',
    'orílẹ́èdebàhámásì'                          => 'bs',
    'orílẹ́èdebàràsílì'                          => 'br',
    'orílẹ́èdebábádósì'                          => 'bb',
    'orílẹ́èdebángáládésì'                      => 'bd',
    'orílẹ́èdebáránì'                             => 'bh',
    'orílẹ́èdebèlísẹ̀'                          => 'bz',
    'orílẹ́èdebégíọ́mù'                        => 'be',
    'orílẹ́èdebélárúsì'                          => 'by',
    'orílẹ́èdebémúdà'                             => 'bm',
    'orílẹ́èdebùùgáríà'                         => 'bg',
    'orílẹ́èdebùùkínáfasò'                      => 'bf',
    'orílẹ́èdebùùrúndì'                          => 'bi',
    'orílẹ́èdebúrúnẹ́lì'                       => 'bn',
    'orílẹ́èdebútánì'                             => 'bt',
    'orílẹ́èdebẹ̀nẹ̀'                          => 'bj',
    'orílẹ́èdebọ̀lífíyà'                       => 'bo',
    'orílẹ́èdebọ̀síníààtiẸtisẹgófínà'  => 'ba',
    'orílẹ́èdebọ̀tìsúwánà'                    => 'bw',
    'orílẹ́èdedíbọ́ótì'                        => 'dj',
    'orílẹ́èdedòmíníkà'                          => 'dm',
    'orílẹ́èdedẹ́mákì'                          => 'dk',
    'orílẹ́èdeekutoriagini'                          => 'gq',
    'orílẹ́èdeekuádò'                              => 'ec',
    'orílẹ́èdeeritira'                               => 'er',
    'orílẹ́èdeesitonia'                              => 'ee',
    'orílẹ́èdeetikunfaginitiamẹrika'               => 'vi',
    'orílẹ́èdeetikunfakalandi'                       => 'fk',
    'orílẹ́èdeetikunguusumariana'                    => 'mp',
    'orílẹ́èdeetikunmáṣali'                       => 'mh',
    'orílẹ́èdeetikunnọ́úfókì'                  => 'nf',
    'orílẹ́èdeetikunsolomoni'                        => 'sb',
    'orílẹ́èdeetopia'                                => 'et',
    'orílẹ́èdeetíkunfágínìtiìlúbírítísì'   => 'vg',
    'orílẹ́èdeetíkunÍndíánìtiÌlúbírítísì' => 'io',
    'orílẹ́èdeetíokunkámánì'                     => 'ky',
    'orílẹ́èdeetíokunkápéféndè'                 => 'cv',
    'orílẹ́èdeetíokunkùúkù'                      => 'ck',
    'orílẹ́èdefaniatu'                               => 'vu',
    'orílẹ́èdefaranse'                               => 'fr',
    'orílẹ́èdefatikani'                              => 'va',
    'orílẹ́èdefiji'                                  => 'fj',
    'orílẹ́èdefilandi'                               => 'fi',
    'orílẹ́èdefilipini'                              => 'ph',
    'orílẹ́èdefirenṣiguana'                        => 'gf',
    'orílẹ́èdefirenṣipolinesia'                    => 'pf',
    'orílẹ́èdefisẹnntiatigenadina'                 => 'vc',
    'orílẹ́èdefẹnẹṣuẹla'                     => 've',
    'orílẹ́èdefẹtinami'                            => 'vn',
    'orílẹ́èdegabon'                                 => 'ga',
    'orílẹ́èdegadelope'                              => 'gp',
    'orílẹ́èdegambia'                                => 'gm',
    'orílẹ́èdegana'                                  => 'gh',
    'orílẹ́èdegemani'                                => 'de',
    'orílẹ́èdegenada'                                => 'gd',
    'orílẹ́èdegene'                                  => 'gn',
    'orílẹ́èdegenebusau'                             => 'gw',
    'orílẹ́èdegerelandi'                             => 'gl',
    'orílẹ́èdegeriisi'                               => 'gr',
    'orílẹ́èdegibaratara'                            => 'gi',
    'orílẹ́èdeguamu'                                 => 'gu',
    'orílẹ́èdeguatemala'                             => 'gt',
    'orílẹ́èdeguusukọria'                          => 'kp',
    'orílẹ́èdeguyana'                                => 'gy',
    'orílẹ́èdegọgia'                               => 'ge',
    'orílẹ́èdehaati'                                 => 'ht',
    'orílẹ́èdehondurasi'                             => 'hn',
    'orílẹ́èdehungari'                               => 'hu',
    'orílẹ́èdehẹlena'                              => 'sh',
    'orílẹ́èdeindia'                                 => 'in',
    'orílẹ́èdeindonesia'                             => 'id',
    'orílẹ́èdeiraki'                                 => 'iq',
    'orílẹ́èdeirani'                                 => 'ir',
    'orílẹ́èdeiserẹli'                             => 'il',
    'orílẹ́èdeitaliyi'                               => 'it',
    'orílẹ́èdeiwọorunpakisitianatigaṣa'          => 'ps',
    'orílẹ́èdejamaika'                               => 'jm',
    'orílẹ́èdejapani'                                => 'jp',
    'orílẹ́èdejọdani'                              => 'jo',
    'orílẹ́èdekaledoniatitun'                        => 'nc',
    'orílẹ́èdekamerúúnì'                          => 'cm',
    'orílẹ́èdekaṣaṣatani'                        => 'kz',
    'orílẹ́èdekenya'                                 => 'ke',
    'orílẹ́èdekiitiatineefi'                         => 'kn',
    'orílẹ́èdekiribati'                              => 'ki',
    'orílẹ́èdekota'                                  => 'qa',
    'orílẹ́èdekuriṣisitani'                        => 'kg',
    'orílẹ́èdekuusitaríkà'                         => 'cr',
    'orílẹ́èdekuweti'                                => 'kw',
    'orílẹ́èdekàmùbódíà'                        => 'kh',
    'orílẹ́èdekánádà'                             => 'ca',
    'orílẹ́èdekòlómíbìa'                         => 'co',
    'orílẹ́èdekòmòrósì'                          => 'km',
    'orílẹ́èdekòróátíà'                         => 'hr',
    'orílẹ́èdekóngò'                               => 'cg',
    'orílẹ́èdekóútèforà'                         => 'ci',
    'orílẹ́èdekúbà'                                => 'cu',
    'orílẹ́èdekúrúsì'                             => 'cy',
    'orílẹ́èdelaberia'                               => 'lr',
    'orílẹ́èdelaosi'                                 => 'la',
    'orílẹ́èdelatifia'                               => 'lv',
    'orílẹ́èdelebanoni'                              => 'lb',
    'orílẹ́èdelesoto'                                => 'ls',
    'orílẹ́èdelibiya'                                => 'ly',
    'orílẹ́èdelituania'                              => 'lt',
    'orílẹ́èdelusemogi'                              => 'lu',
    'orílẹ́èdeluṣia'                               => 'lc',
    'orílẹ́èdelẹṣitẹnisiteni'                  => 'li',
    'orílẹ́èdemadasika'                              => 'mg',
    'orílẹ́èdemakoronesia'                           => 'fm',
    'orílẹ́èdemaladifi'                              => 'mv',
    'orílẹ́èdemalasia'                               => 'my',
    'orílẹ́èdemalata'                                => 'mt',
    'orílẹ́èdemalawi'                                => 'mw',
    'orílẹ́èdemali'                                  => 'ml',
    'orílẹ́èdemanamari'                              => 'mm',
    'orílẹ́èdemaritania'                             => 'mr',
    'orílẹ́èdemaritiusi'                             => 'mu',
    'orílẹ́èdemasidonia'                             => 'mk',
    'orílẹ́èdematinikuwi'                            => 'mq',
    'orílẹ́èdemayote'                                => 'yt',
    'orílẹ́èdemesiko'                                => 'mx',
    'orílẹ́èdemodofia'                               => 'md',
    'orílẹ́èdemogolia'                               => 'mn',
    'orílẹ́èdemonako'                                => 'mc',
    'orílẹ́èdemoroko'                                => 'ma',
    'orílẹ́èdemotserati'                             => 'ms',
    'orílẹ́èdemoṣamibiku'                          => 'mz',
    'orílẹ́èdenamibia'                               => 'na',
    'orílẹ́èdenauru'                                 => 'nr',
    'orílẹ́èdenedalandi'                             => 'nl',
    'orílẹ́èdenedalanditiantelisi'                   => 'an',
    'orílẹ́èdenepa'                                  => 'np',
    'orílẹ́èdenikaragua'                             => 'ni',
    'orílẹ́èdeniue'                                  => 'nu',
    'orílẹ́èdenruguayi'                              => 'uy',
    'orílẹ́èdenàìjá'                              => 'ne',
    'orílẹ́èdenàìjíríà'                         => 'ng',
    'orílẹ́èdenṣibẹkisitani'                     => 'uz',
    'orílẹ́èdenọọwii'                            => 'no',
    'orílẹ́èdeomobabirin'                            => 'gb',
    'orílẹ́èdeorilẹedeamerika'                     => 'us',
    'orílẹ́èdepaalu'                                 => 'pw',
    'orílẹ́èdepaaputigiini'                          => 'pg',
    'orílẹ́èdepakisitan'                             => 'pk',
    'orílẹ́èdepanama'                                => 'pa',
    'orílẹ́èdeparaguye'                              => 'py',
    'orílẹ́èdeperu'                                  => 'pe',
    'orílẹ́èdepikarini'                              => 'pn',
    'orílẹ́èdepolandi'                               => 'pl',
    'orílẹ́èdepẹẹriatimikuloni'                  => 'pm',
    'orílẹ́èdepọtoriko'                            => 'pr',
    'orílẹ́èdepọtugi'                              => 'pt',
    'orílẹ́èderiuniyan'                              => 're',
    'orílẹ́èderomaniya'                              => 'ro',
    'orílẹ́èderuwanda'                               => 'rw',
    'orílẹ́èderọṣia'                             => 'ru',
    'orílẹ́èdesamọ'                                => 'ws',
    'orílẹ́èdesanimarino'                            => 'sm',
    'orílẹ́èdesaotomiatipiriiṣipi'                 => 'st',
    'orílẹ́èdesaudiarabia'                           => 'sa',
    'orílẹ́èdesaṣiland'                            => 'sz',
    'orílẹ́èdeseṣẹlẹsi'                        => 'sc',
    'orílẹ́èdesilofakia'                             => 'sk',
    'orílẹ́èdesilofania'                             => 'si',
    'orílẹ́èdesingapo'                               => 'sg',
    'orílẹ́èdesipani'                                => 'es',
    'orílẹ́èdesiria'                                 => 'sy',
    'orílẹ́èdesirialooni'                            => 'sl',
    'orílẹ́èdesirilanka'                             => 'lk',
    'orílẹ́èdesomalia'                               => 'so',
    'orílẹ́èdesudani'                                => 'sd',
    'orílẹ́èdesurinami'                              => 'sr',
    'orílẹ́èdeswidini'                               => 'se',
    'orílẹ́èdeswitiṣilandi'                        => 'ch',
    'orílẹ́èdesẹbiaatimọtinegoro'                => 'cs',
    'orílẹ́èdesẹnẹga'                            => 'sn',
    'orílẹ́èdetailandi'                              => 'th',
    'orílẹ́èdetaiwani'                               => 'tw',
    'orílẹ́èdetakisitani'                            => 'tj',
    'orílẹ́èdetanṣania'                            => 'tz',
    'orílẹ́èdetirinidaatitobaga'                     => 'tt',
    'orílẹ́èdetogo'                                  => 'tg',
    'orílẹ́èdetokelau'                               => 'tk',
    'orílẹ́èdetonga'                                 => 'to',
    'orílẹ́èdetufalu'                                => 'tv',
    'orílẹ́èdetuniṣia'                             => 'tn',
    'orílẹ́èdetọọki'                             => 'tr',
    'orílẹ́èdetọọkiatietikunkakọsi'            => 'tc',
    'orílẹ́èdetọọkimenisita'                     => 'tm',
    'orílẹ́èdeuganda'                                => 'ug',
    'orílẹ́èdeukarini'                               => 'ua',
    'orílẹ́èdewaliatifutuna'                         => 'wf',
    'orílẹ́èdeyemeni'                                => 'ye',
    'orílẹ́èdeÀfùgànístánì'                    => 'af',
    'orílẹ́èdeÀlùbàníánì'                      => 'al',
    'orílẹ́èdeÀlùgèríánì'                      => 'dz',
    'orílẹ́èdeÀringùngunÁfíríkà'               => 'cf',
    'orílẹ́èdeÀàndórà'                           => 'ad',
    'orílẹ́èdeÀàngólà'                           => 'ao',
    'orílẹ́èdeÀàngúlílà'                        => 'ai',
    'orílẹ́èdeÀàntígúààtibáríbúdà'         => 'ag',
    'orílẹ́èdeÁrúbà'                              => 'aw',
    'orílẹ́èdeÁstràlìá'                          => 'au',
    'orílẹ́èdeÉgípítì'                           => 'eg',
    'orílẹ́èdeÌlàoòrùntímọ̀'                 => 'tl',
    'orílẹ́èdeṣamibia'                             => 'zm',
    'orílẹ́èdeṣilandititun'                        => 'nz',
    'orílẹ́èdeṣimibabe'                            => 'zw',
    'orílẹ́èdeṣààdì'                            => 'td',
    'orílẹ́èdeṣáínà'                            => 'cn',
    'orílẹ́èdeṣílè'                              => 'cl',
    'orílẹ́èdeṣẹ́ẹ́kì'                      => 'cz',
    'orílẹ́èdeẸmiratetiawọnarabu'                => 'ae',
    'orílẹ́èdeẸẹsáfádò'                       => 'sv',
    'orílẹ́èdeỌọma'                              => 'om',
    'outlyingoceania'                                     => 'qo',
    'pacificislandstrustterritory'                        => 'pc',
    'panamacanalzone'                                     => 'pz',
    "people\â\\sdemocraticrepublicofyemen"           => 'yd',
    'polynesia'                                           => '061',
    "saintbarth\Ã\©lemy"                                => 'bl',
    'saintmartin'                                         => 'mf',
    'serbia'                                              => 'rs',
    'southamerica'                                        => '005',
    'southcentralasia'                                    => '062',
    'southeasternasia'                                    => '035',
    'southernafrica'                                      => '018',
    'southernasia'                                        => '034',
    'southerneurope'                                      => '039',
    'southgeorgiaandthesouthsandwichislands'              => 'gs',
    'svalbardandjanmayen'                                 => 'sj',
    'sámóánìtiorílẹ́èdeÀméríkà'              => 'as',
    'tristandacunha'                                      => 'ta',
    "u\.s\.minoroutlyingislands"                          => 'um',
    "u\.s\.miscellaneouspacificislands"                   => 'pu',
    'unionofsovietsocialistrepublics'                     => 'su',
    'unknownregion'                                       => 'zz',
    'wakeisland'                                          => 'wk',
    'westernafrica'                                       => '011',
    'westernasia'                                         => 145,
    'westerneurope'                                       => 155,
    'westernsahara'                                       => 'eh',
    'world'                                               => '001',
    "\Ã\landislands"                                   => 'ax',
);

1;

