package Locales::DB::Territory::br;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::br::VERSION = '0.09';

$Locales::DB::Territory::br::cldr_version = '2.0';

%Locales::DB::Territory::br::code_to_name = (
    '001' => 'bed',
    '002' => 'Afrika',
    '003' => "Norzh\ Amerika",
    '005' => "Su\ Amerika",
    '009' => 'Oseania',
    '011' => "Afrika\ ar\ Cʼhornôg",
    '013' => "Kreiz\ Amerika",
    '014' => "Afrika\ ar\ Reter",
    '015' => "Afrika\ an\ Norzh",
    '017' => "Afrika\ ar\ Cʼhreiz",
    '018' => "Afrika\ ar\ Su",
    '019' => 'Amerikaoù',
    '021' => "Amerika\ an\ Norzh",
    '029' => 'Karib',
    '030' => "Azia\ ar\ Reter",
    '034' => "Azia\ ar\ Su",
    '035' => "Azia\ ar\ Gevred",
    '039' => "Europa\ ar\ Su",
    '053' => "Aostralia\ ha\ Zeland\-Nevez",
    '054' => 'Melanezia',
    '057' => "Rannved\ Mikronezia",
    '061' => 'Polinezia',
    '062' => "South\-Central\ Asia",
    142   => 'Azia',
    143   => "Azia\ ar\ Cʼhreiz",
    145   => "Azia\ ar\ Cʼhornôg",
    150   => 'Europa',
    151   => "Europa\ ar\ Reter",
    154   => "Europa\ an\ Norzh",
    155   => "Europa\ ar\ Cʼhornôg",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Amerika\ Latin\ ha\ Karib",
    830   => "Channel\ Islands",
    'ac'  => "Enez\ Ascension",
    'ad'  => 'Andorra',
    'ae'  => "Emirelezhioù\ Arab\ Unanet",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ ha\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Antilhez\ Nederlandat",
    'ao'  => 'Angola',
    'aq'  => 'Antarktika',
    'ar'  => 'Arcʼhantina',
    'as'  => "Samoa\ Amerikan",
    'at'  => 'Aostria',
    'au'  => 'Aostralia',
    'aw'  => 'Aruba',
    'ax'  => "Inizi\ Åland",
    'az'  => 'Azerbaidjan',
    'ba'  => "Bosnia\ ha\ Herzegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgia',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahrein',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazil',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhoutan',
    'bv'  => "Enez\ Bouvet",
    'bw'  => 'Botswana',
    'by'  => 'Belarus',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Inizi\ Kokoz",
    'cd'  => "Kongo\ \[RDK\]",
    'cf'  => "Republik\ Kreizafrikan",
    'cg'  => "Kongo\ \[Republik\]",
    'ch'  => 'Suis',
    'ci'  => "Aod\ an\ Olifant",
    'ck'  => "Inizi\ Cook",
    'cl'  => 'Chile',
    'cm'  => 'Kameroun',
    'cn'  => 'Sina',
    'co'  => 'Kolombia',
    'cp'  => "Enez\ Clipperton",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ and\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Kab\ Glas",
    'cx'  => "Enez\ Christmas",
    'cy'  => 'Kiprenez',
    'cz'  => "Republik\ Tchek",
    'dd'  => "East\ Germany",
    'de'  => 'Alamagn',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Danmark',
    'dm'  => 'Dominica',
    'do'  => "Republik\ Dominikan",
    'dz'  => 'Aljeria',
    'ea'  => "Ceuta\ ha\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estonia',
    'eg'  => 'Egipt',
    'eh'  => "Sahara\ ar\ Cʼhornôg",
    'er'  => 'Eritrea',
    'es'  => 'Spagn',
    'et'  => 'Etiopia',
    'eu'  => "Unaniezh\ Europa",
    'fi'  => 'Finland',
    'fj'  => 'Fidji',
    'fk'  => "Inizi\ Falkland\ \[Inizi\ Maloù\]",
    'fm'  => 'Mikronezia',
    'fo'  => "Inizi\ Faero",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frañs',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => "Rouantelezh\-Unanet",
    'gd'  => 'Grenada',
    'ge'  => 'Jorjia',
    'gf'  => "Gwiana\ cʼhall",
    'gg'  => 'Gwernenez',
    'gh'  => 'Ghana',
    'gi'  => 'Jibraltar',
    'gl'  => 'Greunland',
    'gm'  => 'Gambia',
    'gn'  => 'Ginea',
    'gp'  => 'Gwadeloup',
    'gq'  => "Ginea\ ar\ Cʼheheder",
    'gr'  => 'Gres',
    'gs'  => "Inizi\ Georgia\ ar\ Su\ hag\ Inizi\ Sandwich\ ar\ Su",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Ginea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Inizi\ Heard\ ha\ McDonald",
    'hn'  => 'Honduras',
    'hr'  => 'Kroatia',
    'ht'  => 'Haiti',
    'hu'  => 'Hungaria',
    'ic'  => "Inizi\ Kanariez",
    'id'  => 'Indonezia',
    'ie'  => 'Iwerzhon',
    'il'  => 'Israel',
    'im'  => "Enez\ Vanav",
    'in'  => 'India',
    'io'  => "Tiriad\ breizhveurat\ Meurvor\ Indez",
    'iq'  => 'Iraq',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Italia',
    'je'  => 'Jerzenez',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordania',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kyrgyzstan',
    'kh'  => 'Kambodja',
    'ki'  => 'Kiribati',
    'km'  => 'Komorez',
    'kn'  => "Saint\ Kitts\ ha\ Nevis",
    'kp'  => "Korea\ an\ Norzh",
    'kr'  => "Korea\ ar\ Su",
    'kw'  => 'Koweit',
    'ky'  => "Inizi\ Cayman",
    'kz'  => 'Kazakstan',
    'la'  => 'Laos',
    'lb'  => 'Liban',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Lituania',
    'lu'  => 'Luksembourg',
    'lv'  => 'Latvia',
    'ly'  => 'Libia',
    'ma'  => 'Maroko',
    'mc'  => 'Monaco',
    'md'  => 'Moldova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Inizi\ Marshall",
    'mi'  => "Midway\ Islands",
    'mk'  => "Makedonia\ \[RYKM\]",
    'ml'  => 'Mali',
    'mm'  => "Myanmar\ \[Birmania\]",
    'mn'  => 'Mongolia',
    'mo'  => 'Macau',
    'mp'  => "Inizi\ Mariana\ an\ Norzh",
    'mq'  => 'Martinik',
    'mr'  => 'Maouritania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Moris',
    'mv'  => 'Maldivez',
    'mw'  => 'Malawi',
    'mx'  => 'Mecʼhiko',
    'my'  => 'Malaysia',
    'mz'  => 'Mozambik',
    'na'  => 'Namibia',
    'nc'  => "Kaledonia\ Nevez",
    'ne'  => 'Niger',
    'nf'  => "Enez\ Norfolk",
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Izelvroioù',
    'no'  => 'Norvegia',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Zeland\-Nevez",
    'om'  => 'Oman',
    'pa'  => 'Panamá',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Perou',
    'pf'  => "Polinezia\ cʼhall",
    'pg'  => "Papoua\ Ginea\-Nevez",
    'ph'  => 'Filipinez',
    'pk'  => 'Pakistan',
    'pl'  => 'Polonia',
    'pm'  => "Sant\-Pêr\-ha\-Mikelon",
    'pn'  => "Enez\ Pitcairn",
    'pr'  => "Puerto\ Rico",
    'ps'  => "Tiriadoù\ Palestina",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Oseania\ diabell",
    're'  => 'Reünion',
    'ro'  => 'Roumania',
    'rs'  => 'Serbia',
    'ru'  => 'Rusia',
    'rw'  => 'Rwanda',
    'sa'  => "Arabia\ Saoudat",
    'sb'  => 'Salomon',
    'sc'  => 'Sechelez',
    'sd'  => 'Soudan',
    'se'  => 'Sveden',
    'sg'  => 'Singapour',
    'sh'  => "Saint\ Helena",
    'si'  => 'Slovenia',
    'sj'  => 'Svalbard',
    'sk'  => 'Slovakia',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "São\ Tomé\ ha\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvador',
    'sy'  => 'Siria',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Inizi\ Turks\ ha\ Caicos",
    'td'  => 'Tchad',
    'tf'  => "Douaroù\ aostral\ Frañs",
    'tg'  => 'Togo',
    'th'  => 'Thailand',
    'tj'  => 'Tadjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ ar\ Reter",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunizia',
    'to'  => 'Tonga',
    'tr'  => 'Turkia',
    'tt'  => "Trinidad\ ha\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukraina',
    'ug'  => 'Ouganda',
    'um'  => "Inizi\ diabell\ ar\ Stadoù\-Unanet",
    'us'  => "Stadoù\-Unanet",
    'uy'  => 'Uruguay',
    'uz'  => 'Ouzbekistan',
    'va'  => 'Vatikan',
    'vc'  => "Sant\ Visant\ hag\ ar\ Grenadinez",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Inizi\ Gwercʼh\ Breizh\-Veur",
    'vi'  => "Inizi\ Gwercʼh\ ar\ Stadoù\-Unanet",
    'vn'  => "Viêt\ Nam",
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ ha\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemen',
    'yt'  => 'Mayotte',
    'za'  => 'Suafrika',
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Rannved\ dianav",
);

%Locales::DB::Territory::br::name_to_code = (
    'afghanistan'                               => 'af',
    'afrika'                                    => '002',
    'afrikaannorzh'                             => '015',
    'afrikaarcʼhornôg'                        => '011',
    'afrikaarcʼhreiz'                          => '017',
    'afrikaarreter'                             => '014',
    'afrikaarsu'                                => '018',
    'alamagn'                                   => 'de',
    'albania'                                   => 'al',
    'aljeria'                                   => 'dz',
    'amerikaannorzh'                            => '021',
    'amerikalatinhakarib'                       => 419,
    'amerikaoù'                                => '019',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarktika'                                => 'aq',
    'antiguahabarbuda'                          => 'ag',
    'antilheznederlandat'                       => 'an',
    'aodanolifant'                              => 'ci',
    'aostralia'                                 => 'au',
    'aostraliahazelandnevez'                    => '053',
    'aostria'                                   => 'at',
    'arabiasaoudat'                             => 'sa',
    'arcʼhantina'                              => 'ar',
    'armenia'                                   => 'am',
    'aruba'                                     => 'aw',
    'azerbaidjan'                               => 'az',
    'azia'                                      => 142,
    'aziaarcʼhornôg'                          => 145,
    'aziaarcʼhreiz'                            => 143,
    'aziaargevred'                              => '035',
    'aziaarreter'                               => '030',
    'aziaarsu'                                  => '034',
    'bahamas'                                   => 'bs',
    'bahrein'                                   => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'bed'                                       => '001',
    'belarus'                                   => 'by',
    'belgia'                                    => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhoutan'                                   => 'bt',
    'bolivia'                                   => 'bo',
    'bosniahaherzegovina'                       => 'ba',
    'botswana'                                  => 'bw',
    'brazil'                                    => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brunei'                                    => 'bn',
    'bulgaria'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'cantonandenderburyislands'                 => 'ct',
    'ceutahamelilla'                            => 'ea',
    'channelislands'                            => 830,
    'chile'                                     => 'cl',
    'commonwealthofindependentstates'           => 172,
    'costarica'                                 => 'cr',
    'czechoslovakia'                            => 200,
    'danmark'                                   => 'dk',
    'diegogarcia'                               => 'dg',
    'djibouti'                                  => 'dj',
    'dominica'                                  => 'dm',
    'douaroùaostralfrañs'                     => 'tf',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egipt'                                     => 'eg',
    'emirelezhioùarabunanet'                   => 'ae',
    'enezascension'                             => 'ac',
    'enezbouvet'                                => 'bv',
    'enezchristmas'                             => 'cx',
    'enezclipperton'                            => 'cp',
    'eneznorfolk'                               => 'nf',
    'enezpitcairn'                              => 'pn',
    'enezvanav'                                 => 'im',
    'eritrea'                                   => 'er',
    'estonia'                                   => 'ee',
    'etiopia'                                   => 'et',
    'europa'                                    => 150,
    'europaannorzh'                             => 154,
    'europaarcʼhornôg'                        => 155,
    'europaarreter'                             => 151,
    'europaarsu'                                => '039',
    'fidji'                                     => 'fj',
    'filipinez'                                 => 'ph',
    'finland'                                   => 'fi',
    'frañs'                                    => 'fr',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabon'                                     => 'ga',
    'gambia'                                    => 'gm',
    'ghana'                                     => 'gh',
    'ginea'                                     => 'gn',
    'gineaarcʼheheder'                         => 'gq',
    'gineabissau'                               => 'gw',
    'grenada'                                   => 'gd',
    'gres'                                      => 'gr',
    'greunland'                                 => 'gl',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guyana'                                    => 'gy',
    'gwadeloup'                                 => 'gp',
    'gwernenez'                                 => 'gg',
    'gwianacʼhall'                             => 'gf',
    'haiti'                                     => 'ht',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hungaria'                                  => 'hu',
    'india'                                     => 'in',
    'indonezia'                                 => 'id',
    'inizicayman'                               => 'ky',
    'inizicook'                                 => 'ck',
    'inizidiabellarstadoùunanet'               => 'um',
    'inizifaero'                                => 'fo',
    'inizifalklandinizimaloù'                  => 'fk',
    'inizigeorgiaarsuhaginizisandwicharsu'      => 'gs',
    'inizigwercʼharstadoùunanet'              => 'vi',
    'inizigwercʼhbreizhveur'                   => 'vg',
    'iniziheardhamcdonald'                      => 'hm',
    'inizikanariez'                             => 'ic',
    'inizikokoz'                                => 'cc',
    'inizimarianaannorzh'                       => 'mp',
    'inizimarshall'                             => 'mh',
    'iniziturkshacaicos'                        => 'tc',
    'iniziÅland'                               => 'ax',
    'iran'                                      => 'ir',
    'iraq'                                      => 'iq',
    'island'                                    => 'is',
    'israel'                                    => 'il',
    'italia'                                    => 'it',
    'iwerzhon'                                  => 'ie',
    'izelvroioù'                               => 'nl',
    'jamaika'                                   => 'jm',
    'japan'                                     => 'jp',
    'jerzenez'                                  => 'je',
    'jibraltar'                                 => 'gi',
    'johnstonisland'                            => 'jt',
    'jordania'                                  => 'jo',
    'jorjia'                                    => 'ge',
    'kabglas'                                   => 'cv',
    'kaledonianevez'                            => 'nc',
    'kambodja'                                  => 'kh',
    'kameroun'                                  => 'cm',
    'kanada'                                    => 'ca',
    'karib'                                     => '029',
    'kazakstan'                                 => 'kz',
    'kenya'                                     => 'ke',
    'kiprenez'                                  => 'cy',
    'kiribati'                                  => 'ki',
    'kolombia'                                  => 'co',
    'komorez'                                   => 'km',
    'kongordk'                                  => 'cd',
    'kongorepublik'                             => 'cg',
    'koreaannorzh'                              => 'kp',
    'koreaarsu'                                 => 'kr',
    'koweit'                                    => 'kw',
    'kreizamerika'                              => '013',
    'kroatia'                                   => 'hr',
    'kuba'                                      => 'cu',
    'kyrgyzstan'                                => 'kg',
    'laos'                                      => 'la',
    'latvia'                                    => 'lv',
    'lesotho'                                   => 'ls',
    'liban'                                     => 'lb',
    'liberia'                                   => 'lr',
    'libia'                                     => 'ly',
    'liechtenstein'                             => 'li',
    'lituania'                                  => 'lt',
    'luksembourg'                               => 'lu',
    'macau'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'makedoniarykm'                             => 'mk',
    'malawi'                                    => 'mw',
    'malaysia'                                  => 'my',
    'maldivez'                                  => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'maouritania'                               => 'mr',
    'maroko'                                    => 'ma',
    'martinik'                                  => 'mq',
    'mayotte'                                   => 'yt',
    'mecʼhiko'                                 => 'mx',
    'melanezia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'midwayislands'                             => 'mi',
    'mikronezia'                                => 'fm',
    'moldova'                                   => 'md',
    'monaco'                                    => 'mc',
    'mongolia'                                  => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'moris'                                     => 'mu',
    'mozambik'                                  => 'mz',
    'myanmarbirmania'                           => 'mm',
    'namibia'                                   => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'niger'                                     => 'ne',
    'nigeria'                                   => 'ng',
    'niue'                                      => 'nu',
    'northvietnam'                              => 'vd',
    'norvegia'                                  => 'no',
    'norzhamerika'                              => '003',
    'oman'                                      => 'om',
    'oseania'                                   => '009',
    'oseaniadiabell'                            => 'qo',
    'ouganda'                                   => 'ug',
    'ouzbekistan'                               => 'uz',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'panamacanalzone'                           => 'pz',
    'panamá'                                   => 'pa',
    'papouagineanevez'                          => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'perou'                                     => 'pe',
    'polinezia'                                 => '061',
    'polineziacʼhall'                          => 'pf',
    'polonia'                                   => 'pl',
    'portugal'                                  => 'pt',
    'puertorico'                                => 'pr',
    'qatar'                                     => 'qa',
    'rannveddianav'                             => 'zz',
    'rannvedmikronezia'                         => '057',
    'republikdominikan'                         => 'do',
    'republikkreizafrikan'                      => 'cf',
    'republiktchek'                             => 'cz',
    'reünion'                                  => 're',
    'rouantelezhunanet'                         => 'gb',
    'roumania'                                  => 'ro',
    'rusia'                                     => 'ru',
    'rwanda'                                    => 'rw',
    'saharaarcʼhornôg'                        => 'eh',
    'saintbarthélemy'                          => 'bl',
    'sainthelena'                               => 'sh',
    'saintkittshanevis'                         => 'kn',
    'saintlucia'                                => 'lc',
    'saintmartin'                               => 'mf',
    'salomon'                                   => 'sb',
    'salvador'                                  => 'sv',
    'samoa'                                     => 'ws',
    'samoaamerikan'                             => 'as',
    'sanmarino'                                 => 'sm',
    'santpêrhamikelon'                         => 'pm',
    'santvisanthagargrenadinez'                 => 'vc',
    'sechelez'                                  => 'sc',
    'senegal'                                   => 'sn',
    'serbia'                                    => 'rs',
    'serbiaandmontenegro'                       => 'cs',
    'sierraleone'                               => 'sl',
    'sina'                                      => 'cn',
    'singapour'                                 => 'sg',
    'siria'                                     => 'sy',
    'slovakia'                                  => 'sk',
    'slovenia'                                  => 'si',
    'somalia'                                   => 'so',
    'soudan'                                    => 'sd',
    'southcentralasia'                          => '062',
    'spagn'                                     => 'es',
    'srilanka'                                  => 'lk',
    'stadoùunanet'                             => 'us',
    'suafrika'                                  => 'za',
    'suamerika'                                 => '005',
    'suis'                                      => 'ch',
    'surinam'                                   => 'sr',
    'svalbard'                                  => 'sj',
    'sveden'                                    => 'se',
    'swaziland'                                 => 'sz',
    'sãotoméhapríncipe'                      => 'st',
    'tadjikistan'                               => 'tj',
    'taiwan'                                    => 'tw',
    'tanzania'                                  => 'tz',
    'tchad'                                     => 'td',
    'thailand'                                  => 'th',
    'timorarreter'                              => 'tl',
    'tiriadbreizhveuratmeurvorindez'            => 'io',
    'tiriadoùpalestina'                        => 'ps',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadhatobago'                          => 'tt',
    'tristandacunha'                            => 'ta',
    'tunizia'                                   => 'tn',
    'turkia'                                    => 'tr',
    'turkmenistan'                              => 'tm',
    'tuvalu'                                    => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ukraina'                                   => 'ua',
    'unaniezheuropa'                            => 'eu',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    'vanuatu'                                   => 'vu',
    'vatikan'                                   => 'va',
    'venezuela'                                 => 've',
    'viêtnam'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'wallishafutuna'                            => 'wf',
    'yemen'                                     => 'ye',
    'zambia'                                    => 'zm',
    'zelandnevez'                               => 'nz',
    'zimbabwe'                                  => 'zw',
);

1;

