package Locales::DB::Territory::so;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::so::VERSION = '0.09';

$Locales::DB::Territory::so::cldr_version = '2.0';

%Locales::DB::Territory::so::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Afrikada\ Bari",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Aasiyada\ Bari",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Yurubta\ Bari",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andora',
    'ae'  => "Imaaraadka\ Carabta\ ee\ Midoobay",
    'af'  => 'Afgaanistaan',
    'ag'  => "Antigua\ iyo\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albaaniya',
    'am'  => 'Armeeniya',
    'an'  => "Netherlands\ Antilles",
    'ao'  => 'Angoola',
    'aq'  => 'Antarctica',
    'ar'  => 'Arjantiin',
    'as'  => "Samowa\ Ameerika",
    'at'  => 'Awsteriya',
    'au'  => 'Awstaraaliya',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerbajaan',
    'ba'  => "Bosniya\ Hersigoviina",
    'bb'  => 'Baarbadoos',
    'bd'  => 'Bangaaladheesh',
    'be'  => 'Biljam',
    'bf'  => "Burkiina\ Faaso",
    'bg'  => 'Bulgaariya',
    'bh'  => 'Baxreyn',
    'bi'  => 'Burundi',
    'bj'  => 'Biniin',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermuuda',
    'bn'  => 'Buruneeya',
    'bo'  => 'Boliifiya',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Braasiil',
    'bs'  => 'Bahaamas',
    'bt'  => 'Bhutan',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botuswaana',
    'by'  => 'Belarus',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Jamhuuriyadda\ Dimuquraadiga\ Kongo",
    'cf'  => "Jamhuuriyadda\ Afrikada\ Dhexe",
    'cg'  => 'Kongo',
    'ch'  => 'Swiiserlaand',
    'ci'  => "Ivory\ coast",
    'ck'  => "Jaziiradda\ Cook",
    'cl'  => 'Jili',
    'cm'  => 'Kaameruun',
    'cn'  => 'Shiinaha',
    'co'  => 'Kolombiya',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kosta\ Riika",
    'cs'  => "serbiya\ iyo\ Monteneegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuuba',
    'cv'  => "Cape\ Verde\ Islands",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Qubrus',
    'cz'  => "Jamhuuriyadda\ Jek",
    'dd'  => "East\ Germany",
    'de'  => 'Jarmal',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jabuuti',
    'dk'  => 'Denmark',
    'dm'  => 'Domeenika',
    'do'  => "Jamhuuriyadda\ Domeenika",
    'dz'  => 'Aljeeriya',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ikuwadoor',
    'ee'  => 'Estooniya',
    'eg'  => 'Masar',
    'eh'  => "Western\ Sahara",
    'er'  => 'Eretereeya',
    'es'  => 'Isbeyn',
    'et'  => 'Itoobiya',
    'eu'  => "European\ Union",
    'fi'  => 'Finland',
    'fj'  => 'Fiji',
    'fk'  => "Jaziiradaha\ Fooklaan",
    'fm'  => 'Micronesia',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Faransiis',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gaaboon',
    'gb'  => "United\ Kingdom",
    'gd'  => 'Giriinaada',
    'ge'  => 'Joorjiya',
    'gf'  => "French\ Guiana",
    'gg'  => 'Guernsey',
    'gh'  => 'Gaana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Greenland',
    'gm'  => 'Gambiya',
    'gn'  => 'Gini',
    'gp'  => 'Guadeloupe',
    'gq'  => "Equatorial\ Guinea",
    'gr'  => 'Giriig',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Guwaatamaala',
    'gu'  => 'Guam',
    'gw'  => "Gini\-Bisaaw",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Honduras',
    'hr'  => 'Korweeshiya',
    'ht'  => 'Hayti',
    'hu'  => 'Hangeri',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indoneesiya',
    'ie'  => 'Ayrlaand',
    'il'  => 'Israaʼiil',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Hindiya',
    'io'  => "British\ Indian\ Ocean\ Territory",
    'iq'  => 'Ciraaq',
    'ir'  => 'Iiraan',
    'is'  => 'Iislaand',
    'it'  => 'Talyaani',
    'je'  => 'Jersey',
    'jm'  => 'Jameyka',
    'jo'  => 'Urdun',
    'jp'  => 'Jabaan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kiiniya',
    'kg'  => 'Kirgistaan',
    'kh'  => 'Kamboodiya',
    'ki'  => 'Kiribati',
    'km'  => 'Komooros',
    'kn'  => "Saint\ Kitts\ and\ Nevis",
    'kp'  => "Kuuriyada\ Waqooyi",
    'kr'  => "Kuuriyada\ Koonfureed",
    'kw'  => 'Kuwayt',
    'ky'  => "Cayman\ Islands",
    'kz'  => 'Kasaakhistaan',
    'la'  => 'Laos',
    'lb'  => 'Lubnaan',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => 'Sirilaanka',
    'lr'  => 'Laybeeriya',
    'ls'  => 'Losooto',
    'lt'  => 'Lituweeniya',
    'lu'  => 'Luksemboorg',
    'lv'  => 'Latfiya',
    'ly'  => 'Liibiya',
    'ma'  => 'Marooko',
    'mc'  => 'Moonako',
    'md'  => 'Moldofa',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Marshall\ Islands",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Makadooniya',
    'ml'  => 'Maali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongooliya',
    'mo'  => 'Macau',
    'mp'  => "Northern\ Mariana\ Islands",
    'mq'  => 'Martinique',
    'mr'  => 'Muritaaniya',
    'ms'  => 'Montserrat',
    'mt'  => 'Maalda',
    'mu'  => 'Murishiyoos',
    'mv'  => 'Maaldiqeen',
    'mw'  => 'Malaawi',
    'mx'  => 'Meksiko',
    'my'  => 'Malaysia',
    'mz'  => 'Musambiig',
    'na'  => 'Namiibiya',
    'nc'  => "New\ Caledonia",
    'ne'  => 'Nayjer',
    'nf'  => "Norfolk\ Island",
    'ng'  => 'Nayjeeriya',
    'ni'  => 'Nikaraaguwa',
    'nl'  => 'Netherlands',
    'no'  => 'Noorweey',
    'np'  => 'Nebaal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => 'Neyuusilaand',
    'om'  => 'Cumaan',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "French\ Polynesia",
    'pg'  => "Papua\ New\ Guinea",
    'ph'  => 'Filibiin',
    'pk'  => 'Bakistaan',
    'pl'  => 'Booland',
    'pm'  => "Saint\ Pierre\ and\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Falastiin\ Daanka\ galbeed\ iyo\ Qasa",
    'pt'  => 'Bortuqaal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qadar',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Réunion',
    'ro'  => 'Rumaaniya',
    'rs'  => 'Serbia',
    'ru'  => 'Ruush',
    'rw'  => 'Ruwanda',
    'sa'  => "Sacuudi\ Carabiya",
    'sb'  => "Solomon\ Islands",
    'sc'  => 'Sishelis',
    'sd'  => 'Suudaan',
    'se'  => 'Iswidhan',
    'sg'  => 'Singaboor',
    'sh'  => "Saint\ Helena",
    'si'  => 'Slovenia',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slovakia',
    'sl'  => 'Siraaliyoon',
    'sm'  => "San\ Marino",
    'sn'  => 'Sinigaal',
    'so'  => 'Soomaaliya',
    'sr'  => 'Suriname',
    'st'  => "São\ Tomé\ and\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Suuriya',
    'sz'  => 'Iswaasilaand',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ and\ Caicos\ Islands",
    'td'  => 'Jaad',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Toogo',
    'th'  => 'Taylaand',
    'tj'  => 'Tajikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timorka\ bari",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tuniisiya',
    'to'  => 'Tonga',
    'tr'  => 'Turki',
    'tt'  => "Trinidad\ and\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taywaan',
    'tz'  => 'Tansaaniya',
    'ua'  => 'Ukrayn',
    'ug'  => 'Ugaanda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Maraykanka',
    'uy'  => 'Uruguwaay',
    'uz'  => 'Uusbakistaan',
    'va'  => 'Faatikaan',
    'vc'  => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => 'Fenisuweela',
    'vg'  => "British\ Virgin\ Islands",
    'vi'  => "U\.S\.\ Virgin\ Islands",
    'vn'  => 'Fiyetnaam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ and\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yaman',
    'yt'  => 'Mayotte',
    'za'  => "Koonfur\ Afrika",
    'zm'  => 'Saambiya',
    'zw'  => 'Simbaabwe',
    'zz'  => "Far\ aan\ la\ aqoon\ amase\ aan\ saxnayn",
);

%Locales::DB::Territory::so::name_to_code = (
    'aasiyadabari'                              => '030',
    'afgaanistaan'                              => 'af',
    'africa'                                    => '002',
    'afrikadabari'                              => '014',
    'albaaniya'                                 => 'al',
    'aljeeriya'                                 => 'dz',
    'americas'                                  => '019',
    'andora'                                    => 'ad',
    'angoola'                                   => 'ao',
    'anguilla'                                  => 'ai',
    'antarctica'                                => 'aq',
    'antiguaiyobarbuda'                         => 'ag',
    'arjantiin'                                 => 'ar',
    'armeeniya'                                 => 'am',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'awstaraaliya'                              => 'au',
    'awsteriya'                                 => 'at',
    'ayrlaand'                                  => 'ie',
    'azerbajaan'                                => 'az',
    'baarbadoos'                                => 'bb',
    'bahaamas'                                  => 'bs',
    'bakistaan'                                 => 'pk',
    'bangaaladheesh'                            => 'bd',
    'baxreyn'                                   => 'bh',
    'belarus'                                   => 'by',
    'belize'                                    => 'bz',
    'bermuuda'                                  => 'bm',
    'bhutan'                                    => 'bt',
    'biljam'                                    => 'be',
    'biniin'                                    => 'bj',
    'boliifiya'                                 => 'bo',
    'booland'                                   => 'pl',
    'bortuqaal'                                 => 'pt',
    'bosniyahersigoviina'                       => 'ba',
    'botuswaana'                                => 'bw',
    'bouvetisland'                              => 'bv',
    'braasiil'                                  => 'br',
    'britishantarcticterritory'                 => 'bq',
    'britishindianoceanterritory'               => 'io',
    'britishvirginislands'                      => 'vg',
    'bulgaariya'                                => 'bg',
    'burkiinafaaso'                             => 'bf',
    'burundi'                                   => 'bi',
    'buruneeya'                                 => 'bn',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'capeverdeislands'                          => 'cv',
    'caribbean'                                 => '029',
    'caymanislands'                             => 'ky',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'ciraaq'                                    => 'iq',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'cumaan'                                    => 'om',
    'czechoslovakia'                            => 200,
    'denmark'                                   => 'dk',
    'diegogarcia'                               => 'dg',
    'domeenika'                                 => 'dm',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'elsalvador'                                => 'sv',
    'equatorialguinea'                          => 'gq',
    'eretereeya'                                => 'er',
    'estooniya'                                 => 'ee',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faatikaan'                                 => 'va',
    'falastiindaankagalbeediyoqasa'             => 'ps',
    'faraanlaaqoonamaseaansaxnayn'              => 'zz',
    'faransiis'                                 => 'fr',
    'faroeislands'                              => 'fo',
    'fenisuweela'                               => 've',
    'fiji'                                      => 'fj',
    'filibiin'                                  => 'ph',
    'finland'                                   => 'fi',
    'fiyetnaam'                                 => 'vn',
    'frenchguiana'                              => 'gf',
    'frenchpolynesia'                           => 'pf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gaaboon'                                   => 'ga',
    'gaana'                                     => 'gh',
    'gambiya'                                   => 'gm',
    'gibraltar'                                 => 'gi',
    'gini'                                      => 'gn',
    'ginibisaaw'                                => 'gw',
    'giriig'                                    => 'gr',
    'giriinaada'                                => 'gd',
    'greenland'                                 => 'gl',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guernsey'                                  => 'gg',
    'guwaatamaala'                              => 'gt',
    'guyana'                                    => 'gy',
    'hangeri'                                   => 'hu',
    'hayti'                                     => 'ht',
    'heardislandandmcdonaldislands'             => 'hm',
    'hindiya'                                   => 'in',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'iiraan'                                    => 'ir',
    'iislaand'                                  => 'is',
    'ikuwadoor'                                 => 'ec',
    'imaaraadkacarabtaeemidoobay'               => 'ae',
    'indoneesiya'                               => 'id',
    'isbeyn'                                    => 'es',
    'isleofman'                                 => 'im',
    'israaʼiil'                                => 'il',
    'iswaasilaand'                              => 'sz',
    'iswidhan'                                  => 'se',
    'itoobiya'                                  => 'et',
    'ivorycoast'                                => 'ci',
    'jaad'                                      => 'td',
    'jabaan'                                    => 'jp',
    'jabuuti'                                   => 'dj',
    'jameyka'                                   => 'jm',
    'jamhuuriyaddaafrikadadhexe'                => 'cf',
    'jamhuuriyaddadimuquraadigakongo'           => 'cd',
    'jamhuuriyaddadomeenika'                    => 'do',
    'jamhuuriyaddajek'                          => 'cz',
    'jarmal'                                    => 'de',
    'jaziiradahafooklaan'                       => 'fk',
    'jaziiraddacook'                            => 'ck',
    'jersey'                                    => 'je',
    'jili'                                      => 'cl',
    'johnstonisland'                            => 'jt',
    'joorjiya'                                  => 'ge',
    'kaameruun'                                 => 'cm',
    'kamboodiya'                                => 'kh',
    'kanada'                                    => 'ca',
    'kasaakhistaan'                             => 'kz',
    'kiiniya'                                   => 'ke',
    'kirgistaan'                                => 'kg',
    'kiribati'                                  => 'ki',
    'kolombiya'                                 => 'co',
    'komooros'                                  => 'km',
    'kongo'                                     => 'cg',
    'koonfurafrika'                             => 'za',
    'korweeshiya'                               => 'hr',
    'kostariika'                                => 'cr',
    'kuuba'                                     => 'cu',
    'kuuriyadakoonfureed'                       => 'kr',
    'kuuriyadawaqooyi'                          => 'kp',
    'kuwayt'                                    => 'kw',
    'laos'                                      => 'la',
    'latfiya'                                   => 'lv',
    'latinamerica'                              => 419,
    'laybeeriya'                                => 'lr',
    'liechtenstein'                             => 'li',
    'liibiya'                                   => 'ly',
    'lituweeniya'                               => 'lt',
    'losooto'                                   => 'ls',
    'lubnaan'                                   => 'lb',
    'luksemboorg'                               => 'lu',
    'maalda'                                    => 'mt',
    'maaldiqeen'                                => 'mv',
    'maali'                                     => 'ml',
    'macau'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'makadooniya'                               => 'mk',
    'malaawi'                                   => 'mw',
    'malaysia'                                  => 'my',
    'maraykanka'                                => 'us',
    'marooko'                                   => 'ma',
    'marshallislands'                           => 'mh',
    'martinique'                                => 'mq',
    'masar'                                     => 'eg',
    'mayotte'                                   => 'yt',
    'meksiko'                                   => 'mx',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesia'                                => 'fm',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'moldofa'                                   => 'md',
    'mongooliya'                                => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'moonako'                                   => 'mc',
    'murishiyoos'                               => 'mu',
    'muritaaniya'                               => 'mr',
    'musambiig'                                 => 'mz',
    'myanmar'                                   => 'mm',
    'namiibiya'                                 => 'na',
    'nauru'                                     => 'nr',
    'nayjeeriya'                                => 'ng',
    'nayjer'                                    => 'ne',
    'nebaal'                                    => 'np',
    'netherlands'                               => 'nl',
    'netherlandsantilles'                       => 'an',
    'neutralzone'                               => 'nt',
    'newcaledonia'                              => 'nc',
    'neyuusilaand'                              => 'nz',
    'nikaraaguwa'                               => 'ni',
    'niue'                                      => 'nu',
    'noorweey'                                  => 'no',
    'norfolkisland'                             => 'nf',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northernmarianaislands'                    => 'mp',
    'northvietnam'                              => 'vd',
    'oceania'                                   => '009',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'palau'                                     => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanewguinea'                            => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'polynesia'                                 => '061',
    'puertorico'                                => 'pr',
    'qadar'                                     => 'qa',
    'qubrus'                                    => 'cy',
    'rumaaniya'                                 => 'ro',
    'ruush'                                     => 'ru',
    'ruwanda'                                   => 'rw',
    'réunion'                                  => 're',
    'saambiya'                                  => 'zm',
    'sacuudicarabiya'                           => 'sa',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'sainthelena'                               => 'sh',
    'saintkittsandnevis'                        => 'kn',
    'saintlucia'                                => 'lc',
    'saintmartin'                               => 'mf',
    'saintpierreandmiquelon'                    => 'pm',
    'saintvincentandthegrenadines'              => 'vc',
    'samoa'                                     => 'ws',
    'samowaameerika'                            => 'as',
    'sanmarino'                                 => 'sm',
    'serbia'                                    => 'rs',
    'serbiyaiyomonteneegro'                     => 'cs',
    'shiinaha'                                  => 'cn',
    'simbaabwe'                                 => 'zw',
    'singaboor'                                 => 'sg',
    'sinigaal'                                  => 'sn',
    'siraaliyoon'                               => 'sl',
    'sirilaanka'                                => 'lk',
    'sishelis'                                  => 'sc',
    'slovakia'                                  => 'sk',
    'slovenia'                                  => 'si',
    'solomonislands'                            => 'sb',
    'soomaaliya'                                => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'suriname'                                  => 'sr',
    'suudaan'                                   => 'sd',
    'suuriya'                                   => 'sy',
    'svalbardandjanmayen'                       => 'sj',
    'swiiserlaand'                              => 'ch',
    'sãotoméandpríncipe'                     => 'st',
    'tajikistan'                                => 'tj',
    'talyaani'                                  => 'it',
    'tansaaniya'                                => 'tz',
    'taylaand'                                  => 'th',
    'taywaan'                                   => 'tw',
    'timorkabari'                               => 'tl',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'toogo'                                     => 'tg',
    'trinidadandtobago'                         => 'tt',
    'tristandacunha'                            => 'ta',
    'tuniisiya'                                 => 'tn',
    'turki'                                     => 'tr',
    'turkmenistan'                              => 'tm',
    'turksandcaicosislands'                     => 'tc',
    'tuvalu'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    "u\.s\.virginislands"                       => 'vi',
    'ugaanda'                                   => 'ug',
    'ukrayn'                                    => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unitedkingdom'                             => 'gb',
    'urdun'                                     => 'jo',
    'uruguwaay'                                 => 'uy',
    'uusbakistaan'                              => 'uz',
    'vanuatu'                                   => 'vu',
    'wakeisland'                                => 'wk',
    'wallisandfutuna'                           => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yaman'                                     => 'ye',
    'yurubtabari'                               => 151,
    "\Ã\landislands"                         => 'ax',
);

1;

