{"delimiters":{"quotation_start":"„","quotation_end":"“","alternate_quotation_start":"‚","alternate_quotation_end":"‘"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":{"draft":"unconfirmed","content":"nä:nää:näh:n"},"yesstr":{"draft":"unconfirmed","content":"jo:joh:joo:j"}},"plural_forms":{"category_list":["one","zero","other"],"category_rules_function":null,"category_rules":{"one":"n is 1","zero":"n is 0"},"category_rules_compiled":{"one":function (n) {if ( (( n == 1))) { return 'one'; } return;},"zero":function (n) {if ( (( n == 0))) { return 'zero'; } return;}}},"cldr_formats":{"territory":"de Jääjend afjekööz met „{0}“","_decimal_format_decimal":",","language":"de Schprooch afjekööz met „{0}“","percent":"#,##0 %","locale":"{0} en {1}","_decimal_format_group":" ","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} un {1}","start":"{0}, {1}","end":"{0} un {1}"}},"fallback":["de_de","nl","nds","en"],"characters":{"more_information":"?"}}