package Locales::DB::Territory::bas;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::bas::VERSION = '0.09';

$Locales::DB::Territory::bas::cldr_version = '2.0';

%Locales::DB::Territory::bas::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Àŋdɔ̂r',
    'ae'  => "Àdnà\ i\ Bilɔ̀ŋ\ bi\ Arābìà",
    'af'  => 'Àfgànìstâŋ',
    'ag'  => "Àŋtigà\ ɓɔ\ Bàrbudà",
    'ai'  => 'Àŋgiyà',
    'al'  => 'Àlbanìà',
    'am'  => 'Àrmenìà',
    'an'  => "Àŋtîy\ ǹlɛ̀ndi",
    'ao'  => 'Àŋgolà',
    'aq'  => 'Antarctica',
    'ar'  => 'Àrgàŋtinà',
    'as'  => "American\ Samoa",
    'at'  => 'Òstrǐk',
    'au'  => 'Òstralìà',
    'aw'  => 'Àrubà',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Àzɛ̀rbajàŋ',
    'ba'  => "Bòhnià\ Ɛrzègòvinà",
    'bb'  => 'Bàrbadò',
    'bd'  => 'Bàŋglàdɛ̂s',
    'be'  => 'Bɛlgyùm',
    'bf'  => "Bùrkìnà\ Fasò",
    'bg'  => 'Bùlgarìà',
    'bh'  => 'Bàraìn',
    'bi'  => 'Bùrundì',
    'bj'  => 'Bènɛ̂ŋ',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bɛ̀rmudà',
    'bn'  => 'Brunei',
    'bo'  => 'Bòlivìà',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Bràsîl',
    'bs'  => 'Bàhamàs',
    'bt'  => 'Bùtân',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Bòdsùanà',
    'by'  => 'Bèlarùs',
    'bz'  => 'Bèlîs',
    'ca'  => 'Kànadà',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Kòŋgo\ ìkɛŋi",
    'cf'  => "Ŋ̀ɛm\ Afrīkà",
    'cg'  => 'Kòŋgo',
    'ch'  => 'Sùwîs',
    'ci'  => "Màŋ\ mi\ Njɔ̂k",
    'ck'  => "Bìòn\ bi\ Kook",
    'cl'  => 'Kìlî',
    'cm'  => 'Kàmɛ̀rûn',
    'cn'  => 'Kinà',
    'co'  => 'Kɔ̀lɔmbìà',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kòstà\ Rikà",
    'cs'  => "Sɛ̀rbî\ nì\ Mɔ̀ntènegrò",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kubà',
    'cv'  => 'Kabwɛ᷆r',
    'cx'  => "Christmas\ Island",
    'cy'  => 'Kiprò',
    'cz'  => "Czech\ Republic",
    'dd'  => "East\ Germany",
    'de'  => 'Jamân',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jìbutì',
    'dk'  => 'Dànmârk',
    'dm'  => 'Dòmnîk',
    'do'  => 'Dòmnikà',
    'dz'  => 'Àlgerìà',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Èkwàtorìà',
    'ee'  => 'Èstonìà',
    'eg'  => 'Ègîptò',
    'eh'  => "Western\ Sahara",
    'er'  => 'Èrìtrěà',
    'es'  => 'Pànya',
    'et'  => 'Ètìopìà',
    'eu'  => "European\ Union",
    'fi'  => 'Fìnlând',
    'fj'  => 'Fiji',
    'fk'  => "Bìòn\ bi\ Falkland",
    'fm'  => 'Mìkrònesìà',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => "Pùlàsi\ \/\ Fɛ̀lɛ̀nsi\ \/",
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gàbɔ̂ŋ',
    'gb'  => "Àdnà\ i\ Lɔ̂ŋ",
    'gd'  => 'Grènadà',
    'ge'  => 'Gèɔrgìà',
    'gf'  => "Gùyanà\ Pùlàsi",
    'gg'  => 'Guernsey',
    'gh'  => 'Ganà',
    'gi'  => 'Gìlbràtâr',
    'gl'  => 'Grǐnlànd',
    'gm'  => 'Gàmbià',
    'gn'  => 'Gìnê',
    'gp'  => 'Gwàdèlûp',
    'gq'  => "Gìne\ Èkwàtorìà",
    'gr'  => 'Grǐkyà',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwàtèmalà',
    'gu'  => 'Gùâm',
    'gw'  => "Gìne\ Bìsàô",
    'gy'  => 'Gùyanà',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Ɔ̀ŋduràs',
    'hr'  => 'Kròasìà',
    'ht'  => 'Àitì',
    'hu'  => 'Ɔ̀ŋgriì',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indònèsià',
    'ie'  => 'Ìrlând',
    'il'  => 'Isràɛ̂l',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Indìà',
    'io'  => "Bìtèk\ bi\ Ŋgisì\ i\ Tūyɛ\ Īndìà",
    'iq'  => 'Ìrâk',
    'ir'  => 'Ìrâŋ',
    'is'  => 'Ìslandìà',
    'it'  => 'Ìtalìà',
    'je'  => 'Jersey',
    'jm'  => 'Jàmàikà',
    'jo'  => 'Yɔ̀rdanià',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenìà',
    'kg'  => 'Kìrgìzìstàŋ',
    'kh'  => 'Kàmbodìà',
    'ki'  => 'Kìrìbatì',
    'km'  => 'Kɔ̀mɔ̂r',
    'kn'  => "Nûmpubi\ Kîts\ nì\ Nevìs",
    'kp'  => "Kɔ̀re\ ì\ Ŋ̀ɔmbɔk",
    'kr'  => "Kɔ̀re\ ì\ Ŋ̀wɛ̀lmbɔk",
    'kw'  => 'Kòwêt',
    'ky'  => "Bìòn\ bi\ Kaymàn",
    'kz'  => 'Kàzàkstâŋ',
    'la'  => 'Làôs',
    'lb'  => 'Lèbanòn',
    'lc'  => "Nûmpubi\ Lusì",
    'li'  => 'Ligstɛntàn',
    'lk'  => 'Srìlaŋkà',
    'lr'  => 'Lìberìà',
    'ls'  => 'Lesòtò',
    'lt'  => 'Lìtùanìà',
    'lu'  => 'Lùgsàmbûr',
    'lv'  => 'Làdvià',
    'ly'  => 'Libìà',
    'ma'  => 'Màrokò',
    'mc'  => 'Mònakò',
    'md'  => 'Moldavìà',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Màdàgàskâr',
    'mh'  => "Bìòn\ bi\ Marcàl",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Màsèdonìà',
    'ml'  => 'Màli',
    'mm'  => 'Myànmâr',
    'mn'  => 'Mòŋgolìà',
    'mo'  => 'Macau',
    'mp'  => "Bìòn\ bi\ Marìanà\ ŋ̀ɔmbɔk",
    'mq'  => 'Màrtìnîk',
    'mr'  => 'Mòrìtanìà',
    'ms'  => 'Mɔ̀ŋseràt',
    'mt'  => 'Maltà',
    'mu'  => 'Mòrîs',
    'mv'  => 'Màldîf',
    'mw'  => 'Màlàwi',
    'mx'  => 'Mɛ̀gsîk',
    'my'  => 'Màlɛ̀sìà',
    'mz'  => 'Mòsàmbîk',
    'na'  => 'Nàmibìà',
    'nc'  => "Kàlèdonìà\ Yɔ̀ndɔ",
    'ne'  => 'Nìjɛ̂r',
    'nf'  => "Òn\ i\ Nɔrfɔ̂k",
    'ng'  => 'Nìgerìà',
    'ni'  => 'Nìkàragwà',
    'nl'  => 'Ǹlɛndi',
    'no'  => 'Nɔ̀rvegìà',
    'np'  => 'Nèpâl',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nerù',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Nìuɛ̀',
    'nz'  => "Sìlând\ Yɔ̀ndɔ",
    'om'  => 'Òmân',
    'pa'  => 'Pànàma',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Pèrû',
    'pf'  => "Pòlìnesìà\ Pùlàsi",
    'pg'  => "Gìne\ ì\ Pàpu",
    'ph'  => 'Fìlìpîn',
    'pk'  => 'Pàkìstân',
    'pl'  => 'Pòlànd',
    'pm'  => "Nûmpubi\ Petrò\ nì\ Mikèlôn",
    'pn'  => 'Pìdkaìrn',
    'pr'  => "Pɔ̀rtò\ Rikò",
    'ps'  => "Pàlɛ̀htinà\ Hyɔ̀ŋg\ nì\ Gazà",
    'pt'  => 'Pɔ̀tɔkì',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Pàlaù',
    'py'  => 'Pàràgwê',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Kàtâr',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Rèunyɔ̂ŋ',
    'ro'  => 'Rùmanìà',
    'rs'  => 'Serbia',
    'ru'  => 'Ruslànd',
    'rw'  => 'Rùandà',
    'sa'  => "Sàudi\ Àrabìà",
    'sb'  => "Bìòn\ bi\ Salōmò",
    'sc'  => 'Sèsɛ̂l',
    'sd'  => 'Sùdâŋ',
    'se'  => 'Swedɛ̀n',
    'sg'  => 'Sìŋgàpûr',
    'sh'  => "Nûmpubi\ Ɛlēnà",
    'si'  => 'Slòvanìà',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slòvakìà',
    'sl'  => "Sièra\ Lèɔ̂n",
    'sm'  => "Nûmpubi\ Māatìn",
    'sn'  => 'Sènègâl',
    'so'  => 'Sòmalìà',
    'sr'  => 'Sùrinâm',
    'st'  => "Sào\ Tòme\ ɓɔ\ Prɛ̀ŋcipè",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Sàlvàdɔ̂r',
    'sy'  => 'Sirìà',
    'sz'  => 'Swàzìlând',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Bìòn\ bi\ Tûrks\ nì\ Kalkòs",
    'td'  => 'Câd',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Tògo',
    'th'  => 'Taylànd',
    'tj'  => 'Tàjìkìstaŋ',
    'tk'  => 'Tòkèlaò',
    'tl'  => "Tìmɔ̂r\ lìkòl",
    'tm'  => 'Tùrgmènìstân',
    'tn'  => 'Tùnisìà',
    'to'  => 'Tɔŋgà',
    'tr'  => 'Tùrkây',
    'tt'  => "Trìnidàd\ ɓɔ\ Tòbagò",
    'tv'  => 'Tùvàlù',
    'tw'  => 'Tàywân',
    'tz'  => 'Tànzànià',
    'ua'  => 'Ùkrɛ̌n',
    'ug'  => 'Ùgandà',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Àdnà\ i\ Bilɔ̀ŋ\ bi\ Amerkà",
    'uy'  => 'Ùrùgwêy',
    'uz'  => 'Ùzbèkìstân',
    'va'  => 'Vàtìkâŋ',
    'vc'  => "Nûmpubi\ Vɛ̂ŋsâŋ\ nì\ grènàdîn",
    'vd'  => "North\ Vietnam",
    've'  => 'Vènèzùelà',
    'vg'  => "Bìòn\ bi\ kɔnji\ bi\ Ŋgisì",
    'vi'  => "Bìòn\ bi\ kɔnji\ bi\ U\.S\.",
    'vn'  => 'Vìɛ̀dnâm',
    'vu'  => 'Vànùatù',
    'wf'  => "Wàlîs\ nì\ Fùtunà",
    'wk'  => "Wake\ Island",
    'ws'  => 'Sàmoà',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yèmɛ̂n',
    'yt'  => 'Màyɔ̂t',
    'za'  => "Àfrǐkà\ Sɔ̀",
    'zm'  => 'Zàmbià',
    'zw'  => 'Zìmbàbwê',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::bas::name_to_code = (
    'africa'                                    => '002',
    'americansamoa'                             => 'as',
    'americas'                                  => '019',
    'antarctica'                                => 'aq',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'bouvetisland'                              => 'bv',
    'britishantarcticterritory'                 => 'bq',
    'brunei'                                    => 'bn',
    'bràsîl'                                  => 'br',
    'bàhamàs'                                 => 'bs',
    'bàraìn'                                  => 'bh',
    'bàrbadò'                                 => 'bb',
    'bàŋglàdɛ̂s'                           => 'bd',
    'bèlarùs'                                 => 'by',
    'bèlîs'                                   => 'bz',
    'bènɛ̂ŋ'                                => 'bj',
    'bìtèkbiŊgisìitūyɛĪndìà'           => 'io',
    'bìònbifalkland'                          => 'fk',
    'bìònbikaymàn'                           => 'ky',
    'bìònbikook'                              => 'ck',
    "bìònbikɔnjibiu\.s\."                    => 'vi',
    'bìònbikɔnjibiŊgisì'                   => 'vg',
    'bìònbimarcàl'                           => 'mh',
    'bìònbimarìanàŋ̀ɔmbɔk'              => 'mp',
    'bìònbisalōmò'                          => 'sb',
    'bìònbitûrksnìkalkòs'                  => 'tc',
    'bòdsùanà'                               => 'bw',
    'bòhniàƐrzègòvinà'                    => 'ba',
    'bòlivìà'                                => 'bo',
    'bùlgarìà'                               => 'bg',
    'bùrkìnàfasò'                           => 'bf',
    'bùrundì'                                 => 'bi',
    'bùtân'                                   => 'bt',
    'bɛlgyùm'                                 => 'be',
    'bɛ̀rmudà'                               => 'bm',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'czechrepublic'                             => 'cz',
    'câd'                                      => 'td',
    'diegogarcia'                               => 'dg',
    'dronningmaudland'                          => 'nq',
    'dànmârk'                                 => 'dk',
    'dòmnikà'                                 => 'do',
    'dòmnîk'                                  => 'dm',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'fiji'                                      => 'fj',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'fìlìpîn'                                => 'ph',
    'fìnlând'                                 => 'fi',
    'ganà'                                     => 'gh',
    'grènadà'                                 => 'gd',
    'grǐkyà'                                  => 'gr',
    'grǐnlànd'                                => 'gl',
    'guernsey'                                  => 'gg',
    'gwàdèlûp'                               => 'gp',
    'gwàtèmalà'                              => 'gt',
    'gàbɔ̂ŋ'                                => 'ga',
    'gàmbià'                                  => 'gm',
    'gèɔrgìà'                               => 'ge',
    'gìlbràtâr'                              => 'gi',
    'gìnebìsàô'                             => 'gw',
    'gìneÈkwàtorìà'                        => 'gq',
    'gìneìpàpu'                              => 'pg',
    'gìnê'                                    => 'gn',
    'gùyanà'                                  => 'gy',
    'gùyanàpùlàsi'                          => 'gf',
    'gùâm'                                    => 'gu',
    'heardislandandmcdonaldislands'             => 'hm',
    'hongkong'                                  => 'hk',
    'indìà'                                   => 'in',
    'indònèsià'                              => 'id',
    'isleofman'                                 => 'im',
    'isràɛ̂l'                                => 'il',
    'jamân'                                    => 'de',
    'japan'                                     => 'jp',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jàmàikà'                                => 'jm',
    'jìbutì'                                  => 'dj',
    'kabwɛ᷆r'                                => 'cv',
    'kenìà'                                   => 'ke',
    'kinà'                                     => 'cn',
    'kiprò'                                    => 'cy',
    'kròasìà'                                => 'hr',
    'kubà'                                     => 'cu',
    'kàlèdonìàyɔ̀ndɔ'                    => 'nc',
    'kàmbodìà'                               => 'kh',
    'kàmɛ̀rûn'                              => 'cm',
    'kànadà'                                  => 'ca',
    'kàtâr'                                   => 'qa',
    'kàzàkstâŋ'                             => 'kz',
    'kìlî'                                    => 'cl',
    'kìrgìzìstàŋ'                          => 'kg',
    'kìrìbatì'                               => 'ki',
    'kòstàrikà'                              => 'cr',
    'kòwêt'                                   => 'kw',
    'kòŋgo'                                   => 'cg',
    'kòŋgoìkɛŋi'                           => 'cd',
    'kɔ̀lɔmbìà'                            => 'co',
    'kɔ̀mɔ̂r'                               => 'km',
    'kɔ̀reìŊ̀wɛ̀lmbɔk'                  => 'kr',
    'kɔ̀reìŊ̀ɔmbɔk'                      => 'kp',
    'latinamerica'                              => 419,
    'lesòtò'                                  => 'ls',
    'libìà'                                   => 'ly',
    'ligstɛntàn'                              => 'li',
    'làdvià'                                  => 'lv',
    'làôs'                                    => 'la',
    'lèbanòn'                                 => 'lb',
    'lìberìà'                                => 'lr',
    'lìtùanìà'                              => 'lt',
    'lùgsàmbûr'                              => 'lu',
    'macau'                                     => 'mo',
    'maltà'                                    => 'mt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'moldavìà'                                => 'md',
    'montenegro'                                => 'me',
    'myànmâr'                                 => 'mm',
    'màdàgàskâr'                            => 'mg',
    'màldîf'                                  => 'mv',
    'màli'                                     => 'ml',
    'màlàwi'                                  => 'mw',
    'màlɛ̀sìà'                             => 'my',
    'màrokò'                                  => 'ma',
    'màrtìnîk'                               => 'mq',
    'màsèdonìà'                             => 'mk',
    'màyɔ̂t'                                 => 'yt',
    'màŋminjɔ̂k'                            => 'ci',
    'mìkrònesìà'                            => 'fm',
    'mònakò'                                  => 'mc',
    'mòrìtanìà'                             => 'mr',
    'mòrîs'                                   => 'mu',
    'mòsàmbîk'                               => 'mz',
    'mòŋgolìà'                              => 'mn',
    'mɔ̀ŋseràt'                             => 'ms',
    'mɛ̀gsîk'                                => 'mx',
    'nerù'                                     => 'nr',
    'neutralzone'                               => 'nt',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'nàmibìà'                                => 'na',
    'nèpâl'                                   => 'np',
    'nìgerìà'                                => 'ng',
    'nìjɛ̂r'                                 => 'ne',
    'nìkàragwà'                              => 'ni',
    'nìuɛ̀'                                  => 'nu',
    'nûmpubikîtsnìnevìs'                    => 'kn',
    'nûmpubilusì'                             => 'lc',
    'nûmpubimāatìn'                          => 'sm',
    'nûmpubipetrònìmikèlôn'                => 'pm',
    'nûmpubivɛ̂ŋsâŋnìgrènàdîn'        => 'vc',
    'nûmpubiƐlēnà'                          => 'sh',
    'nɔ̀rvegìà'                             => 'no',
    'oceania'                                   => '009',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'panamacanalzone'                           => 'pz',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'polynesia'                                 => '061',
    'pàkìstân'                               => 'pk',
    'pàlaù'                                   => 'pw',
    'pàlɛ̀htinàhyɔ̀ŋgnìgazà'           => 'ps',
    'pànya'                                    => 'es',
    'pànàma'                                  => 'pa',
    'pàràgwê'                                => 'py',
    'pèrû'                                    => 'pe',
    'pìdkaìrn'                                => 'pn',
    'pòlànd'                                  => 'pl',
    'pòlìnesìàpùlàsi'                     => 'pf',
    "pùlàsi\/fɛ̀lɛ̀nsi\/"                 => 'fr',
    'pɔ̀rtòrikò'                            => 'pr',
    'pɔ̀tɔkì'                               => 'pt',
    'ruslànd'                                  => 'ru',
    'rèunyɔ̂ŋ'                              => 're',
    'rùandà'                                  => 'rw',
    'rùmanìà'                                => 'ro',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'serbia'                                    => 'rs',
    'sirìà'                                   => 'sy',
    'sièralèɔ̂n'                            => 'sl',
    'slòvakìà'                               => 'sk',
    'slòvanìà'                               => 'si',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'srìlaŋkà'                               => 'lk',
    'svalbardandjanmayen'                       => 'sj',
    'swedɛ̀n'                                 => 'se',
    'swàzìlând'                              => 'sz',
    'sàlvàdɔ̂r'                             => 'sv',
    'sàmoà'                                   => 'ws',
    'sàotòmeɓɔprɛ̀ŋcipè'                => 'st',
    'sàudiÀrabìà'                           => 'sa',
    'sènègâl'                                => 'sn',
    'sèsɛ̂l'                                 => 'sc',
    'sìlândyɔ̀ndɔ'                         => 'nz',
    'sìŋgàpûr'                              => 'sg',
    'sòmalìà'                                => 'so',
    'sùdâŋ'                                  => 'sd',
    'sùrinâm'                                 => 'sr',
    'sùwîs'                                   => 'ch',
    'sɛ̀rbînìmɔ̀ntènegrò'               => 'cs',
    'taylànd'                                  => 'th',
    'tristandacunha'                            => 'ta',
    'trìnidàdɓɔtòbagò'                    => 'tt',
    'tàjìkìstaŋ'                            => 'tj',
    'tànzànià'                               => 'tz',
    'tàywân'                                  => 'tw',
    'tìmɔ̂rlìkòl'                          => 'tl',
    'tògo'                                     => 'tg',
    'tòkèlaò'                                => 'tk',
    'tùnisìà'                                => 'tn',
    'tùrgmènìstân'                          => 'tm',
    'tùrkây'                                  => 'tr',
    'tùvàlù'                                 => 'tv',
    'tɔŋgà'                                  => 'to',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'vànùatù'                                => 'vu',
    'vàtìkâŋ'                               => 'va',
    'vènèzùelà'                             => 've',
    'vìɛ̀dnâm'                              => 'vn',
    'wakeisland'                                => 'wk',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'wàlîsnìfùtunà'                        => 'wf',
    'yèmɛ̂n'                                 => 'ye',
    'yɔ̀rdanià'                              => 'jo',
    'zàmbià'                                  => 'zm',
    'zìmbàbwê'                               => 'zw',
    'Àdnàibilɔ̀ŋbiamerkà'                 => 'us',
    'Àdnàibilɔ̀ŋbiarābìà'               => 'ae',
    'Àdnàilɔ̂ŋ'                            => 'gb',
    'Àfgànìstâŋ'                           => 'af',
    'Àfrǐkàsɔ̀'                            => 'za',
    'Àitì'                                    => 'ht',
    'Àlbanìà'                                => 'al',
    'Àlgerìà'                                => 'dz',
    'Àrgàŋtinà'                             => 'ar',
    'Àrmenìà'                                => 'am',
    'Àrubà'                                   => 'aw',
    'Àzɛ̀rbajàŋ'                           => 'az',
    'Àŋdɔ̂r'                                => 'ad',
    'Àŋgiyà'                                 => 'ai',
    'Àŋgolà'                                 => 'ao',
    'Àŋtigàɓɔbàrbudà'                    => 'ag',
    'Àŋtîyǹlɛ̀ndi'                        => 'an',
    "\Ã\landislands"                         => 'ax',
    'Ègîptò'                                 => 'eg',
    'Èkwàtorìà'                             => 'ec',
    'Èrìtrěà'                               => 'er',
    'Èstonìà'                                => 'ee',
    'Ètìopìà'                               => 'et',
    'Ìrlând'                                  => 'ie',
    'Ìrâk'                                    => 'iq',
    'Ìrâŋ'                                   => 'ir',
    'Ìslandìà'                               => 'is',
    'Ìtalìà'                                 => 'it',
    'Òmân'                                    => 'om',
    'Òninɔrfɔ̂k'                            => 'nf',
    'Òstralìà'                               => 'au',
    'Òstrǐk'                                  => 'at',
    'Ùgandà'                                  => 'ug',
    'Ùkrɛ̌n'                                 => 'ua',
    'Ùrùgwêy'                                => 'uy',
    'Ùzbèkìstân'                            => 'uz',
    'Ŋ̀ɛmafrīkà'                           => 'cf',
    'Ɔ̀ŋduràs'                              => 'hn',
    'Ɔ̀ŋgriì'                               => 'hu',
    'Ǹlɛndi'                                  => 'nl',
);

1;

