package Locales::DB::Territory::sr;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::sr::VERSION = '0.09';

$Locales::DB::Territory::sr::cldr_version = '2.0';

%Locales::DB::Territory::sr::code_to_name = (
    '001' => 'Свет',
    '002' => 'Африка',
    '003' => "Северноамерички\ континент",
    '005' => "Јужна\ Америка",
    '009' => 'Океанија',
    '011' => "Западна\ Африка",
    '013' => "Централна\ Америка",
    '014' => "Источна\ Африка",
    '015' => "Северна\ Африка",
    '017' => "Централна\ Африка",
    '018' => "Јужна\ Африка",
    '019' => 'Америке',
    '021' => "Северна\ Америка",
    '029' => 'Кариби',
    '030' => "Источна\ Азија",
    '034' => "Јужна\ Азија",
    '035' => "Југоисточна\ Азија",
    '039' => "Јужна\ Европа",
    '053' => "Аустралија\ и\ Нови\ Зеланд",
    '054' => 'Меланезија',
    '057' => "Микронезијски\ регион",
    '061' => 'Полинезија',
    '062' => "Јужно\-централна\ Азија",
    142   => 'Азија',
    143   => "Централна\ Азија",
    145   => "Западна\ Азија",
    150   => 'Европа',
    151   => "Источна\ Европа",
    154   => "Северна\ Европа",
    155   => "Западна\ Европа",
    172   => "Комонвелт\ независних\ држава",
    200   => 'Czechoslovakia',
    419   => "Латинска\ Америка\ и\ Кариби",
    830   => "Каналска\ острва",
    'ac'  => "Острво\ Асенсион",
    'ad'  => 'Андора',
    'ae'  => "Уједињени\ Арапски\ Емирати",
    'af'  => 'Авганистан',
    'ag'  => "Антигве\ и\ Барбуда",
    'ai'  => 'Ангвила',
    'al'  => 'Албанија',
    'am'  => 'Арменија',
    'an'  => "Холандски\ Антили",
    'ao'  => 'Ангола',
    'aq'  => 'Антарктик',
    'ar'  => 'Аргентина',
    'as'  => "Америчка\ Самоа",
    'at'  => 'Аустрија',
    'au'  => 'Аустралија',
    'aw'  => 'Аруба',
    'ax'  => "Аландска\ острва",
    'az'  => 'Азербејџан',
    'ba'  => "Босна\ и\ Херцеговина",
    'bb'  => 'Барбадос',
    'bd'  => 'Бангладеш',
    'be'  => 'Белгија',
    'bf'  => "Буркина\ Фасо",
    'bg'  => 'Бугарска',
    'bh'  => 'Бахреин',
    'bi'  => 'Бурунди',
    'bj'  => 'Бенин',
    'bl'  => "Свети\ Бартоломеј",
    'bm'  => 'Бермуда',
    'bn'  => 'Брунеј',
    'bo'  => 'Боливија',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Бразил',
    'bs'  => 'Бахами',
    'bt'  => 'Бутан',
    'bv'  => "Буве\ Острва",
    'bw'  => 'Боцвана',
    'by'  => 'Белорусија',
    'bz'  => 'Белизе',
    'ca'  => 'Канада',
    'cc'  => "Кокос\ \(Келинг\)\ Острва",
    'cd'  => "Конго\ \[ДРК\]",
    'cf'  => "Централно\ Афричка\ Република",
    'cg'  => "Конго\ \[Република\]",
    'ch'  => 'Швајцарска',
    'ci'  => "Обала\ Слоноваче",
    'ck'  => "Кукова\ Острва",
    'cl'  => 'Чиле',
    'cm'  => 'Камерун',
    'cn'  => 'Кина',
    'co'  => 'Колумбија',
    'cp'  => "Острво\ Клипертон",
    'cr'  => 'Костарика',
    'cs'  => "Србија\ и\ Црна\ Гора",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Куба',
    'cv'  => "Капе\ Верде",
    'cx'  => "Божићна\ острва",
    'cy'  => 'Кипар',
    'cz'  => 'Чешка',
    'dd'  => "East\ Germany",
    'de'  => 'Немачка',
    'dg'  => "Дијего\ Гарсија",
    'dj'  => 'Џибути',
    'dk'  => 'Данска',
    'dm'  => 'Доминика',
    'do'  => "Доминиканска\ Република",
    'dz'  => 'Алжир',
    'ea'  => "Сеута\ и\ Мелиља",
    'ec'  => 'Еквадор',
    'ee'  => 'Естонија',
    'eg'  => 'Египат',
    'eh'  => "Западна\ Сахара",
    'er'  => 'Еритреја',
    'es'  => 'Шпанија',
    'et'  => 'Етиопија',
    'eu'  => "Европска\ Унија",
    'fi'  => 'Финска',
    'fj'  => 'Фиџи',
    'fk'  => "Фокландска\ \(Малвинска\)\ острва",
    'fm'  => 'Микронезија',
    'fo'  => "Фарска\ Острва",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Француска',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Габон',
    'gb'  => "Велика\ Британија",
    'gd'  => 'Гренада',
    'ge'  => 'Грузија',
    'gf'  => "Француска\ Гвајана",
    'gg'  => 'Гурнси',
    'gh'  => 'Гана',
    'gi'  => 'Гибралтар',
    'gl'  => 'Гренланд',
    'gm'  => 'Гамбија',
    'gn'  => 'Гвинеја',
    'gp'  => 'Гваделупе',
    'gq'  => "Екваторијална\ Гвинеја",
    'gr'  => 'Грчка',
    'gs'  => "Јужна\ Џорџија\ и\ Јужна\ Сендвич\ Острва",
    'gt'  => 'Гватемала',
    'gu'  => 'Гуам',
    'gw'  => "Гвинеја\-Бисао",
    'gy'  => 'Гвајана',
    'hk'  => "Хонг\ Конг",
    'hm'  => "Херд\ и\ Мекдоналд\ Острва",
    'hn'  => 'Хондурас',
    'hr'  => 'Хрватска',
    'ht'  => 'Хаити',
    'hu'  => 'Мађарска',
    'ic'  => "Канарска\ острва",
    'id'  => 'Индонезија',
    'ie'  => 'Ирска',
    'il'  => 'Израел',
    'im'  => "Острво\ Ман",
    'in'  => 'Индија',
    'io'  => "Британска\ територија\ у\ Индијском\ океану",
    'iq'  => 'Ирак',
    'ir'  => 'Иран',
    'is'  => 'Исланд',
    'it'  => 'Италија',
    'je'  => 'Џерси',
    'jm'  => 'Јамајка',
    'jo'  => 'Јордан',
    'jp'  => 'Јапан',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Кенија',
    'kg'  => 'Киргизстан',
    'kh'  => 'Камбоџа',
    'ki'  => 'Кирибати',
    'km'  => "Коморска\ Острва",
    'kn'  => "Сент\ Китс\ и\ Невис",
    'kp'  => "Северна\ Кореја",
    'kr'  => "Јужна\ Кореја",
    'kw'  => 'Кувајт',
    'ky'  => "Кајманска\ Острва",
    'kz'  => 'Казахстан',
    'la'  => 'Лаос',
    'lb'  => 'Либан',
    'lc'  => "Сент\ Луција",
    'li'  => 'Лихтенштајн',
    'lk'  => "Шри\ Ланка",
    'lr'  => 'Либерија',
    'ls'  => 'Лесото',
    'lt'  => 'Литванија',
    'lu'  => 'Луксембург',
    'lv'  => 'Летонија',
    'ly'  => 'Либија',
    'ma'  => 'Мароко',
    'mc'  => 'Монако',
    'md'  => 'Молдавија',
    'me'  => "Црна\ Гора",
    'mf'  => "Сент\ Мартин",
    'mg'  => 'Мадагаскар',
    'mh'  => "Маршалска\ Острва",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Македонија',
    'ml'  => 'Мали',
    'mm'  => "Мијанмар\ \[Бурма\]",
    'mn'  => 'Монголија',
    'mo'  => 'Макао',
    'mp'  => "Северна\ Маријанска\ Острва",
    'mq'  => 'Мартиник',
    'mr'  => 'Мауританија',
    'ms'  => 'Монсерат',
    'mt'  => 'Малта',
    'mu'  => 'Маурицијус',
    'mv'  => 'Малдиви',
    'mw'  => 'Малави',
    'mx'  => 'Мексико',
    'my'  => 'Малезија',
    'mz'  => 'Мозамбик',
    'na'  => 'Намибија',
    'nc'  => "Нова\ Каледонија",
    'ne'  => 'Нигер',
    'nf'  => "Норфолк\ Острво",
    'ng'  => 'Нигерија',
    'ni'  => 'Никарагва',
    'nl'  => 'Холандија',
    'no'  => 'Норвешка',
    'np'  => 'Непал',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Науру',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Ниуе',
    'nz'  => "Нови\ Зеланд",
    'om'  => 'Оман',
    'pa'  => 'Панама',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Перу',
    'pf'  => "Француска\ Полинезија",
    'pg'  => "Папуа\ Нова\ Гвинеја",
    'ph'  => 'Филипини',
    'pk'  => 'Пакистан',
    'pl'  => 'Пољска',
    'pm'  => "Сен\ Пјер\ и\ Микелон",
    'pn'  => 'Питкерн',
    'pr'  => "Порто\ Рико",
    'ps'  => "Палестинске\ територије",
    'pt'  => 'Португал',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Палау',
    'py'  => 'Парагвај',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Катар',
    'qo'  => "Остала\ океанија",
    're'  => 'Реинион',
    'ro'  => 'Румунија',
    'rs'  => 'Србија',
    'ru'  => 'Русија',
    'rw'  => 'Руанда',
    'sa'  => "Саудијска\ Арабија",
    'sb'  => "Соломонска\ Острва",
    'sc'  => 'Сејшели',
    'sd'  => 'Судан',
    'se'  => 'Шведска',
    'sg'  => 'Сингапур',
    'sh'  => "Света\ Јелена",
    'si'  => 'Словенија',
    'sj'  => "Свалбард\ и\ Јанмајен\ Острва",
    'sk'  => 'Словачка',
    'sl'  => "Сијера\ Леоне",
    'sm'  => "Сан\ Марино",
    'sn'  => 'Сенегал',
    'so'  => 'Сомалија',
    'sr'  => 'Суринам',
    'st'  => "Сао\ Томе\ и\ Принципе",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Салвадор',
    'sy'  => 'Сирија',
    'sz'  => 'Свазиленд',
    'ta'  => "Тристан\ да\ Куња",
    'tc'  => "Туркс\ и\ Кајкос\ Острва",
    'td'  => 'Чад',
    'tf'  => "Француске\ Јужне\ Територије",
    'tg'  => 'Того',
    'th'  => 'Тајланд',
    'tj'  => 'Таџикистан',
    'tk'  => 'Токелау',
    'tl'  => "Источни\ Тимор",
    'tm'  => 'Туркменистан',
    'tn'  => 'Тунис',
    'to'  => 'Тонга',
    'tr'  => 'Турска',
    'tt'  => "Тринидад\ и\ Тобаго",
    'tv'  => 'Тувалу',
    'tw'  => 'Тајван',
    'tz'  => 'Танзанија',
    'ua'  => 'Украјина',
    'ug'  => 'Уганда',
    'um'  => "Мања\ удаљена\ острва\ САД",
    'us'  => "Сједињене\ Америчке\ Државе",
    'uy'  => 'Уругвај',
    'uz'  => 'Узбекистан',
    'va'  => 'Ватикан',
    'vc'  => "Сент\ Винсент\ и\ Гренадини",
    'vd'  => "North\ Vietnam",
    've'  => 'Венецуела',
    'vg'  => "Британска\ Девичанска\ Острва",
    'vi'  => "С\.А\.Д\.\ Девичанска\ Острва",
    'vn'  => 'Вијетнам',
    'vu'  => 'Вануату',
    'wf'  => "Валис\ и\ Футуна\ Острва",
    'wk'  => "Wake\ Island",
    'ws'  => 'Самоа',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Јемен',
    'yt'  => 'Мајоте',
    'za'  => "Јужноафричка\ Република",
    'zm'  => 'Замбија',
    'zw'  => 'Зимбабве',
    'zz'  => "Непозната\ или\ неважећа\ област",
);

%Locales::DB::Territory::sr::name_to_code = (
    'britishantarcticterritory'                                              => 'bq',
    'cantonandenderburyislands'                                              => 'ct',
    'czechoslovakia'                                                         => 200,
    'dronningmaudland'                                                       => 'nq',
    'eastgermany'                                                            => 'dd',
    'frenchsouthernandantarcticterritories'                                  => 'fq',
    'johnstonisland'                                                         => 'jt',
    'metropolitanfrance'                                                     => 'fx',
    'midwayislands'                                                          => 'mi',
    'neutralzone'                                                            => 'nt',
    'northvietnam'                                                           => 'vd',
    'pacificislandstrustterritory'                                           => 'pc',
    'panamacanalzone'                                                        => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                              => 'yd',
    "u\.s\.miscellaneouspacificislands"                                      => 'pu',
    'unionofsovietsocialistrepublics'                                        => 'su',
    'wakeisland'                                                             => 'wk',
    'Јамајка'                                                         => 'jm',
    'Јапан'                                                             => 'jp',
    'Јемен'                                                             => 'ye',
    'Јордан'                                                           => 'jo',
    'ЈугоисточнаАзија'                                       => '035',
    'ЈужнаЏорџијаиЈужнаСендвичОстрва'         => 'gs',
    'ЈужнаАзија'                                                   => '034',
    'ЈужнаАмерика'                                               => '005',
    'ЈужнаАфрика'                                                 => '018',
    'ЈужнаЕвропа'                                                 => '039',
    'ЈужнаКореја'                                                 => 'kr',
    'ЈужноафричкаРепублика'                             => 'za',
    'ЈужноцентралнаАзија'                                 => '062',
    'Џерси'                                                             => 'je',
    'Џибути'                                                           => 'dj',
    'Авганистан'                                                   => 'af',
    'Азербејџан'                                                   => 'az',
    'Азија'                                                             => 142,
    'Аландскаострва'                                           => 'ax',
    'Албанија'                                                       => 'al',
    'Алжир'                                                             => 'dz',
    'Америке'                                                         => '019',
    'АмеричкаСамоа'                                             => 'as',
    'Ангвила'                                                         => 'ai',
    'Ангола'                                                           => 'ao',
    'Андора'                                                           => 'ad',
    'Антарктик'                                                     => 'aq',
    'АнтигвеиБарбуда'                                         => 'ag',
    'Аргентина'                                                     => 'ar',
    'Арменија'                                                       => 'am',
    'Аруба'                                                             => 'aw',
    'Аустралија'                                                   => 'au',
    'АустралијаиНовиЗеланд'                             => '053',
    'Аустрија'                                                       => 'at',
    'Африка'                                                           => '002',
    'Бангладеш'                                                     => 'bd',
    'Барбадос'                                                       => 'bb',
    'Бахами'                                                           => 'bs',
    'Бахреин'                                                         => 'bh',
    'Белгија'                                                         => 'be',
    'Белизе'                                                           => 'bz',
    'Белорусија'                                                   => 'by',
    'Бенин'                                                             => 'bj',
    'Бермуда'                                                         => 'bm',
    'Божићнаострва'                                             => 'cx',
    'Боливија'                                                       => 'bo',
    'БоснаиХерцеговина'                                     => 'ba',
    'Боцвана'                                                         => 'bw',
    'Бразил'                                                           => 'br',
    'БританскаДевичанскаОстрва'                     => 'vg',
    'БританскатериторијауИндијскомокеану' => 'io',
    'Брунеј'                                                           => 'bn',
    'БувеОстрва'                                                   => 'bv',
    'Бугарска'                                                       => 'bg',
    'БуркинаФасо'                                                 => 'bf',
    'Бурунди'                                                         => 'bi',
    'Бутан'                                                             => 'bt',
    'ВалисиФутунаОстрва'                                   => 'wf',
    'Вануату'                                                         => 'vu',
    'Ватикан'                                                         => 'va',
    'ВеликаБританија'                                         => 'gb',
    'Венецуела'                                                     => 've',
    'Вијетнам'                                                       => 'vn',
    'Габон'                                                             => 'ga',
    'Гамбија'                                                         => 'gm',
    'Гана'                                                               => 'gh',
    'Гваделупе'                                                     => 'gp',
    'Гватемала'                                                     => 'gt',
    'Гвајана'                                                         => 'gy',
    'Гвинеја'                                                         => 'gn',
    'ГвинејаБисао'                                               => 'gw',
    'Гибралтар'                                                     => 'gi',
    'Гренада'                                                         => 'gd',
    'Гренланд'                                                       => 'gl',
    'Грузија'                                                         => 'ge',
    'Грчка'                                                             => 'gr',
    'Гуам'                                                               => 'gu',
    'Гурнси'                                                           => 'gg',
    'Данска'                                                           => 'dk',
    'ДијегоГарсија'                                             => 'dg',
    'Доминика'                                                       => 'dm',
    'ДоминиканскаРепублика'                             => 'do',
    'Европа'                                                           => 150,
    'ЕвропскаУнија'                                             => 'eu',
    'Египат'                                                           => 'eg',
    'Еквадор'                                                         => 'ec',
    'ЕкваторијалнаГвинеја'                               => 'gq',
    'Еритреја'                                                       => 'er',
    'Естонија'                                                       => 'ee',
    'Етиопија'                                                       => 'et',
    'Замбија'                                                         => 'zm',
    'ЗападнаАзија'                                               => 145,
    'ЗападнаАфрика'                                             => '011',
    'ЗападнаЕвропа'                                             => 155,
    'ЗападнаСахара'                                             => 'eh',
    'Зимбабве'                                                       => 'zw',
    'Израел'                                                           => 'il',
    'Индија'                                                           => 'in',
    'Индонезија'                                                   => 'id',
    'Ирак'                                                               => 'iq',
    'Иран'                                                               => 'ir',
    'Ирска'                                                             => 'ie',
    'Исланд'                                                           => 'is',
    'ИсточнаАзија'                                               => '030',
    'ИсточнаАфрика'                                             => '014',
    'ИсточнаЕвропа'                                             => 151,
    'ИсточниТимор'                                               => 'tl',
    'Италија'                                                         => 'it',
    'Казахстан'                                                     => 'kz',
    'Камбоџа'                                                         => 'kh',
    'Камерун'                                                         => 'cm',
    'Канада'                                                           => 'ca',
    'Каналскаострва'                                           => 830,
    'Канарскаострва'                                           => 'ic',
    'КапеВерде'                                                     => 'cv',
    'Кариби'                                                           => '029',
    'Катар'                                                             => 'qa',
    'КајманскаОстрва'                                         => 'ky',
    'Кенија'                                                           => 'ke',
    'Кина'                                                               => 'cn',
    'Кипар'                                                             => 'cy',
    'Киргизстан'                                                   => 'kg',
    'Кирибати'                                                       => 'ki',
    'КокосКелингОстрва'                                     => 'cc',
    'Колумбија'                                                     => 'co',
    'Комонвелтнезависнихдржава'                     => 172,
    'КоморскаОстрва'                                           => 'km',
    'КонгоДРК'                                                       => 'cd',
    'КонгоРепублика'                                           => 'cg',
    'Костарика'                                                     => 'cr',
    'Куба'                                                               => 'cu',
    'Кувајт'                                                           => 'kw',
    'КуковаОстрва'                                               => 'ck',
    'Лаос'                                                               => 'la',
    'ЛатинскаАмерикаиКариби'                           => 419,
    'Лесото'                                                           => 'ls',
    'Летонија'                                                       => 'lv',
    'Либан'                                                             => 'lb',
    'Либерија'                                                       => 'lr',
    'Либија'                                                           => 'ly',
    'Литванија'                                                     => 'lt',
    'Лихтенштајн'                                                 => 'li',
    'Луксембург'                                                   => 'lu',
    'Мадагаскар'                                                   => 'mg',
    'Макао'                                                             => 'mo',
    'Македонија'                                                   => 'mk',
    'Малави'                                                           => 'mw',
    'Малдиви'                                                         => 'mv',
    'Малезија'                                                       => 'my',
    'Мали'                                                               => 'ml',
    'Малта'                                                             => 'mt',
    'Мароко'                                                           => 'ma',
    'Мартиник'                                                       => 'mq',
    'МаршалскаОстрва'                                         => 'mh',
    'Мауританија'                                                 => 'mr',
    'Маурицијус'                                                   => 'mu',
    'Мађарска'                                                       => 'hu',
    'Мајоте'                                                           => 'yt',
    'МањаудаљенаострваСАД'                               => 'um',
    'Мексико'                                                         => 'mx',
    'Меланезија'                                                   => '054',
    'Микронезија'                                                 => 'fm',
    'Микронезијскирегион'                                 => '057',
    'МијанмарБурма'                                             => 'mm',
    'Мозамбик'                                                       => 'mz',
    'Молдавија'                                                     => 'md',
    'Монако'                                                           => 'mc',
    'Монголија'                                                     => 'mn',
    'Монсерат'                                                       => 'ms',
    'Намибија'                                                       => 'na',
    'Науру'                                                             => 'nr',
    'Немачка'                                                         => 'de',
    'Непал'                                                             => 'np',
    'Непознатаилиневажећаобласт'                   => 'zz',
    'Нигер'                                                             => 'ne',
    'Нигерија'                                                       => 'ng',
    'Никарагва'                                                     => 'ni',
    'Ниуе'                                                               => 'nu',
    'НоваКаледонија'                                           => 'nc',
    'НовиЗеланд'                                                   => 'nz',
    'Норвешка'                                                       => 'no',
    'НорфолкОстрво'                                             => 'nf',
    'ОбалаСлоноваче'                                           => 'ci',
    'Океанија'                                                       => '009',
    'Оман'                                                               => 'om',
    'Осталаокеанија'                                           => 'qo',
    'ОстрвоАсенсион'                                           => 'ac',
    'ОстрвоКлипертон'                                         => 'cp',
    'ОстрвоМан'                                                     => 'im',
    'Пакистан'                                                       => 'pk',
    'Палау'                                                             => 'pw',
    'Палестинскетериторије'                             => 'ps',
    'Панама'                                                           => 'pa',
    'ПапуаНоваГвинеја'                                       => 'pg',
    'Парагвај'                                                       => 'py',
    'Перу'                                                               => 'pe',
    'Питкерн'                                                         => 'pn',
    'Полинезија'                                                   => '061',
    'ПортоРико'                                                     => 'pr',
    'Португал'                                                       => 'pt',
    'Пољска'                                                           => 'pl',
    'Реинион'                                                         => 're',
    'Руанда'                                                           => 'rw',
    'Румунија'                                                       => 'ro',
    'Русија'                                                           => 'ru',
    "С\.А\.Д\.ДевичанскаОстрва"                           => 'vi',
    'Салвадор'                                                       => 'sv',
    'Самоа'                                                             => 'ws',
    'СанМарино'                                                     => 'sm',
    'СаоТомеиПринципе'                                       => 'st',
    'СаудијскаАрабија'                                       => 'sa',
    'Свазиленд'                                                     => 'sz',
    'СвалбардиЈанмајенОстрва'                         => 'sj',
    'Свет'                                                               => '001',
    'СветаЈелена'                                                 => 'sh',
    'СветиБартоломеј'                                         => 'bl',
    'СевернаАмерика'                                           => '021',
    'СевернаАфрика'                                             => '015',
    'СевернаЕвропа'                                             => 154,
    'СевернаКореја'                                             => 'kp',
    'СевернаМаријанскаОстрва'                         => 'mp',
    'Северноамеричкиконтинент'                       => '003',
    'СенПјериМикелон'                                         => 'pm',
    'Сенегал'                                                         => 'sn',
    'СентВинсентиГренадини'                             => 'vc',
    'СентКитсиНевис'                                           => 'kn',
    'СентЛуција'                                                   => 'lc',
    'СентМартин'                                                   => 'mf',
    'СеутаиМелиља'                                               => 'ea',
    'Сејшели'                                                         => 'sc',
    'Сингапур'                                                       => 'sg',
    'Сирија'                                                           => 'sy',
    'СијераЛеоне'                                                 => 'sl',
    'Словачка'                                                       => 'sk',
    'Словенија'                                                     => 'si',
    'СоломонскаОстрва'                                       => 'sb',
    'Сомалија'                                                       => 'so',
    'Србија'                                                           => 'rs',
    'СрбијаиЦрнаГора'                                         => 'cs',
    'Судан'                                                             => 'sd',
    'Суринам'                                                         => 'sr',
    'СједињенеАмеричкеДржаве'                         => 'us',
    'Танзанија'                                                     => 'tz',
    'Тајван'                                                           => 'tw',
    'Тајланд'                                                         => 'th',
    'Таџикистан'                                                   => 'tj',
    'Того'                                                               => 'tg',
    'Токелау'                                                         => 'tk',
    'Тонга'                                                             => 'to',
    'ТринидадиТобаго'                                         => 'tt',
    'ТристандаКуња'                                             => 'ta',
    'Тувалу'                                                           => 'tv',
    'Тунис'                                                             => 'tn',
    'Туркменистан'                                               => 'tm',
    'ТурксиКајкосОстрва'                                   => 'tc',
    'Турска'                                                           => 'tr',
    'Уганда'                                                           => 'ug',
    'Узбекистан'                                                   => 'uz',
    'Украјина'                                                       => 'ua',
    'Уругвај'                                                         => 'uy',
    'УједињениАрапскиЕмирати'                         => 'ae',
    'ФарскаОстрва'                                               => 'fo',
    'Филипини'                                                       => 'ph',
    'Финска'                                                           => 'fi',
    'Фиџи'                                                               => 'fj',
    'ФокландскаМалвинскаострва'                     => 'fk',
    'Француска'                                                     => 'fr',
    'ФранцускаГвајана'                                       => 'gf',
    'ФранцускаПолинезија'                                 => 'pf',
    'ФранцускеЈужнеТериторије'                       => 'tf',
    'Хаити'                                                             => 'ht',
    'ХердиМекдоналдОстрва'                               => 'hm',
    'Холандија'                                                     => 'nl',
    'ХоландскиАнтили'                                         => 'an',
    'ХонгКонг'                                                       => 'hk',
    'Хондурас'                                                       => 'hn',
    'Хрватска'                                                       => 'hr',
    'ЦентралнаАзија'                                           => 143,
    'ЦентралнаАмерика'                                       => '013',
    'ЦентралнаАфрика'                                         => '017',
    'ЦентралноАфричкаРепублика'                     => 'cf',
    'ЦрнаГора'                                                       => 'me',
    'Чад'                                                                 => 'td',
    'Чешка'                                                             => 'cz',
    'Чиле'                                                               => 'cl',
    'Швајцарска'                                                   => 'ch',
    'Шведска'                                                         => 'se',
    'Шпанија'                                                         => 'es',
    'ШриЛанка'                                                       => 'lk',
);

1;

