package Locales::DB::Territory::ja;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::ja::VERSION = '0.09';

$Locales::DB::Territory::ja::cldr_version = '2.0';

%Locales::DB::Territory::ja::code_to_name = (
    '001' => '世界',
    '002' => 'アフリカ',
    '003' => '北アメリカ大陸',
    '005' => '南アメリカ',
    '009' => 'オセアニア',
    '011' => '西アフリカ',
    '013' => '中央アメリカ',
    '014' => '東アフリカ',
    '015' => '北アフリカ',
    '017' => '中部アフリカ',
    '018' => '南部アフリカ',
    '019' => 'アメリカ大陸',
    '021' => '北アメリカ',
    '029' => 'カリブ',
    '030' => '東アジア',
    '034' => '南アジア',
    '035' => '東南アジア',
    '039' => '南ヨーロッパ',
    '053' => 'オーストラリア・ニュージーランド',
    '054' => 'メラネシア',
    '057' => 'ミクロネシア',
    '061' => 'ポリネシア',
    '062' => '南中央アジア',
    142   => 'アジア',
    143   => '中央アジア',
    145   => '西アジア',
    150   => 'ヨーロッパ',
    151   => '東ヨーロッパ',
    154   => '北ヨーロッパ',
    155   => '西ヨーロッパ',
    172   => '独立国家共同体',
    200   => 'Czechoslovakia',
    419   => 'ラテンアメリカ',
    830   => 'チャネル諸島',
    'ac'  => 'アセンション島',
    'ad'  => 'アンドラ',
    'ae'  => 'アラブ首長国連邦',
    'af'  => 'アフガニスタン',
    'ag'  => 'アンティグア・バーブーダ',
    'ai'  => 'アンギラ',
    'al'  => 'アルバニア',
    'am'  => 'アルメニア',
    'an'  => 'オランダ領アンティル諸島',
    'ao'  => 'アンゴラ',
    'aq'  => '南極',
    'ar'  => 'アルゼンチン',
    'as'  => '米領サモア',
    'at'  => 'オーストリア',
    'au'  => 'オーストラリア',
    'aw'  => 'アルバ島',
    'ax'  => 'オーランド諸島',
    'az'  => 'アゼルバイジャン',
    'ba'  => 'ボスニア・ヘルツェゴビナ',
    'bb'  => 'バルバドス',
    'bd'  => 'バングラデシュ',
    'be'  => 'ベルギー',
    'bf'  => 'ブルキナファソ',
    'bg'  => 'ブルガリア',
    'bh'  => 'バーレーン',
    'bi'  => 'ブルンジ',
    'bj'  => 'ベナン',
    'bl'  => 'サン・バルテルミー',
    'bm'  => 'バミューダ',
    'bn'  => 'ブルネイ',
    'bo'  => 'ボリビア',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'ブラジル',
    'bs'  => 'バハマ',
    'bt'  => 'ブータン',
    'bv'  => 'ブーベ島',
    'bw'  => 'ボツワナ',
    'by'  => 'ベラルーシ',
    'bz'  => 'ベリーズ',
    'ca'  => 'カナダ',
    'cc'  => "ココス\[キーリング\]諸島",
    'cd'  => 'コンゴ民主共和国',
    'cf'  => '中央アフリカ共和国',
    'cg'  => 'コンゴ共和国',
    'ch'  => 'スイス',
    'ci'  => '象牙海岸',
    'ck'  => 'クック諸島',
    'cl'  => 'チリ',
    'cm'  => 'カメルーン',
    'cn'  => '中国',
    'co'  => 'コロンビア',
    'cp'  => 'クリッパートン島',
    'cr'  => 'コスタリカ',
    'cs'  => 'セルビア・モンテネグロ',
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'キューバ',
    'cv'  => 'カーボベルデ',
    'cx'  => 'クリスマス島',
    'cy'  => 'キプロス',
    'cz'  => 'チェコ共和国',
    'dd'  => "East\ Germany",
    'de'  => 'ドイツ',
    'dg'  => 'ディエゴガルシア島',
    'dj'  => 'ジブチ',
    'dk'  => 'デンマーク',
    'dm'  => 'ドミニカ国',
    'do'  => 'ドミニカ共和国',
    'dz'  => 'アルジェリア',
    'ea'  => 'セウタ・メリリャ',
    'ec'  => 'エクアドル',
    'ee'  => 'エストニア',
    'eg'  => 'エジプト',
    'eh'  => '西サハラ',
    'er'  => 'エリトリア',
    'es'  => 'スペイン',
    'et'  => 'エチオピア',
    'eu'  => '欧州連合',
    'fi'  => 'フィンランド',
    'fj'  => 'フィジー',
    'fk'  => "フォークランド諸島\[マルビナス諸島\]",
    'fm'  => 'ミクロネシア連邦',
    'fo'  => 'フェロー諸島',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'フランス',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'ガボン',
    'gb'  => 'イギリス',
    'gd'  => 'グレナダ',
    'ge'  => 'グルジア',
    'gf'  => '仏領ギアナ',
    'gg'  => 'ガーンジー',
    'gh'  => 'ガーナ',
    'gi'  => 'ジブラルタル',
    'gl'  => 'グリーンランド',
    'gm'  => 'ガンビア',
    'gn'  => 'ギニア',
    'gp'  => 'グアドループ',
    'gq'  => '赤道ギニア',
    'gr'  => 'ギリシャ',
    'gs'  => '南ジョージア島・南サンドイッチ諸島',
    'gt'  => 'グアテマラ',
    'gu'  => 'グアム',
    'gw'  => 'ギニアビサウ',
    'gy'  => 'ガイアナ',
    'hk'  => '香港',
    'hm'  => 'ハード島・マクドナルド諸島',
    'hn'  => 'ホンジュラス',
    'hr'  => 'クロアチア',
    'ht'  => 'ハイチ',
    'hu'  => 'ハンガリー',
    'ic'  => 'カナリア諸島',
    'id'  => 'インドネシア',
    'ie'  => 'アイルランド',
    'il'  => 'イスラエル',
    'im'  => 'マン島',
    'in'  => 'インド',
    'io'  => '英領インド洋地域',
    'iq'  => 'イラク',
    'ir'  => 'イラン',
    'is'  => 'アイスランド',
    'it'  => 'イタリア',
    'je'  => 'ジャージー',
    'jm'  => 'ジャマイカ',
    'jo'  => 'ヨルダン',
    'jp'  => '日本',
    'jt'  => "Johnston\ Island",
    'ke'  => 'ケニア',
    'kg'  => 'キルギスタン',
    'kh'  => 'カンボジア',
    'ki'  => 'キリバス',
    'km'  => 'コモロ',
    'kn'  => 'セントクリストファー・ネイビス',
    'kp'  => '朝鮮民主主義人民共和国',
    'kr'  => '大韓民国',
    'kw'  => 'クウェート',
    'ky'  => 'ケイマン諸島',
    'kz'  => 'カザフスタン',
    'la'  => 'ラオス',
    'lb'  => 'レバノン',
    'lc'  => 'セントルシア',
    'li'  => 'リヒテンシュタイン',
    'lk'  => 'スリランカ',
    'lr'  => 'リベリア',
    'ls'  => 'レソト',
    'lt'  => 'リトアニア',
    'lu'  => 'ルクセンブルグ',
    'lv'  => 'ラトビア',
    'ly'  => 'リビア',
    'ma'  => 'モロッコ',
    'mc'  => 'モナコ',
    'md'  => 'モルドバ',
    'me'  => 'モンテネグロ',
    'mf'  => 'セント・マーチン',
    'mg'  => 'マダガスカル',
    'mh'  => 'マーシャル諸島共和国',
    'mi'  => "Midway\ Islands",
    'mk'  => "マケドニア\[旧ユーゴスラヴィア共和国\]",
    'ml'  => 'マリ',
    'mm'  => 'ミャンマー',
    'mn'  => 'モンゴル',
    'mo'  => 'マカオ',
    'mp'  => '北マリアナ諸島',
    'mq'  => 'マルティニーク島',
    'mr'  => 'モーリタニア',
    'ms'  => 'モントセラト島',
    'mt'  => 'マルタ',
    'mu'  => 'モーリシャス',
    'mv'  => 'モルジブ',
    'mw'  => 'マラウィ',
    'mx'  => 'メキシコ',
    'my'  => 'マレーシア',
    'mz'  => 'モザンビーク',
    'na'  => 'ナミビア',
    'nc'  => 'ニューカレドニア',
    'ne'  => 'ニジェール',
    'nf'  => 'ノーフォーク島',
    'ng'  => 'ナイジェリア',
    'ni'  => 'ニカラグア',
    'nl'  => 'オランダ',
    'no'  => 'ノルウェー',
    'np'  => 'ネパール',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'ナウル',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'ニウエ島',
    'nz'  => 'ニュージーランド',
    'om'  => 'オマーン',
    'pa'  => 'パナマ',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'ペルー',
    'pf'  => '仏領ポリネシア',
    'pg'  => 'パプアニューギニア',
    'ph'  => 'フィリピン',
    'pk'  => 'パキスタン',
    'pl'  => 'ポーランド',
    'pm'  => 'サンピエール島・ミクロン島',
    'pn'  => 'ピトケアン島',
    'pr'  => 'プエルトリコ',
    'ps'  => 'パレスチナ',
    'pt'  => 'ポルトガル',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'パラオ',
    'py'  => 'パラグアイ',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'カタール',
    'qo'  => 'その他のオセアニア',
    're'  => 'レユニオン島',
    'ro'  => 'ルーマニア',
    'rs'  => 'セルビア',
    'ru'  => 'ロシア',
    'rw'  => 'ルワンダ',
    'sa'  => 'サウジアラビア',
    'sb'  => 'ソロモン諸島',
    'sc'  => 'セーシェル',
    'sd'  => 'スーダン',
    'se'  => 'スウェーデン',
    'sg'  => 'シンガポール',
    'sh'  => 'セントヘレナ',
    'si'  => 'スロベニア',
    'sj'  => 'スバールバル諸島・ヤンマイエン島',
    'sk'  => 'スロバキア',
    'sl'  => 'シエラレオネ',
    'sm'  => 'サンマリノ',
    'sn'  => 'セネガル',
    'so'  => 'ソマリア',
    'sr'  => 'スリナム',
    'st'  => 'サントメ・プリンシペ',
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'エルサルバドル',
    'sy'  => 'シリア',
    'sz'  => 'スワジランド',
    'ta'  => 'トリスタン・ダ・クーニャ',
    'tc'  => 'タークス諸島・カイコス諸島',
    'td'  => 'チャド',
    'tf'  => '仏領極南諸島',
    'tg'  => 'トーゴ',
    'th'  => 'タイ',
    'tj'  => 'タジキスタン',
    'tk'  => 'トケラウ諸島',
    'tl'  => '東ティモール',
    'tm'  => 'トルクメニスタン',
    'tn'  => 'チュニジア',
    'to'  => 'トンガ',
    'tr'  => 'トルコ',
    'tt'  => 'トリニダード・トバゴ',
    'tv'  => 'ツバル',
    'tw'  => '台湾',
    'tz'  => 'タンザニア',
    'ua'  => 'ウクライナ',
    'ug'  => 'ウガンダ',
    'um'  => '米領太平洋諸島',
    'us'  => 'アメリカ合衆国',
    'uy'  => 'ウルグアイ',
    'uz'  => 'ウズベキスタン',
    'va'  => 'バチカン市国',
    'vc'  => 'セントビンセント・グレナディーン諸島',
    'vd'  => "North\ Vietnam",
    've'  => 'ベネズエラ',
    'vg'  => '英領ヴァージン諸島',
    'vi'  => '米領ヴァージン諸島',
    'vn'  => 'ベトナム',
    'vu'  => 'バヌアツ',
    'wf'  => 'ウォリス・フツナ',
    'wk'  => "Wake\ Island",
    'ws'  => 'サモア',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'イエメン',
    'yt'  => 'マヨット島',
    'za'  => '南アフリカ',
    'zm'  => 'ザンビア',
    'zw'  => 'ジンバブエ',
    'zz'  => '不明な地域',
);

%Locales::DB::Territory::ja::name_to_code = (
    'britishantarcticterritory'                              => 'bq',
    'cantonandenderburyislands'                              => 'ct',
    'czechoslovakia'                                         => 200,
    'dronningmaudland'                                       => 'nq',
    'eastgermany'                                            => 'dd',
    'frenchsouthernandantarcticterritories'                  => 'fq',
    'johnstonisland'                                         => 'jt',
    'metropolitanfrance'                                     => 'fx',
    'midwayislands'                                          => 'mi',
    'neutralzone'                                            => 'nt',
    'northvietnam'                                           => 'vd',
    'pacificislandstrustterritory'                           => 'pc',
    'panamacanalzone'                                        => 'pz',
    "people\â\\sdemocraticrepublicofyemen"              => 'yd',
    "u\.s\.miscellaneouspacificislands"                      => 'pu',
    'unionofsovietsocialistrepublics'                        => 'su',
    'wakeisland'                                             => 'wk',
    'その他のオセアニア'                            => 'qo',
    'アイスランド'                                     => 'is',
    'アイルランド'                                     => 'ie',
    'アジア'                                              => 142,
    'アセンション島'                                  => 'ac',
    'アゼルバイジャン'                               => 'az',
    'アフガニスタン'                                  => 'af',
    'アフリカ'                                           => '002',
    'アメリカ合衆国'                                  => 'us',
    'アメリカ大陸'                                     => '019',
    'アラブ首長国連邦'                               => 'ae',
    'アルジェリア'                                     => 'dz',
    'アルゼンチン'                                     => 'ar',
    'アルバニア'                                        => 'al',
    'アルバ島'                                           => 'aw',
    'アルメニア'                                        => 'am',
    'アンギラ'                                           => 'ai',
    'アンゴラ'                                           => 'ao',
    'アンティグア・バーブーダ'                   => 'ag',
    'アンドラ'                                           => 'ad',
    'イエメン'                                           => 'ye',
    'イギリス'                                           => 'gb',
    'イスラエル'                                        => 'il',
    'イタリア'                                           => 'it',
    'イラク'                                              => 'iq',
    'イラン'                                              => 'ir',
    'インド'                                              => 'in',
    'インドネシア'                                     => 'id',
    'ウォリス・フツナ'                               => 'wf',
    'ウガンダ'                                           => 'ug',
    'ウクライナ'                                        => 'ua',
    'ウズベキスタン'                                  => 'uz',
    'ウルグアイ'                                        => 'uy',
    'エクアドル'                                        => 'ec',
    'エジプト'                                           => 'eg',
    'エストニア'                                        => 'ee',
    'エチオピア'                                        => 'et',
    'エリトリア'                                        => 'er',
    'エルサルバドル'                                  => 'sv',
    'オセアニア'                                        => '009',
    'オマーン'                                           => 'om',
    'オランダ'                                           => 'nl',
    'オランダ領アンティル諸島'                   => 'an',
    'オーストラリア'                                  => 'au',
    'オーストラリア・ニュージーランド'       => '053',
    'オーストリア'                                     => 'at',
    'オーランド諸島'                                  => 'ax',
    'カザフスタン'                                     => 'kz',
    'カタール'                                           => 'qa',
    'カナダ'                                              => 'ca',
    'カナリア諸島'                                     => 'ic',
    'カメルーン'                                        => 'cm',
    'カリブ'                                              => '029',
    'カンボジア'                                        => 'kh',
    'カーボベルデ'                                     => 'cv',
    'ガイアナ'                                           => 'gy',
    'ガボン'                                              => 'ga',
    'ガンビア'                                           => 'gm',
    'ガーナ'                                              => 'gh',
    'ガーンジー'                                        => 'gg',
    'キプロス'                                           => 'cy',
    'キューバ'                                           => 'cu',
    'キリバス'                                           => 'ki',
    'キルギスタン'                                     => 'kg',
    'ギニア'                                              => 'gn',
    'ギニアビサウ'                                     => 'gw',
    'ギリシャ'                                           => 'gr',
    'クウェート'                                        => 'kw',
    'クック諸島'                                        => 'ck',
    'クリスマス島'                                     => 'cx',
    'クリッパートン島'                               => 'cp',
    'クロアチア'                                        => 'hr',
    'グアテマラ'                                        => 'gt',
    'グアドループ'                                     => 'gp',
    'グアム'                                              => 'gu',
    'グリーンランド'                                  => 'gl',
    'グルジア'                                           => 'ge',
    'グレナダ'                                           => 'gd',
    'ケイマン諸島'                                     => 'ky',
    'ケニア'                                              => 'ke',
    'ココスキーリング諸島'                         => 'cc',
    'コスタリカ'                                        => 'cr',
    'コモロ'                                              => 'km',
    'コロンビア'                                        => 'co',
    'コンゴ共和国'                                     => 'cg',
    'コンゴ民主共和国'                               => 'cd',
    'サウジアラビア'                                  => 'sa',
    'サモア'                                              => 'ws',
    'サントメ・プリンシペ'                         => 'st',
    'サンピエール島・ミクロン島'                => 'pm',
    'サンマリノ'                                        => 'sm',
    'サン・バルテルミー'                            => 'bl',
    'ザンビア'                                           => 'zm',
    'シエラレオネ'                                     => 'sl',
    'シリア'                                              => 'sy',
    'シンガポール'                                     => 'sg',
    'ジブチ'                                              => 'dj',
    'ジブラルタル'                                     => 'gi',
    'ジャマイカ'                                        => 'jm',
    'ジャージー'                                        => 'je',
    'ジンバブエ'                                        => 'zw',
    'スイス'                                              => 'ch',
    'スウェーデン'                                     => 'se',
    'スバールバル諸島・ヤンマイエン島'       => 'sj',
    'スペイン'                                           => 'es',
    'スリナム'                                           => 'sr',
    'スリランカ'                                        => 'lk',
    'スロバキア'                                        => 'sk',
    'スロベニア'                                        => 'si',
    'スワジランド'                                     => 'sz',
    'スーダン'                                           => 'sd',
    'セウタ・メリリャ'                               => 'ea',
    'セネガル'                                           => 'sn',
    'セルビア'                                           => 'rs',
    'セルビア・モンテネグロ'                      => 'cs',
    'セントクリストファー・ネイビス'          => 'kn',
    'セントビンセント・グレナディーン諸島' => 'vc',
    'セントヘレナ'                                     => 'sh',
    'セントルシア'                                     => 'lc',
    'セント・マーチン'                               => 'mf',
    'セーシェル'                                        => 'sc',
    'ソマリア'                                           => 'so',
    'ソロモン諸島'                                     => 'sb',
    'タイ'                                                 => 'th',
    'タジキスタン'                                     => 'tj',
    'タンザニア'                                        => 'tz',
    'タークス諸島・カイコス諸島'                => 'tc',
    'チェコ共和国'                                     => 'cz',
    'チャド'                                              => 'td',
    'チャネル諸島'                                     => 830,
    'チュニジア'                                        => 'tn',
    'チリ'                                                 => 'cl',
    'ツバル'                                              => 'tv',
    'ディエゴガルシア島'                            => 'dg',
    'デンマーク'                                        => 'dk',
    'トケラウ諸島'                                     => 'tk',
    'トリスタン・ダ・クーニャ'                   => 'ta',
    'トリニダード・トバゴ'                         => 'tt',
    'トルクメニスタン'                               => 'tm',
    'トルコ'                                              => 'tr',
    'トンガ'                                              => 'to',
    'トーゴ'                                              => 'tg',
    'ドイツ'                                              => 'de',
    'ドミニカ共和国'                                  => 'do',
    'ドミニカ国'                                        => 'dm',
    'ナイジェリア'                                     => 'ng',
    'ナウル'                                              => 'nr',
    'ナミビア'                                           => 'na',
    'ニウエ島'                                           => 'nu',
    'ニカラグア'                                        => 'ni',
    'ニジェール'                                        => 'ne',
    'ニューカレドニア'                               => 'nc',
    'ニュージーランド'                               => 'nz',
    'ネパール'                                           => 'np',
    'ノルウェー'                                        => 'no',
    'ノーフォーク島'                                  => 'nf',
    'ハイチ'                                              => 'ht',
    'ハンガリー'                                        => 'hu',
    'ハード島・マクドナルド諸島'                => 'hm',
    'バチカン市国'                                     => 'va',
    'バヌアツ'                                           => 'vu',
    'バハマ'                                              => 'bs',
    'バミューダ'                                        => 'bm',
    'バルバドス'                                        => 'bb',
    'バングラデシュ'                                  => 'bd',
    'バーレーン'                                        => 'bh',
    'パキスタン'                                        => 'pk',
    'パナマ'                                              => 'pa',
    'パプアニューギニア'                            => 'pg',
    'パラオ'                                              => 'pw',
    'パラグアイ'                                        => 'py',
    'パレスチナ'                                        => 'ps',
    'ピトケアン島'                                     => 'pn',
    'フィジー'                                           => 'fj',
    'フィリピン'                                        => 'ph',
    'フィンランド'                                     => 'fi',
    'フェロー諸島'                                     => 'fo',
    'フォークランド諸島マルビナス諸島'       => 'fk',
    'フランス'                                           => 'fr',
    'ブラジル'                                           => 'br',
    'ブルガリア'                                        => 'bg',
    'ブルキナファソ'                                  => 'bf',
    'ブルネイ'                                           => 'bn',
    'ブルンジ'                                           => 'bi',
    'ブータン'                                           => 'bt',
    'ブーベ島'                                           => 'bv',
    'プエルトリコ'                                     => 'pr',
    'ベトナム'                                           => 'vn',
    'ベナン'                                              => 'bj',
    'ベネズエラ'                                        => 've',
    'ベラルーシ'                                        => 'by',
    'ベリーズ'                                           => 'bz',
    'ベルギー'                                           => 'be',
    'ペルー'                                              => 'pe',
    'ホンジュラス'                                     => 'hn',
    'ボスニア・ヘルツェゴビナ'                   => 'ba',
    'ボツワナ'                                           => 'bw',
    'ボリビア'                                           => 'bo',
    'ポリネシア'                                        => '061',
    'ポルトガル'                                        => 'pt',
    'ポーランド'                                        => 'pl',
    'マカオ'                                              => 'mo',
    'マケドニア旧ユーゴスラヴィア共和国'    => 'mk',
    'マダガスカル'                                     => 'mg',
    'マヨット島'                                        => 'yt',
    'マラウィ'                                           => 'mw',
    'マリ'                                                 => 'ml',
    'マルタ'                                              => 'mt',
    'マルティニーク島'                               => 'mq',
    'マレーシア'                                        => 'my',
    'マン島'                                              => 'im',
    'マーシャル諸島共和国'                         => 'mh',
    'ミクロネシア'                                     => '057',
    'ミクロネシア連邦'                               => 'fm',
    'ミャンマー'                                        => 'mm',
    'メキシコ'                                           => 'mx',
    'メラネシア'                                        => '054',
    'モザンビーク'                                     => 'mz',
    'モナコ'                                              => 'mc',
    'モルジブ'                                           => 'mv',
    'モルドバ'                                           => 'md',
    'モロッコ'                                           => 'ma',
    'モンゴル'                                           => 'mn',
    'モンテネグロ'                                     => 'me',
    'モントセラト島'                                  => 'ms',
    'モーリシャス'                                     => 'mu',
    'モーリタニア'                                     => 'mr',
    'ヨルダン'                                           => 'jo',
    'ヨーロッパ'                                        => 150,
    'ラオス'                                              => 'la',
    'ラテンアメリカ'                                  => 419,
    'ラトビア'                                           => 'lv',
    'リトアニア'                                        => 'lt',
    'リヒテンシュタイン'                            => 'li',
    'リビア'                                              => 'ly',
    'リベリア'                                           => 'lr',
    'ルクセンブルグ'                                  => 'lu',
    'ルワンダ'                                           => 'rw',
    'ルーマニア'                                        => 'ro',
    'レソト'                                              => 'ls',
    'レバノン'                                           => 'lb',
    'レユニオン島'                                     => 're',
    'ロシア'                                              => 'ru',
    '不明な地域'                                        => 'zz',
    '世界'                                                 => '001',
    '中国'                                                 => 'cn',
    '中央アジア'                                        => 143,
    '中央アフリカ共和国'                            => 'cf',
    '中央アメリカ'                                     => '013',
    '中部アフリカ'                                     => '017',
    '仏領ギアナ'                                        => 'gf',
    '仏領ポリネシア'                                  => 'pf',
    '仏領極南諸島'                                     => 'tf',
    '北アフリカ'                                        => '015',
    '北アメリカ'                                        => '021',
    '北アメリカ大陸'                                  => '003',
    '北マリアナ諸島'                                  => 'mp',
    '北ヨーロッパ'                                     => 154,
    '南アジア'                                           => '034',
    '南アフリカ'                                        => 'za',
    '南アメリカ'                                        => '005',
    '南ジョージア島・南サンドイッチ諸島'    => 'gs',
    '南ヨーロッパ'                                     => '039',
    '南中央アジア'                                     => '062',
    '南極'                                                 => 'aq',
    '南部アフリカ'                                     => '018',
    '台湾'                                                 => 'tw',
    '大韓民国'                                           => 'kr',
    '日本'                                                 => 'jp',
    '朝鮮民主主義人民共和国'                      => 'kp',
    '東アジア'                                           => '030',
    '東アフリカ'                                        => '014',
    '東ティモール'                                     => 'tl',
    '東ヨーロッパ'                                     => 151,
    '東南アジア'                                        => '035',
    '欧州連合'                                           => 'eu',
    '独立国家共同体'                                  => 172,
    '米領サモア'                                        => 'as',
    '米領ヴァージン諸島'                            => 'vi',
    '米領太平洋諸島'                                  => 'um',
    '英領インド洋地域'                               => 'io',
    '英領ヴァージン諸島'                            => 'vg',
    '西アジア'                                           => 145,
    '西アフリカ'                                        => '011',
    '西サハラ'                                           => 'eh',
    '西ヨーロッパ'                                     => 155,
    '象牙海岸'                                           => 'ci',
    '赤道ギニア'                                        => 'gq',
    '香港'                                                 => 'hk',
);

1;

