package Locales::DB::Territory::zu;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::zu::VERSION = '0.09';

$Locales::DB::Territory::zu::cldr_version = '2.0';

%Locales::DB::Territory::zu::code_to_name = (
    '001' => 'Umhlaba',
    '002' => "i\-Africa",
    '003' => "e\-North\ America",
    '005' => "i\-South\ America",
    '009' => "i\-Oceania",
    '011' => "e\-Western\ Africa",
    '013' => "i\-Central\ America",
    '014' => "e\-Eastern\ Africa",
    '015' => "e\-Northern\ Africa",
    '017' => "e\-Middle\ Africa",
    '018' => "e\-Southern\ Africa",
    '019' => 'Americas',
    '021' => "e\-Northern\ America",
    '029' => "i\-Caribbean",
    '030' => "e\-Eastern\ Asia",
    '034' => "e\-Southern\ Asia",
    '035' => "e\-South\-Eastern\ Asia",
    '039' => "e\-Southern\ Europe",
    '053' => "i\-Australia\ ne\-New\ Zealand",
    '054' => "i\-Melanesia",
    '057' => "e\-Micronesian\ Region",
    '061' => "i\-Polynesia",
    '062' => "South\-Central\ Asia",
    142   => "i\-Asia",
    143   => "i\-Central\ Asia",
    145   => "e\-Western\ Asia",
    150   => "i\-Europe",
    151   => "e\-Eastern\ Europe",
    154   => "e\-Northern\ Europe",
    155   => "e\-Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "i\-Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "i\-Ascension\ Island",
    'ad'  => "i\-Andorra",
    'ae'  => "i\-United\ Arab\ Emirates",
    'af'  => "i\-Afghanistan",
    'ag'  => "i\-Antigua\ and\ Barbuda",
    'ai'  => "i\-Anguilla",
    'al'  => "i\-Albania",
    'am'  => "i\-Armenia",
    'an'  => "i\-Netherlands\ Antilles",
    'ao'  => "i\-Angola",
    'aq'  => "i\-Antarctica",
    'ar'  => "i\-Argentina",
    'as'  => "i\-American\ Samoa",
    'at'  => "i\-Austria",
    'au'  => "i\-Australia",
    'aw'  => "i\-Aruba",
    'ax'  => "i\-Åland\ Islands",
    'az'  => "i\-Azerbaijan",
    'ba'  => "i\-Bosnia\ ne\-Herzegovina",
    'bb'  => "i\-Barbados",
    'bd'  => "i\-Bangladesh",
    'be'  => "i\-Belgium",
    'bf'  => "i\-Burkina\ Faso",
    'bg'  => "i\-Bulgaria",
    'bh'  => "i\-Bahrain",
    'bi'  => "i\-Burundi",
    'bj'  => "i\-Benin",
    'bl'  => "i\-Saint\ Barthélemy",
    'bm'  => "i\-Bermuda",
    'bn'  => "i\-Brunei",
    'bo'  => "i\-Bolivia",
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => "i\-Brazil",
    'bs'  => "i\-Bahamas",
    'bt'  => "i\-Bhutan",
    'bv'  => "i\-Bouvet\ Island",
    'bw'  => "i\-Botswana",
    'by'  => "i\-Belarus",
    'bz'  => "i\-Belize",
    'ca'  => "i\-Canada",
    'cc'  => "i\-Cocos\ \(Keeling\)\ Islands",
    'cd'  => "e\-Congo\ \[DRC\]",
    'cf'  => "i\-Central\ African\ Republic",
    'cg'  => "e\-Congo\ \[Republic\]",
    'ch'  => "i\-Switzerland",
    'ci'  => "i\-Ivory\ Coast",
    'ck'  => "i\-Cook\ Islands",
    'cl'  => "i\-Chile",
    'cm'  => "i\-Cameroon",
    'cn'  => "i\-China",
    'co'  => "i\-Colombia",
    'cp'  => "i\-Clipperton\ Island",
    'cr'  => "i\-Costa\ Rica",
    'cs'  => "Serbia\ and\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => "i\-Cuba",
    'cv'  => "i\-Cape\ Verde",
    'cx'  => "i\-Christmas\ Island",
    'cy'  => "i\-Cyprus",
    'cz'  => "i\-Czech\ Republic",
    'dd'  => "East\ Germany",
    'de'  => "i\-Germany",
    'dg'  => "e\-Diego\ Garcia",
    'dj'  => "i\-Djibouti",
    'dk'  => "i\-Denmark",
    'dm'  => "i\-Dominica",
    'do'  => "i\-Dominican\ Republic",
    'dz'  => "i\-Algeria",
    'ea'  => "i\-Cueta\ ne\-Melilla",
    'ec'  => "i\-Ecuador",
    'ee'  => "i\-Estonia",
    'eg'  => "i\-Egypt",
    'eh'  => "i\-Western\ Sahara",
    'er'  => "i\-Eritrea",
    'es'  => "i\-Spain",
    'et'  => "i\-Ethiopia",
    'eu'  => "i\-European\ Union",
    'fi'  => "i\-Finland",
    'fj'  => "i\-Fiji",
    'fk'  => "i\-Falkland\ Islands\ \(i\-Islas\ Malvinas\]",
    'fm'  => "i\-Micronesia",
    'fo'  => "i\-Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => "i\-France",
    'fx'  => "Metropolitan\ France",
    'ga'  => "i\-Gabon",
    'gb'  => "i\-United\ Kingdom",
    'gd'  => "i\-Grenada",
    'ge'  => "i\-Georgia",
    'gf'  => "isi\-French\ Guiana",
    'gg'  => "I\-Guernsey",
    'gh'  => "i\-Ghana",
    'gi'  => "i\-Gibraltar",
    'gl'  => "i\-Greenland",
    'gm'  => "i\-Gambia",
    'gn'  => "i\-Guinea",
    'gp'  => "i\-Guadeloupe",
    'gq'  => "i\-Equatorial\ Guinea",
    'gr'  => "i\-Greece",
    'gs'  => "i\-South\ Georgia\ ne\-South\ Sandwich\ Islands",
    'gt'  => "i\-Guatemala",
    'gu'  => "i\-Guam",
    'gw'  => "i\-Guinea\-Bissau",
    'gy'  => "i\-Guyana",
    'hk'  => "i\-Hong\ Kong",
    'hm'  => "i\-Heard\ Island\ ne\-McDonald\ Islands",
    'hn'  => "i\-Honduras",
    'hr'  => "i\-Croatia",
    'ht'  => "i\-Haiti",
    'hu'  => "i\-Hungary",
    'ic'  => "i\-Canary\ Islands",
    'id'  => "i\-Indonesia",
    'ie'  => "i\-Ireland",
    'il'  => "i\-Israel",
    'im'  => "i\-Isle\ of\ Man",
    'in'  => "i\-India",
    'io'  => "i\-British\ Indian\ Ocean\ Territory",
    'iq'  => "i\-Iraq",
    'ir'  => "i\-Iran",
    'is'  => "i\-Iceland",
    'it'  => "i\-Italy",
    'je'  => "isi\-Jersey",
    'jm'  => "i\-Jamaica",
    'jo'  => "i\-Jordan",
    'jp'  => "i\-Japan",
    'jt'  => "Johnston\ Island",
    'ke'  => "i\-Kenya",
    'kg'  => "i\-Kyrgyzstan",
    'kh'  => "i\-Cambodia",
    'ki'  => "i\-Kiribati",
    'km'  => "i\-Comoros",
    'kn'  => "i\-Saint\ Kitts\ ne\-Nevis",
    'kp'  => "i\-North\ Korea",
    'kr'  => "i\-South\ Korea",
    'kw'  => "i\-Kuwait",
    'ky'  => "i\-Cayman\ Islands",
    'kz'  => "i\-Kazakhstan",
    'la'  => "i\-Laos",
    'lb'  => "i\-Lebanon",
    'lc'  => "i\-Saint\ Lucia",
    'li'  => "i\-Liechtenstein",
    'lk'  => "i\-Sri\ Lanka",
    'lr'  => "i\-Liberia",
    'ls'  => "i\-Lesotho",
    'lt'  => "i\-Lithuania",
    'lu'  => "i\-Luxembourg",
    'lv'  => "i\-Latvia",
    'ly'  => "i\-Libya",
    'ma'  => "i\-Morocco",
    'mc'  => "i\-Monaco",
    'md'  => "i\-Moldova",
    'me'  => "i\-Montenegro",
    'mf'  => "i\-Saint\ Martin",
    'mg'  => "i\-Madagascar",
    'mh'  => "i\-Marshall\ Islands",
    'mi'  => "Midway\ Islands",
    'mk'  => "isi\-Macedonia\ \[FYROM\]",
    'ml'  => "i\-Mali",
    'mm'  => "e\-Myanmar\ \[Burma\]",
    'mn'  => "i\-Mongolia",
    'mo'  => "i\-Macau",
    'mp'  => "i\-Northern\ Mariana\ Islands",
    'mq'  => "i\-Martinique",
    'mr'  => "i\-Mauritania",
    'ms'  => "i\-Montserrat",
    'mt'  => "i\-Malta",
    'mu'  => "i\-Mauritius",
    'mv'  => "i\-Maldives",
    'mw'  => "i\-Malawi",
    'mx'  => "i\-Mexico",
    'my'  => "i\-Malaysia",
    'mz'  => "i\-Mozambique",
    'na'  => "i\-Namibia",
    'nc'  => "i\-New\ Caledonia",
    'ne'  => "i\-Niger",
    'nf'  => "i\-Norfolk\ Island",
    'ng'  => "i\-Nigeria",
    'ni'  => "i\-Nicaragua",
    'nl'  => "i\-Netherlands",
    'no'  => "i\-Norway",
    'np'  => "i\-Nepal",
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => "i\-Nauru",
    'nt'  => "Neutral\ Zone",
    'nu'  => "i\-Niue",
    'nz'  => "i\-New\ Zealand",
    'om'  => "i\-Oman",
    'pa'  => "i\-Panama",
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => "i\-Peru",
    'pf'  => "i\-French\ Polynesia",
    'pg'  => "i\-Papua\ New\ Guinea",
    'ph'  => "i\-Philippines",
    'pk'  => "i\-Pakistan",
    'pl'  => "i\-Poland",
    'pm'  => "i\-Saint\ Pierre\ kanye\ ne\-Miquelon",
    'pn'  => "i\-Pitcairn\ Islands",
    'pr'  => "i\-Puerto\ Rico",
    'ps'  => "i\-Palestinian\ Territories",
    'pt'  => "i\-Portugal",
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => "i\-Palau",
    'py'  => "i\-Paraguay",
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => "i\-Qatar",
    'qo'  => "i\-Outlying\ Oceania",
    're'  => "i\-Réunion",
    'ro'  => "i\-Romania",
    'rs'  => "i\-Serbia",
    'ru'  => "i\-Russia",
    'rw'  => "i\-Rwanda",
    'sa'  => "i\-Saudi\ Arabia",
    'sb'  => "i\-Solomon\ Islands",
    'sc'  => "i\-Seychelles",
    'sd'  => "i\-Sudan",
    'se'  => "i\-Sweden",
    'sg'  => "i\-Singapore",
    'sh'  => "i\-Saint\ Helena",
    'si'  => "i\-Slovenia",
    'sj'  => "I\-Svalbard\ ne\-Jan\ Mayen",
    'sk'  => "i\-Slovakia",
    'sl'  => "i\-Sierra\ Leone",
    'sm'  => "i\-San\ Marino",
    'sn'  => "i\-Senegal",
    'so'  => "i\-Somalia",
    'sr'  => "i\-Suriname",
    'st'  => "i\-São\ Tomé\ kanye\ ne\-Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "i\-El\ Salvador",
    'sy'  => "i\-Syria",
    'sz'  => "i\-Swaziland",
    'ta'  => "i\-Tristan\ da\ Cunha",
    'tc'  => "i\-Turks\ and\ Caicos\ Islands",
    'td'  => "i\-Chad",
    'tf'  => "e\-French\ Southern\ Territories",
    'tg'  => "i\-Togo",
    'th'  => "i\-Thailand",
    'tj'  => "i\-Tajikistan",
    'tk'  => "i\-Tokelau",
    'tl'  => "i\-East\ Timor",
    'tm'  => "i\-Turkmenistan",
    'tn'  => "i\-Tunisia",
    'to'  => "i\-Tonga",
    'tr'  => "i\-Turkey",
    'tt'  => "i\-Trinidad\ ne\-Tobago",
    'tv'  => "i\-Tuvalu",
    'tw'  => "i\-Taiwan",
    'tz'  => "i\-Tanzania",
    'ua'  => "i\-Ukraine",
    'ug'  => "i\-Uganda",
    'um'  => "e\-U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "i\-United\ States",
    'uy'  => "i\-Uruguay",
    'uz'  => "i\-Uzbekistan",
    'va'  => "i\-Vatican\ City",
    'vc'  => "i\-Saint\ Vincent\ ne\-Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => "i\-Venezuela",
    'vg'  => "i\-British\ Virgin\ Islands",
    'vi'  => "i\-U\.S\.\ Virgin\ Islands",
    'vn'  => "i\-Vietnam",
    'vu'  => "i\-Vanuatu",
    'wf'  => "i\-Wallis\ ne\-Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => "i\-Samoa",
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => "i\-Yemen",
    'yt'  => "i\-Mayotte",
    'za'  => "iNingizimu\ Afrika",
    'zm'  => "i\-Zambia",
    'zw'  => "i\-Zimbabwe",
    'zz'  => "Isifunda\ esingaziwa",
);

%Locales::DB::Territory::zu::name_to_code = (
    'americas'                                  => '019',
    'britishantarcticterritory'                 => 'bq',
    'cantonandenderburyislands'                 => 'ct',
    'channelislands'                            => 830,
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'econgodrc'                                 => 'cd',
    'econgorepublic'                            => 'cg',
    'ediegogarcia'                              => 'dg',
    'eeasternafrica'                            => '014',
    'eeasternasia'                              => '030',
    'eeasterneurope'                            => 151,
    'efrenchsouthernterritories'                => 'tf',
    'emicronesianregion'                        => '057',
    'emiddleafrica'                             => '017',
    'emyanmarburma'                             => 'mm',
    'enorthamerica'                             => '003',
    'enorthernafrica'                           => '015',
    'enorthernamerica'                          => '021',
    'enortherneurope'                           => 154,
    'esoutheasternasia'                         => '035',
    'esouthernafrica'                           => '018',
    'esouthernasia'                             => '034',
    'esoutherneurope'                           => '039',
    "eu\.s\.minoroutlyingislands"               => 'um',
    'ewesternafrica'                            => '011',
    'ewesternasia'                              => 145,
    'ewesterneurope'                            => 155,
    'frenchsouthernandantarcticterritories'     => 'fq',
    'iafghanistan'                              => 'af',
    'iafrica'                                   => '002',
    'ialbania'                                  => 'al',
    'ialgeria'                                  => 'dz',
    'iamericansamoa'                            => 'as',
    'iandorra'                                  => 'ad',
    'iangola'                                   => 'ao',
    'ianguilla'                                 => 'ai',
    'iantarctica'                               => 'aq',
    'iantiguaandbarbuda'                        => 'ag',
    'iargentina'                                => 'ar',
    'iarmenia'                                  => 'am',
    'iaruba'                                    => 'aw',
    'iascensionisland'                          => 'ac',
    'iasia'                                     => 142,
    'iaustralia'                                => 'au',
    'iaustralianenewzealand'                    => '053',
    'iaustria'                                  => 'at',
    'iazerbaijan'                               => 'az',
    'ibahamas'                                  => 'bs',
    'ibahrain'                                  => 'bh',
    'ibangladesh'                               => 'bd',
    'ibarbados'                                 => 'bb',
    'ibelarus'                                  => 'by',
    'ibelgium'                                  => 'be',
    'ibelize'                                   => 'bz',
    'ibenin'                                    => 'bj',
    'ibermuda'                                  => 'bm',
    'ibhutan'                                   => 'bt',
    'ibolivia'                                  => 'bo',
    'ibosnianeherzegovina'                      => 'ba',
    'ibotswana'                                 => 'bw',
    'ibouvetisland'                             => 'bv',
    'ibrazil'                                   => 'br',
    'ibritishindianoceanterritory'              => 'io',
    'ibritishvirginislands'                     => 'vg',
    'ibrunei'                                   => 'bn',
    'ibulgaria'                                 => 'bg',
    'iburkinafaso'                              => 'bf',
    'iburundi'                                  => 'bi',
    'icambodia'                                 => 'kh',
    'icameroon'                                 => 'cm',
    'icanada'                                   => 'ca',
    'icanaryislands'                            => 'ic',
    'icapeverde'                                => 'cv',
    'icaribbean'                                => '029',
    'icaymanislands'                            => 'ky',
    'icentralafricanrepublic'                   => 'cf',
    'icentralamerica'                           => '013',
    'icentralasia'                              => 143,
    'ichad'                                     => 'td',
    'ichile'                                    => 'cl',
    'ichina'                                    => 'cn',
    'ichristmasisland'                          => 'cx',
    'iclippertonisland'                         => 'cp',
    'icocoskeelingislands'                      => 'cc',
    'icolombia'                                 => 'co',
    'icomoros'                                  => 'km',
    'icookislands'                              => 'ck',
    'icostarica'                                => 'cr',
    'icroatia'                                  => 'hr',
    'icuba'                                     => 'cu',
    'icuetanemelilla'                           => 'ea',
    'icyprus'                                   => 'cy',
    'iczechrepublic'                            => 'cz',
    'idenmark'                                  => 'dk',
    'idjibouti'                                 => 'dj',
    'idominica'                                 => 'dm',
    'idominicanrepublic'                        => 'do',
    'ieasttimor'                                => 'tl',
    'iecuador'                                  => 'ec',
    'iegypt'                                    => 'eg',
    'ielsalvador'                               => 'sv',
    'iequatorialguinea'                         => 'gq',
    'ieritrea'                                  => 'er',
    'iestonia'                                  => 'ee',
    'iethiopia'                                 => 'et',
    'ieurope'                                   => 150,
    'ieuropeanunion'                            => 'eu',
    'ifalklandislandsiislasmalvinas'            => 'fk',
    'ifaroeislands'                             => 'fo',
    'ifiji'                                     => 'fj',
    'ifinland'                                  => 'fi',
    'ifrance'                                   => 'fr',
    'ifrenchpolynesia'                          => 'pf',
    'igabon'                                    => 'ga',
    'igambia'                                   => 'gm',
    'igeorgia'                                  => 'ge',
    'igermany'                                  => 'de',
    'ighana'                                    => 'gh',
    'igibraltar'                                => 'gi',
    'igreece'                                   => 'gr',
    'igreenland'                                => 'gl',
    'igrenada'                                  => 'gd',
    'iguadeloupe'                               => 'gp',
    'iguam'                                     => 'gu',
    'iguatemala'                                => 'gt',
    'iguernsey'                                 => 'gg',
    'iguinea'                                   => 'gn',
    'iguineabissau'                             => 'gw',
    'iguyana'                                   => 'gy',
    'ihaiti'                                    => 'ht',
    'iheardislandnemcdonaldislands'             => 'hm',
    'ihonduras'                                 => 'hn',
    'ihongkong'                                 => 'hk',
    'ihungary'                                  => 'hu',
    'iiceland'                                  => 'is',
    'iindia'                                    => 'in',
    'iindonesia'                                => 'id',
    'iiran'                                     => 'ir',
    'iiraq'                                     => 'iq',
    'iireland'                                  => 'ie',
    'iisleofman'                                => 'im',
    'iisrael'                                   => 'il',
    'iitaly'                                    => 'it',
    'iivorycoast'                               => 'ci',
    'ijamaica'                                  => 'jm',
    'ijapan'                                    => 'jp',
    'ijordan'                                   => 'jo',
    'ikazakhstan'                               => 'kz',
    'ikenya'                                    => 'ke',
    'ikiribati'                                 => 'ki',
    'ikuwait'                                   => 'kw',
    'ikyrgyzstan'                               => 'kg',
    'ilaos'                                     => 'la',
    'ilatinamerica'                             => 419,
    'ilatvia'                                   => 'lv',
    'ilebanon'                                  => 'lb',
    'ilesotho'                                  => 'ls',
    'iliberia'                                  => 'lr',
    'ilibya'                                    => 'ly',
    'iliechtenstein'                            => 'li',
    'ilithuania'                                => 'lt',
    'iluxembourg'                               => 'lu',
    'imacau'                                    => 'mo',
    'imadagascar'                               => 'mg',
    'imalawi'                                   => 'mw',
    'imalaysia'                                 => 'my',
    'imaldives'                                 => 'mv',
    'imali'                                     => 'ml',
    'imalta'                                    => 'mt',
    'imarshallislands'                          => 'mh',
    'imartinique'                               => 'mq',
    'imauritania'                               => 'mr',
    'imauritius'                                => 'mu',
    'imayotte'                                  => 'yt',
    'imelanesia'                                => '054',
    'imexico'                                   => 'mx',
    'imicronesia'                               => 'fm',
    'imoldova'                                  => 'md',
    'imonaco'                                   => 'mc',
    'imongolia'                                 => 'mn',
    'imontenegro'                               => 'me',
    'imontserrat'                               => 'ms',
    'imorocco'                                  => 'ma',
    'imozambique'                               => 'mz',
    'inamibia'                                  => 'na',
    'inauru'                                    => 'nr',
    'inepal'                                    => 'np',
    'inetherlands'                              => 'nl',
    'inetherlandsantilles'                      => 'an',
    'inewcaledonia'                             => 'nc',
    'inewzealand'                               => 'nz',
    'inicaragua'                                => 'ni',
    'iniger'                                    => 'ne',
    'inigeria'                                  => 'ng',
    'iningizimuafrika'                          => 'za',
    'iniue'                                     => 'nu',
    'inorfolkisland'                            => 'nf',
    'inorthernmarianaislands'                   => 'mp',
    'inorthkorea'                               => 'kp',
    'inorway'                                   => 'no',
    'ioceania'                                  => '009',
    'ioman'                                     => 'om',
    'ioutlyingoceania'                          => 'qo',
    'ipakistan'                                 => 'pk',
    'ipalau'                                    => 'pw',
    'ipalestinianterritories'                   => 'ps',
    'ipanama'                                   => 'pa',
    'ipapuanewguinea'                           => 'pg',
    'iparaguay'                                 => 'py',
    'iperu'                                     => 'pe',
    'iphilippines'                              => 'ph',
    'ipitcairnislands'                          => 'pn',
    'ipoland'                                   => 'pl',
    'ipolynesia'                                => '061',
    'iportugal'                                 => 'pt',
    'ipuertorico'                               => 'pr',
    'iqatar'                                    => 'qa',
    'iromania'                                  => 'ro',
    'irussia'                                   => 'ru',
    'irwanda'                                   => 'rw',
    'iréunion'                                 => 're',
    'isaintbarthélemy'                         => 'bl',
    'isainthelena'                              => 'sh',
    'isaintkittsnenevis'                        => 'kn',
    'isaintlucia'                               => 'lc',
    'isaintmartin'                              => 'mf',
    'isaintpierrekanyenemiquelon'               => 'pm',
    'isaintvincentnegrenadines'                 => 'vc',
    'isamoa'                                    => 'ws',
    'isanmarino'                                => 'sm',
    'isaudiarabia'                              => 'sa',
    'isenegal'                                  => 'sn',
    'iserbia'                                   => 'rs',
    'iseychelles'                               => 'sc',
    'isierraleone'                              => 'sl',
    'isifrenchguiana'                           => 'gf',
    'isifundaesingaziwa'                        => 'zz',
    'isijersey'                                 => 'je',
    'isimacedoniafyrom'                         => 'mk',
    'isingapore'                                => 'sg',
    'islovakia'                                 => 'sk',
    'islovenia'                                 => 'si',
    'isolomonislands'                           => 'sb',
    'isomalia'                                  => 'so',
    'isouthamerica'                             => '005',
    'isouthgeorgianesouthsandwichislands'       => 'gs',
    'isouthkorea'                               => 'kr',
    'ispain'                                    => 'es',
    'isrilanka'                                 => 'lk',
    'isudan'                                    => 'sd',
    'isuriname'                                 => 'sr',
    'isvalbardnejanmayen'                       => 'sj',
    'iswaziland'                                => 'sz',
    'isweden'                                   => 'se',
    'iswitzerland'                              => 'ch',
    'isyria'                                    => 'sy',
    'isãotomékanyenepríncipe'                => 'st',
    'itaiwan'                                   => 'tw',
    'itajikistan'                               => 'tj',
    'itanzania'                                 => 'tz',
    'ithailand'                                 => 'th',
    'itogo'                                     => 'tg',
    'itokelau'                                  => 'tk',
    'itonga'                                    => 'to',
    'itrinidadnetobago'                         => 'tt',
    'itristandacunha'                           => 'ta',
    'itunisia'                                  => 'tn',
    'iturkey'                                   => 'tr',
    'iturkmenistan'                             => 'tm',
    'iturksandcaicosislands'                    => 'tc',
    'ituvalu'                                   => 'tv',
    "iu\.s\.virginislands"                      => 'vi',
    'iuganda'                                   => 'ug',
    'iukraine'                                  => 'ua',
    'iunitedarabemirates'                       => 'ae',
    'iunitedkingdom'                            => 'gb',
    'iunitedstates'                             => 'us',
    'iuruguay'                                  => 'uy',
    'iuzbekistan'                               => 'uz',
    'ivanuatu'                                  => 'vu',
    'ivaticancity'                              => 'va',
    'ivenezuela'                                => 've',
    'ivietnam'                                  => 'vn',
    'iwallisnefutuna'                           => 'wf',
    'iwesternsahara'                            => 'eh',
    'iyemen'                                    => 'ye',
    'izambia'                                   => 'zm',
    'izimbabwe'                                 => 'zw',
    'iÅlandislands'                            => 'ax',
    'johnstonisland'                            => 'jt',
    'metropolitanfrance'                        => 'fx',
    'midwayislands'                             => 'mi',
    'neutralzone'                               => 'nt',
    'northvietnam'                              => 'vd',
    'pacificislandstrustterritory'              => 'pc',
    'panamacanalzone'                           => 'pz',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'serbiaandmontenegro'                       => 'cs',
    'southcentralasia'                          => '062',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'umhlaba'                                   => '001',
    'unionofsovietsocialistrepublics'           => 'su',
    'wakeisland'                                => 'wk',
);

1;

