package Locales::DB::Territory::fi;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::fi::VERSION = '0.09';

$Locales::DB::Territory::fi::cldr_version = '2.0';

%Locales::DB::Territory::fi::code_to_name = (
    '001' => 'maailma',
    '002' => 'Afrikka',
    '003' => "Pohjois\-Amerikka",
    '005' => "Etelä\-Amerikka",
    '009' => 'Oseania',
    '011' => "Länsi\-Afrikka",
    '013' => "Väli\-Amerikka",
    '014' => "Itä\-Afrikka",
    '015' => "Pohjois\-Afrikka",
    '017' => "Keski\-Afrikka",
    '018' => "eteläinen\ Afrikka",
    '019' => 'Amerikka',
    '021' => "pohjoinen\ Amerikka",
    '029' => 'Karibia',
    '030' => "Itä\-Aasia",
    '034' => "Etelä\-Aasia",
    '035' => "Kaakkois\-Aasia",
    '039' => "Etelä\-Eurooppa",
    '053' => "Australia\ ja\ Uusi\-Seelanti",
    '054' => 'Melanesia',
    '057' => 'Mikronesia',
    '061' => 'Polynesia',
    '062' => "Etelä\-\ ja\ Keski\-Aasia",
    142   => 'Aasia',
    143   => "Keski\-Aasia",
    145   => "Länsi\-Aasia",
    150   => 'Eurooppa',
    151   => "Itä\-Eurooppa",
    154   => "Pohjois\-Eurooppa",
    155   => "Länsi\-Eurooppa",
    172   => "Itsenäisten\ valtioiden\ yhteisö",
    200   => 'Czechoslovakia',
    419   => "Latinalainen\ Amerikka\ ja\ Karibia",
    830   => 'Kanaalisaaret',
    'ac'  => "Ascension\-saari",
    'ad'  => 'Andorra',
    'ae'  => 'Arabiemiirikunnat',
    'af'  => 'Afganistan',
    'ag'  => "Antigua\ ja\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Alankomaiden\ Antillit",
    'ao'  => 'Angola',
    'aq'  => 'Antarktis',
    'ar'  => 'Argentiina',
    'as'  => "Amerikan\ Samoa",
    'at'  => 'Itävalta',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => 'Ahvenanmaa',
    'az'  => 'Azerbaidžan',
    'ba'  => "Bosnia\ ja\ Hertsegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgia',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\-Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasilia',
    'bs'  => 'Bahama',
    'bt'  => 'Bhutan',
    'bv'  => 'Bouvet’nsaari',
    'bw'  => 'Botswana',
    'by'  => "Valko\-Venäjä",
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => 'Kookossaaret',
    'cd'  => "Kongo\-Kinshasa",
    'cf'  => "Keski\-Afrikan\ tasavalta",
    'cg'  => "Kongo\-Brazzaville",
    'ch'  => 'Sveitsi',
    'ci'  => "Côte\ d\'Ivoire",
    'ck'  => 'Cookinsaaret',
    'cl'  => 'Chile',
    'cm'  => 'Kamerun',
    'cn'  => 'Kiina',
    'co'  => 'Kolumbia',
    'cp'  => 'Clippertoninsaari',
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ ja\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuuba',
    'cv'  => "Kap\ Verde",
    'cx'  => 'Joulusaari',
    'cy'  => 'Kypros',
    'cz'  => 'Tšekki',
    'dd'  => "East\ Germany",
    'de'  => 'Saksa',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Tanska',
    'dm'  => 'Dominica',
    'do'  => "Dominikaaninen\ tasavalta",
    'dz'  => 'Algeria',
    'ea'  => "Ceuta\ ja\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Viro',
    'eg'  => 'Egypti',
    'eh'  => "Länsi\-Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Espanja',
    'et'  => 'Etiopia',
    'eu'  => 'EU',
    'fi'  => 'Suomi',
    'fj'  => 'Fidži',
    'fk'  => "Falklandinsaaret\ \[Malvinassaaret\]",
    'fm'  => "Mikronesian\ liittovaltio",
    'fo'  => 'Färsaaret',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Ranska',
    'fx'  => "Ranskan\ Eurooppaan\ kuuluvat\ osat",
    'ga'  => 'Gabon',
    'gb'  => 'Britannia',
    'gd'  => 'Grenada',
    'ge'  => 'Georgia',
    'gf'  => "Ranskan\ Guayana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grönlanti',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => "Päiväntasaajan\ Guinea",
    'gr'  => 'Kreikka',
    'gs'  => "Etelä\-Georgia\ ja\ Eteläiset\ Sandwichsaaret",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\-\ ja\ McDonaldinsaaret",
    'hn'  => 'Honduras',
    'hr'  => 'Kroatia',
    'ht'  => 'Haiti',
    'hu'  => 'Unkari',
    'ic'  => 'Kanariansaaret',
    'id'  => 'Indonesia',
    'ie'  => 'Irlanti',
    'il'  => 'Israel',
    'im'  => 'Mansaari',
    'in'  => 'Intia',
    'io'  => "Brittiläinen\ Intian\ valtameren\ alue",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Islanti',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordania',
    'jp'  => 'Japani',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirgisia',
    'kh'  => 'Kambodža',
    'ki'  => 'Kiribati',
    'km'  => 'Komorit',
    'kn'  => "Saint\ Kitts\ ja\ Nevis",
    'kp'  => "Pohjois\-Korea",
    'kr'  => "Etelä\-Korea",
    'kw'  => 'Kuwait',
    'ky'  => 'Caymansaaret',
    'kz'  => 'Kazakstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Liettua',
    'lu'  => 'Luxemburg',
    'lv'  => 'Latvia',
    'ly'  => 'Libya',
    'ma'  => 'Marokko',
    'mc'  => 'Monaco',
    'md'  => 'Moldova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\-Martin",
    'mg'  => 'Madagaskar',
    'mh'  => 'Marshallinsaaret',
    'mi'  => "Midway\ Islands",
    'mk'  => "EJT\ Makedonia",
    'ml'  => 'Mali',
    'mm'  => "Myanmar\ \[Burma\]",
    'mn'  => 'Mongolia',
    'mo'  => 'Macao',
    'mp'  => "Pohjois\-Mariaanit",
    'mq'  => 'Martinique',
    'mr'  => 'Mauritania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Malediivit',
    'mw'  => 'Malawi',
    'mx'  => 'Meksiko',
    'my'  => 'Malesia',
    'mz'  => 'Mosambik',
    'na'  => 'Namibia',
    'nc'  => "Uusi\-Kaledonia",
    'ne'  => 'Niger',
    'nf'  => 'Norfolkinsaari',
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Alankomaat',
    'no'  => 'Norja',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Uusi\-Seelanti",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Ranskan\ Polynesia",
    'pg'  => "Papua\-Uusi\-Guinea",
    'ph'  => 'Filippiinit',
    'pk'  => 'Pakistan',
    'pl'  => 'Puola',
    'pm'  => "Saint\-Pierre\ ja\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => 'Palestiina',
    'pt'  => 'Portugali',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => 'ulkomeri',
    're'  => 'Réunion',
    'ro'  => 'Romania',
    'rs'  => 'Serbia',
    'ru'  => 'Venäjä',
    'rw'  => 'Ruanda',
    'sa'  => "Saudi\-Arabia",
    'sb'  => 'Salomonsaaret',
    'sc'  => 'Seychellit',
    'sd'  => 'Sudan',
    'se'  => 'Ruotsi',
    'sg'  => 'Singapore',
    'sh'  => "Saint\ Helena",
    'si'  => 'Slovenia',
    'sj'  => "Huippuvuoret\ ja\ Jan\ Mayen",
    'sk'  => 'Slovakia',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "São\ Tomé\ ja\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Syyria',
    'sz'  => 'Swazimaa',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\-\ ja\ Caicossaaret",
    'td'  => 'Tšad',
    'tf'  => "Ranskan\ ulkopuoliset\ eteläiset\ alueet",
    'tg'  => 'Togo',
    'th'  => 'Thaimaa',
    'tj'  => 'Tadžikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\-Leste",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunisia',
    'to'  => 'Tonga',
    'tr'  => 'Turkki',
    'tt'  => "Trinidad\ ja\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tansania',
    'ua'  => 'Ukraina',
    'ug'  => 'Uganda',
    'um'  => "Yhdysvaltain\ pienet\ erillissaaret",
    'us'  => 'Yhdysvallat',
    'uy'  => 'Uruguay',
    'uz'  => 'Uzbekistan',
    'va'  => 'Vatikaani',
    'vc'  => "Saint\ Vincent\ ja\ Grenadiinit",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Brittiläiset\ Neitsytsaaret",
    'vi'  => "Yhdysvaltain\ Neitsytsaaret",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ ja\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => "Etelä\-Afrikka",
    'zm'  => 'Sambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "tuntematon\ tai\ virheellinen\ alue",
);

%Locales::DB::Territory::fi::name_to_code = (
    'aasia'                                     => 142,
    'afganistan'                                => 'af',
    'afrikka'                                   => '002',
    'ahvenanmaa'                                => 'ax',
    'alankomaat'                                => 'nl',
    'alankomaidenantillit'                      => 'an',
    'albania'                                   => 'al',
    'algeria'                                   => 'dz',
    'amerikansamoa'                             => 'as',
    'amerikka'                                  => '019',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarktis'                                 => 'aq',
    'antiguajabarbuda'                          => 'ag',
    'arabiemiirikunnat'                         => 'ae',
    'argentiina'                                => 'ar',
    'armenia'                                   => 'am',
    'aruba'                                     => 'aw',
    'ascensionsaari'                            => 'ac',
    'australia'                                 => 'au',
    'australiajauusiseelanti'                   => '053',
    'azerbaidžan'                              => 'az',
    'bahama'                                    => 'bs',
    'bahrain'                                   => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgia'                                    => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhutan'                                    => 'bt',
    'bolivia'                                   => 'bo',
    'bosniajahertsegovina'                      => 'ba',
    'botswana'                                  => 'bw',
    'bouvet’nsaari'                           => 'bv',
    'brasilia'                                  => 'br',
    'britannia'                                 => 'gb',
    'britishantarcticterritory'                 => 'bq',
    'brittiläinenintianvaltamerenalue'         => 'io',
    'brittiläisetneitsytsaaret'                => 'vg',
    'brunei'                                    => 'bn',
    'bulgaria'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'cantonandenderburyislands'                 => 'ct',
    'caymansaaret'                              => 'ky',
    'ceutajamelilla'                            => 'ea',
    'chile'                                     => 'cl',
    'clippertoninsaari'                         => 'cp',
    'cookinsaaret'                              => 'ck',
    'costarica'                                 => 'cr',
    'czechoslovakia'                            => 200,
    'côtedivoire'                              => 'ci',
    'diegogarcia'                               => 'dg',
    'djibouti'                                  => 'dj',
    'dominica'                                  => 'dm',
    'dominikaaninentasavalta'                   => 'do',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egypti'                                    => 'eg',
    'ejtmakedonia'                              => 'mk',
    'elsalvador'                                => 'sv',
    'eritrea'                                   => 'er',
    'espanja'                                   => 'es',
    'eteläaasia'                               => '034',
    'eteläafrikka'                             => 'za',
    'eteläamerikka'                            => '005',
    'eteläeurooppa'                            => '039',
    'etelägeorgiajaeteläisetsandwichsaaret'   => 'gs',
    'eteläinenafrikka'                         => '018',
    'eteläjakeskiaasia'                        => '062',
    'eteläkorea'                               => 'kr',
    'etiopia'                                   => 'et',
    'eu'                                        => 'eu',
    'eurooppa'                                  => 150,
    'falklandinsaaretmalvinassaaret'            => 'fk',
    'fidži'                                    => 'fj',
    'filippiinit'                               => 'ph',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'färsaaret'                                => 'fo',
    'gabon'                                     => 'ga',
    'gambia'                                    => 'gm',
    'georgia'                                   => 'ge',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'grenada'                                   => 'gd',
    'grönlanti'                                => 'gl',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guinea'                                    => 'gn',
    'guineabissau'                              => 'gw',
    'guyana'                                    => 'gy',
    'haiti'                                     => 'ht',
    'heardjamcdonaldinsaaret'                   => 'hm',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'huippuvuoretjajanmayen'                    => 'sj',
    'indonesia'                                 => 'id',
    'intia'                                     => 'in',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'irlanti'                                   => 'ie',
    'islanti'                                   => 'is',
    'israel'                                    => 'il',
    'italia'                                    => 'it',
    'itsenäistenvaltioidenyhteisö'            => 172,
    'itäaasia'                                 => '030',
    'itäafrikka'                               => '014',
    'itäeurooppa'                              => 151,
    'itävalta'                                 => 'at',
    'jamaika'                                   => 'jm',
    'japani'                                    => 'jp',
    'jemen'                                     => 'ye',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordania'                                  => 'jo',
    'joulusaari'                                => 'cx',
    'kaakkoisaasia'                             => '035',
    'kambodža'                                 => 'kh',
    'kamerun'                                   => 'cm',
    'kanaalisaaret'                             => 830,
    'kanada'                                    => 'ca',
    'kanariansaaret'                            => 'ic',
    'kapverde'                                  => 'cv',
    'karibia'                                   => '029',
    'kazakstan'                                 => 'kz',
    'kenia'                                     => 'ke',
    'keskiaasia'                                => 143,
    'keskiafrikantasavalta'                     => 'cf',
    'keskiafrikka'                              => '017',
    'kiina'                                     => 'cn',
    'kirgisia'                                  => 'kg',
    'kiribati'                                  => 'ki',
    'kolumbia'                                  => 'co',
    'komorit'                                   => 'km',
    'kongobrazzaville'                          => 'cg',
    'kongokinshasa'                             => 'cd',
    'kookossaaret'                              => 'cc',
    'kreikka'                                   => 'gr',
    'kroatia'                                   => 'hr',
    'kuuba'                                     => 'cu',
    'kuwait'                                    => 'kw',
    'kypros'                                    => 'cy',
    'laos'                                      => 'la',
    'latinalainenamerikkajakaribia'             => 419,
    'latvia'                                    => 'lv',
    'lesotho'                                   => 'ls',
    'libanon'                                   => 'lb',
    'liberia'                                   => 'lr',
    'libya'                                     => 'ly',
    'liechtenstein'                             => 'li',
    'liettua'                                   => 'lt',
    'luxemburg'                                 => 'lu',
    'länsiaasia'                               => 145,
    'länsiafrikka'                             => '011',
    'länsieurooppa'                            => 155,
    'länsisahara'                              => 'eh',
    'maailma'                                   => '001',
    'macao'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'malawi'                                    => 'mw',
    'malediivit'                                => 'mv',
    'malesia'                                   => 'my',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'mansaari'                                  => 'im',
    'marokko'                                   => 'ma',
    'marshallinsaaret'                          => 'mh',
    'martinique'                                => 'mq',
    'mauritania'                                => 'mr',
    'mauritius'                                 => 'mu',
    'mayotte'                                   => 'yt',
    'meksiko'                                   => 'mx',
    'melanesia'                                 => '054',
    'midwayislands'                             => 'mi',
    'mikronesia'                                => '057',
    'mikronesianliittovaltio'                   => 'fm',
    'moldova'                                   => 'md',
    'monaco'                                    => 'mc',
    'mongolia'                                  => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mosambik'                                  => 'mz',
    'myanmarburma'                              => 'mm',
    'namibia'                                   => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'niger'                                     => 'ne',
    'nigeria'                                   => 'ng',
    'niue'                                      => 'nu',
    'norfolkinsaari'                            => 'nf',
    'norja'                                     => 'no',
    'northvietnam'                              => 'vd',
    'oman'                                      => 'om',
    'oseania'                                   => '009',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'palestiina'                                => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuauusiguinea'                           => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'pohjoinenamerikka'                         => '021',
    'pohjoisafrikka'                            => '015',
    'pohjoisamerikka'                           => '003',
    'pohjoiseurooppa'                           => 154,
    'pohjoiskorea'                              => 'kp',
    'pohjoismariaanit'                          => 'mp',
    'polynesia'                                 => '061',
    'portugali'                                 => 'pt',
    'puertorico'                                => 'pr',
    'puola'                                     => 'pl',
    'päiväntasaajanguinea'                    => 'gq',
    'qatar'                                     => 'qa',
    'ranska'                                    => 'fr',
    'ranskaneurooppaankuuluvatosat'             => 'fx',
    'ranskanguayana'                            => 'gf',
    'ranskanpolynesia'                          => 'pf',
    'ranskanulkopuoliseteteläisetalueet'       => 'tf',
    'romania'                                   => 'ro',
    'ruanda'                                    => 'rw',
    'ruotsi'                                    => 'se',
    'réunion'                                  => 're',
    'saintbarthélemy'                          => 'bl',
    'sainthelena'                               => 'sh',
    'saintkittsjanevis'                         => 'kn',
    'saintlucia'                                => 'lc',
    'saintmartin'                               => 'mf',
    'saintpierrejamiquelon'                     => 'pm',
    'saintvincentjagrenadiinit'                 => 'vc',
    'saksa'                                     => 'de',
    'salomonsaaret'                             => 'sb',
    'sambia'                                    => 'zm',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saudiarabia'                               => 'sa',
    'senegal'                                   => 'sn',
    'serbia'                                    => 'rs',
    'serbiajamontenegro'                        => 'cs',
    'seychellit'                                => 'sc',
    'sierraleone'                               => 'sl',
    'singapore'                                 => 'sg',
    'slovakia'                                  => 'sk',
    'slovenia'                                  => 'si',
    'somalia'                                   => 'so',
    'srilanka'                                  => 'lk',
    'sudan'                                     => 'sd',
    'suomi'                                     => 'fi',
    'surinam'                                   => 'sr',
    'sveitsi'                                   => 'ch',
    'swazimaa'                                  => 'sz',
    'syyria'                                    => 'sy',
    'sãotoméjapríncipe'                      => 'st',
    'tadžikistan'                              => 'tj',
    'taiwan'                                    => 'tw',
    'tansania'                                  => 'tz',
    'tanska'                                    => 'dk',
    'thaimaa'                                   => 'th',
    'timorleste'                                => 'tl',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadjatobago'                          => 'tt',
    'tristandacunha'                            => 'ta',
    'tunisia'                                   => 'tn',
    'tuntematontaivirheellinenalue'             => 'zz',
    'turkki'                                    => 'tr',
    'turkmenistan'                              => 'tm',
    'turksjacaicossaaret'                       => 'tc',
    'tuvalu'                                    => 'tv',
    'tšad'                                     => 'td',
    'tšekki'                                   => 'cz',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukraina'                                   => 'ua',
    'ulkomeri'                                  => 'qo',
    'unionofsovietsocialistrepublics'           => 'su',
    'unkari'                                    => 'hu',
    'uruguay'                                   => 'uy',
    'uusikaledonia'                             => 'nc',
    'uusiseelanti'                              => 'nz',
    'uzbekistan'                                => 'uz',
    'valkovenäjä'                             => 'by',
    'vanuatu'                                   => 'vu',
    'vatikaani'                                 => 'va',
    'venezuela'                                 => 've',
    'venäjä'                                  => 'ru',
    'vietnam'                                   => 'vn',
    'viro'                                      => 'ee',
    'väliamerikka'                             => '013',
    'wakeisland'                                => 'wk',
    'wallisjafutuna'                            => 'wf',
    'yhdysvallat'                               => 'us',
    'yhdysvaltainneitsytsaaret'                 => 'vi',
    'yhdysvaltainpieneterillissaaret'           => 'um',
    'zimbabwe'                                  => 'zw',
);

1;

