package Locales::DB::Territory::et;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::et::VERSION = '0.09';

$Locales::DB::Territory::et::cldr_version = '2.0';

%Locales::DB::Territory::et::code_to_name = (
    '001' => 'maailm',
    '002' => 'Aafrika',
    '003' => "Põhja\-Ameerika",
    '005' => "Lõuna\-Ameerika",
    '009' => 'Okeaania',
    '011' => "Lääne\-Aafrika",
    '013' => "Kesk\-Ameerika",
    '014' => "Ida\-Aafrika",
    '015' => "Põhja\-Aafrika",
    '017' => "Kesk\-Aafrika",
    '018' => "Lõuna\-Aafrika",
    '019' => "Ameerika\ maailmajagu",
    '021' => "Ameerika\ põhjaosa",
    '029' => "Kariibi\ meri",
    '030' => "Ida\-Aasia",
    '034' => "Lõuna\-Aasia",
    '035' => "Kagu\-Aasia",
    '039' => "Lõuna\-Euroopa",
    '053' => "Austraalia\ ja\ Uus\-Meremaa",
    '054' => 'Melaneesia',
    '057' => 'Mikroneesia',
    '061' => 'Polüneesia',
    '062' => "Kesk\-Aasia\ lõunaosa",
    142   => 'Aasia',
    143   => "Kesk\-Aasia",
    145   => "Lääne\-Aasia",
    150   => 'Euroopa',
    151   => "Ida\-Euroopa",
    154   => "Põhja\-Euroopa",
    155   => "Lääne\-Euroopa",
    172   => "Sõltumatute\ Riikide\ Ühendus",
    200   => 'Czechoslovakia',
    419   => "Ladina\-Ameerika\ ja\ Kariibi\ meri",
    830   => "Channel\ Islands",
    'ac'  => "Ascensioni\ saar",
    'ad'  => 'Andorra',
    'ae'  => "Araabia\ Ühendemiraadid",
    'af'  => 'Afganistan',
    'ag'  => "Antigua\ ja\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albaania',
    'am'  => 'Armeenia',
    'an'  => "Hollandi\ Antillid",
    'ao'  => 'Angola',
    'aq'  => 'Antarktis',
    'ar'  => 'Argentina',
    'as'  => "Ameerika\ Samoa",
    'at'  => 'Austria',
    'au'  => 'Austraalia',
    'aw'  => 'Aruba',
    'ax'  => 'Ahvenamaa',
    'az'  => 'Aserbaidžaan',
    'ba'  => "Bosnia\ ja\ Hertsegoviina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgia',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaaria',
    'bh'  => 'Bahrein',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Boliivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasiilia',
    'bs'  => 'Bahama',
    'bt'  => 'Bhutan',
    'bv'  => "Bouvet’\ saar",
    'bw'  => 'Botswana',
    'by'  => 'Valgevene',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => 'Kookossaared',
    'cd'  => "Kongo\-Kinshasa",
    'cf'  => "Kesk\-Aafrika\ Vabariik",
    'cg'  => "Kongo\-Brazzaville",
    'ch'  => 'Šveits',
    'ci'  => 'Elevandiluurannik',
    'ck'  => "Cooki\ saared",
    'cl'  => 'Tšiili',
    'cm'  => 'Kamerun',
    'cn'  => 'Hiina',
    'co'  => 'Colombia',
    'cp'  => "Clippertoni\ saar",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ ja\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuuba',
    'cv'  => 'Roheneemesaared',
    'cx'  => 'Jõulusaar',
    'cy'  => 'Küpros',
    'cz'  => 'Tšehhi',
    'dd'  => "East\ Germany",
    'de'  => 'Saksamaa',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Taani',
    'dm'  => 'Dominica',
    'do'  => "Dominikaani\ Vabariik",
    'dz'  => 'Alžeeria',
    'ea'  => "Ceuta\ ja\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Eesti',
    'eg'  => 'Egiptus',
    'eh'  => "Lääne\-Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Hispaania',
    'et'  => 'Etioopia',
    'eu'  => "Euroopa\ Liit",
    'fi'  => 'Soome',
    'fj'  => 'Fidži',
    'fk'  => "Falklandi\ saared",
    'fm'  => "Mikroneesia\ Liiduriigid",
    'fo'  => "Fääri\ saared",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Prantsusmaa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => 'Suurbritannia',
    'gd'  => 'Grenada',
    'ge'  => 'Gruusia',
    'gf'  => "Prantsuse\ Guajaana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Gröönimaa',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => "Ekvatoriaal\-Guinea",
    'gr'  => 'Kreeka',
    'gs'  => "Lõuna\-Georgia\ ja\ Lõuna\-Sandwichi\ saared",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\ ja\ McDonald\ saared",
    'hn'  => 'Honduras',
    'hr'  => 'Horvaatia',
    'ht'  => 'Haiti',
    'hu'  => 'Ungari',
    'ic'  => "Kanaari\ saared",
    'id'  => 'Indoneesia',
    'ie'  => 'Iirimaa',
    'il'  => 'Iisrael',
    'im'  => "Mani\ saar",
    'in'  => 'India',
    'io'  => "Briti\ India\ ookeani\ ala",
    'iq'  => 'Iraak',
    'ir'  => 'Iraan',
    'is'  => 'Island',
    'it'  => 'Itaalia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordaania',
    'jp'  => 'Jaapan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kõrgõzstan',
    'kh'  => 'Kambodža',
    'ki'  => 'Kiribati',
    'km'  => 'Komoorid',
    'kn'  => "Saint\ Kitts\ ja\ Nevis",
    'kp'  => "Põhja\-Korea",
    'kr'  => "Lõuna\-Korea",
    'kw'  => 'Kuveit',
    'ky'  => 'Kaimanisaared',
    'kz'  => 'Kasahstan',
    'la'  => 'Laos',
    'lb'  => 'Liibanon',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Libeeria',
    'ls'  => 'Lesotho',
    'lt'  => 'Leedu',
    'lu'  => 'Luksemburg',
    'lv'  => 'Läti',
    'ly'  => 'Liibüa',
    'ma'  => 'Maroko',
    'mc'  => 'Monaco',
    'md'  => 'Moldova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Marshalli\ saared",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Makedoonia',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongoolia',
    'mo'  => 'Aomen',
    'mp'  => "Põhja\-Mariaanid",
    'mq'  => 'Martinique',
    'mr'  => 'Mauritaania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Maldiivid',
    'mw'  => 'Malawi',
    'mx'  => 'Mehhiko',
    'my'  => 'Malaisia',
    'mz'  => 'Mosambiik',
    'na'  => 'Namiibia',
    'nc'  => "Uus\-Kaledoonia",
    'ne'  => 'Niger',
    'nf'  => 'Norfolk',
    'ng'  => 'Nigeeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Holland',
    'no'  => 'Norra',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Uus\-Meremaa",
    'om'  => 'Omaan',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peruu',
    'pf'  => "Prantsuse\ Polüneesia",
    'pg'  => "Paapua\ Uus\-Guinea",
    'ph'  => 'Filipiinid',
    'pk'  => 'Pakistan',
    'pl'  => 'Poola',
    'pm'  => "Saint\ Pierre\ ja\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Palestiina\ ala",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Belau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Okeaania\ hajasaared",
    're'  => 'Réunion',
    'ro'  => 'Rumeenia',
    'rs'  => 'Serbia',
    'ru'  => 'Venemaa',
    'rw'  => 'Rwanda',
    'sa'  => "Saudi\ Araabia",
    'sb'  => "Saalomoni\ Saared",
    'sc'  => 'Seišellid',
    'sd'  => 'Sudaan',
    'se'  => 'Rootsi',
    'sg'  => 'Singapur',
    'sh'  => "Saint\ Helena",
    'si'  => 'Sloveenia',
    'sj'  => "Svalbard\ ja\ Jan\ Mayen",
    'sk'  => 'Slovakkia',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somaalia',
    'sr'  => 'Suriname',
    'st'  => "São\ Tomé\ ja\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Süüria',
    'sz'  => 'Svaasimaa',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ ja\ Caicos",
    'td'  => 'Tšaad',
    'tf'  => "Prantsuse\ Lõunaalad",
    'tg'  => 'Togo',
    'th'  => 'Tai',
    'tj'  => 'Tadžikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Ida\-Timor",
    'tm'  => 'Türkmenistan',
    'tn'  => 'Tuneesia',
    'to'  => 'Tonga',
    'tr'  => 'Türgi',
    'tt'  => "Trinidad\ ja\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tansaania',
    'ua'  => 'Ukraina',
    'ug'  => 'Uganda',
    'um'  => "Ühendriikide\ hajasaared",
    'us'  => "Ameerika\ Ühendriigid",
    'uy'  => 'Uruguay',
    'uz'  => 'Usbekistan',
    'va'  => 'Vatikan',
    'vc'  => "Saint\ Vincent\ ja\ Grenadiinid",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Briti\ Neitsisaared",
    'vi'  => "USA\ Neitsisaared",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ ja\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jeemen',
    'yt'  => 'Mayotte',
    'za'  => "Lõuna\-Aafrika\ Vabariik",
    'zm'  => 'Sambia',
    'zw'  => 'Zimbabwe',
    'zz'  => 'määramata',
);

%Locales::DB::Territory::et::name_to_code = (
    'aafrika'                                   => '002',
    'aasia'                                     => 142,
    'afganistan'                                => 'af',
    'ahvenamaa'                                 => 'ax',
    'albaania'                                  => 'al',
    'alžeeria'                                 => 'dz',
    'ameerikamaailmajagu'                       => '019',
    'ameerikapõhjaosa'                         => '021',
    'ameerikasamoa'                             => 'as',
    'ameerikaÜhendriigid'                      => 'us',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarktis'                                 => 'aq',
    'antiguajabarbuda'                          => 'ag',
    'aomen'                                     => 'mo',
    'araabiaÜhendemiraadid'                    => 'ae',
    'argentina'                                 => 'ar',
    'armeenia'                                  => 'am',
    'aruba'                                     => 'aw',
    'ascensionisaar'                            => 'ac',
    'aserbaidžaan'                             => 'az',
    'austraalia'                                => 'au',
    'austraaliajauusmeremaa'                    => '053',
    'austria'                                   => 'at',
    'bahama'                                    => 'bs',
    'bahrein'                                   => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'belau'                                     => 'pw',
    'belgia'                                    => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhutan'                                    => 'bt',
    'boliivia'                                  => 'bo',
    'bosniajahertsegoviina'                     => 'ba',
    'botswana'                                  => 'bw',
    'bouvet’saar'                             => 'bv',
    'brasiilia'                                 => 'br',
    'britiindiaookeaniala'                      => 'io',
    'britineitsisaared'                         => 'vg',
    'britishantarcticterritory'                 => 'bq',
    'brunei'                                    => 'bn',
    'bulgaaria'                                 => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'cantonandenderburyislands'                 => 'ct',
    'ceutajamelilla'                            => 'ea',
    'channelislands'                            => 830,
    'clippertonisaar'                           => 'cp',
    'colombia'                                  => 'co',
    'cookisaared'                               => 'ck',
    'costarica'                                 => 'cr',
    'czechoslovakia'                            => 200,
    'diegogarcia'                               => 'dg',
    'djibouti'                                  => 'dj',
    'dominica'                                  => 'dm',
    'dominikaanivabariik'                       => 'do',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'eesti'                                     => 'ee',
    'egiptus'                                   => 'eg',
    'ekvatoriaalguinea'                         => 'gq',
    'elevandiluurannik'                         => 'ci',
    'elsalvador'                                => 'sv',
    'eritrea'                                   => 'er',
    'etioopia'                                  => 'et',
    'euroopa'                                   => 150,
    'euroopaliit'                               => 'eu',
    'falklandisaared'                           => 'fk',
    'fidži'                                    => 'fj',
    'filipiinid'                                => 'ph',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'fäärisaared'                             => 'fo',
    'gabon'                                     => 'ga',
    'gambia'                                    => 'gm',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'grenada'                                   => 'gd',
    'gruusia'                                   => 'ge',
    'gröönimaa'                               => 'gl',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guinea'                                    => 'gn',
    'guineabissau'                              => 'gw',
    'guyana'                                    => 'gy',
    'haiti'                                     => 'ht',
    'heardjamcdonaldsaared'                     => 'hm',
    'hiina'                                     => 'cn',
    'hispaania'                                 => 'es',
    'holland'                                   => 'nl',
    'hollandiantillid'                          => 'an',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'horvaatia'                                 => 'hr',
    'idaaafrika'                                => '014',
    'idaaasia'                                  => '030',
    'idaeuroopa'                                => 151,
    'idatimor'                                  => 'tl',
    'iirimaa'                                   => 'ie',
    'iisrael'                                   => 'il',
    'india'                                     => 'in',
    'indoneesia'                                => 'id',
    'iraak'                                     => 'iq',
    'iraan'                                     => 'ir',
    'island'                                    => 'is',
    'itaalia'                                   => 'it',
    'jaapan'                                    => 'jp',
    'jamaica'                                   => 'jm',
    'jeemen'                                    => 'ye',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordaania'                                 => 'jo',
    'jõulusaar'                                => 'cx',
    'kaguaasia'                                 => '035',
    'kaimanisaared'                             => 'ky',
    'kambodža'                                 => 'kh',
    'kamerun'                                   => 'cm',
    'kanaarisaared'                             => 'ic',
    'kanada'                                    => 'ca',
    'kariibimeri'                               => '029',
    'kasahstan'                                 => 'kz',
    'katar'                                     => 'qa',
    'kenya'                                     => 'ke',
    'keskaafrika'                               => '017',
    'keskaafrikavabariik'                       => 'cf',
    'keskaasia'                                 => 143,
    'keskaasialõunaosa'                        => '062',
    'keskameerika'                              => '013',
    'kiribati'                                  => 'ki',
    'komoorid'                                  => 'km',
    'kongobrazzaville'                          => 'cg',
    'kongokinshasa'                             => 'cd',
    'kookossaared'                              => 'cc',
    'kreeka'                                    => 'gr',
    'kuuba'                                     => 'cu',
    'kuveit'                                    => 'kw',
    'kõrgõzstan'                              => 'kg',
    'küpros'                                   => 'cy',
    'ladinaameerikajakariibimeri'               => 419,
    'laos'                                      => 'la',
    'leedu'                                     => 'lt',
    'lesotho'                                   => 'ls',
    'libeeria'                                  => 'lr',
    'liechtenstein'                             => 'li',
    'liibanon'                                  => 'lb',
    'liibüa'                                   => 'ly',
    'luksemburg'                                => 'lu',
    'läti'                                     => 'lv',
    'lääneaafrika'                            => '011',
    'lääneaasia'                              => 145,
    'lääneeuroopa'                            => 155,
    'läänesahara'                             => 'eh',
    'lõunaaafrika'                             => '018',
    'lõunaaafrikavabariik'                     => 'za',
    'lõunaaasia'                               => '034',
    'lõunaameerika'                            => '005',
    'lõunaeuroopa'                             => '039',
    'lõunageorgiajalõunasandwichisaared'      => 'gs',
    'lõunakorea'                               => 'kr',
    'maailm'                                    => '001',
    'madagaskar'                                => 'mg',
    'makedoonia'                                => 'mk',
    'malaisia'                                  => 'my',
    'malawi'                                    => 'mw',
    'maldiivid'                                 => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'manisaar'                                  => 'im',
    'maroko'                                    => 'ma',
    'marshallisaared'                           => 'mh',
    'martinique'                                => 'mq',
    'mauritaania'                               => 'mr',
    'mauritius'                                 => 'mu',
    'mayotte'                                   => 'yt',
    'mehhiko'                                   => 'mx',
    'melaneesia'                                => '054',
    'metropolitanfrance'                        => 'fx',
    'midwayislands'                             => 'mi',
    'mikroneesia'                               => '057',
    'mikroneesialiiduriigid'                    => 'fm',
    'moldova'                                   => 'md',
    'monaco'                                    => 'mc',
    'mongoolia'                                 => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mosambiik'                                 => 'mz',
    'myanmar'                                   => 'mm',
    'määramata'                               => 'zz',
    'namiibia'                                  => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'nigeeria'                                  => 'ng',
    'niger'                                     => 'ne',
    'niue'                                      => 'nu',
    'norfolk'                                   => 'nf',
    'norra'                                     => 'no',
    'northvietnam'                              => 'vd',
    'okeaania'                                  => '009',
    'okeaaniahajasaared'                        => 'qo',
    'omaan'                                     => 'om',
    'paapuauusguinea'                           => 'pg',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palestiinaala'                             => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peruu'                                     => 'pe',
    'pitcairn'                                  => 'pn',
    'polüneesia'                               => '061',
    'poola'                                     => 'pl',
    'portugal'                                  => 'pt',
    'prantsuseguajaana'                         => 'gf',
    'prantsuselõunaalad'                       => 'tf',
    'prantsusepolüneesia'                      => 'pf',
    'prantsusmaa'                               => 'fr',
    'puertorico'                                => 'pr',
    'põhjaaafrika'                             => '015',
    'põhjaameerika'                            => '003',
    'põhjaeuroopa'                             => 154,
    'põhjakorea'                               => 'kp',
    'põhjamariaanid'                           => 'mp',
    'roheneemesaared'                           => 'cv',
    'rootsi'                                    => 'se',
    'rumeenia'                                  => 'ro',
    'rwanda'                                    => 'rw',
    'réunion'                                  => 're',
    'saalomonisaared'                           => 'sb',
    'saintbarthélemy'                          => 'bl',
    'sainthelena'                               => 'sh',
    'saintkittsjanevis'                         => 'kn',
    'saintlucia'                                => 'lc',
    'saintmartin'                               => 'mf',
    'saintpierrejamiquelon'                     => 'pm',
    'saintvincentjagrenadiinid'                 => 'vc',
    'saksamaa'                                  => 'de',
    'sambia'                                    => 'zm',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saudiaraabia'                              => 'sa',
    'seišellid'                                => 'sc',
    'senegal'                                   => 'sn',
    'serbia'                                    => 'rs',
    'serbiajamontenegro'                        => 'cs',
    'sierraleone'                               => 'sl',
    'singapur'                                  => 'sg',
    'slovakkia'                                 => 'sk',
    'sloveenia'                                 => 'si',
    'somaalia'                                  => 'so',
    'soome'                                     => 'fi',
    'srilanka'                                  => 'lk',
    'sudaan'                                    => 'sd',
    'suriname'                                  => 'sr',
    'suurbritannia'                             => 'gb',
    'svaasimaa'                                 => 'sz',
    'svalbardjajanmayen'                        => 'sj',
    'sãotoméjapríncipe'                      => 'st',
    'sõltumatuteriikideÜhendus'               => 172,
    'süüria'                                  => 'sy',
    'taani'                                     => 'dk',
    'tadžikistan'                              => 'tj',
    'tai'                                       => 'th',
    'taiwan'                                    => 'tw',
    'tansaania'                                 => 'tz',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadjatobago'                          => 'tt',
    'tristandacunha'                            => 'ta',
    'tuneesia'                                  => 'tn',
    'turksjacaicos'                             => 'tc',
    'tuvalu'                                    => 'tv',
    'türgi'                                    => 'tr',
    'türkmenistan'                             => 'tm',
    'tšaad'                                    => 'td',
    'tšehhi'                                   => 'cz',
    'tšiili'                                   => 'cl',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukraina'                                   => 'ua',
    'ungari'                                    => 'hu',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    'usaneitsisaared'                           => 'vi',
    'usbekistan'                                => 'uz',
    'uuskaledoonia'                             => 'nc',
    'uusmeremaa'                                => 'nz',
    'valgevene'                                 => 'by',
    'vanuatu'                                   => 'vu',
    'vatikan'                                   => 'va',
    'venemaa'                                   => 'ru',
    'venezuela'                                 => 've',
    'vietnam'                                   => 'vn',
    'wakeisland'                                => 'wk',
    'wallisjafutuna'                            => 'wf',
    'zimbabwe'                                  => 'zw',
    'Ühendriikidehajasaared'                   => 'um',
    'Šveits'                                   => 'ch',
);

1;

