package Locales::DB::Territory::eo;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::eo::VERSION = '0.09';

$Locales::DB::Territory::eo::cldr_version = '2.0';

%Locales::DB::Territory::eo::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andoro',
    'ae'  => "Unuiĝintaj\ Arabaj\ Emirlandos",
    'af'  => 'Afganujo',
    'ag'  => "Antigvo\-Barbudo",
    'ai'  => 'Angvilo',
    'al'  => 'Albanujo',
    'am'  => 'Armenujo',
    'an'  => "Nederlandaj\ Antiloj",
    'ao'  => 'Angolo',
    'aq'  => 'Antarkto',
    'ar'  => 'Argentino',
    'as'  => "American\ Samoa",
    'at'  => 'Aŭstrujo',
    'au'  => 'Aŭstralio',
    'aw'  => 'Arubo',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerbajĝano',
    'ba'  => "Bosnio\-Hercegovino",
    'bb'  => 'Barbado',
    'bd'  => 'Bangladeŝo',
    'be'  => 'Belgujo',
    'bf'  => 'Burkino',
    'bg'  => 'Bulgarujo',
    'bh'  => 'Barejno',
    'bi'  => 'Burundo',
    'bj'  => 'Benino',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermudoj',
    'bn'  => 'Brunejo',
    'bo'  => 'Bolivio',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazilo',
    'bs'  => 'Bahamoj',
    'bt'  => 'Butano',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Bocvano',
    'by'  => 'Belorusujo',
    'bz'  => 'Belizo',
    'ca'  => 'Kanado',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Congo\ \[DRC\]",
    'cf'  => "Centr\-Afrika\ Respubliko",
    'cg'  => 'Kongolo',
    'ch'  => 'Svisujo',
    'ci'  => "Ebur\-Bordo",
    'ck'  => 'Kukinsuloj',
    'cl'  => 'Ĉilio',
    'cm'  => 'Kameruno',
    'cn'  => 'Ĉinujo',
    'co'  => 'Kolombio',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kostariko',
    'cs'  => 'Serbujo',
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kubo',
    'cv'  => "Kabo\-Verdo",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Kipro',
    'cz'  => 'Ĉeĥujo',
    'dd'  => "East\ Germany",
    'de'  => 'Germanujo',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Ĝibutio',
    'dk'  => 'Danujo',
    'dm'  => 'Dominiko',
    'do'  => 'Domingo',
    'dz'  => 'Alĝerio',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekvadoro',
    'ee'  => 'Estonujo',
    'eg'  => 'Egipto',
    'eh'  => "Okcidenta\ Saharo",
    'er'  => 'Eritreo',
    'es'  => 'Hispanujo',
    'et'  => 'Etiopujo',
    'eu'  => "European\ Union",
    'fi'  => 'Finnlando',
    'fj'  => 'Fiĝoj',
    'fk'  => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm'  => 'Mikronezio',
    'fo'  => 'Ferooj',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Francujo',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabono',
    'gb'  => "Unuiĝinta\ Reĝlando",
    'gd'  => 'Grenado',
    'ge'  => 'Kartvelujo',
    'gf'  => "Franca\ Gviano",
    'gg'  => 'Guernsey',
    'gh'  => 'Ganao',
    'gi'  => 'Ĝibraltaro',
    'gl'  => 'Gronlando',
    'gm'  => 'Gambio',
    'gn'  => 'Gvineo',
    'gp'  => 'Gvadelupo',
    'gq'  => "Ekvatora\ Gvineo",
    'gr'  => 'Grekujo',
    'gs'  => "Sud\-Georgio\ kaj\ Sud\-Sandviĉinsuloj",
    'gt'  => 'Gvatemalo',
    'gu'  => 'Gvamo',
    'gw'  => "Gvineo\-Bisaŭo",
    'gy'  => 'Gujano',
    'hk'  => "Hong\ Kong",
    'hm'  => "Herda\ kaj\ Makdonaldaj\ Insuloj",
    'hn'  => 'Honduro',
    'hr'  => 'Kroatujo',
    'ht'  => 'Haitio',
    'hu'  => 'Hungarujo',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonezio',
    'ie'  => 'Irlando',
    'il'  => 'Israelo',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Hindujo',
    'io'  => "Brita\ Hindoceana\ Teritorio",
    'iq'  => 'Irako',
    'ir'  => 'Irano',
    'is'  => 'Islando',
    'it'  => 'Italujo',
    'je'  => 'Jersey',
    'jm'  => 'Jamajko',
    'jo'  => 'Jordanio',
    'jp'  => 'Japanujo',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenjo',
    'kg'  => 'Kirgizistano',
    'kh'  => 'Kamboĝo',
    'ki'  => 'Kiribato',
    'km'  => 'Komoroj',
    'kn'  => "Sent\-Kristofo\ kaj\ Neviso",
    'kp'  => "Nord\-Koreo",
    'kr'  => "Sud\-Koreo",
    'kw'  => 'Kuvajto',
    'ky'  => 'Kejmanoj',
    'kz'  => 'Kazaĥstano',
    'la'  => 'Laoso',
    'lb'  => 'Libano',
    'lc'  => "Sent\-Lucio",
    'li'  => 'Liĥtenŝtejno',
    'lk'  => "Sri\-Lanko",
    'lr'  => 'Liberio',
    'ls'  => 'Lesoto',
    'lt'  => 'Litovujo',
    'lu'  => 'Luksemburgo',
    'lv'  => 'Latvujo',
    'ly'  => 'Libio',
    'ma'  => 'Maroko',
    'mc'  => 'Monako',
    'md'  => 'Moldavujo',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskaro',
    'mh'  => 'Marŝaloj',
    'mi'  => "Midway\ Islands",
    'mk'  => 'Makedonujo',
    'ml'  => 'Malio',
    'mm'  => 'Mjanmao',
    'mn'  => 'Mongolujo',
    'mo'  => 'Macau',
    'mp'  => "Nord\-Marianoj",
    'mq'  => 'Martiniko',
    'mr'  => 'Maŭritanujo',
    'ms'  => 'Montserrat',
    'mt'  => 'Malto',
    'mu'  => 'Maŭricio',
    'mv'  => 'Maldivoj',
    'mw'  => 'Malavio',
    'mx'  => 'Meksiko',
    'my'  => 'Malajzio',
    'mz'  => 'Mozambiko',
    'na'  => 'Namibio',
    'nc'  => "Nov\-Kaledonio",
    'ne'  => 'Niĝero',
    'nf'  => 'Norfolkinsulo',
    'ng'  => 'Niĝerio',
    'ni'  => 'Nikaragvo',
    'nl'  => 'Nederlando',
    'no'  => 'Norvegujo',
    'np'  => 'Nepalo',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauro',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niuo',
    'nz'  => "Nov\-Zelando",
    'om'  => 'Omano',
    'pa'  => 'Panamo',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peruo',
    'pf'  => "Franca\ Polinezio",
    'pg'  => "Papuo\-Nov\-Gvineo",
    'ph'  => 'Filipinoj',
    'pk'  => 'Pakistano',
    'pl'  => 'Pollando',
    'pm'  => "Sent\-Piero\ kaj\ Mikelono",
    'pn'  => "Pitkarna\ Insulo",
    'pr'  => "Puerto\-Riko",
    'ps'  => "Palestinian\ Territories",
    'pt'  => 'Portugalujo',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Belaŭo',
    'py'  => 'Paragvajo',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Kataro',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Reunio',
    'ro'  => 'Rumanujo',
    'rs'  => 'Serbia',
    'ru'  => 'Rusujo',
    'rw'  => 'Ruando',
    'sa'  => "Saŭda\ Arabujo",
    'sb'  => 'Salomonoj',
    'sc'  => 'Sejŝeloj',
    'sd'  => 'Sudano',
    'se'  => 'Svedujo',
    'sg'  => 'Singapuro',
    'sh'  => "Sent\-Heleno",
    'si'  => 'Slovenujo',
    'sj'  => "Svalbardo\ kaj\ Jan\-Majen\-insulo",
    'sk'  => 'Slovakujo',
    'sl'  => "Siera\-Leono",
    'sm'  => "San\-Marino",
    'sn'  => 'Senegalo',
    'so'  => 'Somalujo',
    'sr'  => 'Surinamo',
    'st'  => "Sao\-Tomeo\ kaj\ Principeo",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvadoro',
    'sy'  => 'Sirio',
    'sz'  => 'Svazilando',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ and\ Caicos\ Islands",
    'td'  => 'Ĉado',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togolo',
    'th'  => 'Tajlando',
    'tj'  => 'Taĝikujo',
    'tk'  => 'Tokelau',
    'tl'  => "East\ Timor",
    'tm'  => 'Turkmenujo',
    'tn'  => 'Tunizio',
    'to'  => 'Tongo',
    'tr'  => 'Turkujo',
    'tt'  => "Trinidado\ kaj\ Tobago",
    'tv'  => 'Tuvalo',
    'tw'  => 'Tajvano',
    'tz'  => 'Tanzanio',
    'ua'  => 'Ukrajno',
    'ug'  => 'Ugando',
    'um'  => "Usonaj\ malgrandaj\ insuloj",
    'us'  => 'Usono',
    'uy'  => 'Urugvajo',
    'uz'  => 'Uzbekujo',
    'va'  => 'Vatikano',
    'vc'  => "Sent\-Vincento\ kaj\ la\ Grenadinoj",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuelo',
    'vg'  => "Britaj\ Virgulininsuloj",
    'vi'  => "Usonaj\ Virgulininsuloj",
    'vn'  => 'Vjetnamo',
    'vu'  => 'Vanuatuo',
    'wf'  => "Valiso\ kaj\ Futuno",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoo',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemeno',
    'yt'  => 'Majoto',
    'za'  => "Sud\-Afriko",
    'zm'  => 'Zambio',
    'zw'  => 'Zimbabvo',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::eo::name_to_code = (
    'afganujo'                                  => 'af',
    'africa'                                    => '002',
    'albanujo'                                  => 'al',
    'alĝerio'                                  => 'dz',
    'americansamoa'                             => 'as',
    'americas'                                  => '019',
    'andoro'                                    => 'ad',
    'angolo'                                    => 'ao',
    'angvilo'                                   => 'ai',
    'antarkto'                                  => 'aq',
    'antigvobarbudo'                            => 'ag',
    'argentino'                                 => 'ar',
    'armenujo'                                  => 'am',
    'arubo'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'azerbajĝano'                              => 'az',
    'aŭstralio'                                => 'au',
    'aŭstrujo'                                 => 'at',
    'bahamoj'                                   => 'bs',
    'bangladeŝo'                               => 'bd',
    'barbado'                                   => 'bb',
    'barejno'                                   => 'bh',
    'belaŭo'                                   => 'pw',
    'belgujo'                                   => 'be',
    'belizo'                                    => 'bz',
    'belorusujo'                                => 'by',
    'benino'                                    => 'bj',
    'bermudoj'                                  => 'bm',
    'bocvano'                                   => 'bw',
    'bolivio'                                   => 'bo',
    'bosniohercegovino'                         => 'ba',
    'bouvetisland'                              => 'bv',
    'brazilo'                                   => 'br',
    'britahindoceanateritorio'                  => 'io',
    'britajvirgulininsuloj'                     => 'vg',
    'britishantarcticterritory'                 => 'bq',
    'brunejo'                                   => 'bn',
    'bulgarujo'                                 => 'bg',
    'burkino'                                   => 'bf',
    'burundo'                                   => 'bi',
    'butano'                                    => 'bt',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centrafrikarespubliko'                     => 'cf',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'congodrc'                                  => 'cd',
    'czechoslovakia'                            => 200,
    'danujo'                                    => 'dk',
    'diegogarcia'                               => 'dg',
    'domingo'                                   => 'do',
    'dominiko'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'easttimor'                                 => 'tl',
    'eburbordo'                                 => 'ci',
    'egipto'                                    => 'eg',
    'ekvadoro'                                  => 'ec',
    'ekvatoragvineo'                            => 'gq',
    'eritreo'                                   => 'er',
    'estonujo'                                  => 'ee',
    'etiopujo'                                  => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'falklandislandsislasmalvinas'              => 'fk',
    'ferooj'                                    => 'fo',
    'filipinoj'                                 => 'ph',
    'finnlando'                                 => 'fi',
    'fiĝoj'                                    => 'fj',
    'francagviano'                              => 'gf',
    'francapolinezio'                           => 'pf',
    'francujo'                                  => 'fr',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabono'                                    => 'ga',
    'gambio'                                    => 'gm',
    'ganao'                                     => 'gh',
    'germanujo'                                 => 'de',
    'grekujo'                                   => 'gr',
    'grenado'                                   => 'gd',
    'gronlando'                                 => 'gl',
    'guernsey'                                  => 'gg',
    'gujano'                                    => 'gy',
    'gvadelupo'                                 => 'gp',
    'gvamo'                                     => 'gu',
    'gvatemalo'                                 => 'gt',
    'gvineo'                                    => 'gn',
    'gvineobisaŭo'                             => 'gw',
    'haitio'                                    => 'ht',
    'herdakajmakdonaldajinsuloj'                => 'hm',
    'hindujo'                                   => 'in',
    'hispanujo'                                 => 'es',
    'honduro'                                   => 'hn',
    'hongkong'                                  => 'hk',
    'hungarujo'                                 => 'hu',
    'indonezio'                                 => 'id',
    'irako'                                     => 'iq',
    'irano'                                     => 'ir',
    'irlando'                                   => 'ie',
    'islando'                                   => 'is',
    'isleofman'                                 => 'im',
    'israelo'                                   => 'il',
    'italujo'                                   => 'it',
    'jamajko'                                   => 'jm',
    'japanujo'                                  => 'jp',
    'jemeno'                                    => 'ye',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordanio'                                  => 'jo',
    'kaboverdo'                                 => 'cv',
    'kamboĝo'                                  => 'kh',
    'kameruno'                                  => 'cm',
    'kanado'                                    => 'ca',
    'kartvelujo'                                => 'ge',
    'kataro'                                    => 'qa',
    'kazaĥstano'                               => 'kz',
    'kejmanoj'                                  => 'ky',
    'kenjo'                                     => 'ke',
    'kipro'                                     => 'cy',
    'kirgizistano'                              => 'kg',
    'kiribato'                                  => 'ki',
    'kolombio'                                  => 'co',
    'komoroj'                                   => 'km',
    'kongolo'                                   => 'cg',
    'kostariko'                                 => 'cr',
    'kroatujo'                                  => 'hr',
    'kubo'                                      => 'cu',
    'kukinsuloj'                                => 'ck',
    'kuvajto'                                   => 'kw',
    'laoso'                                     => 'la',
    'latinamerica'                              => 419,
    'latvujo'                                   => 'lv',
    'lesoto'                                    => 'ls',
    'libano'                                    => 'lb',
    'liberio'                                   => 'lr',
    'libio'                                     => 'ly',
    'litovujo'                                  => 'lt',
    'liĥtenŝtejno'                            => 'li',
    'luksemburgo'                               => 'lu',
    'macau'                                     => 'mo',
    'madagaskaro'                               => 'mg',
    'majoto'                                    => 'yt',
    'makedonujo'                                => 'mk',
    'malajzio'                                  => 'my',
    'malavio'                                   => 'mw',
    'maldivoj'                                  => 'mv',
    'malio'                                     => 'ml',
    'malto'                                     => 'mt',
    'maroko'                                    => 'ma',
    'martiniko'                                 => 'mq',
    'marŝaloj'                                 => 'mh',
    'maŭricio'                                 => 'mu',
    'maŭritanujo'                              => 'mr',
    'meksiko'                                   => 'mx',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikronezio'                                => 'fm',
    'mjanmao'                                   => 'mm',
    'moldavujo'                                 => 'md',
    'monako'                                    => 'mc',
    'mongolujo'                                 => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mozambiko'                                 => 'mz',
    'namibio'                                   => 'na',
    'nauro'                                     => 'nr',
    'nederlandajantiloj'                        => 'an',
    'nederlando'                                => 'nl',
    'nepalo'                                    => 'np',
    'neutralzone'                               => 'nt',
    'nikaragvo'                                 => 'ni',
    'niuo'                                      => 'nu',
    'niĝerio'                                  => 'ng',
    'niĝero'                                   => 'ne',
    'nordkoreo'                                 => 'kp',
    'nordmarianoj'                              => 'mp',
    'norfolkinsulo'                             => 'nf',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'norvegujo'                                 => 'no',
    'novkaledonio'                              => 'nc',
    'novzelando'                                => 'nz',
    'oceania'                                   => '009',
    'okcidentasaharo'                           => 'eh',
    'omano'                                     => 'om',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakistano'                                 => 'pk',
    'palestinianterritories'                    => 'ps',
    'panamacanalzone'                           => 'pz',
    'panamo'                                    => 'pa',
    'papuonovgvineo'                            => 'pg',
    'paragvajo'                                 => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peruo'                                     => 'pe',
    'pitkarnainsulo'                            => 'pn',
    'pollando'                                  => 'pl',
    'polynesia'                                 => '061',
    'portugalujo'                               => 'pt',
    'puertoriko'                                => 'pr',
    'reunio'                                    => 're',
    'ruando'                                    => 'rw',
    'rumanujo'                                  => 'ro',
    'rusujo'                                    => 'ru',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'salomonoj'                                 => 'sb',
    'salvadoro'                                 => 'sv',
    'samoo'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saotomeokajprincipeo'                      => 'st',
    'saŭdaarabujo'                             => 'sa',
    'sejŝeloj'                                 => 'sc',
    'senegalo'                                  => 'sn',
    'sentheleno'                                => 'sh',
    'sentkristofokajneviso'                     => 'kn',
    'sentlucio'                                 => 'lc',
    'sentpierokajmikelono'                      => 'pm',
    'sentvincentokajlagrenadinoj'               => 'vc',
    'serbia'                                    => 'rs',
    'serbujo'                                   => 'cs',
    'sieraleono'                                => 'sl',
    'singapuro'                                 => 'sg',
    'sirio'                                     => 'sy',
    'slovakujo'                                 => 'sk',
    'slovenujo'                                 => 'si',
    'somalujo'                                  => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'srilanko'                                  => 'lk',
    'sudafriko'                                 => 'za',
    'sudano'                                    => 'sd',
    'sudgeorgiokajsudsandviĉinsuloj'           => 'gs',
    'sudkoreo'                                  => 'kr',
    'surinamo'                                  => 'sr',
    'svalbardokajjanmajeninsulo'                => 'sj',
    'svazilando'                                => 'sz',
    'svedujo'                                   => 'se',
    'svisujo'                                   => 'ch',
    'tajlando'                                  => 'th',
    'tajvano'                                   => 'tw',
    'tanzanio'                                  => 'tz',
    'taĝikujo'                                 => 'tj',
    'togolo'                                    => 'tg',
    'tokelau'                                   => 'tk',
    'tongo'                                     => 'to',
    'trinidadokajtobago'                        => 'tt',
    'tristandacunha'                            => 'ta',
    'tunizio'                                   => 'tn',
    'turkmenujo'                                => 'tm',
    'turksandcaicosislands'                     => 'tc',
    'turkujo'                                   => 'tr',
    'tuvalo'                                    => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ugando'                                    => 'ug',
    'ukrajno'                                   => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'unuiĝintajarabajemirlandos'               => 'ae',
    'unuiĝintareĝlando'                       => 'gb',
    'urugvajo'                                  => 'uy',
    'usonajmalgrandajinsuloj'                   => 'um',
    'usonajvirgulininsuloj'                     => 'vi',
    'usono'                                     => 'us',
    'uzbekujo'                                  => 'uz',
    'valisokajfutuno'                           => 'wf',
    'vanuatuo'                                  => 'vu',
    'vatikano'                                  => 'va',
    'venezuelo'                                 => 've',
    'vjetnamo'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'world'                                     => '001',
    'zambio'                                    => 'zm',
    'zimbabvo'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
    'Ĉado'                                     => 'td',
    'Ĉeĥujo'                                  => 'cz',
    'Ĉilio'                                    => 'cl',
    'Ĉinujo'                                   => 'cn',
    'Ĝibraltaro'                               => 'gi',
    'Ĝibutio'                                  => 'dj',
);

1;

