package Locales::DB::Native;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Native::VERSION = '0.09';

$Locales::DB::Native::cldr_version = '2.0';

%Locales::DB::Native::code_to_name = (
    'sid'    => 'Sidaamu Afo',
    'ne'     => 'नेपाली',
    'tr'     => 'Türkçe',
    'ki'     => 'Gikuyu',
    'gl'     => 'Galego',
    'lun'    => 'Lunda',
    'kum'    => 'Kumyk',
    'fat'    => 'Fanti',
    'ro'     => 'română',
    'br'     => 'brezhoneg',
    'syc'    => 'Classical Syriac',
    'gil'    => 'Gilbertese',
    'cs'     => 'čeština',
    'sux'    => 'Sumerian',
    'km'     => 'ភាសាខ្មែរ',
    'af'     => 'Afrikaans',
    'tai'    => 'Tai Language',
    'mun'    => 'Munda Language',
    'ga'     => 'Gaeilge',
    'hsb'    => 'Upper Sorbian',
    'ada'    => 'Adangme',
    'dak'    => 'Dakota',
    'arn'    => 'Araucanian',
    'mi'     => 'Maori',
    'sv'     => 'svenska',
    'za'     => 'Zhuang',
    'mkh'    => 'Mon-Khmer Language',
    'fa'     => 'فارسی',
    'pau'    => 'Palauan',
    'wal'    => 'ወላይታቱ',
    'afh'    => 'Afrihili',
    'man'    => 'Mandingo',
    'pt_br'  => 'português do Brasil',
    'cmc'    => 'Chamic Language',
    've'     => 'Tshivenḓa',
    'na'     => 'Nauru',
    'ba'     => 'Bashkir',
    'pra'    => 'Prakrit Language',
    'id'     => 'Bahasa Indonesia',
    'arc'    => 'Aramaic',
    'trv'    => 'Taroko',
    'si'     => 'සිංහල',
    'kac'    => 'Kachin',
    'om'     => 'Oromoo',
    'rwk'    => 'Kiruwa',
    'fi'     => 'suomi',
    'mai'    => 'Maithili',
    'wo'     => 'Wolof',
    'pt_pt'  => 'português europeu',
    'ii'     => 'ꆈꌠꉙ',
    'yue'    => 'Cantonese',
    'bi'     => 'Bislama',
    'ace'    => 'Achinese',
    'kj'     => 'Kuanyama',
    'ota'    => 'Ottoman Turkish',
    'xal'    => 'Kalmyk',
    'en_ca'  => 'Canadian English',
    'mn'     => 'монгол',
    'nv'     => 'Navajo',
    'gd'     => 'Scottish Gaelic',
    'map'    => 'Austronesian Language',
    'bai'    => 'Bamileke Language',
    'ber'    => 'Berber',
    'cr'     => 'Cree',
    'sg'     => 'Sängö',
    'kam'    => 'Kikamba',
    'yao'    => 'Yao',
    'ira'    => 'Iranian Language',
    'pon'    => 'Pohnpeian',
    'tum'    => 'Tumbuka',
    'suk'    => 'Sukuma',
    'enm'    => 'Middle English',
    'bej'    => 'Beja',
    'nub'    => 'Nubian Language',
    'dgr'    => 'Dogrib',
    'bg'     => 'български',
    'guz'    => 'Ekegusii',
    'del'    => 'Delaware',
    'chr'    => 'ᏣᎳᎩ',
    'sq'     => 'shqipe',
    'ca'     => 'català',
    'es_419' => 'español latinoamericano',
    'paa'    => 'Papuan Language',
    'nds'    => 'Plattdüütsch',
    'luo'    => 'Dholuo',
    'es'     => 'español',
    'sw'     => 'Kiswahili',
    'bez'    => 'Hibena',
    'yap'    => 'Yapese',
    'sla'    => 'Slavic Language',
    'sa'     => 'Sanskrit',
    'mua'    => 'MUNDAŊ',
    'anp'    => 'Angika',
    'krl'    => 'Karelian',
    'loz'    => 'Lozi',
    'ie'     => 'Interlingue',
    'tl'     => 'Tagalog',
    'dyo'    => 'joola',
    'nd'     => 'isiNdebele',
    'hil'    => 'Hiligaynon',
    'udm'    => 'Udmurt',
    'de'     => 'Deutsch',
    'kbd'    => 'Kabardian',
    'tzm'    => 'Tamaziɣt',
    'mag'    => 'Magahi',
    'hz'     => 'Herero',
    'nai'    => 'North American Indian Language',
    'haw'    => 'ʻŌlelo Hawaiʻi',
    'sel'    => 'Selkup',
    'frr'    => 'Northern Frisian',
    'he'     => 'עברית',
    'zh'     => '中文',
    'lol'    => 'Mongo',
    'dum'    => 'Middle Dutch',
    'fr_ch'  => 'français suisse',
    'sat'    => 'Santali',
    'tyv'    => 'Tuvinian',
    'mwr'    => 'Marwari',
    'egy'    => 'Ancient Egyptian',
    'twq'    => 'Tasawaq senni',
    'da'     => 'dansk',
    'ug'     => 'Uyghur',
    'sbp'    => 'Ishisangu',
    'moh'    => 'Mohawk',
    'ta'     => 'தமிழ்',
    'ady'    => 'Adyghe',
    'efi'    => 'Efik',
    'rw'     => 'Kinyarwanda',
    'mos'    => 'Mossi',
    'doi'    => 'Dogri',
    'saq'    => 'Kisampur',
    'sem'    => 'Semitic Language',
    'zun'    => 'Zuni',
    'cus'    => 'Cushitic Language',
    'mo'     => 'Moldavian',
    'cop'    => 'Coptic',
    'mis'    => 'Miscellaneous Language',
    'ps'     => 'پښتو',
    'ksf'    => 'rikpa',
    'av'     => 'Avaric',
    'fon'    => 'Fon',
    'kab'    => 'Taqbaylit',
    'nic'    => 'Niger-Kordofanian Language',
    'is'     => 'íslenska',
    'qu'     => 'Quechua',
    'shn'    => 'Shan',
    'mt'     => 'Malti',
    'men'    => 'Mende',
    'la'     => 'Latin',
    'bh'     => 'Bihari',
    'oc'     => 'occitan',
    'pap'    => 'Papiamento',
    'zxx'    => 'No linguistic content',
    'art'    => 'Artificial Language',
    'nyo'    => 'Nyoro',
    'kha'    => 'Khasi',
    'hai'    => 'Haida',
    'naq'    => 'Khoekhoegowab',
    'ach'    => 'Acoli',
    'ng'     => 'Ndonga',
    'dv'     => 'Divehi',
    'jv'     => 'Javanese',
    'smj'    => 'Lule Sami',
    'hi'     => 'हिन्दी',
    'lad'    => 'Ladino',
    'csb'    => 'Kashubian',
    'os'     => 'Ossetic',
    'fr'     => 'français',
    'got'    => 'Gothic',
    'jmc'    => 'Kimachame',
    'kaa'    => 'Kara-Kalpak',
    'sr'     => 'Српски',
    'kok'    => 'कोंकणी',
    'vo'     => 'Volapük',
    'xog'    => 'Olusoga',
    'tet'    => 'Tetum',
    'fj'     => 'Fijian',
    'srr'    => 'Serer',
    'pam'    => 'Pampanga',
    'cpe'    => 'English-based Creole or Pidgin',
    'kaw'    => 'Kawi',
    'sd'     => 'Sindhi',
    'bho'    => 'Bhojpuri',
    'gon'    => 'Gondi',
    'ha'     => 'Hausa',
    'gba'    => 'Gbaya',
    'hit'    => 'Hittite',
    'lg'     => 'Luganda',
    'bug'    => 'Buginese',
    'mul'    => 'Multiple Languages',
    'dua'    => 'duálá',
    'tig'    => 'ትግረ',
    'mr'     => 'मराठी',
    'cad'    => 'Caddo',
    'rm'     => 'rumantsch',
    'kaj'    => 'Jju',
    'ilo'    => 'Iloko',
    'kn'     => 'ಕನ್ನಡ',
    'rn'     => 'Ikirundi',
    'uga'    => 'Ugaritic',
    'nog'    => 'Nogai',
    'cho'    => 'Choctaw',
    'nmg'    => '',
    'ik'     => 'Inupiaq',
    'hmn'    => 'Hmong',
    'mg'     => 'Malagasy',
    'ru'     => 'русский',
    'kar'    => 'Karen',
    'ku'     => 'کوردی',
    'znd'    => 'Zande',
    'lo'     => 'ລາວ',
    'lb'     => 'Luxembourgish',
    'mus'    => 'Creek',
    'ml'     => 'മലയാളം',
    'grc'    => 'Ancient Greek',
    'sas'    => 'Sasak',
    'nah'    => 'Nahuatl',
    'peo'    => 'Old Persian',
    'bal'    => 'Baluchi',
    'nyn'    => 'Runyankore',
    'kho'    => 'Khotanese',
    'kl'     => 'kalaallisut',
    'bs'     => 'bosanski',
    'to'     => 'lea fakatonga',
    'cu'     => 'Church Slavic',
    'ch'     => 'Chamorro',
    'eu'     => 'euskara',
    'wa'     => 'Walloon',
    'ine'    => 'Indo-European Language',
    'pl'     => 'polski',
    'ay'     => 'Aymara',
    'lez'    => 'Lezghian',
    'den'    => 'Slave',
    'non'    => 'Old Norse',
    'apa'    => 'Apache Language',
    'lua'    => 'Luba-Lulua',
    'an'     => 'Aragonese',
    'kfo'    => 'Koro',
    'khi'    => 'Khoisan Language',
    'ceb'    => 'Cebuano',
    'tt'     => 'Tatar',
    'ast'    => 'Asturian',
    'ss'     => 'Siswati',
    'or'     => 'ଓଡ଼ିଆ',
    'dra'    => 'Dravidian Language',
    'xh'     => 'isiXhosa',
    'th'     => 'ไทย',
    'tut'    => 'Altaic Language',
    'iba'    => 'Iban',
    'sam'    => 'Samaritan Aramaic',
    'chg'    => 'Chagatai',
    'gn'     => 'Guarani',
    'hr'     => 'hrvatski',
    'ypk'    => 'Yupik Language',
    'niu'    => 'Niuean',
    'cv'     => 'Chuvash',
    'tmh'    => 'Tamashek',
    'chn'    => 'Chinook Jargon',
    'awa'    => 'Awadhi',
    'ja'     => '日本語',
    'dsb'    => 'Lower Sorbian',
    'ijo'    => 'Ijo',
    'bla'    => 'Siksika',
    'cay'    => 'Cayuga',
    'nl'     => 'Nederlands',
    'wae'    => 'Walser',
    'ebu'    => 'Kĩembu',
    'nap'    => 'Neapolitan',
    'el'     => 'Ελληνικά',
    'kk'     => 'қазақ тілі',
    'elx'    => 'Elamite',
    'gor'    => 'Gorontalo',
    'tlh'    => '',
    'my'     => 'ဗမာ',
    'sog'    => 'Sogdien',
    'see'    => 'Seneca',
    'krc'    => 'Karachay-Balkar',
    'mno'    => 'Manobo Language',
    'tn'     => 'Setswana',
    'co'     => 'Corsican',
    'bas'    => 'Ɓàsàa',
    'bnt'    => 'Bantu',
    'lam'    => 'Lamba',
    'bo'     => 'པོད་སྐད་',
    'cy'     => 'Cymraeg',
    'mwl'    => 'Mirandese',
    'frm'    => 'Middle French',
    'kut'    => 'Kutenai',
    'ky'     => 'Кыргыз',
    'ti'     => 'ትግርኛ',
    'rar'    => 'Rarotongan',
    'ka'     => 'ქართული',
    'iro'    => 'Iroquoian Language',
    'kea'    => 'kabuverdianu',
    'sal'    => 'Salishan Language',
    'und'    => 'Unknown Language',
    'de_at'  => 'Österreichisches Deutsch',
    'hu'     => 'magyar',
    'rof'    => 'Kihorombo',
    'byn'    => 'ብሊን',
    'ssa'    => 'Nilo-Saharan Language',
    'mgh'    => 'Makua',
    'se'     => 'davvisámegiella',
    'dyu'    => 'Dyula',
    'mic'    => 'Micmac',
    'kv'     => 'Komi',
    'dje'    => 'Zarmaciine',
    'son'    => 'Songhai',
    'bin'    => 'Bini',
    'kcg'    => 'Tyap',
    'sco'    => 'Scots',
    'teo'    => 'Kiteso',
    'fr_ca'  => 'français canadien',
    'no'     => 'Norwegian',
    'lv'     => 'latviešu',
    'shi'    => 'tamazight',
    'ln'     => 'lingála',
    'rom'    => 'Romany',
    'kde'    => 'Chimakonde',
    'mas'    => 'Maa',
    'ab'     => 'Abkhazian',
    'roa'    => 'Romance Language',
    'chm'    => 'Mari',
    'li'     => 'Limburgish',
    'kpe'    => 'Kpelle',
    'jpr'    => 'Judeo-Persian',
    'seh'    => 'sena',
    'fan'    => 'Fang',
    'zen'    => 'Zenaga',
    'gmh'    => 'Middle High German',
    'gv'     => 'Gaelg',
    'bra'    => 'Braj',
    'nia'    => 'Nias',
    'fil'    => 'Filipino',
    'pa'     => 'ਪੰਜਾਬੀ',
    'am'     => 'አማርኛ',
    'gay'    => 'Gayo',
    'gem'    => 'Germanic Language',
    'ee'     => 'eʋegbe',
    'bat'    => 'Baltic Language',
    'umb'    => 'Umbundu',
    'alt'    => 'Southern Altai',
    'bem'    => 'Ichibemba',
    'car'    => 'Carib',
    'lag'    => 'Kɨlaangi',
    'eo'     => 'esperanto',
    'fy'     => 'Western Frisian',
    'as'     => 'অসমীয়া',
    'ae'     => 'Avestan',
    'nqo'    => 'N’Ko',
    'bua'    => 'Buriat',
    'ia'     => 'interlingua',
    'vi'     => 'Tiếng Việt',
    'day'    => 'Dayak',
    'bm'     => 'bamanakan',
    'mdf'    => 'Moksha',
    'nr'     => 'isiNdebele',
    'luy'    => 'Luluhia',
    'kw'     => 'kernewek',
    'nym'    => 'Nyamwezi',
    'pag'    => 'Pangasinan',
    'ang'    => 'Old English',
    'uz'     => 'Ўзбек',
    'fiu'    => 'Finno-Ugrian Language',
    'ht'     => 'Haitian',
    'brx'    => 'बड़ो',
    'yo'     => 'Èdè Yorùbá',
    'bad'    => 'Banda',
    'ter'    => 'Tereno',
    'gu'     => 'ગુજરાતી',
    'mni'    => 'Manipuri',
    'kos'    => 'Kosraean',
    'raj'    => 'Rajasthani',
    'asa'    => 'Kipare',
    'srn'    => 'Sranan Tongo',
    'oj'     => 'Ojibwa',
    'sk'     => 'slovenčina',
    'cai'    => 'Central American Indian Language',
    'eka'    => 'Ekajuk',
    'en_gb'  => 'British English',
    'ty'     => 'Tahitian',
    'gaa'    => 'Ga',
    'jrb'    => 'Judeo-Arabic',
    'hup'    => 'Hupa',
    'phi'    => 'Philippine Language',
    'akk'    => 'Akkadian',
    'new'    => 'Newari',
    'osa'    => 'Osage',
    'et'     => 'eesti',
    'sad'    => 'Sandawe',
    'mk'     => 'македонски',
    'cpf'    => 'French-based Creole or Pidgin',
    'en'     => 'English',
    'aus'    => 'Australian Language',
    'zza'    => 'Zaza',
    'chb'    => 'Chibcha',
    'zu'     => 'isiZulu',
    'alg'    => 'Algonquian Language',
    'snk'    => 'Soninke',
    'pro'    => 'Old Provençal',
    'mga'    => 'Middle Irish',
    'wak'    => 'Wakashan Language',
    'swc'    => 'Kiswahili ya Kongo',
    'nn'     => 'nynorsk',
    'bn'     => 'বাংলা',
    'pal'    => 'Pahlavi',
    'ban'    => 'Balinese',
    'min'    => 'Minangkabau',
    'ar'     => 'العربية',
    'sm'     => 'Samoan',
    'grb'    => 'Grebo',
    'ny'     => 'Nyanja',
    'was'    => 'Washo',
    'sus'    => 'Susu',
    'khq'    => 'Koyra ciini',
    'ksh'    => 'Colognian',
    'cel'    => 'Celtic Language',
    'gsw'    => 'Schwiizertüütsch',
    'him'    => 'Himachali',
    'tpi'    => 'Tok Pisin',
    'yav'    => 'nuasue',
    'en_au'  => 'Australian English',
    'nzi'    => 'Nzima',
    'ain'    => 'Ainu',
    'st'     => 'Sesotho',
    'ko'     => '한국어',
    'sit'    => 'Sino-Tibetan Language',
    'ak'     => 'Akan',
    'chp'    => 'Chipewyan',
    'mfe'    => 'kreol morisien',
    'ssy'    => 'Saho',
    'wen'    => 'Sorbian Language',
    'nwc'    => 'Classical Newari',
    'sms'    => 'Skolt Sami',
    'rap'    => 'Rapanui',
    'oto'    => 'Otomian Language',
    'hy'     => 'Հայերէն',
    'ms'     => 'Bahasa Melayu',
    'fro'    => 'Old French',
    'myv'    => 'Erzya',
    'tsi'    => 'Tsimshian',
    'it'     => 'italiano',
    'tiv'    => 'Tiv',
    'scn'    => 'Sicilian',
    'mdr'    => 'Mandar',
    'sma'    => 'Southern Sami',
    'vot'    => 'Votic',
    'ale'    => 'Aleut',
    'vai'    => 'ꕙꔤ',
    'kru'    => 'Kurukh',
    'sai'    => 'South American Indian Language',
    'lu'     => 'Tshiluba',
    'ks'     => 'Kashmiri',
    'pt'     => 'português',
    'swb'    => 'Comorian',
    'tli'    => 'Tlingit',
    'mh'     => 'Marshallese',
    'gwi'    => 'Gwichʼin',
    'kg'     => 'Kongo',
    'smn'    => 'Inari Sami',
    'vun'    => 'Kyivunjo',
    'ho'     => 'Hiri Motu',
    'ewo'    => 'ewondo',
    'afa'    => 'Afro-Asiatic Language',
    'ff'     => 'Pulaar',
    'tem'    => 'Timne',
    'lus'    => 'Lushai',
    'tkl'    => 'Tokelau',
    'inh'    => 'Ingush',
    'sn'     => 'chiShona',
    'ath'    => 'Athapascan Language',
    'yi'     => 'Yiddish',
    'cch'    => 'Atsam',
    'frs'    => 'Eastern Frisian',
    'arp'    => 'Arapaho',
    'war'    => 'Waray',
    'mad'    => 'Madurese',
    'sl'     => 'slovenščina',
    'rup'    => 'Aromanian',
    'dz'     => 'རྫོང་ཁ',
    'jbo'    => 'Lojban',
    'de_ch'  => 'Schweizer Hochdeutsch',
    'crh'    => 'Crimean Turkish',
    'cpp'    => 'Portuguese-based Creole or Pidgin',
    'sga'    => 'Old Irish',
    'tk'     => 'Turkmen',
    'tup'    => 'Tupi Language',
    'su'     => 'Sundanese',
    'kln'    => 'Kalenjin',
    'sc'     => 'Sardinian',
    'chy'    => 'Cheyenne',
    'sgn'    => 'Sign Language',
    'sio'    => 'Siouan Language',
    'goh'    => 'Old High German',
    'zap'    => 'Zapotec',
    'nb'     => 'norsk bokmål',
    'nso'    => 'Sesotho sa Leboa',
    'az'     => 'azərbaycanca',
    'ksb'    => 'Kishambaa',
    'sah'    => 'саха тыла',
    'aa'     => 'Qafar',
    'fur'    => 'furlan',
    'ts'     => 'Xitsonga',
    'btk'    => 'Batak',
    'agq'    => 'Aghem',
    'dav'    => 'Kitaita',
    'zbl'    => 'Blissymbols',
    'inc'    => 'Indic Language',
    'es_es'  => 'español de España',
    'crp'    => 'Creole or Pidgin',
    'mer'    => 'Kĩmĩrũ',
    'iu'     => 'Inuktitut',
    'en_us'  => 'U.S. English',
    'lah'    => 'Lahnda',
    'nl_be'  => 'Vlaams',
    'cau'    => 'Caucasian Language',
    'lui'    => 'Luiseno',
    'mak'    => 'Makasar',
    'gez'    => 'Geez',
    'uk'     => 'українська',
    'nus'    => 'Thok Nath',
    'kr'     => 'Kanuri',
    'smi'    => 'Sami Language',
    'fo'     => 'føroyskt',
    'syr'    => 'Syriac',
    'sh'     => 'Serbo-Croatian',
    'io'     => 'Ido',
    'so'     => 'Soomaali',
    'kmb'    => 'Kimbundu',
    'dar'    => 'Dargwa',
    'phn'    => 'Phoenician',
    'bik'    => 'Bikol',
    'lt'     => 'lietuvių',
    'be'     => 'беларуская',
    'din'    => 'Dinka',
    'ur'     => 'اردو',
    'arw'    => 'Arawak',
    'chk'    => 'Chuukese',
    'tw'     => 'Twi',
    'ce'     => 'Chechen',
    'kro'    => 'Kru',
    'tvl'    => 'Tuvalu',
    'pi'     => 'Pali',
    'tg'     => 'Tajik',
    'tog'    => 'Nyasa Tonga',
    'ses'    => 'Koyraboro senni',
    'te'     => 'తెలుగు',
    'ig'     => 'Igbo',
    'myn'    => 'Mayan Language',
    'cgg'    => 'Rukiga',
    'mnc'    => 'Manchu',
);

%Locales::DB::Native::value_is_fallback = (
    'gor' => '1',
    'elx' => '1',
    'tlh' => '1',
    'sog' => '1',
    'see' => '1',
    'lun' => '1',
    'kum' => '1',
    'krc' => '1',
    'fat' => '1',
    'mno' => '1',
    'co'  => '1',
    'bnt' => '1',
    'lam' => '1',
    'mwl' => '1',
    'syc' => '1',
    'gil' => '1',
    'frm' => '1',
    'sux' => '1',
    'kut' => '1',
    'tai' => '1',
    'mun' => '1',
    'rar' => '1',
    'hsb' => '1',
    'ada' => '1',
    'iro' => '1',
    'dak' => '1',
    'arn' => '1',
    'mi'  => '1',
    'sal' => '1',
    'und' => '1',
    'za'  => '1',
    'mkh' => '1',
    'pau' => '1',
    'afh' => '1',
    'ssa' => '1',
    'man' => '1',
    'dyu' => '1',
    'mic' => '1',
    'kv'  => '1',
    'cmc' => '1',
    'na'  => '1',
    'son' => '1',
    'ba'  => '1',
    'bin' => '1',
    'sco' => '1',
    'pra' => '1',
    'rom' => '1',
    'arc' => '1',
    'kac' => '1',
    'roa' => '1',
    'ab'  => '1',
    'chm' => '1',
    'mai' => '1',
    'wo'  => '1',
    'li'  => '1',
    'kpe' => '1',
    'jpr' => '1',
    'fan' => '1',
    'zen' => '1',
    'gmh' => '1',
    'yue' => '1',
    'nia' => '1',
    'bra' => '1',
    'gem' => '1',
    'gay' => '1',
    'bi'  => '1',
    'ace' => '1',
    'kj'  => '1',
    'bat' => '1',
    'umb' => '1',
    'ota' => '1',
    'alt' => '1',
    'xal' => '1',
    'car' => '1',
    'fy'  => '1',
    'nv'  => '1',
    'gd'  => '1',
    'ae'  => '1',
    'nqo' => '1',
    'bua' => '1',
    'map' => '1',
    'bai' => '1',
    'ber' => '1',
    'cr'  => '1',
    'day' => '1',
    'mdf' => '1',
    'yao' => '1',
    'ira' => '1',
    'pon' => '1',
    'tum' => '1',
    'pag' => '1',
    'nym' => '1',
    'ang' => '1',
    'fiu' => '1',
    'ht'  => '1',
    'suk' => '1',
    'bej' => '1',
    'enm' => '1',
    'bad' => '1',
    'nub' => '1',
    'dgr' => '1',
    'ter' => '1',
    'mni' => '1',
    'raj' => '1',
    'kos' => '1',
    'del' => '1',
    'paa' => '1',
    'srn' => '1',
    'oj'  => '1',
    'cai' => '1',
    'eka' => '1',
    'ty'  => '1',
    'jrb' => '1',
    'yap' => '1',
    'sla' => '1',
    'hup' => '1',
    'phi' => '1',
    'sa'  => '1',
    'new' => '1',
    'anp' => '1',
    'akk' => '1',
    'osa' => '1',
    'krl' => '1',
    'loz' => '1',
    'ie'  => '1',
    'sad' => '1',
    'cpf' => '1',
    'hil' => '1',
    'udm' => '1',
    'aus' => '1',
    'zza' => '1',
    'chb' => '1',
    'alg' => '1',
    'snk' => '1',
    'kbd' => '1',
    'pro' => '1',
    'mga' => '1',
    'mag' => '1',
    'wak' => '1',
    'hz'  => '1',
    'nai' => '1',
    'sel' => '1',
    'pal' => '1',
    'frr' => '1',
    'min' => '1',
    'ban' => '1',
    'lol' => '1',
    'dum' => '1',
    'sm'  => '1',
    'ny'  => '1',
    'grb' => '1',
    'was' => '1',
    'sat' => '1',
    'tyv' => '1',
    'mwr' => '1',
    'egy' => '1',
    'sus' => '1',
    'ug'  => '1',
    'cel' => '1',
    'moh' => '1',
    'him' => '1',
    'tpi' => '1',
    'ady' => '1',
    'efi' => '1',
    'doi' => '1',
    'mos' => '1',
    'nzi' => '1',
    'ain' => '1',
    'sit' => '1',
    'sem' => '1',
    'chp' => '1',
    'zun' => '1',
    'cus' => '1',
    'cop' => '1',
    'mis' => '1',
    'wen' => '1',
    'nwc' => '1',
    'av'  => '1',
    'sms' => '1',
    'fon' => '1',
    'nic' => '1',
    'rap' => '1',
    'oto' => '1',
    'qu'  => '1',
    'shn' => '1',
    'la'  => '1',
    'men' => '1',
    'bh'  => '1',
    'fro' => '1',
    'myv' => '1',
    'tsi' => '1',
    'pap' => '1',
    'zxx' => '1',
    'art' => '1',
    'tiv' => '1',
    'scn' => '1',
    'kha' => '1',
    'nyo' => '1',
    'sma' => '1',
    'hai' => '1',
    'mdr' => '1',
    'vot' => '1',
    'ach' => '1',
    'ale' => '1',
    'dv'  => '1',
    'ng'  => '1',
    'kru' => '1',
    'sai' => '1',
    'jv'  => '1',
    'smj' => '1',
    'tli' => '1',
    'swb' => '1',
    'ks'  => '1',
    'mh'  => '1',
    'gwi' => '1',
    'smn' => '1',
    'kg'  => '1',
    'lad' => '1',
    'csb' => '1',
    'ho'  => '1',
    'os'  => '1',
    'got' => '1',
    'kaa' => '1',
    'afa' => '1',
    'vo'  => '1',
    'tet' => '1',
    'tem' => '1',
    'fj'  => '1',
    'lus' => '1',
    'srr' => '1',
    'pam' => '1',
    'tkl' => '1',
    'inh' => '1',
    'cpe' => '1',
    'kaw' => '1',
    'sd'  => '1',
    'ath' => '1',
    'yi'  => '1',
    'bho' => '1',
    'arp' => '1',
    'frs' => '1',
    'gon' => '1',
    'gba' => '1',
    'hit' => '1',
    'war' => '1',
    'bug' => '1',
    'mad' => '1',
    'mul' => '1',
    'rup' => '1',
    'cad' => '1',
    'ilo' => '1',
    'uga' => '1',
    'cho' => '1',
    'nog' => '1',
    'jbo' => '1',
    'crh' => '1',
    'ik'  => '1',
    'hmn' => '1',
    'cpp' => '1',
    'tup' => '1',
    'tk'  => '1',
    'sga' => '1',
    'su'  => '1',
    'sc'  => '1',
    'sio' => '1',
    'sgn' => '1',
    'chy' => '1',
    'goh' => '1',
    'zap' => '1',
    'kar' => '1',
    'znd' => '1',
    'lb'  => '1',
    'mus' => '1',
    'grc' => '1',
    'sas' => '1',
    'nah' => '1',
    'btk' => '1',
    'bal' => '1',
    'peo' => '1',
    'kho' => '1',
    'zbl' => '1',
    'crp' => '1',
    'inc' => '1',
    'iu'  => '1',
    'cu'  => '1',
    'ch'  => '1',
    'lah' => '1',
    'wa'  => '1',
    'ine' => '1',
    'cau' => '1',
    'ay'  => '1',
    'lez' => '1',
    'den' => '1',
    'lui' => '1',
    'mak' => '1',
    'apa' => '1',
    'non' => '1',
    'gez' => '1',
    'an'  => '1',
    'kfo' => '1',
    'lua' => '1',
    'khi' => '1',
    'ceb' => '1',
    'kr'  => '1',
    'tt'  => '1',
    'smi' => '1',
    'ast' => '1',
    'syr' => '1',
    'dra' => '1',
    'io'  => '1',
    'tut' => '1',
    'iba' => '1',
    'kmb' => '1',
    'sam' => '1',
    'dar' => '1',
    'phn' => '1',
    'bik' => '1',
    'chg' => '1',
    'gn'  => '1',
    'ypk' => '1',
    'din' => '1',
    'niu' => '1',
    'cv'  => '1',
    'arw' => '1',
    'chk' => '1',
    'tw'  => '1',
    'tmh' => '1',
    'ce'  => '1',
    'chn' => '1',
    'awa' => '1',
    'kro' => '1',
    'tvl' => '1',
    'dsb' => '1',
    'pi'  => '1',
    'tog' => '1',
    'ijo' => '1',
    'bla' => '1',
    'cay' => '1',
    'myn' => '1',
    'mnc' => '1',
    'nap' => '1',
);

1;
