{"delimiters":{"quotation_start":"«","quotation_end":"»","alternate_quotation_start":"‹","alternate_quotation_end":"›"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":"näi:n","yesstr":"ja:j"},"plural_forms":{"category_list":["one","other"],"category_rules_function":null,"category_rules":{"one":"n is 1"},"category_rules_compiled":{"one":function (n) {if ( (( n == 1))) { return 'one'; } return;}}},"cldr_formats":{"territory":"Regioon: {0}","_decimal_format_decimal":".","language":"Schpraach: {0}","percent":"#,##0 %","locale":"{0} ({1})","_decimal_format_group":"’","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} und {1}","start":"{0}, {1}","end":"{0} und {1}"}},"fallback":["de_ch"],"characters":{"more_information":"?"}}