package Locales::DB::Territory::nn;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::nn::VERSION = '0.09';

$Locales::DB::Territory::nn::cldr_version = '2.0';

%Locales::DB::Territory::nn::code_to_name = (
    '001' => 'verda',
    '002' => 'Afrika',
    '003' => "Nord\-Amerika",
    '005' => "Sør\-Amerika",
    '009' => 'Oseania',
    '011' => "Vest\-Afrika",
    '013' => "Sentral\-Amerika",
    '014' => "Aust\-Afrika",
    '015' => "Nord\-Afrika",
    '017' => "Sentral\-Afrika",
    '018' => "Sørlege\ Afrika",
    '019' => 'Amerika',
    '021' => "nordlege\ Amerika",
    '029' => 'Karibia',
    '030' => "Aust\-Asia",
    '034' => "Sør\-Asia",
    '035' => "Søraust\-Asia",
    '039' => "Sør\-Europa",
    '053' => "Australia\ og\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => 'Mikronesia',
    '061' => 'Polynesia',
    '062' => "Sørlege\ Sentral\-Asia",
    142   => 'Asia',
    143   => "Sentral\-Asia",
    145   => "Vest\-Asia",
    150   => 'Europa',
    151   => "Aust\-Europa",
    154   => "Nord\-Europa",
    155   => "Vest\-Europa",
    172   => "Samveldet\ av\ uavhengige\ statar",
    200   => 'Czechoslovakia',
    419   => "Latin\-Amerika\ og\ Karibia",
    830   => 'Kanaløyane',
    'ac'  => 'Ascension',
    'ad'  => 'Andorra',
    'ae'  => "Dei\ sameinte\ arabiske\ emirata",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ og\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Dei\ nederlandske\ Antillane",
    'ao'  => 'Angola',
    'aq'  => 'Antarktis',
    'ar'  => 'Argentina',
    'as'  => "Amerikansk\ Samoa",
    'at'  => 'Austerrike',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => 'Åland',
    'az'  => 'Aserbajdsjan',
    'ba'  => "Bosnia\ og\ Hercegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgia',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => "Brunei\ Darussalam",
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasil',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhutan',
    'bv'  => 'Bouvetøya',
    'bw'  => 'Botswana',
    'by'  => 'Kviterussland',
    'bz'  => 'Belize',
    'ca'  => 'Canada',
    'cc'  => 'Kokosøyane',
    'cd'  => "Kongo\-Kinshasa",
    'cf'  => "Den\ sentralafrikanske\ republikken",
    'cg'  => "Kongo\-Brazzaville",
    'ch'  => 'Sveits',
    'ci'  => 'Elfenbeinskysten',
    'ck'  => 'Cookøyane',
    'cl'  => 'Chile',
    'cm'  => 'Kamerun',
    'cn'  => 'Kina',
    'co'  => 'Colombia',
    'cp'  => 'Clippertonøya',
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ og\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Kapp\ Verde",
    'cx'  => 'Christmasøya',
    'cy'  => 'Kypros',
    'cz'  => 'Tsjekkia',
    'dd'  => "East\ Germany",
    'de'  => 'Tyskland',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Danmark',
    'dm'  => 'Dominica',
    'do'  => "Den\ dominikanske\ republikken",
    'dz'  => 'Algerie',
    'ea'  => "Ceuta\ og\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estland',
    'eg'  => 'Egypt',
    'eh'  => "Vest\-Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Spania',
    'et'  => 'Etiopia',
    'eu'  => "Den\ europeiske\ unionen",
    'fi'  => 'Finland',
    'fj'  => 'Fiji',
    'fk'  => 'Falklandsøyane',
    'fm'  => 'Mikronesiaføderasjonen',
    'fo'  => 'Færøyane',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frankrike',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => 'Storbritannia',
    'gd'  => 'Grenada',
    'ge'  => 'Georgia',
    'gf'  => "Fransk\ Guyana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grønland',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => "Ekvatorial\-Guinea",
    'gr'  => 'Hellas',
    'gs'  => "Sør\-Georgia\ og\ Sør\-Sandwich\-øyane",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\-\ og\ McDonaldsøyane",
    'hn'  => 'Honduras',
    'hr'  => 'Kroatia',
    'ht'  => 'Haiti',
    'hu'  => 'Ungarn',
    'ic'  => 'Kanariøyane',
    'id'  => 'Indonesia',
    'ie'  => 'Irland',
    'il'  => 'Israel',
    'im'  => 'Man',
    'in'  => 'India',
    'io'  => "Britiske\ område\ i\ Det\ indiske\ hav",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordan',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirgisistan',
    'kh'  => 'Kambodsja',
    'ki'  => 'Kiribati',
    'km'  => 'Komorene',
    'kn'  => "St\.\ Christopher\ og\ Nevis",
    'kp'  => "Nord\-Korea",
    'kr'  => "Sør\-Korea",
    'kw'  => 'Kuwait',
    'ky'  => 'Caymanøyane',
    'kz'  => 'Kasakhstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "St\.\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Litauen',
    'lu'  => 'Luxembourg',
    'lv'  => 'Latvia',
    'ly'  => 'Libya',
    'ma'  => 'Marokko',
    'mc'  => 'Monaco',
    'md'  => 'Moldova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => 'Marshalløyane',
    'mi'  => "Midway\ Islands",
    'mk'  => 'Makedonia',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongolia',
    'mo'  => 'Macao',
    'mp'  => "Nord\-Marianane",
    'mq'  => 'Martinique',
    'mr'  => 'Mauritania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Maldivane',
    'mw'  => 'Malawi',
    'mx'  => 'Mexico',
    'my'  => 'Malaysia',
    'mz'  => 'Mosambik',
    'na'  => 'Namibia',
    'nc'  => "Ny\-Caledonia",
    'ne'  => 'Niger',
    'nf'  => 'Norfolkøyane',
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Nederland',
    'no'  => 'Noreg',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "New\ Zealand",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Fransk\ Polynesia",
    'pg'  => "Papua\ Ny\-Guinea",
    'ph'  => 'Filippinane',
    'pk'  => 'Pakistan',
    'pl'  => 'Polen',
    'pm'  => "St\.\ Pierre\ og\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Palestinsk\ territorium",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Ytre\ Oseania",
    're'  => 'Réunion',
    'ro'  => 'Romania',
    'rs'  => 'Serbia',
    'ru'  => 'Russland',
    'rw'  => 'Rwanda',
    'sa'  => "Saudi\ Arabia",
    'sb'  => 'Salomonøyane',
    'sc'  => 'Seychellane',
    'sd'  => 'Sudan',
    'se'  => 'Sverige',
    'sg'  => 'Singapore',
    'sh'  => "Saint\ Helena",
    'si'  => 'Slovenia',
    'sj'  => "Svalbard\ og\ Jan\ Mayen",
    'sk'  => 'Slovakia',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "São\ Tomé\ og\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Syria',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\-\ og\ Caicosøyane",
    'td'  => 'Tchad',
    'tf'  => "Franske\ sørområde",
    'tg'  => 'Togo',
    'th'  => 'Thailand',
    'tj'  => 'Tadsjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Aust\-Timor",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunisia',
    'to'  => 'Tonga',
    'tr'  => 'Tyrkia',
    'tt'  => "Trinidad\ og\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukraina',
    'ug'  => 'Uganda',
    'um'  => "USAs\ ytre\ småøyar",
    'us'  => 'USA',
    'uy'  => 'Uruguay',
    'uz'  => 'Usbekistan',
    'va'  => 'Vatikanstaten',
    'vc'  => "St\.\ Vincent\ og\ Grenadinane",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Dei\ britiske\ jomfruøyane",
    'vi'  => "Dei\ amerikanske\ jomfruøyane",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ og\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemen',
    'yt'  => 'Mayotte',
    'za'  => "Sør\-Afrika",
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "ukjent\ område",
);

%Locales::DB::Territory::nn::name_to_code = (
    'afghanistan'                               => 'af',
    'afrika'                                    => '002',
    'albania'                                   => 'al',
    'algerie'                                   => 'dz',
    'amerika'                                   => '019',
    'amerikansksamoa'                           => 'as',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarktis'                                 => 'aq',
    'antiguaogbarbuda'                          => 'ag',
    'argentina'                                 => 'ar',
    'armenia'                                   => 'am',
    'aruba'                                     => 'aw',
    'ascension'                                 => 'ac',
    'aserbajdsjan'                              => 'az',
    'asia'                                      => 142,
    'austafrika'                                => '014',
    'austasia'                                  => '030',
    'austerrike'                                => 'at',
    'austeuropa'                                => 151,
    'australia'                                 => 'au',
    'australiaognewzealand'                     => '053',
    'austtimor'                                 => 'tl',
    'bahamas'                                   => 'bs',
    'bahrain'                                   => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgia'                                    => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhutan'                                    => 'bt',
    'bolivia'                                   => 'bo',
    'bosniaoghercegovina'                       => 'ba',
    'botswana'                                  => 'bw',
    'bouvetøya'                                => 'bv',
    'brasil'                                    => 'br',
    'britishantarcticterritory'                 => 'bq',
    'britiskeområdeidetindiskehav'             => 'io',
    'bruneidarussalam'                          => 'bn',
    'bulgaria'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'canada'                                    => 'ca',
    'cantonandenderburyislands'                 => 'ct',
    'caymanøyane'                              => 'ky',
    'ceutaogmelilla'                            => 'ea',
    'chile'                                     => 'cl',
    'christmasøya'                             => 'cx',
    'clippertonøya'                            => 'cp',
    'colombia'                                  => 'co',
    'cookøyane'                                => 'ck',
    'costarica'                                 => 'cr',
    'cuba'                                      => 'cu',
    'czechoslovakia'                            => 200,
    'danmark'                                   => 'dk',
    'deiamerikanskejomfruøyane'                => 'vi',
    'deibritiskejomfruøyane'                   => 'vg',
    'deinederlandskeantillane'                  => 'an',
    'deisameintearabiskeemirata'                => 'ae',
    'dendominikanskerepublikken'                => 'do',
    'deneuropeiskeunionen'                      => 'eu',
    'densentralafrikanskerepublikken'           => 'cf',
    'diegogarcia'                               => 'dg',
    'djibouti'                                  => 'dj',
    'dominica'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egypt'                                     => 'eg',
    'ekvatorialguinea'                          => 'gq',
    'elfenbeinskysten'                          => 'ci',
    'elsalvador'                                => 'sv',
    'eritrea'                                   => 'er',
    'estland'                                   => 'ee',
    'etiopia'                                   => 'et',
    'europa'                                    => 150,
    'falklandsøyane'                           => 'fk',
    'fiji'                                      => 'fj',
    'filippinane'                               => 'ph',
    'finland'                                   => 'fi',
    'frankrike'                                 => 'fr',
    'franskesørområde'                        => 'tf',
    'franskguyana'                              => 'gf',
    'franskpolynesia'                           => 'pf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'færøyane'                                => 'fo',
    'gabon'                                     => 'ga',
    'gambia'                                    => 'gm',
    'georgia'                                   => 'ge',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'grenada'                                   => 'gd',
    'grønland'                                 => 'gl',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guinea'                                    => 'gn',
    'guineabissau'                              => 'gw',
    'guyana'                                    => 'gy',
    'haiti'                                     => 'ht',
    'heardogmcdonaldsøyane'                    => 'hm',
    'hellas'                                    => 'gr',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'india'                                     => 'in',
    'indonesia'                                 => 'id',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'irland'                                    => 'ie',
    'island'                                    => 'is',
    'israel'                                    => 'il',
    'italia'                                    => 'it',
    'jamaica'                                   => 'jm',
    'japan'                                     => 'jp',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordan'                                    => 'jo',
    'kambodsja'                                 => 'kh',
    'kamerun'                                   => 'cm',
    'kanaløyane'                               => 830,
    'kanariøyane'                              => 'ic',
    'kappverde'                                 => 'cv',
    'karibia'                                   => '029',
    'kasakhstan'                                => 'kz',
    'kenya'                                     => 'ke',
    'kina'                                      => 'cn',
    'kirgisistan'                               => 'kg',
    'kiribati'                                  => 'ki',
    'kokosøyane'                               => 'cc',
    'komorene'                                  => 'km',
    'kongobrazzaville'                          => 'cg',
    'kongokinshasa'                             => 'cd',
    'kroatia'                                   => 'hr',
    'kuwait'                                    => 'kw',
    'kviterussland'                             => 'by',
    'kypros'                                    => 'cy',
    'laos'                                      => 'la',
    'latinamerikaogkaribia'                     => 419,
    'latvia'                                    => 'lv',
    'lesotho'                                   => 'ls',
    'libanon'                                   => 'lb',
    'liberia'                                   => 'lr',
    'libya'                                     => 'ly',
    'liechtenstein'                             => 'li',
    'litauen'                                   => 'lt',
    'luxembourg'                                => 'lu',
    'macao'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'makedonia'                                 => 'mk',
    'malawi'                                    => 'mw',
    'malaysia'                                  => 'my',
    'maldivane'                                 => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'man'                                       => 'im',
    'marokko'                                   => 'ma',
    'marshalløyane'                            => 'mh',
    'martinique'                                => 'mq',
    'mauritania'                                => 'mr',
    'mauritius'                                 => 'mu',
    'mayotte'                                   => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'mexico'                                    => 'mx',
    'midwayislands'                             => 'mi',
    'mikronesia'                                => '057',
    'mikronesiaføderasjonen'                   => 'fm',
    'moldova'                                   => 'md',
    'monaco'                                    => 'mc',
    'mongolia'                                  => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mosambik'                                  => 'mz',
    'myanmar'                                   => 'mm',
    'namibia'                                   => 'na',
    'nauru'                                     => 'nr',
    'nederland'                                 => 'nl',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'newzealand'                                => 'nz',
    'nicaragua'                                 => 'ni',
    'niger'                                     => 'ne',
    'nigeria'                                   => 'ng',
    'niue'                                      => 'nu',
    'nordafrika'                                => '015',
    'nordamerika'                               => '003',
    'nordeuropa'                                => 154,
    'nordkorea'                                 => 'kp',
    'nordlegeamerika'                           => '021',
    'nordmarianane'                             => 'mp',
    'noreg'                                     => 'no',
    'norfolkøyane'                             => 'nf',
    'northvietnam'                              => 'vd',
    'nycaledonia'                               => 'nc',
    'oman'                                      => 'om',
    'oseania'                                   => '009',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'palestinskterritorium'                     => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanyguinea'                             => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'polen'                                     => 'pl',
    'polynesia'                                 => '061',
    'portugal'                                  => 'pt',
    'puertorico'                                => 'pr',
    'qatar'                                     => 'qa',
    'romania'                                   => 'ro',
    'russland'                                  => 'ru',
    'rwanda'                                    => 'rw',
    'réunion'                                  => 're',
    'saintbarthélemy'                          => 'bl',
    'sainthelena'                               => 'sh',
    'saintmartin'                               => 'mf',
    'salomonøyane'                             => 'sb',
    'samoa'                                     => 'ws',
    'samveldetavuavhengigestatar'               => 172,
    'sanmarino'                                 => 'sm',
    'saudiarabia'                               => 'sa',
    'senegal'                                   => 'sn',
    'sentralafrika'                             => '017',
    'sentralamerika'                            => '013',
    'sentralasia'                               => 143,
    'serbia'                                    => 'rs',
    'serbiaogmontenegro'                        => 'cs',
    'seychellane'                               => 'sc',
    'sierraleone'                               => 'sl',
    'singapore'                                 => 'sg',
    'slovakia'                                  => 'sk',
    'slovenia'                                  => 'si',
    'somalia'                                   => 'so',
    'spania'                                    => 'es',
    'srilanka'                                  => 'lk',
    "st\.christopherognevis"                    => 'kn',
    "st\.lucia"                                 => 'lc',
    "st\.pierreogmiquelon"                      => 'pm',
    "st\.vincentoggrenadinane"                  => 'vc',
    'storbritannia'                             => 'gb',
    'sudan'                                     => 'sd',
    'surinam'                                   => 'sr',
    'svalbardogjanmayen'                        => 'sj',
    'sveits'                                    => 'ch',
    'sverige'                                   => 'se',
    'swaziland'                                 => 'sz',
    'syria'                                     => 'sy',
    'sãotoméogpríncipe'                      => 'st',
    'sørafrika'                                => 'za',
    'søramerika'                               => '005',
    'sørasia'                                  => '034',
    'søraustasia'                              => '035',
    'søreuropa'                                => '039',
    'sørgeorgiaogsørsandwichøyane'           => 'gs',
    'sørkorea'                                 => 'kr',
    'sørlegeafrika'                            => '018',
    'sørlegesentralasia'                       => '062',
    'tadsjikistan'                              => 'tj',
    'taiwan'                                    => 'tw',
    'tanzania'                                  => 'tz',
    'tchad'                                     => 'td',
    'thailand'                                  => 'th',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadogtobago'                          => 'tt',
    'tristandacunha'                            => 'ta',
    'tsjekkia'                                  => 'cz',
    'tunisia'                                   => 'tn',
    'turkmenistan'                              => 'tm',
    'turksogcaicosøyane'                       => 'tc',
    'tuvalu'                                    => 'tv',
    'tyrkia'                                    => 'tr',
    'tyskland'                                  => 'de',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukjentområde'                             => 'zz',
    'ukraina'                                   => 'ua',
    'ungarn'                                    => 'hu',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    'usa'                                       => 'us',
    'usasytresmåøyar'                         => 'um',
    'usbekistan'                                => 'uz',
    'vanuatu'                                   => 'vu',
    'vatikanstaten'                             => 'va',
    'venezuela'                                 => 've',
    'verda'                                     => '001',
    'vestafrika'                                => '011',
    'vestasia'                                  => 145,
    'vesteuropa'                                => 155,
    'vestsahara'                                => 'eh',
    'vietnam'                                   => 'vn',
    'wakeisland'                                => 'wk',
    'wallisogfutuna'                            => 'wf',
    'yemen'                                     => 'ye',
    'ytreoseania'                               => 'qo',
    'zambia'                                    => 'zm',
    'zimbabwe'                                  => 'zw',
    'Åland'                                    => 'ax',
);

1;

