package Locales::DB::Territory::vi;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::vi::VERSION = '0.09';

$Locales::DB::Territory::vi::cldr_version = '2.0';

%Locales::DB::Territory::vi::code_to_name = (
    '001' => "Thế\ giới",
    '002' => "Châu\ Phi",
    '003' => "Bắc\ Mỹ",
    '005' => "Nam\ Mỹ",
    '009' => "Châu\ Đại\ Dương",
    '011' => "Tây\ Phi",
    '013' => "Trung\ Mỹ",
    '014' => "Đông\ Phí",
    '015' => "Bắc\ Phi",
    '017' => "Trung\ Phi",
    '018' => "Miền\ Nam\ Châu\ Phi",
    '019' => "Châu\ Mỹ",
    '021' => "Miền\ Bắc\ Châu\ Mỹ",
    '029' => "Ca\-ri\-bê",
    '030' => "Đông\ Á",
    '034' => "Nam\ Á",
    '035' => "Đông\ Nam\ Á",
    '039' => "Nam\ Âu",
    '053' => "Úc\ và\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Vùng\ Micronesian",
    '061' => 'Polynesia',
    '062' => "Trung\ Nam\ Á",
    142   => "Châu\ Á",
    143   => "Trung\ Á",
    145   => "Tây\ Á",
    150   => "Âu\ Châu",
    151   => "Đông\ Âu",
    154   => "Miền\ Bắc\ Châu\ Âu",
    155   => "Tây\ Âu",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Châu\ Mỹ\ La\-tinh\ và\ Ca\-ri\-be",
    830   => "Channel\ Islands",
    'ac'  => "Đảo\ Ascension",
    'ad'  => 'Andorra',
    'ae'  => "Các\ Tiểu\ Vương\ quốc\ A\-rập\ Thống\ nhất",
    'af'  => "Áp\-ga\-ni\-xtan",
    'ag'  => "An\-ti\-gu\-a\ và\ Ba\-bu\-đa",
    'ai'  => 'Anguilla',
    'al'  => "An\-ba\-ni",
    'am'  => "Ác\-mê\-ni\-a",
    'an'  => "Tây\ Ấn\ Hà\ Lan",
    'ao'  => "Ăng\-gô\-la",
    'aq'  => "Nam\ Cực",
    'ar'  => "Ác\-hen\-ti\-na",
    'as'  => "Đảo\ Somoa\ thuộc\ Mỹ",
    'at'  => 'Áo',
    'au'  => 'Úc',
    'aw'  => 'Aruba',
    'ax'  => "Quần\ đảo\ Aland",
    'az'  => "Ai\-déc\-bai\-gian",
    'ba'  => "Bô\-xni\-a\ Héc\-xê\-gô\-vi\-na",
    'bb'  => "Bác\-ba\-đốt",
    'bd'  => "Băng\-la\-đét",
    'be'  => 'Bỉ',
    'bf'  => "Buốc\-ki\-na\ Pha\-xô",
    'bg'  => "Bun\-ga\-ri",
    'bh'  => "Ba\-ren",
    'bi'  => "Bu\-run\-đi",
    'bj'  => "Bê\-nanh",
    'bl'  => 'BL',
    'bm'  => 'Bermuda',
    'bn'  => "Bru\-nây",
    'bo'  => "Bô\-li\-vi\-a",
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => "Bra\-xin",
    'bs'  => "Ba\-ha\-ma",
    'bt'  => "Bu\-tan\ \(Bhutan\)",
    'bv'  => "Đảo\ Bouvet\ \(Na\ Uy\)",
    'bw'  => "Bốt\-xoa\-na",
    'by'  => "Bê\-la\-rút",
    'bz'  => "Bê\-li\-xê",
    'ca'  => "Ca\-na\-đa",
    'cc'  => "Quần\ đảo\ Cocos",
    'cd'  => "Công\-gô\ \(DRC\)",
    'cf'  => "Cộng\ hòa\ Trung\ Phi",
    'cg'  => "Cộng\ hòa\ Công\-gô",
    'ch'  => "Thụy\ Sĩ",
    'ci'  => "Bờ\ Biển\ Ngà",
    'ck'  => "Quần\ Đảo\ Cook",
    'cl'  => "Chi\-lê",
    'cm'  => "Ca\-mơ\-run",
    'cn'  => "Trung\ Quốc",
    'co'  => "Cô\-lôm\-bi\-a",
    'cp'  => "Đảo\ Clipperton",
    'cr'  => "Cốt\-xta\ Ri\-ca",
    'cs'  => "Séc\-bia",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => "Cu\ Ba",
    'cv'  => "Cáp\-ve",
    'cx'  => "Đảo\ Giáng\ Sinh",
    'cy'  => 'Síp',
    'cz'  => "Cộng\ hòa\ Séc",
    'dd'  => "East\ Germany",
    'de'  => 'Đức',
    'dg'  => "Diego\ Garcia",
    'dj'  => "Gi\-bu\-ti",
    'dk'  => "Đan\ Mạch",
    'dm'  => 'Dominica',
    'do'  => "Cộng\ hoà\ Đô\-mi\-ni\-ca",
    'dz'  => "An\-giê\-ri",
    'ea'  => "Ceuta\ và\ Melilla",
    'ec'  => "Ê\-cu\-a\-đo",
    'ee'  => "E\-xtô\-ni\-a",
    'eg'  => "Ai\ Cập",
    'eh'  => "Tây\ Sahara",
    'er'  => "Ê\-ri\-tơ\-rê\-a",
    'es'  => "Tây\ Ban\ Nha",
    'et'  => "Ê\-ti\-ô\-pi\-a",
    'eu'  => "Liên\ Minh\ Châu\ Âu",
    'fi'  => "Phần\ Lan",
    'fj'  => "Phi\-gi",
    'fk'  => "Quần\ đảo\ Falkland\ \[Islas\ Malvinas\]",
    'fm'  => "Mi\-crô\-nê\-xi\-a",
    'fo'  => "Quần\ Đảo\ Faroe",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Pháp',
    'fx'  => "Metropolitan\ France",
    'ga'  => "Ga\-bông",
    'gb'  => "Vương\ quốc\ Anh",
    'gd'  => "Grê\-na\-đa",
    'ge'  => "Gru\-di\-a",
    'gf'  => "Quiana\ thuộc\ Pháp",
    'gg'  => 'Guernsey',
    'gh'  => "Gha\-na",
    'gi'  => 'Gibraltar',
    'gl'  => "Băng\ Đảo",
    'gm'  => "Găm\-bi\-a",
    'gn'  => "Ghi\-nê",
    'gp'  => 'Guadeloupe',
    'gq'  => "Ghi\-nê\ Xích\-đạo",
    'gr'  => "Hy\ Lạp",
    'gs'  => "Quần\ đảo\ Nam\ Georgia\ và\ Nam\ Sandwich",
    'gt'  => "Goa\-tê\-ma\-la",
    'gu'  => "Đảo\ Gu\-am",
    'gw'  => "Ghi\-nê\ Bít\-xao",
    'gy'  => "Guy\-a\-na",
    'hk'  => "Hồng\ Kông",
    'hm'  => "Đảo\ Heard\ và\ Quần\ đảo\ McDonald",
    'hn'  => "Hôn\-đu\-rát",
    'hr'  => "Crô\-a\-ti\-a",
    'ht'  => "Ha\-i\-ti",
    'hu'  => "Hung\-ga\-ri",
    'ic'  => "Quần\ đảo\ Canary",
    'id'  => "Nam\ Dương",
    'ie'  => "Ai\-len",
    'il'  => "I\-xra\-en",
    'im'  => "Đảo\ Man",
    'in'  => "Ấn\ Độ",
    'io'  => "Thuộc\ địa\ Anh\ tại\ Ấn\ Độ\ Dương",
    'iq'  => "I\-rắc",
    'ir'  => "I\-ran",
    'is'  => "Ai\-xơ\-len",
    'it'  => 'Ý',
    'je'  => 'Jersey',
    'jm'  => "Ha\-mai\-ca",
    'jo'  => "Gióc\-đa\-ni",
    'jp'  => "Nhật\ Bản",
    'jt'  => "Johnston\ Island",
    'ke'  => "Kê\-ni\-a",
    'kg'  => "Cư\-rơ\-gư\-xtan",
    'kh'  => 'Campuchia',
    'ki'  => "Ki\-ri\-ba\-ti",
    'km'  => "Cô\-mô",
    'kn'  => "Xan\-kít\ và\ Nê\-vi",
    'kp'  => "Bắc\ Triều\ Tiên",
    'kr'  => "Hàn\ Quốc",
    'kw'  => "Cô\-oét",
    'ky'  => "Quần\ Đảo\ Cayman",
    'kz'  => "Ka\-dắc\-xtan",
    'la'  => 'Lào',
    'lb'  => "Li\-băng",
    'lc'  => "Xan\ Lu\-xi",
    'li'  => "Lich\-ten\-xtên",
    'lk'  => "Xri\ Lan\-ca",
    'lr'  => "Li\-bê\-ri\-a",
    'ls'  => "Lê\-xô\-thô",
    'lt'  => "Li\-tu\-a\-ni\-a",
    'lu'  => "Lúc\-xăm\-bua",
    'lv'  => "Lát\-vi\-a",
    'ly'  => "Li\-bi",
    'ma'  => "Ma\-rốc",
    'mc'  => "Mô\-na\-cô",
    'md'  => "Môn\-đô\-va",
    'me'  => 'Montenegro',
    'mf'  => 'MF',
    'mg'  => "Ma\-đa\-gát\-xca",
    'mh'  => "Quần\ đảo\ Mác\-san",
    'mi'  => "Midway\ Islands",
    'mk'  => "Macedonia\ \[FYROM\]",
    'ml'  => "Ma\-li",
    'mm'  => "Mi\-an\-ma",
    'mn'  => "Mông\ Cổ",
    'mo'  => 'Macao',
    'mp'  => "Quần\ Đảo\ Bắc\ Mariana",
    'mq'  => 'MQ',
    'mr'  => "Mô\-ri\-ta\-ni",
    'ms'  => 'Montserrat',
    'mt'  => "Man\-ta",
    'mu'  => "Mô\-ri\-xơ",
    'mv'  => "Man\-đi\-vơ",
    'mw'  => "Ma\-la\-uy",
    'mx'  => "Mê\-hi\-cô",
    'my'  => "Ma\-lay\-xi\-a",
    'mz'  => "Mô\-dăm\-bích",
    'na'  => "Nam\-mi\-bi\-a",
    'nc'  => "New\ Caledonia",
    'ne'  => "Ni\-giê",
    'nf'  => "Đảo\ Norfolk",
    'ng'  => "Ni\-giê\-ri\-a",
    'ni'  => "Ni\-ca\-ra\-goa",
    'nl'  => "Hà\ Lan",
    'no'  => "Na\ Uy",
    'np'  => "Nê\-pan",
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Niu\ Di\-lân",
    'om'  => "Ô\-man",
    'pa'  => "Pa\-na\-ma",
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => "Pê\-ru",
    'pf'  => "Polynesia\ thuộc\ Pháp",
    'pg'  => "Pa\-pu\-a\ Niu\ Ghi\-nê",
    'ph'  => "Phi\-lip\-pin",
    'pk'  => "Pa\-ki\-xtan",
    'pl'  => "Ba\ Lan",
    'pm'  => "Saint\ Pierre\ và\ Miquelon",
    'pn'  => "Quần\ đảo\ Pitcairn",
    'pr'  => "Puerto\ Rico",
    'ps'  => "Lãnh\ thổ\ Palestine",
    'pt'  => "Bồ\ Đào\ Nha",
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => "Pa\-ra\-goay",
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => "Ca\-ta",
    'qo'  => "Vùng\ xa\ xôi\ thuộc\ Châu\ Đại\ Dương",
    're'  => 'RE',
    'ro'  => "Ru\-ma\-ni",
    'rs'  => "Xéc\-bi",
    'ru'  => 'Nga',
    'rw'  => "Ru\-an\-đa",
    'sa'  => "A\-rập\ Xê\-út",
    'sb'  => "Quần\ đảo\ Xô\-lô\-mông",
    'sc'  => "Xây\-sen",
    'sd'  => "Xu\-đăng",
    'se'  => "Thụy\ Điển",
    'sg'  => "Xin\-ga\-po",
    'sh'  => "Saint\ Helena",
    'si'  => "Xlô\-ven\-ni\-a",
    'sj'  => "Svalbard\ và\ Jan\ Mayen",
    'sk'  => "Xlô\-va\-ki\-a",
    'sl'  => "Xi\-ê\-ra\ Lê\-ôn",
    'sm'  => "Xan\ Ma\-ri\-nô",
    'sn'  => "Xê\-nê\-gan",
    'so'  => "Xô\-ma\-li",
    'sr'  => "Xu\-ri\-nam",
    'st'  => "Xao\ Tô\-mê\ và\ Prin\-xi\-pê",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "En\-san\-va\-đo",
    'sy'  => "Xi\-ri",
    'sz'  => "Xoa\-di\-len",
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Quần\ Đảo\ Turk\ và\ Caicos",
    'td'  => 'Sát',
    'tf'  => "Thuộc\ Địa\ Nam\ của\ Pháp",
    'tg'  => "Tô\-gô",
    'th'  => "Thái\ Lan",
    'tj'  => "Tát\-gi\-ki\-xtan",
    'tk'  => 'Tokelau',
    'tl'  => "Đông\ Timor",
    'tm'  => "Tuốc\-mê\-ni\-xtan",
    'tn'  => "Tuy\-ni\-di",
    'to'  => "Tông\-ga",
    'tr'  => "Thổ\ Nhĩ\ Kỳ",
    'tt'  => "Tri\-ni\-đát\ và\ Tô\-ba\-gô",
    'tv'  => "Tu\-va\-lu",
    'tw'  => "Đài\ Loan",
    'tz'  => "Tan\-da\-ni\-a",
    'ua'  => "U\-crai\-na",
    'ug'  => "U\-gan\-đa",
    'um'  => "Các\ đảo\ nhỏ\ xa\ trung\ tâm\ thuộc\ Mỹ",
    'us'  => "Hoa\ Kỳ",
    'uy'  => "U\-ru\-goay",
    'uz'  => "U\-dơ\-bê\-ki\-xtan",
    'va'  => "Va\-ti\-căng",
    'vc'  => "Xan\ Vin\-xen\ và\ Grê\-na\-din",
    'vd'  => "North\ Vietnam",
    've'  => "Vê\-nê\-zu\-ê\-la",
    'vg'  => "Đảo\ Virgin\,\ thuộc\ Anh",
    'vi'  => "Quần\ đảo\ Virgin\,\ Mỹ",
    'vn'  => "Việt\ Nam",
    'vu'  => "Va\-nu\-a\-tu",
    'wf'  => "Wallis\ và\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => "Xa\-moa",
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => "Y\-ê\-men",
    'yt'  => 'YT',
    'za'  => "Nam\ Phi",
    'zm'  => "Dăm\-bi\-a",
    'zw'  => "Dim\-ba\-bu\-ê",
    'zz'  => "Vùng\ Chưa\ biết\ hoặc\ không\ Hợp\ lệ",
);

%Locales::DB::Territory::vi::name_to_code = (
    'aicập'                                    => 'eg',
    'aidécbaigian'                              => 'az',
    'ailen'                                      => 'ie',
    'aixơlen'                                   => 'is',
    'anbani'                                     => 'al',
    'andorra'                                    => 'ad',
    'angiêri'                                   => 'dz',
    'anguilla'                                   => 'ai',
    'antiguavàbabuđa'                          => 'ag',
    'aruba'                                      => 'aw',
    'arậpxêút'                               => 'sa',
    'bahama'                                     => 'bs',
    'balan'                                      => 'pl',
    'baren'                                      => 'bh',
    'bermuda'                                    => 'bm',
    'bl'                                         => 'bl',
    'braxin'                                     => 'br',
    'britishantarcticterritory'                  => 'bq',
    'brunây'                                    => 'bn',
    'bungari'                                    => 'bg',
    'burunđi'                                   => 'bi',
    'butanbhutan'                                => 'bt',
    'buốckinaphaxô'                           => 'bf',
    'bácbađốt'                               => 'bb',
    'bêlarút'                                  => 'by',
    'bêlixê'                                   => 'bz',
    'bênanh'                                    => 'bj',
    'bôlivia'                                   => 'bo',
    'bôxniahécxêgôvina'                      => 'ba',
    'bănglađét'                               => 'bd',
    'băngĐảo'                                => 'gl',
    'bắcmỹ'                                  => '003',
    'bắcphi'                                   => '015',
    'bắctriềutiên'                          => 'kp',
    'bỉ'                                       => 'be',
    'bốtxoana'                                 => 'bw',
    'bồĐàonha'                               => 'pt',
    'bờbiểnngà'                             => 'ci',
    'campuchia'                                  => 'kh',
    'camơrun'                                   => 'cm',
    'canađa'                                    => 'ca',
    'cantonandenderburyislands'                  => 'ct',
    'caribê'                                    => '029',
    'cata'                                       => 'qa',
    'ceutavàmelilla'                            => 'ea',
    'channelislands'                             => 830,
    'chilê'                                     => 'cl',
    'châumỹ'                                  => '019',
    'châumỹlatinhvàcaribe'                   => 419,
    'châuphi'                                   => '002',
    'châuÁ'                                    => 142,
    'châuĐạidương'                         => '009',
    'commonwealthofindependentstates'            => 172,
    'crôatia'                                   => 'hr',
    'cuba'                                       => 'cu',
    'czechoslovakia'                             => 200,
    'cáctiểuvươngquốcarậpthốngnhất' => 'ae',
    'cácđảonhỏxatrungtâmthuộcmỹ'      => 'um',
    'cápve'                                     => 'cv',
    'côlômbia'                                 => 'co',
    'cômô'                                     => 'km',
    'cônggôdrc'                                => 'cd',
    'côoét'                                    => 'kw',
    'cưrơgưxtan'                              => 'kg',
    'cốtxtarica'                               => 'cr',
    'cộnghoàĐôminica'                       => 'do',
    'cộnghòacônggô'                         => 'cg',
    'cộnghòaséc'                             => 'cz',
    'cộnghòatrungphi'                         => 'cf',
    'diegogarcia'                                => 'dg',
    'dimbabuê'                                  => 'zw',
    'dominica'                                   => 'dm',
    'dronningmaudland'                           => 'nq',
    'dămbia'                                    => 'zm',
    'eastgermany'                                => 'dd',
    'ensanvađo'                                 => 'sv',
    'extônia'                                   => 'ee',
    'frenchsouthernandantarcticterritories'      => 'fq',
    'gabông'                                    => 'ga',
    'ghana'                                      => 'gh',
    'ghinê'                                     => 'gn',
    'ghinêbítxao'                              => 'gw',
    'ghinêxíchđạo'                          => 'gq',
    'gibraltar'                                  => 'gi',
    'gibuti'                                     => 'dj',
    'giócđani'                                 => 'jo',
    'goatêmala'                                 => 'gt',
    'grudia'                                     => 'ge',
    'grênađa'                                  => 'gd',
    'guadeloupe'                                 => 'gp',
    'guernsey'                                   => 'gg',
    'guyana'                                     => 'gy',
    'gămbia'                                    => 'gm',
    'haiti'                                      => 'ht',
    'hamaica'                                    => 'jm',
    'hoakỳ'                                    => 'us',
    'hunggari'                                   => 'hu',
    'hylạp'                                    => 'gr',
    'hàlan'                                     => 'nl',
    'hànquốc'                                 => 'kr',
    'hônđurát'                                => 'hn',
    'hồngkông'                                => 'hk',
    'iran'                                       => 'ir',
    'irắc'                                     => 'iq',
    'ixraen'                                     => 'il',
    'jersey'                                     => 'je',
    'johnstonisland'                             => 'jt',
    'kadắcxtan'                                => 'kz',
    'kiribati'                                   => 'ki',
    'kênia'                                     => 'ke',
    'libi'                                       => 'ly',
    'libêria'                                   => 'lr',
    'libăng'                                    => 'lb',
    'lichtenxtên'                               => 'li',
    'lituania'                                   => 'lt',
    'liênminhchâuÂu'                          => 'eu',
    'lào'                                       => 'la',
    'látvia'                                    => 'lv',
    'lãnhthổpalestine'                        => 'ps',
    'lêxôthô'                                 => 'ls',
    'lúcxămbua'                                => 'lu',
    'macao'                                      => 'mo',
    'macedoniafyrom'                             => 'mk',
    'malauy'                                     => 'mw',
    'malayxia'                                   => 'my',
    'mali'                                       => 'ml',
    'manta'                                      => 'mt',
    'manđivơ'                                  => 'mv',
    'marốc'                                    => 'ma',
    'mađagátxca'                               => 'mg',
    'melanesia'                                  => '054',
    'metropolitanfrance'                         => 'fx',
    'mf'                                         => 'mf',
    'mianma'                                     => 'mm',
    'micrônêxia'                               => 'fm',
    'midwayislands'                              => 'mi',
    'miềnbắcchâumỹ'                       => '021',
    'miềnbắcchâuÂu'                        => 154,
    'miềnnamchâuphi'                          => '018',
    'montenegro'                                 => 'me',
    'montserrat'                                 => 'ms',
    'mq'                                         => 'mq',
    'mêhicô'                                   => 'mx',
    'môdămbích'                               => 'mz',
    'mônacô'                                   => 'mc',
    'môngcổ'                                  => 'mn',
    'mônđôva'                                 => 'md',
    'môritani'                                  => 'mr',
    'môrixơ'                                   => 'mu',
    'namcực'                                   => 'aq',
    'namdương'                                 => 'id',
    'nammibia'                                   => 'na',
    'nammỹ'                                    => '005',
    'namphi'                                     => 'za',
    'namÁ'                                      => '034',
    'namÂu'                                     => '039',
    'nauru'                                      => 'nr',
    'nauy'                                       => 'no',
    'neutralzone'                                => 'nt',
    'newcaledonia'                               => 'nc',
    'nga'                                        => 'ru',
    'nhậtbản'                                => 'jp',
    'nicaragoa'                                  => 'ni',
    'nigiê'                                     => 'ne',
    'nigiêria'                                  => 'ng',
    'niudilân'                                  => 'nz',
    'niue'                                       => 'nu',
    'northvietnam'                               => 'vd',
    'nêpan'                                     => 'np',
    'pacificislandstrustterritory'               => 'pc',
    'pakixtan'                                   => 'pk',
    'palau'                                      => 'pw',
    'panama'                                     => 'pa',
    'panamacanalzone'                            => 'pz',
    'papuaniughinê'                             => 'pg',
    'paragoay'                                   => 'py',
    "people\â\\sdemocraticrepublicofyemen"  => 'yd',
    'phigi'                                      => 'fj',
    'philippin'                                  => 'ph',
    'pháp'                                      => 'fr',
    'phầnlan'                                  => 'fi',
    'polynesia'                                  => '061',
    'polynesiathuộcpháp'                      => 'pf',
    'puertorico'                                 => 'pr',
    'pêru'                                      => 'pe',
    'quianathuộcpháp'                         => 'gf',
    'quầnĐảobắcmariana'                   => 'mp',
    'quầnĐảocayman'                         => 'ky',
    'quầnĐảocook'                           => 'ck',
    'quầnĐảofaroe'                          => 'fo',
    'quầnĐảoturkvàcaicos'                  => 'tc',
    'quầnđảoaland'                          => 'ax',
    'quầnđảocanary'                         => 'ic',
    'quầnđảococos'                          => 'cc',
    'quầnđảofalklandislasmalvinas'          => 'fk',
    'quầnđảomácsan'                        => 'mh',
    'quầnđảonamgeorgiavànamsandwich'       => 'gs',
    'quầnđảopitcairn'                       => 'pn',
    "quầnđảovirgin\,mỹ"                   => 'vi',
    'quầnđảoxôlômông'                    => 'sb',
    're'                                         => 're',
    'ruanđa'                                    => 'rw',
    'rumani'                                     => 'ro',
    'sainthelena'                                => 'sh',
    'saintpierrevàmiquelon'                     => 'pm',
    'svalbardvàjanmayen'                        => 'sj',
    'sát'                                       => 'td',
    'sécbia'                                    => 'cs',
    'síp'                                       => 'cy',
    'tandania'                                   => 'tz',
    'thuộcĐịanamcủapháp'                 => 'tf',
    'thuộcđịaanhtạiẤnĐộdương'      => 'io',
    'tháilan'                                   => 'th',
    'thếgiới'                                => '001',
    'thổnhĩkỳ'                              => 'tr',
    'thụysĩ'                                  => 'ch',
    'thụyĐiển'                              => 'se',
    'tokelau'                                    => 'tk',
    'triniđátvàtôbagô'                      => 'tt',
    'tristandacunha'                             => 'ta',
    'trungmỹ'                                  => '013',
    'trungnamÁ'                                 => '062',
    'trungphi'                                   => '017',
    'trungquốc'                                => 'cn',
    'trungÁ'                                    => 143,
    'tuvalu'                                     => 'tv',
    'tuynidi'                                    => 'tn',
    'tuốcmênixtan'                            => 'tm',
    'tátgikixtan'                               => 'tj',
    'tâybannha'                                 => 'es',
    'tâyphi'                                    => '011',
    'tâysahara'                                 => 'eh',
    'tâyÁ'                                     => 145,
    'tâyÂu'                                    => 155,
    'tâyẤnhàlan'                             => 'an',
    'tôgô'                                     => 'tg',
    'tôngga'                                    => 'to',
    "u\.s\.miscellaneouspacificislands"          => 'pu',
    'ucraina'                                    => 'ua',
    'udơbêkixtan'                              => 'uz',
    'uganđa'                                    => 'ug',
    'unionofsovietsocialistrepublics'            => 'su',
    'urugoay'                                    => 'uy',
    'vanuatu'                                    => 'vu',
    'vaticăng'                                  => 'va',
    'việtnam'                                  => 'vn',
    'vênêzuêla'                               => 've',
    'vùngchưabiếthoặckhônghợplệ'      => 'zz',
    'vùngmicronesian'                           => '057',
    'vùngxaxôithuộcchâuĐạidương'       => 'qo',
    'vươngquốcanh'                           => 'gb',
    'wakeisland'                                 => 'wk',
    'wallisvàfutuna'                            => 'wf',
    'xamoa'                                      => 'ws',
    'xankítvànêvi'                            => 'kn',
    'xanluxi'                                    => 'lc',
    'xanmarinô'                                 => 'sm',
    'xanvinxenvàgrênadin'                      => 'vc',
    'xaotômêvàprinxipê'                      => 'st',
    'xingapo'                                    => 'sg',
    'xiri'                                       => 'sy',
    'xiêralêôn'                               => 'sl',
    'xlôvakia'                                  => 'sk',
    'xlôvennia'                                 => 'si',
    'xoadilen'                                   => 'sz',
    'xrilanca'                                   => 'lk',
    'xurinam'                                    => 'sr',
    'xuđăng'                                   => 'sd',
    'xâysen'                                    => 'sc',
    'xécbi'                                     => 'rs',
    'xênêgan'                                  => 'sn',
    'xômali'                                    => 'so',
    'yt'                                         => 'yt',
    'yêmen'                                     => 'ye',
    'Áchentina'                                 => 'ar',
    'Ácmênia'                                  => 'am',
    'Áo'                                        => 'at',
    'Ápganixtan'                                => 'af',
    'Âuchâu'                                   => 150,
    'Êcuađo'                                   => 'ec',
    'Êritơrêa'                                => 'er',
    'Êtiôpia'                                  => 'et',
    'Ôman'                                      => 'om',
    'Úc'                                        => 'au',
    'Úcvànewzealand'                           => '053',
    'Ý'                                         => 'it',
    'Ănggôla'                                  => 'ao',
    'Đanmạch'                                 => 'dk',
    'Đàiloan'                                  => 'tw',
    'ĐôngnamÁ'                                => '035',
    'Đôngphí'                                 => '014',
    'Đôngtimor'                                => 'tl',
    'ĐôngÁ'                                   => '030',
    'ĐôngÂu'                                  => 151,
    'Đảoascension'                            => 'ac',
    'Đảobouvetnauy'                           => 'bv',
    'Đảoclipperton'                           => 'cp',
    'Đảogiángsinh'                           => 'cx',
    'Đảoguam'                                 => 'gu',
    'Đảoheardvàquầnđảomcdonald'         => 'hm',
    'Đảoman'                                  => 'im',
    'Đảonorfolk'                              => 'nf',
    'Đảosomoathuộcmỹ'                     => 'as',
    "Đảovirgin\,thuộcanh"                   => 'vg',
    'Đức'                                     => 'de',
    'ẤnĐộ'                                  => 'in',
);

1;

