package Locales::DB::Territory::ha;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::ha::VERSION = '0.09';

$Locales::DB::Territory::ha::cldr_version = '2.0';

%Locales::DB::Territory::ha::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andora',
    'ae'  => "Haɗaɗɗiyar\ Daular\ Larabawa",
    'af'  => 'Afaganistan',
    'ag'  => "Antigwa\ da\ Barbuba",
    'ai'  => 'Angila',
    'al'  => 'Albaniya',
    'am'  => 'Armeniya',
    'an'  => "Antiya\ Na\ Holan",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Arjantiniya',
    'as'  => "Samowa\ Ta\ Amurka",
    'at'  => 'Ostiriya',
    'au'  => 'Ostareliya',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azarbaijan',
    'ba'  => "Bosniya\ Harzagobina",
    'bb'  => 'Barbadas',
    'bd'  => 'Bangiladas',
    'be'  => 'Belgiyom',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgariya',
    'bh'  => 'Baharan',
    'bi'  => 'Burundi',
    'bj'  => 'Binin',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Barmuda',
    'bn'  => 'Burune',
    'bo'  => 'Bolibiya',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Birazil',
    'bs'  => 'Bahamas',
    'bt'  => 'Butan',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Baswana',
    'by'  => 'Belarus',
    'bz'  => 'Beliz',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Jamhuriyar\ Dimokuraɗiyyar\ Kongo",
    'cf'  => "Jamhuriyar\ Afirka\ Ta\ Tsakiya",
    'cg'  => 'Kongo',
    'ch'  => 'Suwizalan',
    'ci'  => "Aibari\ Kwas",
    'ck'  => "Tsibiran\ Kuku",
    'cl'  => 'Cayile',
    'cm'  => 'Kamaru',
    'cn'  => "Caina\,\ Sin",
    'co'  => 'Kolambiya',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kwasta\ Rika",
    'cs'  => "Sarbiya\ Da\ Mantanegiro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kyuba',
    'cv'  => "Tsibiran\ Kap\ Barde",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Sifurus',
    'cz'  => "Jamhuriyar\ Cak",
    'dd'  => "East\ Germany",
    'de'  => 'Jamus',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jibuti',
    'dk'  => 'Danmark',
    'dm'  => 'Dominika',
    'do'  => "Jamhuriyar\ Dominika",
    'dz'  => 'Aljeriya',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwador',
    'ee'  => 'Estoniya',
    'eg'  => "Masar\,\ Misira",
    'eh'  => "Western\ Sahara",
    'er'  => 'Eritireya',
    'es'  => 'Sipen',
    'et'  => 'Habasha',
    'eu'  => "European\ Union",
    'fi'  => 'Finlan',
    'fj'  => 'Fiji',
    'fk'  => "Tsibiran\ Falkilan",
    'fm'  => 'Mikuronesiya',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Faransa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => 'Birtaniya',
    'gd'  => 'Girnada',
    'ge'  => 'Jiwarjiya',
    'gf'  => "Gini\ Ta\ Faransa",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Jibaraltar',
    'gl'  => 'Grinlan',
    'gm'  => 'Gambiya',
    'gn'  => 'Gini',
    'gp'  => 'Gwadaluf',
    'gq'  => "Gini\ Ta\ Ikwaita",
    'gr'  => 'Girka',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatamala',
    'gu'  => 'Gwam',
    'gw'  => "Gini\ Bisau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Honduras',
    'hr'  => 'Kurowaishiya',
    'ht'  => 'Haiti',
    'hu'  => 'Hungari',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indunusiya',
    'ie'  => 'Ayalan',
    'il'  => "Izira\'ila",
    'im'  => "Isle\ of\ Man",
    'in'  => 'Indiya',
    'io'  => "Yankin\ Birtaniya\ Na\ Tekun\ Indiya",
    'iq'  => 'Iraƙi',
    'ir'  => 'Iran',
    'is'  => 'Aisalan',
    'it'  => 'Italiya',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordan',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirgizistan',
    'kh'  => 'Kambodiya',
    'ki'  => 'Kiribati',
    'km'  => 'Kwamoras',
    'kn'  => "San\ Kiti\ Da\ Nebis",
    'kp'  => "Koreya\ Ta\ Arewa",
    'kr'  => "Koreya\ Ta\ Kudu",
    'kw'  => 'Kwiyat',
    'ky'  => "Tsibiran\ Kaiman",
    'kz'  => 'Kazakistan',
    'la'  => 'Lawas',
    'lb'  => 'Labanan',
    'lc'  => "San\ Lusiya",
    'li'  => 'Licansitan',
    'lk'  => "Siri\ Lanka",
    'lr'  => 'Laberiya',
    'ls'  => 'Lesoto',
    'lt'  => 'Lituweniya',
    'lu'  => 'Lukusambur',
    'lv'  => 'latibiya',
    'ly'  => 'Libiya',
    'ma'  => 'Maroko',
    'mc'  => 'Monako',
    'md'  => 'Maldoba',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Tsibiran\ Marshal",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedoniya',
    'ml'  => 'Mali',
    'mm'  => "Burma\,\ Miyamar",
    'mn'  => 'Mangoliya',
    'mo'  => 'Macau',
    'mp'  => "Tsibiran\ Mariyana\ Na\ Arewa",
    'mq'  => 'Martinik',
    'mr'  => 'Moritaniya',
    'ms'  => 'Manserati',
    'mt'  => 'Malta',
    'mu'  => 'Moritus',
    'mv'  => 'Maldibi',
    'mw'  => 'Malawi',
    'mx'  => 'Makasiko',
    'my'  => 'Malaisiya',
    'mz'  => 'Mozambik',
    'na'  => 'Namibiya',
    'nc'  => "Kaledoniya\ Sabuwa",
    'ne'  => 'Nijar',
    'nf'  => "Tsibirin\ Narfalk",
    'ng'  => 'Najeriya',
    'ni'  => 'Nikaraguwa',
    'nl'  => 'Holan',
    'no'  => 'Norwe',
    'np'  => 'Nefal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niyu',
    'nz'  => 'Nuzilan',
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Folinesiya\ Ta\ Faransa",
    'pg'  => "Papuwa\ Nugini",
    'ph'  => 'Filipin',
    'pk'  => 'Pakistan',
    'pl'  => 'Polan',
    'pm'  => "San\ Piyar\ Da\ Mikelan",
    'pn'  => 'Pitakarin',
    'pr'  => "Porto\ Riko",
    'ps'  => 'Palasɗinu',
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paragai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Kwatar',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Rawuniyan',
    'ro'  => 'Romaniya',
    'rs'  => 'Serbia',
    'ru'  => 'Rasha',
    'rw'  => 'Ruwanda',
    'sa'  => "Ƙasar\ Makka",
    'sb'  => "Tsibiran\ Salaman",
    'sc'  => 'Saishal',
    'sd'  => 'Sudan',
    'se'  => 'Suwedan',
    'sg'  => 'Singapur',
    'sh'  => "San\ Helena",
    'si'  => 'Sulobeniya',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Sulobakiya',
    'sl'  => 'Salewo',
    'sm'  => "San\ Marino",
    'sn'  => 'Sinigal',
    'so'  => 'Somaliya',
    'sr'  => 'Suriname',
    'st'  => "Sawo\ Tome\ Da\ Paransip",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salbador",
    'sy'  => "Sham\,\ Siriya",
    'sz'  => 'Suwazilan',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turkis\ Da\ Tsibiran\ Kaikwas",
    'td'  => 'Cadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Tailan',
    'tj'  => 'Tajikistan',
    'tk'  => 'Takelau',
    'tl'  => "Timor\ Ta\ Gabas",
    'tm'  => 'Turkumenistan',
    'tn'  => 'Tunisiya',
    'to'  => 'Tanga',
    'tr'  => 'Turkiyya',
    'tt'  => "Tirinidad\ Da\ Tobago",
    'tv'  => 'Tubalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzaniya',
    'ua'  => 'Yukaran',
    'ug'  => 'Yuganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Amurka',
    'uy'  => 'Yurugai',
    'uz'  => 'Uzubekistan',
    'va'  => 'Batikan',
    'vc'  => "San\ Binsan\ Da\ Girnadin",
    'vd'  => "North\ Vietnam",
    've'  => 'Benezuwela',
    'vg'  => "Tsibirin\ Birjin\ Na\ Birtaniya",
    'vi'  => "Tsibiran\ Birjin\ Ta\ Amurka",
    'vn'  => 'Biyetinam',
    'vu'  => 'Banuwatu',
    'wf'  => "Walis\ Da\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samowa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yamal',
    'yt'  => 'Mayoti',
    'za'  => "Afirka\ Ta\ Kudu",
    'zm'  => 'Zambiya',
    'zw'  => 'Zimbabuwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::ha::name_to_code = (
    'afaganistan'                               => 'af',
    'afirkatakudu'                              => 'za',
    'africa'                                    => '002',
    'aibarikwas'                                => 'ci',
    'aisalan'                                   => 'is',
    'albaniya'                                  => 'al',
    'aljeriya'                                  => 'dz',
    'americas'                                  => '019',
    'amurka'                                    => 'us',
    'andora'                                    => 'ad',
    'angila'                                    => 'ai',
    'angola'                                    => 'ao',
    'antarctica'                                => 'aq',
    'antigwadabarbuba'                          => 'ag',
    'antiyanaholan'                             => 'an',
    'arjantiniya'                               => 'ar',
    'armeniya'                                  => 'am',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'ayalan'                                    => 'ie',
    'azarbaijan'                                => 'az',
    'bahamas'                                   => 'bs',
    'baharan'                                   => 'bh',
    'bangiladas'                                => 'bd',
    'banuwatu'                                  => 'vu',
    'barbadas'                                  => 'bb',
    'barmuda'                                   => 'bm',
    'baswana'                                   => 'bw',
    'batikan'                                   => 'va',
    'belarus'                                   => 'by',
    'belgiyom'                                  => 'be',
    'beliz'                                     => 'bz',
    'benezuwela'                                => 've',
    'binin'                                     => 'bj',
    'birazil'                                   => 'br',
    'birtaniya'                                 => 'gb',
    'biyetinam'                                 => 'vn',
    'bolibiya'                                  => 'bo',
    'bosniyaharzagobina'                        => 'ba',
    'bouvetisland'                              => 'bv',
    'britishantarcticterritory'                 => 'bq',
    'bulgariya'                                 => 'bg',
    'burkinafaso'                               => 'bf',
    "burma\,miyamar"                            => 'mm',
    'burundi'                                   => 'bi',
    'burune'                                    => 'bn',
    'butan'                                     => 'bt',
    'cadi'                                      => 'td',
    "caina\,sin"                                => 'cn',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'cayile'                                    => 'cl',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danmark'                                   => 'dk',
    'diegogarcia'                               => 'dg',
    'dominika'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekwador'                                   => 'ec',
    'elsalbador'                                => 'sv',
    'eritireya'                                 => 'er',
    'estoniya'                                  => 'ee',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faransa'                                   => 'fr',
    'faroeislands'                              => 'fo',
    'fiji'                                      => 'fj',
    'filipin'                                   => 'ph',
    'finlan'                                    => 'fi',
    'folinesiyatafaransa'                       => 'pf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabon'                                     => 'ga',
    'gambiya'                                   => 'gm',
    'gana'                                      => 'gh',
    'gini'                                      => 'gn',
    'ginibisau'                                 => 'gw',
    'ginitafaransa'                             => 'gf',
    'ginitaikwaita'                             => 'gq',
    'girka'                                     => 'gr',
    'girnada'                                   => 'gd',
    'grinlan'                                   => 'gl',
    'guernsey'                                  => 'gg',
    'guyana'                                    => 'gy',
    'gwadaluf'                                  => 'gp',
    'gwam'                                      => 'gu',
    'gwatamala'                                 => 'gt',
    'habasha'                                   => 'et',
    'haiti'                                     => 'ht',
    'haɗaɗɗiyardaularlarabawa'               => 'ae',
    'heardislandandmcdonaldislands'             => 'hm',
    'holan'                                     => 'nl',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hungari'                                   => 'hu',
    'indiya'                                    => 'in',
    'indunusiya'                                => 'id',
    'iran'                                      => 'ir',
    'iraƙi'                                    => 'iq',
    'isleofman'                                 => 'im',
    'italiya'                                   => 'it',
    'iziraila'                                  => 'il',
    'jamaika'                                   => 'jm',
    'jamhuriyarafirkatatsakiya'                 => 'cf',
    'jamhuriyarcak'                             => 'cz',
    'jamhuriyardimokuraɗiyyarkongo'            => 'cd',
    'jamhuriyardominika'                        => 'do',
    'jamus'                                     => 'de',
    'japan'                                     => 'jp',
    'jersey'                                    => 'je',
    'jibaraltar'                                => 'gi',
    'jibuti'                                    => 'dj',
    'jiwarjiya'                                 => 'ge',
    'johnstonisland'                            => 'jt',
    'jordan'                                    => 'jo',
    'kaledoniyasabuwa'                          => 'nc',
    'kamaru'                                    => 'cm',
    'kambodiya'                                 => 'kh',
    'kanada'                                    => 'ca',
    'kazakistan'                                => 'kz',
    'kenya'                                     => 'ke',
    'kirgizistan'                               => 'kg',
    'kiribati'                                  => 'ki',
    'kolambiya'                                 => 'co',
    'kongo'                                     => 'cg',
    'koreyataarewa'                             => 'kp',
    'koreyatakudu'                              => 'kr',
    'kurowaishiya'                              => 'hr',
    'kwamoras'                                  => 'km',
    'kwastarika'                                => 'cr',
    'kwatar'                                    => 'qa',
    'kwiyat'                                    => 'kw',
    'kyuba'                                     => 'cu',
    'labanan'                                   => 'lb',
    'laberiya'                                  => 'lr',
    'latibiya'                                  => 'lv',
    'latinamerica'                              => 419,
    'lawas'                                     => 'la',
    'lesoto'                                    => 'ls',
    'libiya'                                    => 'ly',
    'licansitan'                                => 'li',
    'lituweniya'                                => 'lt',
    'lukusambur'                                => 'lu',
    'macau'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'makasiko'                                  => 'mx',
    'malaisiya'                                 => 'my',
    'malawi'                                    => 'mw',
    'maldibi'                                   => 'mv',
    'maldoba'                                   => 'md',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'mangoliya'                                 => 'mn',
    'manserati'                                 => 'ms',
    'maroko'                                    => 'ma',
    'martinik'                                  => 'mq',
    "masar\,misira"                             => 'eg',
    'masedoniya'                                => 'mk',
    'mayoti'                                    => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikuronesiya'                              => 'fm',
    'monako'                                    => 'mc',
    'montenegro'                                => 'me',
    'moritaniya'                                => 'mr',
    'moritus'                                   => 'mu',
    'mozambik'                                  => 'mz',
    'najeriya'                                  => 'ng',
    'namibiya'                                  => 'na',
    'nauru'                                     => 'nr',
    'nefal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nijar'                                     => 'ne',
    'nikaraguwa'                                => 'ni',
    'niyu'                                      => 'nu',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'norwe'                                     => 'no',
    'nuzilan'                                   => 'nz',
    'oceania'                                   => '009',
    'oman'                                      => 'om',
    'ostareliya'                                => 'au',
    'ostiriya'                                  => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palasɗinu'                                => 'ps',
    'palau'                                     => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuwanugini'                              => 'pg',
    'paragai'                                   => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitakarin'                                 => 'pn',
    'polan'                                     => 'pl',
    'polynesia'                                 => '061',
    'portoriko'                                 => 'pr',
    'portugal'                                  => 'pt',
    'rasha'                                     => 'ru',
    'rawuniyan'                                 => 're',
    'romaniya'                                  => 'ro',
    'ruwanda'                                   => 'rw',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'saishal'                                   => 'sc',
    'salewo'                                    => 'sl',
    'samowa'                                    => 'ws',
    'samowataamurka'                            => 'as',
    'sanbinsandagirnadin'                       => 'vc',
    'sanhelena'                                 => 'sh',
    'sankitidanebis'                            => 'kn',
    'sanlusiya'                                 => 'lc',
    'sanmarino'                                 => 'sm',
    'sanpiyardamikelan'                         => 'pm',
    'sarbiyadamantanegiro'                      => 'cs',
    'sawotomedaparansip'                        => 'st',
    'serbia'                                    => 'rs',
    "sham\,siriya"                              => 'sy',
    'sifurus'                                   => 'cy',
    'singapur'                                  => 'sg',
    'sinigal'                                   => 'sn',
    'sipen'                                     => 'es',
    'sirilanka'                                 => 'lk',
    'somaliya'                                  => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'sudan'                                     => 'sd',
    'sulobakiya'                                => 'sk',
    'sulobeniya'                                => 'si',
    'suriname'                                  => 'sr',
    'suwazilan'                                 => 'sz',
    'suwedan'                                   => 'se',
    'suwizalan'                                 => 'ch',
    'svalbardandjanmayen'                       => 'sj',
    'tailan'                                    => 'th',
    'taiwan'                                    => 'tw',
    'tajikistan'                                => 'tj',
    'takelau'                                   => 'tk',
    'tanga'                                     => 'to',
    'tanzaniya'                                 => 'tz',
    'timortagabas'                              => 'tl',
    'tirinidaddatobago'                         => 'tt',
    'togo'                                      => 'tg',
    'tristandacunha'                            => 'ta',
    'tsibiranbirjintaamurka'                    => 'vi',
    'tsibiranfalkilan'                          => 'fk',
    'tsibirankaiman'                            => 'ky',
    'tsibirankapbarde'                          => 'cv',
    'tsibirankuku'                              => 'ck',
    'tsibiranmariyananaarewa'                   => 'mp',
    'tsibiranmarshal'                           => 'mh',
    'tsibiransalaman'                           => 'sb',
    'tsibirinbirjinnabirtaniya'                 => 'vg',
    'tsibirinnarfalk'                           => 'nf',
    'tubalu'                                    => 'tv',
    'tunisiya'                                  => 'tn',
    'turkisdatsibirankaikwas'                   => 'tc',
    'turkiyya'                                  => 'tr',
    'turkumenistan'                             => 'tm',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'uzubekistan'                               => 'uz',
    'wakeisland'                                => 'wk',
    'walisdafutuna'                             => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yamal'                                     => 'ye',
    'yankinbirtaniyanatekunindiya'              => 'io',
    'yuganda'                                   => 'ug',
    'yukaran'                                   => 'ua',
    'yurugai'                                   => 'uy',
    'zambiya'                                   => 'zm',
    'zimbabuwe'                                 => 'zw',
    "\Ã\landislands"                         => 'ax',
    'Ƙasarmakka'                               => 'sa',
);

1;

