package Locales::DB::Territory::rn;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::rn::VERSION = '0.09';

$Locales::DB::Territory::rn::cldr_version = '2.0';

%Locales::DB::Territory::rn::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andora',
    'ae'  => "Leta\ Zunze\ Ubumwe\ z\'Abarabu",
    'af'  => 'Afuganisitani',
    'ag'  => "Antigwa\ na\ Baribuda",
    'ai'  => 'Angwila',
    'al'  => 'Alubaniya',
    'am'  => 'Arumeniya',
    'an'  => "Antiye\ y\'Abaholandi",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Arijantine',
    'as'  => "Samowa\ nyamerika",
    'at'  => 'Otirishe',
    'au'  => 'Ositaraliya',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerubayijani',
    'ba'  => "Bosiniya\ na\ Herigozevine",
    'bb'  => 'Barubadosi',
    'bd'  => 'Bangaladeshi',
    'be'  => 'Ububiligi',
    'bf'  => "Burukina\ Faso",
    'bg'  => 'Buligariya',
    'bh'  => 'Bahareyini',
    'bi'  => 'Uburundi',
    'bj'  => 'Bene',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Berimuda',
    'bn'  => 'Buruneyi',
    'bo'  => 'Boliviya',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Burezili',
    'bs'  => 'Bahamasi',
    'bt'  => 'Butani',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswana',
    'by'  => 'Belausi',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Repubulika\ Iharanira\ Demokarasi\ ya\ Kongo",
    'cf'  => "Repubulika\ ya\ Santarafurika",
    'cg'  => 'Kongo',
    'ch'  => 'Ubusuwisi',
    'ci'  => 'Kotedivuware',
    'ck'  => "I\\inga\ rya\ Kuku",
    'cl'  => 'Shili',
    'cm'  => 'Kameruni',
    'cn'  => 'Ubushinwa',
    'co'  => 'Kolombiya',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kositarika',
    'cs'  => "Seribiya\ na\ Montenegoro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kiba',
    'cv'  => "Ibirwa\ bya\ Kapuveri",
    'cx'  => "Christmas\ Island",
    'cy'  => "Izinga\ rya\ Shipure",
    'cz'  => "Repubulika\ ya\ Ceke",
    'dd'  => "East\ Germany",
    'de'  => 'Ubudage',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jibuti',
    'dk'  => 'Danimariki',
    'dm'  => 'Dominika',
    'do'  => "Repubulika\ ya\ Dominika",
    'dz'  => 'Alijeriya',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwateri',
    'ee'  => 'Esitoniya',
    'eg'  => 'Misiri',
    'eh'  => "Western\ Sahara",
    'er'  => 'Elitereya',
    'es'  => 'Hisipaniya',
    'et'  => 'Etiyopiya',
    'eu'  => "European\ Union",
    'fi'  => 'Finilandi',
    'fj'  => 'Fiji',
    'fk'  => "Izinga\ rya\ Filikilandi",
    'fm'  => 'Mikoroniziya',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Ubufaransa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabo',
    'gb'  => 'Ubwongereza',
    'gd'  => 'Gerenada',
    'ge'  => 'Jeworujiya',
    'gf'  => "Gwayana\ y\'Abafaransa",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Juburalitari',
    'gl'  => 'Gurunilandi',
    'gm'  => 'Gambiya',
    'gn'  => 'Guneya',
    'gp'  => 'Gwadelupe',
    'gq'  => "Gineya\ Ekwatoriyali",
    'gr'  => 'Ubugereki',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatemala',
    'gu'  => 'Gwamu',
    'gw'  => "Gineya\ Bisawu",
    'gy'  => 'Guyane',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hondurasi',
    'hr'  => 'Korowasiya',
    'ht'  => 'Hayiti',
    'hu'  => 'Hungariya',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indoneziya',
    'ie'  => 'Irilandi',
    'il'  => 'Isiraheli',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Ubuhindi',
    'io'  => "Intara\ y\'Ubwongereza\ yo\ mu\ birwa\ by\'Abahindi",
    'iq'  => 'Iraki',
    'ir'  => 'Irani',
    'is'  => 'Ayisilandi',
    'it'  => 'Ubutaliyani',
    'je'  => 'Jersey',
    'jm'  => 'Jamayika',
    'jo'  => 'Yorudaniya',
    'jp'  => 'Ubuyapani',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirigisitani',
    'kh'  => 'Kamboje',
    'ki'  => 'Kiribati',
    'km'  => "Izinga\ rya\ Komore",
    'kn'  => "Sekitsi\ na\ Nevisi",
    'kp'  => "Koreya\ y\'amajaruguru",
    'kr'  => "Koreya\ y\'amajepfo",
    'kw'  => 'Koweti',
    'ky'  => "Ibirwa\ bya\ Keyimani",
    'kz'  => 'Kazakisitani',
    'la'  => 'Layosi',
    'lb'  => 'Libani',
    'lc'  => 'Selusiya',
    'li'  => 'Lishyitenshitayini',
    'lk'  => 'Sirilanka',
    'lr'  => 'Liberiya',
    'ls'  => 'Lesoto',
    'lt'  => 'Lituwaniya',
    'lu'  => 'Lukusamburu',
    'lv'  => 'Lativa',
    'ly'  => 'Libiya',
    'ma'  => 'Maroke',
    'mc'  => 'Monako',
    'md'  => 'Moludavi',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagasikari',
    'mh'  => "Izinga\ rya\ Marishari",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedoniya',
    'ml'  => 'Mali',
    'mm'  => 'Birimaniya',
    'mn'  => 'Mongoliya',
    'mo'  => 'Macau',
    'mp'  => "Amazinga\ ya\ Mariyana\ ryo\ mu\ majaruguru",
    'mq'  => 'Maritiniki',
    'mr'  => 'Moritaniya',
    'ms'  => 'Monteserati',
    'mt'  => 'Malita',
    'mu'  => "Izinga\ rya\ Morise",
    'mv'  => 'Moludave',
    'mw'  => 'Malawi',
    'mx'  => 'Migizike',
    'my'  => 'Maleziya',
    'mz'  => 'Mozambiki',
    'na'  => 'Namibiya',
    'nc'  => 'Niyukaledoniya',
    'ne'  => 'Nijeri',
    'nf'  => "izinga\ rya\ Norufoluke",
    'ng'  => 'Nijeriya',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Ubuholandi',
    'no'  => 'Noruveji',
    'np'  => 'Nepali',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nawuru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niyuwe',
    'nz'  => 'Nuvelizelandi',
    'om'  => 'Omani',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polineziya\ y\'Abafaransa",
    'pg'  => "Papuwa\ Niyugineya",
    'ph'  => "Amazinga\ ya\ Filipine",
    'pk'  => 'Pakisitani',
    'pl'  => 'Polonye',
    'pm'  => "Sempiyeri\ na\ Mikeloni",
    'pn'  => 'Pitikeyirini',
    'pr'  => 'Puwetoriko',
    'ps'  => "Palesitina\ Wesitibanka\ na\ Gaza",
    'pt'  => 'Porutugali',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palawu',
    'py'  => 'Paragwe',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katari',
    'qo'  => "Outlying\ Oceania",
    're'  => "Amazinga\ ya\ Reyiniyo",
    'ro'  => 'Rumaniya',
    'rs'  => 'Serbia',
    'ru'  => 'Uburusiya',
    'rw'  => "u\ Rwanda",
    'sa'  => "Arabiya\ Sawudite",
    'sb'  => "Amazinga\ ya\ Salumoni",
    'sc'  => "Amazinga\ ya\ Seyisheli",
    'sd'  => 'Sudani',
    'se'  => 'Suwedi',
    'sg'  => 'Singapuru',
    'sh'  => 'Sehelene',
    'si'  => 'Siloveniya',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Silovakiya',
    'sl'  => 'Siyeralewone',
    'sm'  => 'Sanimarino',
    'sn'  => 'Senegali',
    'so'  => 'Somaliya',
    'sr'  => 'Suriname',
    'st'  => "Sawotome\ na\ Perensipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "Eli\ Saluvatori",
    'sy'  => 'Siriya',
    'sz'  => 'Suwazilandi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Amazinga\ ya\ Turkisi\ na\ Cayikosi",
    'td'  => 'Cadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Tayilandi',
    'tj'  => 'Tajikisitani',
    'tk'  => 'Tokelawu',
    'tl'  => "Timoru\ y\'iburasirazuba",
    'tm'  => 'Turukumenisitani',
    'tn'  => 'Tuniziya',
    'to'  => 'Tonga',
    'tr'  => 'Turukiya',
    'tt'  => "Tirinidadi\ na\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Tayiwani',
    'tz'  => 'Tanzaniya',
    'ua'  => 'Ikerene',
    'ug'  => 'Ubugande',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Leta\ Zunze\ Ubumwe\ za\ Amerika",
    'uy'  => 'Irigwe',
    'uz'  => 'Uzubekisitani',
    'va'  => "Umurwa\ wa\ Vatikani",
    'vc'  => "Sevensa\ na\ Gerenadine",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuwela',
    'vg'  => "Ibirwa\ by\'isugi\ by\'Abongereza",
    'vi'  => "Amazinga\ y\'Isugi\ y\'Abanyamerika",
    'vn'  => 'Viyetinamu',
    'vu'  => 'Vanuwatu',
    'wf'  => "Walisi\ na\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samowa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemeni',
    'yt'  => 'Mayote',
    'za'  => "Afurika\ y\'Epfo",
    'zm'  => 'Zambiya',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::rn::name_to_code = (
    'africa'                                    => '002',
    'afuganisitani'                             => 'af',
    'afurikayepfo'                              => 'za',
    'alijeriya'                                 => 'dz',
    'alubaniya'                                 => 'al',
    'amazingayafilipine'                        => 'ph',
    'amazingayamariyanaryomumajaruguru'         => 'mp',
    'amazingayareyiniyo'                        => 're',
    'amazingayasalumoni'                        => 'sb',
    'amazingayaseyisheli'                       => 'sc',
    'amazingayaturkisinacayikosi'               => 'tc',
    'amazingayisugiyabanyamerika'               => 'vi',
    'americas'                                  => '019',
    'andora'                                    => 'ad',
    'angola'                                    => 'ao',
    'angwila'                                   => 'ai',
    'antarctica'                                => 'aq',
    'antigwanabaribuda'                         => 'ag',
    'antiyeyabaholandi'                         => 'an',
    'arabiyasawudite'                           => 'sa',
    'arijantine'                                => 'ar',
    'aruba'                                     => 'aw',
    'arumeniya'                                 => 'am',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'ayisilandi'                                => 'is',
    'azerubayijani'                             => 'az',
    'bahamasi'                                  => 'bs',
    'bahareyini'                                => 'bh',
    'bangaladeshi'                              => 'bd',
    'barubadosi'                                => 'bb',
    'belausi'                                   => 'by',
    'belize'                                    => 'bz',
    'bene'                                      => 'bj',
    'berimuda'                                  => 'bm',
    'birimaniya'                                => 'mm',
    'boliviya'                                  => 'bo',
    'bosiniyanaherigozevine'                    => 'ba',
    'botswana'                                  => 'bw',
    'bouvetisland'                              => 'bv',
    'britishantarcticterritory'                 => 'bq',
    'buligariya'                                => 'bg',
    'burezili'                                  => 'br',
    'burukinafaso'                              => 'bf',
    'buruneyi'                                  => 'bn',
    'butani'                                    => 'bt',
    'cadi'                                      => 'td',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danimariki'                                => 'dk',
    'diegogarcia'                               => 'dg',
    'dominika'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekwateri'                                  => 'ec',
    'elisaluvatori'                             => 'sv',
    'elitereya'                                 => 'er',
    'esitoniya'                                 => 'ee',
    'etiyopiya'                                 => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'fiji'                                      => 'fj',
    'finilandi'                                 => 'fi',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabo'                                      => 'ga',
    'gambiya'                                   => 'gm',
    'gana'                                      => 'gh',
    'gerenada'                                  => 'gd',
    'gineyabisawu'                              => 'gw',
    'gineyaekwatoriyali'                        => 'gq',
    'guernsey'                                  => 'gg',
    'guneya'                                    => 'gn',
    'gurunilandi'                               => 'gl',
    'guyane'                                    => 'gy',
    'gwadelupe'                                 => 'gp',
    'gwamu'                                     => 'gu',
    'gwatemala'                                 => 'gt',
    'gwayanayabafaransa'                        => 'gf',
    'hayiti'                                    => 'ht',
    'heardislandandmcdonaldislands'             => 'hm',
    'hisipaniya'                                => 'es',
    'hondurasi'                                 => 'hn',
    'hongkong'                                  => 'hk',
    'hungariya'                                 => 'hu',
    "i\\ingaryakuku"                            => 'ck',
    'ibirwabyakapuveri'                         => 'cv',
    'ibirwabyakeyimani'                         => 'ky',
    'ibirwabyisugibyabongereza'                 => 'vg',
    'ikerene'                                   => 'ua',
    'indoneziya'                                => 'id',
    'intarayubwongerezayomubirwabyabahindi'     => 'io',
    'iraki'                                     => 'iq',
    'irani'                                     => 'ir',
    'irigwe'                                    => 'uy',
    'irilandi'                                  => 'ie',
    'isiraheli'                                 => 'il',
    'isleofman'                                 => 'im',
    'izingaryafilikilandi'                      => 'fk',
    'izingaryakomore'                           => 'km',
    'izingaryamarishari'                        => 'mh',
    'izingaryamorise'                           => 'mu',
    'izingaryanorufoluke'                       => 'nf',
    'izingaryashipure'                          => 'cy',
    'jamayika'                                  => 'jm',
    'jersey'                                    => 'je',
    'jeworujiya'                                => 'ge',
    'jibuti'                                    => 'dj',
    'johnstonisland'                            => 'jt',
    'juburalitari'                              => 'gi',
    'kamboje'                                   => 'kh',
    'kameruni'                                  => 'cm',
    'kanada'                                    => 'ca',
    'katari'                                    => 'qa',
    'kazakisitani'                              => 'kz',
    'kenya'                                     => 'ke',
    'kiba'                                      => 'cu',
    'kiribati'                                  => 'ki',
    'kirigisitani'                              => 'kg',
    'kolombiya'                                 => 'co',
    'kongo'                                     => 'cg',
    'koreyayamajaruguru'                        => 'kp',
    'koreyayamajepfo'                           => 'kr',
    'korowasiya'                                => 'hr',
    'kositarika'                                => 'cr',
    'kotedivuware'                              => 'ci',
    'koweti'                                    => 'kw',
    'latinamerica'                              => 419,
    'lativa'                                    => 'lv',
    'layosi'                                    => 'la',
    'lesoto'                                    => 'ls',
    'letazunzeubumwezaamerika'                  => 'us',
    'letazunzeubumwezabarabu'                   => 'ae',
    'libani'                                    => 'lb',
    'liberiya'                                  => 'lr',
    'libiya'                                    => 'ly',
    'lishyitenshitayini'                        => 'li',
    'lituwaniya'                                => 'lt',
    'lukusamburu'                               => 'lu',
    'macau'                                     => 'mo',
    'madagasikari'                              => 'mg',
    'malawi'                                    => 'mw',
    'maleziya'                                  => 'my',
    'mali'                                      => 'ml',
    'malita'                                    => 'mt',
    'maritiniki'                                => 'mq',
    'maroke'                                    => 'ma',
    'masedoniya'                                => 'mk',
    'mayote'                                    => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'migizike'                                  => 'mx',
    'mikoroniziya'                              => 'fm',
    'misiri'                                    => 'eg',
    'moludave'                                  => 'mv',
    'moludavi'                                  => 'md',
    'monako'                                    => 'mc',
    'mongoliya'                                 => 'mn',
    'montenegro'                                => 'me',
    'monteserati'                               => 'ms',
    'moritaniya'                                => 'mr',
    'mozambiki'                                 => 'mz',
    'namibiya'                                  => 'na',
    'nawuru'                                    => 'nr',
    'nepali'                                    => 'np',
    'neutralzone'                               => 'nt',
    'nijeri'                                    => 'ne',
    'nijeriya'                                  => 'ng',
    'nikaragwa'                                 => 'ni',
    'niyukaledoniya'                            => 'nc',
    'niyuwe'                                    => 'nu',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'noruveji'                                  => 'no',
    'nuvelizelandi'                             => 'nz',
    'oceania'                                   => '009',
    'omani'                                     => 'om',
    'ositaraliya'                               => 'au',
    'otirishe'                                  => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakisitani'                                => 'pk',
    'palawu'                                    => 'pw',
    'palesitinawesitibankanagaza'               => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuwaniyugineya'                          => 'pg',
    'paragwe'                                   => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitikeyirini'                              => 'pn',
    'polineziyayabafaransa'                     => 'pf',
    'polonye'                                   => 'pl',
    'polynesia'                                 => '061',
    'porutugali'                                => 'pt',
    'puwetoriko'                                => 'pr',
    'repubulikaiharanirademokarasiyakongo'      => 'cd',
    'repubulikayaceke'                          => 'cz',
    'repubulikayadominika'                      => 'do',
    'repubulikayasantarafurika'                 => 'cf',
    'rumaniya'                                  => 'ro',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'samowa'                                    => 'ws',
    'samowanyamerika'                           => 'as',
    'sanimarino'                                => 'sm',
    'sawotomenaperensipe'                       => 'st',
    'sehelene'                                  => 'sh',
    'sekitsinanevisi'                           => 'kn',
    'selusiya'                                  => 'lc',
    'sempiyerinamikeloni'                       => 'pm',
    'senegali'                                  => 'sn',
    'serbia'                                    => 'rs',
    'seribiyanamontenegoro'                     => 'cs',
    'sevensanagerenadine'                       => 'vc',
    'shili'                                     => 'cl',
    'silovakiya'                                => 'sk',
    'siloveniya'                                => 'si',
    'singapuru'                                 => 'sg',
    'sirilanka'                                 => 'lk',
    'siriya'                                    => 'sy',
    'siyeralewone'                              => 'sl',
    'somaliya'                                  => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'sudani'                                    => 'sd',
    'suriname'                                  => 'sr',
    'suwazilandi'                               => 'sz',
    'suwedi'                                    => 'se',
    'svalbardandjanmayen'                       => 'sj',
    'tajikisitani'                              => 'tj',
    'tanzaniya'                                 => 'tz',
    'tayilandi'                                 => 'th',
    'tayiwani'                                  => 'tw',
    'timoruyiburasirazuba'                      => 'tl',
    'tirinidadinatobago'                        => 'tt',
    'togo'                                      => 'tg',
    'tokelawu'                                  => 'tk',
    'tonga'                                     => 'to',
    'tristandacunha'                            => 'ta',
    'tuniziya'                                  => 'tn',
    'turukiya'                                  => 'tr',
    'turukumenisitani'                          => 'tm',
    'tuvalu'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ububiligi'                                 => 'be',
    'ubudage'                                   => 'de',
    'ubufaransa'                                => 'fr',
    'ubugande'                                  => 'ug',
    'ubugereki'                                 => 'gr',
    'ubuhindi'                                  => 'in',
    'ubuholandi'                                => 'nl',
    'uburundi'                                  => 'bi',
    'uburusiya'                                 => 'ru',
    'ubushinwa'                                 => 'cn',
    'ubusuwisi'                                 => 'ch',
    'ubutaliyani'                               => 'it',
    'ubuyapani'                                 => 'jp',
    'ubwongereza'                               => 'gb',
    'umurwawavatikani'                          => 'va',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'urwanda'                                   => 'rw',
    'uzubekisitani'                             => 'uz',
    'vanuwatu'                                  => 'vu',
    'venezuwela'                                => 've',
    'viyetinamu'                                => 'vn',
    'wakeisland'                                => 'wk',
    'walisinafutuna'                            => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yemeni'                                    => 'ye',
    'yorudaniya'                                => 'jo',
    'zambiya'                                   => 'zm',
    'zimbabwe'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
);

1;

