package Locales::DB::Territory::luy;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::luy::VERSION = '0.09';

$Locales::DB::Territory::luy::cldr_version = '2.0';

%Locales::DB::Territory::luy::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andora',
    'ae'  => "Falme\ za\ Kiarabu",
    'af'  => 'Afuganistani',
    'ag'  => "Antigua\ na\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Antili\ za\ Uholanzi",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Ajentina',
    'as'  => "Samoa\ lya\ Marekani",
    'at'  => 'Austria',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azabajani',
    'ba'  => "Bosnia\ na\ Hezegovina",
    'bb'  => 'Babadosi',
    'bd'  => 'Bangladeshi',
    'be'  => 'Ubelgiji',
    'bf'  => 'Bukinafaso',
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahareni',
    'bi'  => 'Burundi',
    'bj'  => 'Benini',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazili',
    'bs'  => 'Bahama',
    'bt'  => 'Butani',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswana',
    'by'  => 'Belarusi',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Jamhuri\ ya\ Kidemokrasia\ ya\ Kongo",
    'cf'  => "Jamhuri\ ya\ Afrika\ ya\ Kati",
    'cg'  => 'Kongo',
    'ch'  => 'Uswisi',
    'ci'  => 'Kodivaa',
    'ck'  => "Visiwa\ vya\ Cook",
    'cl'  => 'Chile',
    'cm'  => 'Kameruni',
    'cn'  => 'China',
    'co'  => 'Kolombia',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kostarika',
    'cs'  => "Serbia\ na\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => 'Kepuvede',
    'cx'  => "Christmas\ Island",
    'cy'  => 'Kuprosi',
    'cz'  => "Jamhuri\ ya\ Cheki",
    'dd'  => "East\ Germany",
    'de'  => 'Ujerumani',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jibuti',
    'dk'  => 'Denmaki',
    'dm'  => 'Dominika',
    'do'  => "Jamhuri\ ya\ Dominika",
    'dz'  => 'Aljeria',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwado',
    'ee'  => 'Estonia',
    'eg'  => 'Misri',
    'eh'  => "Western\ Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Hispania',
    'et'  => 'Uhabeshi',
    'eu'  => "European\ Union",
    'fi'  => 'Ufini',
    'fj'  => 'Fiji',
    'fk'  => "Visiwa\ vya\ Falkland",
    'fm'  => 'Mikronesia',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Ufaransa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gaboni',
    'gb'  => 'Uingereza',
    'gd'  => 'Grenada',
    'ge'  => 'Jojia',
    'gf'  => "Gwiyana\ ya\ Ufaransa",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Jibralta',
    'gl'  => 'Grinlandi',
    'gm'  => 'Gambia',
    'gn'  => 'Gine',
    'gp'  => 'Gwadelupe',
    'gq'  => 'Ginekweta',
    'gr'  => 'Ugiriki',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatemala',
    'gu'  => 'Gwam',
    'gw'  => 'Ginebisau',
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hondurasi',
    'hr'  => 'Korasia',
    'ht'  => 'Haiti',
    'hu'  => 'Hungaria',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonesia',
    'ie'  => 'Ayalandi',
    'il'  => 'Israeli',
    'im'  => "Isle\ of\ Man",
    'in'  => 'India',
    'io'  => "Eneo\ la\ Uingereza\ katika\ Bahari\ Hindi",
    'iq'  => 'Iraki',
    'ir'  => 'Uajemi',
    'is'  => 'Aislandi',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Yordani',
    'jp'  => 'Japani',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirigizistani',
    'kh'  => 'Kambodia',
    'ki'  => 'Kiribati',
    'km'  => 'Komoro',
    'kn'  => "Santakitzi\ na\ Nevis",
    'kp'  => "Korea\ Kaskazini",
    'kr'  => "Korea\ Kusini",
    'kw'  => 'Kuwaiti',
    'ky'  => "Visiwa\ vya\ Kayman",
    'kz'  => 'Kazakistani',
    'la'  => 'Laosi',
    'lb'  => 'Lebanoni',
    'lc'  => 'Santalusia',
    'li'  => 'Lishenteni',
    'lk'  => 'Sirilanka',
    'lr'  => 'Liberia',
    'ls'  => 'Lesoto',
    'lt'  => 'Litwania',
    'lu'  => 'Lasembagi',
    'lv'  => 'Lativia',
    'ly'  => 'Libya',
    'ma'  => 'Moroko',
    'mc'  => 'Monako',
    'md'  => 'Moldova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Bukini',
    'mh'  => "Visiwa\ vya\ Marshal",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedonia',
    'ml'  => 'Mali',
    'mm'  => 'Myama',
    'mn'  => 'Mongolia',
    'mo'  => 'Macau',
    'mp'  => "Visiwa\ vya\ Mariana\ vya\ Kaskazini",
    'mq'  => 'Martiniki',
    'mr'  => 'Moritania',
    'ms'  => 'Montserrati',
    'mt'  => 'Malta',
    'mu'  => 'Morisi',
    'mv'  => 'Modivu',
    'mw'  => 'Malawi',
    'mx'  => 'Meksiko',
    'my'  => 'Malesia',
    'mz'  => 'Msumbiji',
    'na'  => 'Namibia',
    'nc'  => 'Nyukaledonia',
    'ne'  => 'Nijeri',
    'nf'  => "Kisiwa\ cha\ Norfok",
    'ng'  => 'Nijeria',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Uholanzi',
    'no'  => 'Norwe',
    'np'  => 'Nepali',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => 'Nyuzilandi',
    'om'  => 'Omani',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polinesia\ ya\ Ufaransa",
    'pg'  => 'Papua',
    'ph'  => 'Filipino',
    'pk'  => 'Pakistani',
    'pl'  => 'Polandi',
    'pm'  => "Santapieri\ na\ Mikeloni",
    'pn'  => 'Pitkairni',
    'pr'  => 'Pwetoriko',
    'ps'  => "Ukingo\ wa\ Magharibi\ na\ Ukanda\ wa\ Gaza\ wa\ Palestina",
    'pt'  => 'Ureno',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paragwai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katari',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Riyunioni',
    'ro'  => 'Romania',
    'rs'  => 'Serbia',
    'ru'  => 'Urusi',
    'rw'  => 'Rwanda',
    'sa'  => 'Saudi',
    'sb'  => "Visiwa\ vya\ Solomon",
    'sc'  => 'Shelisheli',
    'sd'  => 'Sudani',
    'se'  => 'Uswidi',
    'sg'  => 'Singapoo',
    'sh'  => 'Santahelena',
    'si'  => 'Slovenia',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slovakia',
    'sl'  => "Siera\ Leoni",
    'sm'  => 'Samarino',
    'sn'  => 'Senegali',
    'so'  => 'Somalia',
    'sr'  => 'Surinamu',
    'st'  => "Sao\ Tome\ na\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Elsavado',
    'sy'  => 'Siria',
    'sz'  => 'Uswazi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Visiwa\ vya\ Turki\ na\ Kaiko",
    'td'  => 'Chadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Tailandi',
    'tj'  => 'Tajikistani',
    'tk'  => 'Tokelau',
    'tl'  => "Timori\ ya\ Mashariki",
    'tm'  => 'Turukimenistani',
    'tn'  => 'Tunisia',
    'to'  => 'Tonga',
    'tr'  => 'Uturuki',
    'tt'  => "Trinidad\ na\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwani',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukraini',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Marekani',
    'uy'  => 'Urugwai',
    'uz'  => 'Uzibekistani',
    'va'  => 'Vatikani',
    'vc'  => "Santavisenti\ na\ Grenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Visiwa\ vya\ Virgin\ vya\ Uingereza",
    'vi'  => "Visiwa\ vya\ Virgin\ vya\ Marekani",
    'vn'  => 'Vietinamu',
    'vu'  => 'Vanuatu',
    'wf'  => "Walis\ na\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemeni',
    'yt'  => 'Mayotte',
    'za'  => "Afrika\ Kusini",
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::luy::name_to_code = (
    'africa'                                     => '002',
    'afrikakusini'                               => 'za',
    'afuganistani'                               => 'af',
    'aislandi'                                   => 'is',
    'ajentina'                                   => 'ar',
    'albania'                                    => 'al',
    'aljeria'                                    => 'dz',
    'americas'                                   => '019',
    'andora'                                     => 'ad',
    'angola'                                     => 'ao',
    'anguilla'                                   => 'ai',
    'antarctica'                                 => 'aq',
    'antiguanabarbuda'                           => 'ag',
    'antilizauholanzi'                           => 'an',
    'armenia'                                    => 'am',
    'aruba'                                      => 'aw',
    'ascensionisland'                            => 'ac',
    'asia'                                       => 142,
    'australia'                                  => 'au',
    'australiaandnewzealand'                     => '053',
    'austria'                                    => 'at',
    'ayalandi'                                   => 'ie',
    'azabajani'                                  => 'az',
    'babadosi'                                   => 'bb',
    'bahama'                                     => 'bs',
    'bahareni'                                   => 'bh',
    'bangladeshi'                                => 'bd',
    'belarusi'                                   => 'by',
    'belize'                                     => 'bz',
    'benini'                                     => 'bj',
    'bermuda'                                    => 'bm',
    'bolivia'                                    => 'bo',
    'bosnianahezegovina'                         => 'ba',
    'botswana'                                   => 'bw',
    'bouvetisland'                               => 'bv',
    'brazili'                                    => 'br',
    'britishantarcticterritory'                  => 'bq',
    'brunei'                                     => 'bn',
    'bukinafaso'                                 => 'bf',
    'bukini'                                     => 'mg',
    'bulgaria'                                   => 'bg',
    'burundi'                                    => 'bi',
    'butani'                                     => 'bt',
    'canaryislands'                              => 'ic',
    'cantonandenderburyislands'                  => 'ct',
    'caribbean'                                  => '029',
    'centralamerica'                             => '013',
    'centralasia'                                => 143,
    'ceutaandmelilla'                            => 'ea',
    'chadi'                                      => 'td',
    'channelislands'                             => 830,
    'chile'                                      => 'cl',
    'china'                                      => 'cn',
    'christmasisland'                            => 'cx',
    'clippertonisland'                           => 'cp',
    'cocoskeelingislands'                        => 'cc',
    'commonwealthofindependentstates'            => 172,
    'czechoslovakia'                             => 200,
    'denmaki'                                    => 'dk',
    'diegogarcia'                                => 'dg',
    'dominika'                                   => 'dm',
    'dronningmaudland'                           => 'nq',
    'easternafrica'                              => '014',
    'easternasia'                                => '030',
    'easterneurope'                              => 151,
    'eastgermany'                                => 'dd',
    'ekwado'                                     => 'ec',
    'elsavado'                                   => 'sv',
    'eneolauingerezakatikabaharihindi'           => 'io',
    'eritrea'                                    => 'er',
    'estonia'                                    => 'ee',
    'europe'                                     => 150,
    'europeanunion'                              => 'eu',
    'falmezakiarabu'                             => 'ae',
    'faroeislands'                               => 'fo',
    'fiji'                                       => 'fj',
    'filipino'                                   => 'ph',
    'frenchsouthernandantarcticterritories'      => 'fq',
    'frenchsouthernterritories'                  => 'tf',
    'gaboni'                                     => 'ga',
    'gambia'                                     => 'gm',
    'ghana'                                      => 'gh',
    'gine'                                       => 'gn',
    'ginebisau'                                  => 'gw',
    'ginekweta'                                  => 'gq',
    'grenada'                                    => 'gd',
    'grinlandi'                                  => 'gl',
    'guernsey'                                   => 'gg',
    'guyana'                                     => 'gy',
    'gwadelupe'                                  => 'gp',
    'gwam'                                       => 'gu',
    'gwatemala'                                  => 'gt',
    'gwiyanayaufaransa'                          => 'gf',
    'haiti'                                      => 'ht',
    'heardislandandmcdonaldislands'              => 'hm',
    'hispania'                                   => 'es',
    'hondurasi'                                  => 'hn',
    'hongkong'                                   => 'hk',
    'hungaria'                                   => 'hu',
    'india'                                      => 'in',
    'indonesia'                                  => 'id',
    'iraki'                                      => 'iq',
    'isleofman'                                  => 'im',
    'israeli'                                    => 'il',
    'italia'                                     => 'it',
    'jamaika'                                    => 'jm',
    'jamhuriyaafrikayakati'                      => 'cf',
    'jamhuriyacheki'                             => 'cz',
    'jamhuriyadominika'                          => 'do',
    'jamhuriyakidemokrasiayakongo'               => 'cd',
    'japani'                                     => 'jp',
    'jersey'                                     => 'je',
    'jibralta'                                   => 'gi',
    'jibuti'                                     => 'dj',
    'johnstonisland'                             => 'jt',
    'jojia'                                      => 'ge',
    'kambodia'                                   => 'kh',
    'kameruni'                                   => 'cm',
    'kanada'                                     => 'ca',
    'katari'                                     => 'qa',
    'kazakistani'                                => 'kz',
    'kenya'                                      => 'ke',
    'kepuvede'                                   => 'cv',
    'kiribati'                                   => 'ki',
    'kirigizistani'                              => 'kg',
    'kisiwachanorfok'                            => 'nf',
    'kodivaa'                                    => 'ci',
    'kolombia'                                   => 'co',
    'komoro'                                     => 'km',
    'kongo'                                      => 'cg',
    'korasia'                                    => 'hr',
    'koreakaskazini'                             => 'kp',
    'koreakusini'                                => 'kr',
    'kostarika'                                  => 'cr',
    'kuba'                                       => 'cu',
    'kuprosi'                                    => 'cy',
    'kuwaiti'                                    => 'kw',
    'laosi'                                      => 'la',
    'lasembagi'                                  => 'lu',
    'latinamerica'                               => 419,
    'lativia'                                    => 'lv',
    'lebanoni'                                   => 'lb',
    'lesoto'                                     => 'ls',
    'liberia'                                    => 'lr',
    'libya'                                      => 'ly',
    'lishenteni'                                 => 'li',
    'litwania'                                   => 'lt',
    'macau'                                      => 'mo',
    'malawi'                                     => 'mw',
    'malesia'                                    => 'my',
    'mali'                                       => 'ml',
    'malta'                                      => 'mt',
    'marekani'                                   => 'us',
    'martiniki'                                  => 'mq',
    'masedonia'                                  => 'mk',
    'mayotte'                                    => 'yt',
    'meksiko'                                    => 'mx',
    'melanesia'                                  => '054',
    'metropolitanfrance'                         => 'fx',
    'micronesianregion'                          => '057',
    'middleafrica'                               => '017',
    'midwayislands'                              => 'mi',
    'mikronesia'                                 => 'fm',
    'misri'                                      => 'eg',
    'modivu'                                     => 'mv',
    'moldova'                                    => 'md',
    'monako'                                     => 'mc',
    'mongolia'                                   => 'mn',
    'montenegro'                                 => 'me',
    'montserrati'                                => 'ms',
    'morisi'                                     => 'mu',
    'moritania'                                  => 'mr',
    'moroko'                                     => 'ma',
    'msumbiji'                                   => 'mz',
    'myama'                                      => 'mm',
    'namibia'                                    => 'na',
    'nauru'                                      => 'nr',
    'nepali'                                     => 'np',
    'neutralzone'                                => 'nt',
    'nijeri'                                     => 'ne',
    'nijeria'                                    => 'ng',
    'nikaragwa'                                  => 'ni',
    'niue'                                       => 'nu',
    'northamerica'                               => '003',
    'northernafrica'                             => '015',
    'northernamerica'                            => '021',
    'northerneurope'                             => 154,
    'northvietnam'                               => 'vd',
    'norwe'                                      => 'no',
    'nyukaledonia'                               => 'nc',
    'nyuzilandi'                                 => 'nz',
    'oceania'                                    => '009',
    'omani'                                      => 'om',
    'outlyingoceania'                            => 'qo',
    'pacificislandstrustterritory'               => 'pc',
    'pakistani'                                  => 'pk',
    'palau'                                      => 'pw',
    'panama'                                     => 'pa',
    'panamacanalzone'                            => 'pz',
    'papua'                                      => 'pg',
    'paragwai'                                   => 'py',
    "people\â\\sdemocraticrepublicofyemen"  => 'yd',
    'peru'                                       => 'pe',
    'pitkairni'                                  => 'pn',
    'polandi'                                    => 'pl',
    'polinesiayaufaransa'                        => 'pf',
    'polynesia'                                  => '061',
    'pwetoriko'                                  => 'pr',
    'riyunioni'                                  => 're',
    'romania'                                    => 'ro',
    'rwanda'                                     => 'rw',
    "saintbarth\Ã\©lemy"                       => 'bl',
    'saintmartin'                                => 'mf',
    'samarino'                                   => 'sm',
    'samoa'                                      => 'ws',
    'samoalyamarekani'                           => 'as',
    'santahelena'                                => 'sh',
    'santakitzinanevis'                          => 'kn',
    'santalusia'                                 => 'lc',
    'santapierinamikeloni'                       => 'pm',
    'santavisentinagrenadini'                    => 'vc',
    'saotomenaprincipe'                          => 'st',
    'saudi'                                      => 'sa',
    'senegali'                                   => 'sn',
    'serbia'                                     => 'rs',
    'serbianamontenegro'                         => 'cs',
    'shelisheli'                                 => 'sc',
    'sieraleoni'                                 => 'sl',
    'singapoo'                                   => 'sg',
    'siria'                                      => 'sy',
    'sirilanka'                                  => 'lk',
    'slovakia'                                   => 'sk',
    'slovenia'                                   => 'si',
    'somalia'                                    => 'so',
    'southamerica'                               => '005',
    'southcentralasia'                           => '062',
    'southeasternasia'                           => '035',
    'southernafrica'                             => '018',
    'southernasia'                               => '034',
    'southerneurope'                             => '039',
    'southgeorgiaandthesouthsandwichislands'     => 'gs',
    'sudani'                                     => 'sd',
    'surinamu'                                   => 'sr',
    'svalbardandjanmayen'                        => 'sj',
    'tailandi'                                   => 'th',
    'taiwani'                                    => 'tw',
    'tajikistani'                                => 'tj',
    'tanzania'                                   => 'tz',
    'timoriyamashariki'                          => 'tl',
    'togo'                                       => 'tg',
    'tokelau'                                    => 'tk',
    'tonga'                                      => 'to',
    'trinidadnatobago'                           => 'tt',
    'tristandacunha'                             => 'ta',
    'tunisia'                                    => 'tn',
    'turukimenistani'                            => 'tm',
    'tuvalu'                                     => 'tv',
    "u\.s\.minoroutlyingislands"                 => 'um',
    "u\.s\.miscellaneouspacificislands"          => 'pu',
    'uajemi'                                     => 'ir',
    'ubelgiji'                                   => 'be',
    'ufaransa'                                   => 'fr',
    'ufini'                                      => 'fi',
    'uganda'                                     => 'ug',
    'ugiriki'                                    => 'gr',
    'uhabeshi'                                   => 'et',
    'uholanzi'                                   => 'nl',
    'uingereza'                                  => 'gb',
    'ujerumani'                                  => 'de',
    'ukingowamagharibinaukandawagazawapalestina' => 'ps',
    'ukraini'                                    => 'ua',
    'unionofsovietsocialistrepublics'            => 'su',
    'unknownregion'                              => 'zz',
    'ureno'                                      => 'pt',
    'urugwai'                                    => 'uy',
    'urusi'                                      => 'ru',
    'uswazi'                                     => 'sz',
    'uswidi'                                     => 'se',
    'uswisi'                                     => 'ch',
    'uturuki'                                    => 'tr',
    'uzibekistani'                               => 'uz',
    'vanuatu'                                    => 'vu',
    'vatikani'                                   => 'va',
    'venezuela'                                  => 've',
    'vietinamu'                                  => 'vn',
    'visiwavyacook'                              => 'ck',
    'visiwavyafalkland'                          => 'fk',
    'visiwavyakayman'                            => 'ky',
    'visiwavyamarianavyakaskazini'               => 'mp',
    'visiwavyamarshal'                           => 'mh',
    'visiwavyasolomon'                           => 'sb',
    'visiwavyaturkinakaiko'                      => 'tc',
    'visiwavyavirginvyamarekani'                 => 'vi',
    'visiwavyavirginvyauingereza'                => 'vg',
    'wakeisland'                                 => 'wk',
    'walisnafutuna'                              => 'wf',
    'westernafrica'                              => '011',
    'westernasia'                                => 145,
    'westerneurope'                              => 155,
    'westernsahara'                              => 'eh',
    'world'                                      => '001',
    'yemeni'                                     => 'ye',
    'yordani'                                    => 'jo',
    'zambia'                                     => 'zm',
    'zimbabwe'                                   => 'zw',
    "\Ã\landislands"                          => 'ax',
);

1;

