package Locales::DB::Territory::nl_be;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::nl_be::VERSION = '0.09';

$Locales::DB::Territory::nl_be::cldr_version = '2.0';

%Locales::DB::Territory::nl_be::code_to_name = (
    '001' => 'Wereld',
    '002' => 'Afrika',
    '003' => "Noord\-Amerika",
    '005' => "Zuid\-Amerika",
    '009' => 'Oceanië',
    '011' => "West\-Afrika",
    '013' => "Centraal\-Amerika",
    '014' => "Oost\-Afrika",
    '015' => "Noord\-Afrika",
    '017' => "Centraal\-Afrika",
    '018' => "Zuidelijk\ Afrika",
    '019' => 'Amerika',
    '021' => "Noordelijk\ Amerika",
    '029' => "Caribisch\ gebied",
    '030' => "Oost\-Azië",
    '034' => "Zuid\-Azië",
    '035' => "Zuidoost\-Azië",
    '039' => "Zuid\-Europa",
    '053' => "Australië\ en\ Nieuw\-Zeeland",
    '054' => 'Melanesië',
    '057' => "Micronesische\ regio",
    '061' => 'Polynesië',
    '062' => "Zuidelijk\ Centraal\-Azië",
    142   => 'Azië',
    143   => "Centraal\-Azië",
    145   => "West\-Azië",
    150   => 'Europa',
    151   => "Oost\-Europa",
    154   => "Noord\-Europa",
    155   => "West\-Europa",
    172   => "Gemenebest\ van\ Onafhankelijke\ Staten",
    200   => 'Czechoslovakia',
    419   => "Latijns\-Amerika\ en\ het\ Caribisch\ gebied",
    830   => 'Kanaaleilanden',
    'ac'  => 'Ascension',
    'ad'  => 'Andorra',
    'ae'  => "Verenigde\ Arabische\ Emiraten",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ en\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albanië',
    'am'  => 'Armenië',
    'an'  => "Nederlandse\ Antillen",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Argentinië',
    'as'  => "Amerikaans\ Samoa",
    'at'  => 'Oostenrijk',
    'au'  => 'Australië',
    'aw'  => 'Aruba',
    'ax'  => 'Ålandeilanden',
    'az'  => 'Azerbeidzjan',
    'ba'  => "Bosnië\ en\ Herzegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'België',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgarije',
    'bh'  => 'Bahrein',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazilië',
    'bs'  => 'Bahama’s',
    'bt'  => 'Bhutan',
    'bv'  => 'Bouveteiland',
    'bw'  => 'Botswana',
    'by'  => "Wit\-Rusland",
    'bz'  => 'Belize',
    'ca'  => 'Canada',
    'cc'  => 'Cocoseilanden',
    'cd'  => "Congo\ \[DRC\]",
    'cf'  => "Centraal\-Afrikaanse\ Republiek",
    'cg'  => "Congo\ \[Republiek\]",
    'ch'  => 'Zwitserland',
    'ci'  => 'Ivoorkust',
    'ck'  => 'Cookeilanden',
    'cl'  => 'Chili',
    'cm'  => 'Kameroen',
    'cn'  => 'China',
    'co'  => 'Colombia',
    'cp'  => 'Clipperton',
    'cr'  => "Costa\ Rica",
    'cs'  => "Servië\ en\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => 'Kaapverdië',
    'cx'  => 'Christmaseiland',
    'cy'  => 'Cyprus',
    'cz'  => 'Tsjechië',
    'dd'  => "East\ Germany",
    'de'  => 'Duitsland',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Denemarken',
    'dm'  => 'Dominica',
    'do'  => "Dominicaanse\ Republiek",
    'dz'  => 'Algerije',
    'ea'  => "Ceuta\ en\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estland',
    'eg'  => 'Egypte',
    'eh'  => "Westelijke\ Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Spanje',
    'et'  => 'Ethiopië',
    'eu'  => "Europese\ Unie",
    'fi'  => 'Finland',
    'fj'  => 'Fiji',
    'fk'  => "Falklandeilanden\ \[Islas\ Malvinas\]",
    'fm'  => 'Micronesië',
    'fo'  => 'Faeröer',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frankrijk',
    'fx'  => "Europese\ Frankrijk",
    'ga'  => 'Gabon',
    'gb'  => "Verenigd\ Koninkrijk",
    'gd'  => 'Grenada',
    'ge'  => 'Georgië',
    'gf'  => "Frans\-Guyana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Groenland',
    'gm'  => 'Gambia',
    'gn'  => 'Guinee',
    'gp'  => 'Guadeloupe',
    'gq'  => "Equatoriaal\-Guinea",
    'gr'  => 'Griekenland',
    'gs'  => "Zuid\-Georgië\ en\ Zuidelijke\ Sandwicheilanden",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinee\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\-\ en\ McDonaldeilanden",
    'hn'  => 'Honduras',
    'hr'  => 'Kroatië',
    'ht'  => 'Haïti',
    'hu'  => 'Hongarije',
    'ic'  => "Canarische\ Eilanden",
    'id'  => 'Indonesië',
    'ie'  => 'Ierland',
    'il'  => 'Israël',
    'im'  => "Het\ Eiland\ Man",
    'in'  => 'India',
    'io'  => "Britse\ Gebieden\ in\ de\ Indische\ Oceaan",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'IJsland',
    'it'  => 'Italië',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordanië',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirgizië',
    'kh'  => 'Cambodja',
    'ki'  => 'Kiribati',
    'km'  => 'Comoren',
    'kn'  => "Saint\ Kitts\ en\ Nevis",
    'kp'  => "Noord\-Korea",
    'kr'  => "Zuid\-Korea",
    'kw'  => 'Koeweit',
    'ky'  => 'Caymaneilanden',
    'kz'  => 'Kazachstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Litouwen',
    'lu'  => 'Luxemburg',
    'lv'  => 'Letland',
    'ly'  => 'Libië',
    'ma'  => 'Marokko',
    'mc'  => 'Monaco',
    'md'  => 'Moldavië',
    'me'  => 'Montenegro',
    'mf'  => "Sint\-Maarten",
    'mg'  => 'Madagaskar',
    'mh'  => 'Marshalleilanden',
    'mi'  => "Midway\ Islands",
    'mk'  => "Macedonië\ \[FYROM\]",
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongolië',
    'mo'  => 'Macao',
    'mp'  => "Noordelijke\ Marianeneilanden",
    'mq'  => 'Martinique',
    'mr'  => 'Mauritanië',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Malediven',
    'mw'  => 'Malawi',
    'mx'  => 'Mexico',
    'my'  => 'Maleisië',
    'mz'  => 'Mozambique',
    'na'  => 'Namibië',
    'nc'  => "Nieuw\-Caledonië",
    'ne'  => 'Niger',
    'nf'  => 'Norfolkeiland',
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Nederland',
    'no'  => 'Noorwegen',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nieuw\-Zeeland",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Frans\-Polynesië",
    'pg'  => "Papoea\-Nieuw\-Guinea",
    'ph'  => 'Filipijnen',
    'pk'  => 'Pakistan',
    'pl'  => 'Polen',
    'pm'  => "Saint\ Pierre\ en\ Miquelon",
    'pn'  => 'Pitcairneilanden',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Palestijnse\ gebieden",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Overig\ Oceanië",
    're'  => 'Réunion',
    'ro'  => 'Roemenië',
    'rs'  => 'Servië',
    'ru'  => 'Rusland',
    'rw'  => 'Rwanda',
    'sa'  => "Saoedi\-Arabië",
    'sb'  => 'Salomoneilanden',
    'sc'  => 'Seychellen',
    'sd'  => 'Soedan',
    'se'  => 'Zweden',
    'sg'  => 'Singapore',
    'sh'  => "Sint\-Helena",
    'si'  => 'Slovenië',
    'sj'  => "Svalbard\ en\ Jan\ Mayen",
    'sk'  => 'Slowakije',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalië',
    'sr'  => 'Suriname',
    'st'  => "Sao\ Tomé\ en\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Syrië',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\-\ en\ Caicoseilanden",
    'td'  => 'Tsjaad',
    'tf'  => "Franse\ Gebieden\ in\ de\ zuidelijke\ Indische\ Oceaan",
    'tg'  => 'Togo',
    'th'  => 'Thailand',
    'tj'  => 'Tadzjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Oost\-Timor",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunesië',
    'to'  => 'Tonga',
    'tr'  => 'Turkije',
    'tt'  => "Trinidad\ en\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzania',
    'ua'  => 'Oekraïne',
    'ug'  => 'Oeganda',
    'um'  => "Kleine\ afgelegen\ eilanden\ van\ de\ Verenigde\ Staten",
    'us'  => "Verenigde\ Staten",
    'uy'  => 'Uruguay',
    'uz'  => 'Oezbekistan',
    'va'  => 'Vaticaanstad',
    'vc'  => "Saint\ Vincent\ en\ de\ Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Britse\ Maagdeneilanden",
    'vi'  => "Amerikaanse\ Maagdeneilanden",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ en\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => "Zuid\-Afrika",
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Onbekend\ of\ onjuist\ gebied",
);

%Locales::DB::Territory::nl_be::name_to_code = (
    'afghanistan'                                 => 'af',
    'afrika'                                      => '002',
    'albanië'                                    => 'al',
    'algerije'                                    => 'dz',
    'amerika'                                     => '019',
    'amerikaansemaagdeneilanden'                  => 'vi',
    'amerikaanssamoa'                             => 'as',
    'andorra'                                     => 'ad',
    'angola'                                      => 'ao',
    'anguilla'                                    => 'ai',
    'antarctica'                                  => 'aq',
    'antiguaenbarbuda'                            => 'ag',
    'argentinië'                                 => 'ar',
    'armenië'                                    => 'am',
    'aruba'                                       => 'aw',
    'ascension'                                   => 'ac',
    'australië'                                  => 'au',
    'australiëennieuwzeeland'                    => '053',
    'azerbeidzjan'                                => 'az',
    'azië'                                       => 142,
    'bahama’s'                                  => 'bs',
    'bahrein'                                     => 'bh',
    'bangladesh'                                  => 'bd',
    'barbados'                                    => 'bb',
    'belgië'                                     => 'be',
    'belize'                                      => 'bz',
    'benin'                                       => 'bj',
    'bermuda'                                     => 'bm',
    'bhutan'                                      => 'bt',
    'bolivia'                                     => 'bo',
    'bosniëenherzegovina'                        => 'ba',
    'botswana'                                    => 'bw',
    'bouveteiland'                                => 'bv',
    'brazilië'                                   => 'br',
    'britishantarcticterritory'                   => 'bq',
    'britsegebiedenindeindischeoceaan'            => 'io',
    'britsemaagdeneilanden'                       => 'vg',
    'brunei'                                      => 'bn',
    'bulgarije'                                   => 'bg',
    'burkinafaso'                                 => 'bf',
    'burundi'                                     => 'bi',
    'cambodja'                                    => 'kh',
    'canada'                                      => 'ca',
    'canarischeeilanden'                          => 'ic',
    'cantonandenderburyislands'                   => 'ct',
    'caribischgebied'                             => '029',
    'caymaneilanden'                              => 'ky',
    'centraalafrika'                              => '017',
    'centraalafrikaanserepubliek'                 => 'cf',
    'centraalamerika'                             => '013',
    'centraalazië'                               => 143,
    'ceutaenmelilla'                              => 'ea',
    'chili'                                       => 'cl',
    'china'                                       => 'cn',
    'christmaseiland'                             => 'cx',
    'clipperton'                                  => 'cp',
    'cocoseilanden'                               => 'cc',
    'colombia'                                    => 'co',
    'comoren'                                     => 'km',
    'congodrc'                                    => 'cd',
    'congorepubliek'                              => 'cg',
    'cookeilanden'                                => 'ck',
    'costarica'                                   => 'cr',
    'cuba'                                        => 'cu',
    'cyprus'                                      => 'cy',
    'czechoslovakia'                              => 200,
    'denemarken'                                  => 'dk',
    'diegogarcia'                                 => 'dg',
    'djibouti'                                    => 'dj',
    'dominica'                                    => 'dm',
    'dominicaanserepubliek'                       => 'do',
    'dronningmaudland'                            => 'nq',
    'duitsland'                                   => 'de',
    'eastgermany'                                 => 'dd',
    'ecuador'                                     => 'ec',
    'egypte'                                      => 'eg',
    'elsalvador'                                  => 'sv',
    'equatoriaalguinea'                           => 'gq',
    'eritrea'                                     => 'er',
    'estland'                                     => 'ee',
    'ethiopië'                                   => 'et',
    'europa'                                      => 150,
    'europesefrankrijk'                           => 'fx',
    'europeseunie'                                => 'eu',
    'faeröer'                                    => 'fo',
    'falklandeilandenislasmalvinas'               => 'fk',
    'fiji'                                        => 'fj',
    'filipijnen'                                  => 'ph',
    'finland'                                     => 'fi',
    'frankrijk'                                   => 'fr',
    'fransegebiedenindezuidelijkeindischeoceaan'  => 'tf',
    'fransguyana'                                 => 'gf',
    'franspolynesië'                             => 'pf',
    'frenchsouthernandantarcticterritories'       => 'fq',
    'gabon'                                       => 'ga',
    'gambia'                                      => 'gm',
    'gemenebestvanonafhankelijkestaten'           => 172,
    'georgië'                                    => 'ge',
    'ghana'                                       => 'gh',
    'gibraltar'                                   => 'gi',
    'grenada'                                     => 'gd',
    'griekenland'                                 => 'gr',
    'groenland'                                   => 'gl',
    'guadeloupe'                                  => 'gp',
    'guam'                                        => 'gu',
    'guatemala'                                   => 'gt',
    'guernsey'                                    => 'gg',
    'guinee'                                      => 'gn',
    'guineebissau'                                => 'gw',
    'guyana'                                      => 'gy',
    'haïti'                                      => 'ht',
    'heardenmcdonaldeilanden'                     => 'hm',
    'heteilandman'                                => 'im',
    'honduras'                                    => 'hn',
    'hongarije'                                   => 'hu',
    'hongkong'                                    => 'hk',
    'ierland'                                     => 'ie',
    'ijsland'                                     => 'is',
    'india'                                       => 'in',
    'indonesië'                                  => 'id',
    'irak'                                        => 'iq',
    'iran'                                        => 'ir',
    'israël'                                     => 'il',
    'italië'                                     => 'it',
    'ivoorkust'                                   => 'ci',
    'jamaica'                                     => 'jm',
    'japan'                                       => 'jp',
    'jemen'                                       => 'ye',
    'jersey'                                      => 'je',
    'johnstonisland'                              => 'jt',
    'jordanië'                                   => 'jo',
    'kaapverdië'                                 => 'cv',
    'kameroen'                                    => 'cm',
    'kanaaleilanden'                              => 830,
    'kazachstan'                                  => 'kz',
    'kenia'                                       => 'ke',
    'kirgizië'                                   => 'kg',
    'kiribati'                                    => 'ki',
    'kleineafgelegeneilandenvandeverenigdestaten' => 'um',
    'koeweit'                                     => 'kw',
    'kroatië'                                    => 'hr',
    'laos'                                        => 'la',
    'latijnsamerikaenhetcaribischgebied'          => 419,
    'lesotho'                                     => 'ls',
    'letland'                                     => 'lv',
    'libanon'                                     => 'lb',
    'liberia'                                     => 'lr',
    'libië'                                      => 'ly',
    'liechtenstein'                               => 'li',
    'litouwen'                                    => 'lt',
    'luxemburg'                                   => 'lu',
    'macao'                                       => 'mo',
    'macedoniëfyrom'                             => 'mk',
    'madagaskar'                                  => 'mg',
    'malawi'                                      => 'mw',
    'malediven'                                   => 'mv',
    'maleisië'                                   => 'my',
    'mali'                                        => 'ml',
    'malta'                                       => 'mt',
    'marokko'                                     => 'ma',
    'marshalleilanden'                            => 'mh',
    'martinique'                                  => 'mq',
    'mauritanië'                                 => 'mr',
    'mauritius'                                   => 'mu',
    'mayotte'                                     => 'yt',
    'melanesië'                                  => '054',
    'mexico'                                      => 'mx',
    'micronesischeregio'                          => '057',
    'micronesië'                                 => 'fm',
    'midwayislands'                               => 'mi',
    'moldavië'                                   => 'md',
    'monaco'                                      => 'mc',
    'mongolië'                                   => 'mn',
    'montenegro'                                  => 'me',
    'montserrat'                                  => 'ms',
    'mozambique'                                  => 'mz',
    'myanmar'                                     => 'mm',
    'namibië'                                    => 'na',
    'nauru'                                       => 'nr',
    'nederland'                                   => 'nl',
    'nederlandseantillen'                         => 'an',
    'nepal'                                       => 'np',
    'neutralzone'                                 => 'nt',
    'nicaragua'                                   => 'ni',
    'nieuwcaledonië'                             => 'nc',
    'nieuwzeeland'                                => 'nz',
    'niger'                                       => 'ne',
    'nigeria'                                     => 'ng',
    'niue'                                        => 'nu',
    'noordafrika'                                 => '015',
    'noordamerika'                                => '003',
    'noordelijkamerika'                           => '021',
    'noordelijkemarianeneilanden'                 => 'mp',
    'noordeuropa'                                 => 154,
    'noordkorea'                                  => 'kp',
    'noorwegen'                                   => 'no',
    'norfolkeiland'                               => 'nf',
    'northvietnam'                                => 'vd',
    'oceanië'                                    => '009',
    'oeganda'                                     => 'ug',
    'oekraïne'                                   => 'ua',
    'oezbekistan'                                 => 'uz',
    'oman'                                        => 'om',
    'onbekendofonjuistgebied'                     => 'zz',
    'oostafrika'                                  => '014',
    'oostazië'                                   => '030',
    'oostenrijk'                                  => 'at',
    'oosteuropa'                                  => 151,
    'oosttimor'                                   => 'tl',
    'overigoceanië'                              => 'qo',
    'pacificislandstrustterritory'                => 'pc',
    'pakistan'                                    => 'pk',
    'palau'                                       => 'pw',
    'palestijnsegebieden'                         => 'ps',
    'panama'                                      => 'pa',
    'panamacanalzone'                             => 'pz',
    'papoeanieuwguinea'                           => 'pg',
    'paraguay'                                    => 'py',
    "people\â\\sdemocraticrepublicofyemen"   => 'yd',
    'peru'                                        => 'pe',
    'pitcairneilanden'                            => 'pn',
    'polen'                                       => 'pl',
    'polynesië'                                  => '061',
    'portugal'                                    => 'pt',
    'puertorico'                                  => 'pr',
    'qatar'                                       => 'qa',
    'roemenië'                                   => 'ro',
    'rusland'                                     => 'ru',
    'rwanda'                                      => 'rw',
    'réunion'                                    => 're',
    'saintbarthélemy'                            => 'bl',
    'saintkittsennevis'                           => 'kn',
    'saintlucia'                                  => 'lc',
    'saintpierreenmiquelon'                       => 'pm',
    'saintvincentendegrenadines'                  => 'vc',
    'salomoneilanden'                             => 'sb',
    'samoa'                                       => 'ws',
    'sanmarino'                                   => 'sm',
    'saoediarabië'                               => 'sa',
    'saotoméenprincipe'                          => 'st',
    'senegal'                                     => 'sn',
    'servië'                                     => 'rs',
    'serviëenmontenegro'                         => 'cs',
    'seychellen'                                  => 'sc',
    'sierraleone'                                 => 'sl',
    'singapore'                                   => 'sg',
    'sinthelena'                                  => 'sh',
    'sintmaarten'                                 => 'mf',
    'slovenië'                                   => 'si',
    'slowakije'                                   => 'sk',
    'soedan'                                      => 'sd',
    'somalië'                                    => 'so',
    'spanje'                                      => 'es',
    'srilanka'                                    => 'lk',
    'suriname'                                    => 'sr',
    'svalbardenjanmayen'                          => 'sj',
    'swaziland'                                   => 'sz',
    'syrië'                                      => 'sy',
    'tadzjikistan'                                => 'tj',
    'taiwan'                                      => 'tw',
    'tanzania'                                    => 'tz',
    'thailand'                                    => 'th',
    'togo'                                        => 'tg',
    'tokelau'                                     => 'tk',
    'tonga'                                       => 'to',
    'trinidadentobago'                            => 'tt',
    'tristandacunha'                              => 'ta',
    'tsjaad'                                      => 'td',
    'tsjechië'                                   => 'cz',
    'tunesië'                                    => 'tn',
    'turkije'                                     => 'tr',
    'turkmenistan'                                => 'tm',
    'turksencaicoseilanden'                       => 'tc',
    'tuvalu'                                      => 'tv',
    "u\.s\.miscellaneouspacificislands"           => 'pu',
    'unionofsovietsocialistrepublics'             => 'su',
    'uruguay'                                     => 'uy',
    'vanuatu'                                     => 'vu',
    'vaticaanstad'                                => 'va',
    'venezuela'                                   => 've',
    'verenigdearabischeemiraten'                  => 'ae',
    'verenigdestaten'                             => 'us',
    'verenigdkoninkrijk'                          => 'gb',
    'vietnam'                                     => 'vn',
    'wakeisland'                                  => 'wk',
    'wallisenfutuna'                              => 'wf',
    'wereld'                                      => '001',
    'westafrika'                                  => '011',
    'westazië'                                   => 145,
    'westelijkesahara'                            => 'eh',
    'westeuropa'                                  => 155,
    'witrusland'                                  => 'by',
    'zambia'                                      => 'zm',
    'zimbabwe'                                    => 'zw',
    'zuidafrika'                                  => 'za',
    'zuidamerika'                                 => '005',
    'zuidazië'                                   => '034',
    'zuidelijkafrika'                             => '018',
    'zuidelijkcentraalazië'                      => '062',
    'zuideuropa'                                  => '039',
    'zuidgeorgiëenzuidelijkesandwicheilanden'    => 'gs',
    'zuidkorea'                                   => 'kr',
    'zuidoostazië'                               => '035',
    'zweden'                                      => 'se',
    'zwitserland'                                 => 'ch',
    'Ålandeilanden'                              => 'ax',
);

1;

