package Locales::DB::Territory::kea;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::kea::VERSION = '0.09';

$Locales::DB::Territory::kea::cldr_version = '2.0';

%Locales::DB::Territory::kea::code_to_name = (
    '001' => 'Mundu',
    '002' => 'Afrika',
    '003' => "Merka\ di\ Norti",
    '005' => "Merka\ di\ Sul",
    '009' => 'Oseania',
    '011' => "Afrika\ Osidental",
    '013' => "Merka\ Sentral",
    '014' => "Afrika\ Oriental",
    '015' => "Norti\ di\ Afrika",
    '017' => "Afrika\ Sentral",
    '018' => "Sul\ di\ Afrika",
    '019' => 'Merkas',
    '021' => "Norti\ di\ Merka",
    '029' => 'Karaibas',
    '030' => "Azia\ Oriental",
    '034' => "Sul\ di\ Azia",
    '035' => "Sudesti\ Aziatiku",
    '039' => "Europa\ di\ Sul",
    '053' => "Australia\ y\ Nova\ Zelandia",
    '054' => 'Melanezia',
    '057' => "Rejiãu\ di\ Mikronezia",
    '061' => 'Polinezia',
    '062' => "South\-Central\ Asia",
    142   => 'Azia',
    143   => "Azia\ Sentral",
    145   => "Azia\ Osidental",
    150   => 'Europa',
    151   => "Europa\ Oriental",
    154   => "Europa\ di\ Norti",
    155   => "Europa\ Osidental",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Merka\ Latinu",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andora',
    'ae'  => "Emiradus\ Arabi\ Unidu",
    'af'  => 'Afeganistãu',
    'ag'  => "Antigua\ i\ Barbuda",
    'ai'  => 'Angila',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Antilhas\ Olandeza",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Arjentina',
    'as'  => "Samoa\ Merkanu",
    'at'  => 'Austria',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerbaijãu',
    'ba'  => "Bosnia\-Erzegovina",
    'bb'  => 'Barbadus',
    'bd'  => 'Bangladexi',
    'be'  => 'Béljika',
    'bf'  => "Burkina\ Fasu",
    'bg'  => 'Bulgaria',
    'bh'  => 'Barain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermudas',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brazil',
    'bs'  => 'Baamas',
    'bt'  => 'Butãu',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botsuana',
    'by'  => 'Belarus',
    'bz'  => 'Belizi',
    'ca'  => 'Kanadá',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Republika\ Dimokratika\ di\ Kongu",
    'cf'  => "Republika\ Sentru\-Afrikanu",
    'cg'  => 'Kongu',
    'ch'  => 'Suisa',
    'ci'  => "Kosta\ di\ Marfin",
    'ck'  => "Ilhas\ Kuk",
    'cl'  => 'Xili',
    'cm'  => 'Kamarõis',
    'cn'  => 'Xina',
    'co'  => 'Kulombia',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kosta\ Rika",
    'cs'  => "Servia\ i\ Montinegru",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Kabu\ Verdi",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Xipri',
    'cz'  => "Republika\ Txeka",
    'dd'  => "East\ Germany",
    'de'  => 'Alimanha',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibuti',
    'dk'  => 'Dinamarka',
    'dm'  => 'Dominika',
    'do'  => "Repúblika\ Dominikana",
    'dz'  => 'Arjelia',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekuador',
    'ee'  => 'Stonia',
    'eg'  => 'Ejitu',
    'eh'  => "Western\ Sahara",
    'er'  => 'Iritreia',
    'es'  => 'Spanha',
    'et'  => 'Itiopia',
    'eu'  => "European\ Union",
    'fi'  => 'Finlandia',
    'fj'  => 'Fidji',
    'fk'  => "Ilhas\ Malvinas",
    'fm'  => 'Mikronezia',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Fransa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabãu',
    'gb'  => "Reinu\ Unidu",
    'gd'  => 'Granada',
    'ge'  => 'Jiorjia',
    'gf'  => "Giana\ Franseza",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Jibraltar',
    'gl'  => 'Gronelandia',
    'gm'  => 'Gambia',
    'gn'  => 'Gine',
    'gp'  => 'Guadalupi',
    'gq'  => "Gine\ Ekuatorial",
    'gr'  => 'Gresia',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Guatimala',
    'gu'  => 'Guam',
    'gw'  => "Gine\-Bisau",
    'gy'  => 'Giana',
    'hk'  => "Ong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Onduras',
    'hr'  => 'Kroasia',
    'ht'  => 'Aiti',
    'hu'  => 'Ungria',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonezia',
    'ie'  => 'Irlanda',
    'il'  => 'Israel',
    'im'  => "Isle\ of\ Man",
    'in'  => 'India',
    'io'  => "Ilhas\ Britanika\ di\ Indiku",
    'iq'  => 'Iraki',
    'ir'  => 'Iron',
    'is'  => 'Islandia',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordania',
    'jp'  => 'Japãu',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirgiston',
    'kh'  => 'Kambodja',
    'ki'  => 'Kiribati',
    'km'  => 'Kamoris',
    'kn'  => "Sãu\ Kristovãu\ i\ Nevis",
    'kp'  => "Koreia\ di\ Norti",
    'kr'  => "Koreia\ di\ Sul",
    'kw'  => 'Kueiti',
    'ky'  => "Ilhas\ Kaimãu",
    'kz'  => 'Kazakistãu',
    'la'  => 'Laus',
    'lb'  => 'Libanu',
    'lc'  => "Santa\ Lúsia",
    'li'  => 'Lixenstain',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lezotu',
    'lt'  => 'Lituania',
    'lu'  => 'Luxemburgu',
    'lv'  => 'Letonia',
    'ly'  => 'Libia',
    'ma'  => 'Marokus',
    'mc'  => 'Monaku',
    'md'  => 'Moldavia',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Ilhas\ Marxal",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masidonia',
    'ml'  => 'Mali',
    'mm'  => 'Mianmar',
    'mn'  => 'Mongolia',
    'mo'  => 'Macau',
    'mp'  => "Ilhas\ Marianas\ di\ Norti",
    'mq'  => 'Martinika',
    'mr'  => 'Mauritania',
    'ms'  => 'Monserat',
    'mt'  => 'Malta',
    'mu'  => "Ilhas\ Maurisia",
    'mv'  => 'Maldivas',
    'mw'  => 'Malaui',
    'mx'  => 'Mexiku',
    'my'  => 'Malazia',
    'mz'  => 'Musambiki',
    'na'  => 'Namibia',
    'nc'  => "Nova\ Kalidonia",
    'ne'  => 'Nijer',
    'nf'  => "Ilhas\ Norfolk",
    'ng'  => 'Nijeria',
    'ni'  => 'Nikaragua',
    'nl'  => 'Olanda',
    'no'  => 'Noruega',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nova\ Zilandia",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polinezia\ Franseza",
    'pg'  => "Papua\-Nova\ Gine",
    'ph'  => 'Filipinas',
    'pk'  => 'Pakistãu',
    'pl'  => 'Pulonia',
    'pm'  => "San\ Piere\ i\ Mikelon",
    'pn'  => 'Pirkairn',
    'pr'  => "Portu\ Riku",
    'ps'  => 'Palistina',
    'pt'  => 'Purtugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Runion',
    'ro'  => 'Romenia',
    'rs'  => 'Serbia',
    'ru'  => 'Rúsia',
    'rw'  => 'Ruanda',
    'sa'  => "Arabia\ Saudita",
    'sb'  => "Ilhas\ Salumon",
    'sc'  => 'Seixelis',
    'sd'  => 'Sudãu',
    'se'  => 'Suesia',
    'sg'  => 'Singapura',
    'sh'  => "Santa\ Ilena",
    'si'  => 'Slovenia',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slovakia',
    'sl'  => "Sera\ Lioa",
    'sm'  => "San\ Marinu",
    'sn'  => 'Senegal',
    'so'  => 'Sumalia',
    'sr'  => 'Surinami',
    'st'  => "Sãu\ Tume\ i\ Prinsipi",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Siria',
    'sz'  => 'Suazilándia',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Ilhas\ Turkas\ i\ Kaikus",
    'td'  => 'Txadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togu',
    'th'  => 'Tailandia',
    'tj'  => 'Tadjikistãu',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ Lesti",
    'tm'  => 'Turkumenistãu',
    'tn'  => 'Tunizia',
    'to'  => 'Tonga',
    'tr'  => 'Turkia',
    'tt'  => "Trinidad\ i\ Tobagu",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiuan',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukrania',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Stadus\ Unidos\ di\ Merka",
    'uy'  => 'Uruguai',
    'uz'  => 'Uzbekistãu',
    'va'  => 'Vatikanu',
    'vc'  => "Sãu\ Bisenti\ i\ Granadinas",
    'vd'  => "North\ Vietnam",
    've'  => 'Vinizuea',
    'vg'  => "Ilhas\ Virjens\ Britanikas",
    'vi'  => "Ilhas\ Virjens\ Merkanu",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Ualis\ i\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Iemen',
    'yt'  => 'Maiote',
    'za'  => "Afrika\ di\ Sul",
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabui',
    'zz'  => "rejiãu\ diskonxedu",
);

%Locales::DB::Territory::kea::name_to_code = (
    'afeganistãu'                              => 'af',
    'afrika'                                    => '002',
    'afrikadisul'                               => 'za',
    'afrikaoriental'                            => '014',
    'afrikaosidental'                           => '011',
    'afrikasentral'                             => '017',
    'aiti'                                      => 'ht',
    'albania'                                   => 'al',
    'alimanha'                                  => 'de',
    'andora'                                    => 'ad',
    'angila'                                    => 'ai',
    'angola'                                    => 'ao',
    'antarctica'                                => 'aq',
    'antiguaibarbuda'                           => 'ag',
    'antilhasolandeza'                          => 'an',
    'arabiasaudita'                             => 'sa',
    'arjelia'                                   => 'dz',
    'arjentina'                                 => 'ar',
    'armenia'                                   => 'am',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'australia'                                 => 'au',
    'australiaynovazelandia'                    => '053',
    'austria'                                   => 'at',
    'azerbaijãu'                               => 'az',
    'azia'                                      => 142,
    'aziaoriental'                              => '030',
    'aziaosidental'                             => 145,
    'aziasentral'                               => 143,
    'baamas'                                    => 'bs',
    'bangladexi'                                => 'bd',
    'barain'                                    => 'bh',
    'barbadus'                                  => 'bb',
    'belarus'                                   => 'by',
    'belizi'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermudas'                                  => 'bm',
    'bolivia'                                   => 'bo',
    'bosniaerzegovina'                          => 'ba',
    'botsuana'                                  => 'bw',
    'bouvetisland'                              => 'bv',
    'brazil'                                    => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brunei'                                    => 'bn',
    'bulgaria'                                  => 'bg',
    'burkinafasu'                               => 'bf',
    'burundi'                                   => 'bi',
    'butãu'                                    => 'bt',
    'béljika'                                  => 'be',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'diegogarcia'                               => 'dg',
    'dinamarka'                                 => 'dk',
    'djibuti'                                   => 'dj',
    'dominika'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ejitu'                                     => 'eg',
    'ekuador'                                   => 'ec',
    'elsalvador'                                => 'sv',
    'emiradusarabiunidu'                        => 'ae',
    'europa'                                    => 150,
    'europadinorti'                             => 154,
    'europadisul'                               => '039',
    'europaoriental'                            => 151,
    'europaosidental'                           => 155,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'fidji'                                     => 'fj',
    'filipinas'                                 => 'ph',
    'finlandia'                                 => 'fi',
    'fransa'                                    => 'fr',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabãu'                                    => 'ga',
    'gambia'                                    => 'gm',
    'gana'                                      => 'gh',
    'giana'                                     => 'gy',
    'gianafranseza'                             => 'gf',
    'gine'                                      => 'gn',
    'ginebisau'                                 => 'gw',
    'gineekuatorial'                            => 'gq',
    'granada'                                   => 'gd',
    'gresia'                                    => 'gr',
    'gronelandia'                               => 'gl',
    'guadalupi'                                 => 'gp',
    'guam'                                      => 'gu',
    'guatimala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'heardislandandmcdonaldislands'             => 'hm',
    'iemen'                                     => 'ye',
    'ilhasbritanikadiindiku'                    => 'io',
    'ilhaskaimãu'                              => 'ky',
    'ilhaskuk'                                  => 'ck',
    'ilhasmalvinas'                             => 'fk',
    'ilhasmarianasdinorti'                      => 'mp',
    'ilhasmarxal'                               => 'mh',
    'ilhasmaurisia'                             => 'mu',
    'ilhasnorfolk'                              => 'nf',
    'ilhassalumon'                              => 'sb',
    'ilhasturkasikaikus'                        => 'tc',
    'ilhasvirjensbritanikas'                    => 'vg',
    'ilhasvirjensmerkanu'                       => 'vi',
    'india'                                     => 'in',
    'indonezia'                                 => 'id',
    'iraki'                                     => 'iq',
    'iritreia'                                  => 'er',
    'irlanda'                                   => 'ie',
    'iron'                                      => 'ir',
    'islandia'                                  => 'is',
    'isleofman'                                 => 'im',
    'israel'                                    => 'il',
    'italia'                                    => 'it',
    'itiopia'                                   => 'et',
    'jamaika'                                   => 'jm',
    'japãu'                                    => 'jp',
    'jersey'                                    => 'je',
    'jibraltar'                                 => 'gi',
    'jiorjia'                                   => 'ge',
    'johnstonisland'                            => 'jt',
    'jordania'                                  => 'jo',
    'kabuverdi'                                 => 'cv',
    'kamarõis'                                 => 'cm',
    'kambodja'                                  => 'kh',
    'kamoris'                                   => 'km',
    'kanadá'                                   => 'ca',
    'karaibas'                                  => '029',
    'katar'                                     => 'qa',
    'kazakistãu'                               => 'kz',
    'kenia'                                     => 'ke',
    'kirgiston'                                 => 'kg',
    'kiribati'                                  => 'ki',
    'kongu'                                     => 'cg',
    'koreiadinorti'                             => 'kp',
    'koreiadisul'                               => 'kr',
    'kostadimarfin'                             => 'ci',
    'kostarika'                                 => 'cr',
    'kroasia'                                   => 'hr',
    'kuba'                                      => 'cu',
    'kueiti'                                    => 'kw',
    'kulombia'                                  => 'co',
    'laus'                                      => 'la',
    'letonia'                                   => 'lv',
    'lezotu'                                    => 'ls',
    'libanu'                                    => 'lb',
    'liberia'                                   => 'lr',
    'libia'                                     => 'ly',
    'lituania'                                  => 'lt',
    'lixenstain'                                => 'li',
    'luxemburgu'                                => 'lu',
    'macau'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'maiote'                                    => 'yt',
    'malaui'                                    => 'mw',
    'malazia'                                   => 'my',
    'maldivas'                                  => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'marokus'                                   => 'ma',
    'martinika'                                 => 'mq',
    'masidonia'                                 => 'mk',
    'mauritania'                                => 'mr',
    'melanezia'                                 => '054',
    'merkadinorti'                              => '003',
    'merkadisul'                                => '005',
    'merkalatinu'                               => 419,
    'merkas'                                    => '019',
    'merkasentral'                              => '013',
    'metropolitanfrance'                        => 'fx',
    'mexiku'                                    => 'mx',
    'mianmar'                                   => 'mm',
    'midwayislands'                             => 'mi',
    'mikronezia'                                => 'fm',
    'moldavia'                                  => 'md',
    'monaku'                                    => 'mc',
    'mongolia'                                  => 'mn',
    'monserat'                                  => 'ms',
    'montenegro'                                => 'me',
    'mundu'                                     => '001',
    'musambiki'                                 => 'mz',
    'namibia'                                   => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nijer'                                     => 'ne',
    'nijeria'                                   => 'ng',
    'nikaragua'                                 => 'ni',
    'niue'                                      => 'nu',
    'northvietnam'                              => 'vd',
    'nortidiafrika'                             => '015',
    'nortidimerka'                              => '021',
    'noruega'                                   => 'no',
    'novakalidonia'                             => 'nc',
    'novazilandia'                              => 'nz',
    'olanda'                                    => 'nl',
    'oman'                                      => 'om',
    'onduras'                                   => 'hn',
    'ongkong'                                   => 'hk',
    'oseania'                                   => '009',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakistãu'                                 => 'pk',
    'palau'                                     => 'pw',
    'palistina'                                 => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanovagine'                             => 'pg',
    'paraguai'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pirkairn'                                  => 'pn',
    'polinezia'                                 => '061',
    'polineziafranseza'                         => 'pf',
    'porturiku'                                 => 'pr',
    'pulonia'                                   => 'pl',
    'purtugal'                                  => 'pt',
    'reinuunidu'                                => 'gb',
    'rejiãudimikronezia'                       => '057',
    'rejiãudiskonxedu'                         => 'zz',
    'republikadimokratikadikongu'               => 'cd',
    'republikasentruafrikanu'                   => 'cf',
    'republikatxeka'                            => 'cz',
    'repúblikadominikana'                      => 'do',
    'romenia'                                   => 'ro',
    'ruanda'                                    => 'rw',
    'runion'                                    => 're',
    'rúsia'                                    => 'ru',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'samoa'                                     => 'ws',
    'samoamerkanu'                              => 'as',
    'sanmarinu'                                 => 'sm',
    'sanpiereimikelon'                          => 'pm',
    'santailena'                                => 'sh',
    'santalúsia'                               => 'lc',
    'seixelis'                                  => 'sc',
    'senegal'                                   => 'sn',
    'seralioa'                                  => 'sl',
    'serbia'                                    => 'rs',
    'serviaimontinegru'                         => 'cs',
    'singapura'                                 => 'sg',
    'siria'                                     => 'sy',
    'slovakia'                                  => 'sk',
    'slovenia'                                  => 'si',
    'southcentralasia'                          => '062',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'spanha'                                    => 'es',
    'srilanka'                                  => 'lk',
    'stadusunidosdimerka'                       => 'us',
    'stonia'                                    => 'ee',
    'suazilándia'                              => 'sz',
    'sudestiaziatiku'                           => '035',
    'sudãu'                                    => 'sd',
    'suesia'                                    => 'se',
    'suisa'                                     => 'ch',
    'suldiafrika'                               => '018',
    'suldiazia'                                 => '034',
    'sumalia'                                   => 'so',
    'surinami'                                  => 'sr',
    'svalbardandjanmayen'                       => 'sj',
    'sãubisentiigranadinas'                    => 'vc',
    'sãukristovãuinevis'                      => 'kn',
    'sãutumeiprinsipi'                         => 'st',
    'tadjikistãu'                              => 'tj',
    'tailandia'                                 => 'th',
    'taiuan'                                    => 'tw',
    'tanzania'                                  => 'tz',
    'timorlesti'                                => 'tl',
    'togu'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidaditobagu'                           => 'tt',
    'tristandacunha'                            => 'ta',
    'tunizia'                                   => 'tn',
    'turkia'                                    => 'tr',
    'turkumenistãu'                            => 'tm',
    'tuvalu'                                    => 'tv',
    'txadi'                                     => 'td',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ualisifutuna'                              => 'wf',
    'uganda'                                    => 'ug',
    'ukrania'                                   => 'ua',
    'ungria'                                    => 'hu',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguai'                                   => 'uy',
    'uzbekistãu'                               => 'uz',
    'vanuatu'                                   => 'vu',
    'vatikanu'                                  => 'va',
    'vietnam'                                   => 'vn',
    'vinizuea'                                  => 've',
    'wakeisland'                                => 'wk',
    'westernsahara'                             => 'eh',
    'xili'                                      => 'cl',
    'xina'                                      => 'cn',
    'xipri'                                     => 'cy',
    'zambia'                                    => 'zm',
    'zimbabui'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
);

1;

