package Locales::DB::Territory::bg;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::bg::VERSION = '0.09';

$Locales::DB::Territory::bg::cldr_version = '2.0';

%Locales::DB::Territory::bg::code_to_name = (
    '001' => 'Земята',
    '002' => 'Африка',
    '003' => "Северноамерикански\ континент",
    '005' => "Южна\ Америка",
    '009' => 'Океания',
    '011' => "Западна\ Афирка",
    '013' => "Централна\ Америка",
    '014' => "Източна\ Африка",
    '015' => "Северна\ Африка",
    '017' => "Централна\ Африка",
    '018' => "Южноафрикански\ регион",
    '019' => 'Америка',
    '021' => "Северна\ Америка",
    '029' => "Карибски\ о\-ви",
    '030' => "Източна\ Азия",
    '034' => "Южна\ Азия",
    '035' => "Югоизточна\ Азия",
    '039' => "Южна\ Европа",
    '053' => "Австралия\ и\ Нова\ Зеландия",
    '054' => 'Меланезия',
    '057' => 'Микронезия',
    '061' => 'Полинезия',
    '062' => "Южна\ Азия\ \[062\]",
    142   => 'Азия',
    143   => "Централна\ Азия",
    145   => "Западна\ Азия",
    150   => 'Европа',
    151   => "Източна\ Европа",
    154   => "Северна\ Европа",
    155   => "Западна\ Европа",
    172   => "Общност\ на\ независимите\ държави",
    200   => 'Czechoslovakia',
    419   => "Латинска\ Америка\ и\ Карибски\ басейн",
    830   => "Нормандски\ о\-ви",
    'ac'  => "Остров\ Възнесение",
    'ad'  => 'Андора',
    'ae'  => "Обединени\ арабски\ емирства",
    'af'  => 'Афганистан',
    'ag'  => "Антигуа\ и\ Барбуда",
    'ai'  => 'Ангуила',
    'al'  => 'Албания',
    'am'  => 'Армения',
    'an'  => "Холандски\ Антили",
    'ao'  => 'Ангола',
    'aq'  => 'Антарктика',
    'ar'  => 'Аржентина',
    'as'  => "Американско\ Самоа",
    'at'  => 'Австрия',
    'au'  => 'Австралия',
    'aw'  => 'Аруба',
    'ax'  => "Аландски\ о\-ви",
    'az'  => 'Азербайджан',
    'ba'  => "Босна\ и\ Херцеговина",
    'bb'  => 'Барбадос',
    'bd'  => 'Бангладеш',
    'be'  => 'Белгия',
    'bf'  => "Буркина\ Фасо",
    'bg'  => 'България',
    'bh'  => 'Бахрейн',
    'bi'  => 'Бурунди',
    'bj'  => 'Бенин',
    'bl'  => "Сейнт\ Бартоломей",
    'bm'  => 'Бермуда',
    'bn'  => "Бруней\ Дарусалам",
    'bo'  => 'Боливия',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Бразилия',
    'bs'  => 'Бахами',
    'bt'  => 'Бутан',
    'bv'  => "Остров\ Буве",
    'bw'  => 'Ботсуана',
    'by'  => 'Беларус',
    'bz'  => 'Белиз',
    'ca'  => 'Канада',
    'cc'  => "Кокосови\ \[Кийлинг\]\ острови",
    'cd'  => "Конго\ \[ДРК\]",
    'cf'  => "Централноафриканска\ Република",
    'cg'  => "Конго\ \[Република\]",
    'ch'  => 'Швейцария',
    'ci'  => "Кот\ д\'Ивоар",
    'ck'  => "Острови\ Кук",
    'cl'  => 'Чили',
    'cm'  => 'Камерун',
    'cn'  => 'Китай',
    'co'  => 'Колумбия',
    'cp'  => "Остров\ Клипертон",
    'cr'  => "Коста\ Рика",
    'cs'  => "Сърбия\ и\ Черна\ гора",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Куба',
    'cv'  => "Кабо\ Верде",
    'cx'  => "Остров\ Кристмас",
    'cy'  => 'Кипър',
    'cz'  => "Чешка\ република",
    'dd'  => "East\ Germany",
    'de'  => 'Германия',
    'dg'  => "Диего\ Гарсия",
    'dj'  => 'Джибути',
    'dk'  => 'Дания',
    'dm'  => 'Доминика',
    'do'  => "Доминиканска\ република",
    'dz'  => 'Алжир',
    'ea'  => "Сеута\ и\ Мелия",
    'ec'  => 'Еквадор',
    'ee'  => 'Естония',
    'eg'  => 'Египет',
    'eh'  => "Западна\ Сахара",
    'er'  => 'Еритрея',
    'es'  => 'Испания',
    'et'  => 'Етиопия',
    'eu'  => "Европейски\ съюз",
    'fi'  => 'Финландия',
    'fj'  => 'Фиджи',
    'fk'  => "Фолкландски\ острови\ \[Малвини\]",
    'fm'  => "Микронезия\,\ Обединени\ Щати",
    'fo'  => "Фарьорски\ острови",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Франция',
    'fx'  => "Континентална\ Франция",
    'ga'  => 'Габон',
    'gb'  => "Обединено\ кралство",
    'gd'  => 'Гренада',
    'ge'  => 'Грузия',
    'gf'  => "Френска\ Гвиана",
    'gg'  => "о\.\ Гърнзи",
    'gh'  => 'Гана',
    'gi'  => 'Гибралтар',
    'gl'  => 'Гренландия',
    'gm'  => 'Гамбия',
    'gn'  => 'Гвинея',
    'gp'  => 'Гваделупа',
    'gq'  => "Екваториална\ Гвинея",
    'gr'  => 'Гърция',
    'gs'  => "Южна\ Джорджия\ и\ Южни\ Сандвичеви\ Острови",
    'gt'  => 'Гватемала',
    'gu'  => 'Гуам',
    'gw'  => "Гвинея\-Бисау",
    'gy'  => 'Гвиана',
    'hk'  => 'Хонконг',
    'hm'  => "Остров\ Хърд\ и\ Острови\ Макдоналд",
    'hn'  => 'Хондурас',
    'hr'  => 'Хърватска',
    'ht'  => 'Хаити',
    'hu'  => 'Унгария',
    'ic'  => "Канарски\ острови",
    'id'  => 'Индонезия',
    'ie'  => 'Ирландия',
    'il'  => 'Израел',
    'im'  => "Острови\ Ман",
    'in'  => 'Индия',
    'io'  => "Британски\ територии\ в\ Индийския\ океан",
    'iq'  => 'Ирак',
    'ir'  => "Иран\,\ Ислямска\ република",
    'is'  => 'Исландия',
    'it'  => 'Италия',
    'je'  => "о\.\ Джързи",
    'jm'  => 'Ямайка',
    'jo'  => 'Йордания',
    'jp'  => 'Япония',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Кения',
    'kg'  => 'Киргизстан',
    'kh'  => 'Камбоджа',
    'ki'  => 'Кирибати',
    'km'  => 'Комори',
    'kn'  => "Сейнт\ Китс\ и\ Невис",
    'kp'  => "Северна\ Корея",
    'kr'  => "Корея\,\ Южна",
    'kw'  => 'Кувейт',
    'ky'  => "Кайманови\ острови",
    'kz'  => 'Казахстан',
    'la'  => "Народна\ демократична\ република\ Лаос",
    'lb'  => 'Ливан',
    'lc'  => "Сейнт\ Лусия",
    'li'  => 'Лихтенщайн',
    'lk'  => "Шри\ Ланка",
    'lr'  => 'Либерия',
    'ls'  => 'Лесото',
    'lt'  => 'Литва',
    'lu'  => 'Люксембург',
    'lv'  => 'Латвия',
    'ly'  => "Либийска\ арабска\ джамахирия",
    'ma'  => 'Мароко',
    'mc'  => 'Монако',
    'md'  => "Молдова\,\ Република",
    'me'  => "Черна\ гора",
    'mf'  => "Сейнт\ Мартин",
    'mg'  => 'Мадагаскар',
    'mh'  => "Маршалови\ острови",
    'mi'  => "Midway\ Islands",
    'mk'  => "Македония\ \[БЮРМ\]",
    'ml'  => 'Мали',
    'mm'  => "Мианмар\ \[Бирма\]",
    'mn'  => 'Монголия',
    'mo'  => 'Макао',
    'mp'  => "Северни\ Мариански\ Острови",
    'mq'  => 'Мартиника',
    'mr'  => 'Мавритания',
    'ms'  => 'Монсерат',
    'mt'  => 'Малта',
    'mu'  => 'Мавриций',
    'mv'  => 'Малдиви',
    'mw'  => 'Малави',
    'mx'  => 'Мексико',
    'my'  => 'Малайзия',
    'mz'  => 'Мозамбик',
    'na'  => 'Намибия',
    'nc'  => "Нова\ Каледония",
    'ne'  => 'Нигер',
    'nf'  => "Остров\ Норфолк",
    'ng'  => 'Нигерия',
    'ni'  => 'Никарагуа',
    'nl'  => 'Холандия',
    'no'  => 'Норвегия',
    'np'  => 'Непал',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Науру',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Ниуе',
    'nz'  => "Нова\ Зеландия",
    'om'  => 'Оман',
    'pa'  => 'Панама',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Перу',
    'pf'  => "Френска\ Полинезия",
    'pg'  => "Папуа\ Нова\ Гвинея",
    'ph'  => 'Филипини',
    'pk'  => 'Пакистан',
    'pl'  => 'Полша',
    'pm'  => "Сен\ Пиер\ и\ Мигелон",
    'pn'  => 'Питкайрн',
    'pr'  => "Пуерто\ Рико",
    'ps'  => "Палестински\ територии",
    'pt'  => 'Португалия',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Палау',
    'py'  => 'Парагвай',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Катар',
    'qo'  => "Океания\ \[QO\]",
    're'  => 'Реюниън',
    'ro'  => 'Румъния',
    'rs'  => 'Сърбия',
    'ru'  => "Руска\ федерация",
    'rw'  => 'Руанда',
    'sa'  => "Саудитска\ Арабия",
    'sb'  => "Соломонови\ острови",
    'sc'  => 'Сейшели',
    'sd'  => 'Судан',
    'se'  => 'Швеция',
    'sg'  => 'Сингапур',
    'sh'  => "Света\ Елена",
    'si'  => 'Словения',
    'sj'  => "Свалбард\ и\ Ян\ Майен",
    'sk'  => 'Словакия',
    'sl'  => "Сиера\ Леоне",
    'sm'  => "Сан\ Марино",
    'sn'  => 'Сенегал',
    'so'  => 'Сомалия',
    'sr'  => 'Суринам',
    'st'  => "Сао\ Томе\ и\ Принципе",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "Ел\ Салвадор",
    'sy'  => "Сирийска\ арабска\ република",
    'sz'  => 'Суазиленд',
    'ta'  => "Тристан\ да\ Куня",
    'tc'  => "Острови\ Туркс\ и\ Кайкос",
    'td'  => 'Чад',
    'tf'  => "Френски\ южни\ територии",
    'tg'  => 'Того',
    'th'  => 'Тайланд',
    'tj'  => 'Таджикистан',
    'tk'  => 'Токелау',
    'tl'  => "Източен\ Тимор",
    'tm'  => 'Туркменистан',
    'tn'  => 'Тунис',
    'to'  => 'Тонга',
    'tr'  => 'Турция',
    'tt'  => "Тринидад\ и\ Тобаго",
    'tv'  => 'Тувалу',
    'tw'  => 'Тайван',
    'tz'  => 'Танзания',
    'ua'  => 'Украйна',
    'ug'  => 'Уганда',
    'um'  => "САЩ\ \-\ външни\ острови",
    'us'  => 'САЩ',
    'uy'  => 'Уругвай',
    'uz'  => 'Узбекистан',
    'va'  => "Свещено\ море\ \[Ватиканска\ държава\]",
    'vc'  => "Сейнт\ Винсънт\ и\ Гренадини",
    'vd'  => "North\ Vietnam",
    've'  => 'Венецуела',
    'vg'  => "Британски\ Вирджински\ острони",
    'vi'  => "САЩ\,\ Вирджински\ острови",
    'vn'  => 'Виетнам',
    'vu'  => 'Вануату',
    'wf'  => "Уолис\ и\ Футуна",
    'wk'  => "Wake\ Island",
    'ws'  => 'Самоа',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Йемен',
    'yt'  => 'Мейот',
    'za'  => "Южна\ Африка",
    'zm'  => 'Замбия',
    'zw'  => 'Зимбабве',
    'zz'  => "Непозната\ или\ несъществуваща\ област",
);

%Locales::DB::Territory::bg::name_to_code = (
    'britishantarcticterritory'                                            => 'bq',
    'cantonandenderburyislands'                                            => 'ct',
    'czechoslovakia'                                                       => 200,
    'dronningmaudland'                                                     => 'nq',
    'eastgermany'                                                          => 'dd',
    'frenchsouthernandantarcticterritories'                                => 'fq',
    'johnstonisland'                                                       => 'jt',
    'midwayislands'                                                        => 'mi',
    'neutralzone'                                                          => 'nt',
    'northvietnam'                                                         => 'vd',
    'pacificislandstrustterritory'                                         => 'pc',
    'panamacanalzone'                                                      => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                            => 'yd',
    "u\.s\.miscellaneouspacificislands"                                    => 'pu',
    'unionofsovietsocialistrepublics'                                      => 'su',
    'wakeisland'                                                           => 'wk',
    'Австралия'                                                   => 'au',
    'АвстралияиНоваЗеландия'                         => '053',
    'Австрия'                                                       => 'at',
    'Азербайджан'                                               => 'az',
    'Азия'                                                             => 142,
    'Аландскиови'                                               => 'ax',
    'Албания'                                                       => 'al',
    'Алжир'                                                           => 'dz',
    'Америка'                                                       => '019',
    'АмериканскоСамоа'                                     => 'as',
    'Ангола'                                                         => 'ao',
    'Ангуила'                                                       => 'ai',
    'Андора'                                                         => 'ad',
    'Антарктика'                                                 => 'aq',
    'АнтигуаиБарбуда'                                       => 'ag',
    'Аржентина'                                                   => 'ar',
    'Армения'                                                       => 'am',
    'Аруба'                                                           => 'aw',
    'Афганистан'                                                 => 'af',
    'Африка'                                                         => '002',
    'Бангладеш'                                                   => 'bd',
    'Барбадос'                                                     => 'bb',
    'Бахами'                                                         => 'bs',
    'Бахрейн'                                                       => 'bh',
    'Беларус'                                                       => 'by',
    'Белгия'                                                         => 'be',
    'Белиз'                                                           => 'bz',
    'Бенин'                                                           => 'bj',
    'Бермуда'                                                       => 'bm',
    'Боливия'                                                       => 'bo',
    'БоснаиХерцеговина'                                   => 'ba',
    'Ботсуана'                                                     => 'bw',
    'Бразилия'                                                     => 'br',
    'БританскиВирджинскиострони'                 => 'vg',
    'БританскитериториивИндийскияокеан'   => 'io',
    'БрунейДарусалам'                                       => 'bn',
    'БуркинаФасо'                                               => 'bf',
    'Бурунди'                                                       => 'bi',
    'Бутан'                                                           => 'bt',
    'България'                                                     => 'bg',
    'Вануату'                                                       => 'vu',
    'Венецуела'                                                   => 've',
    'Виетнам'                                                       => 'vn',
    'Габон'                                                           => 'ga',
    'Гамбия'                                                         => 'gm',
    'Гана'                                                             => 'gh',
    'Гваделупа'                                                   => 'gp',
    'Гватемала'                                                   => 'gt',
    'Гвиана'                                                         => 'gy',
    'Гвинея'                                                         => 'gn',
    'ГвинеяБисау'                                               => 'gw',
    'Германия'                                                     => 'de',
    'Гибралтар'                                                   => 'gi',
    'Гренада'                                                       => 'gd',
    'Гренландия'                                                 => 'gl',
    'Грузия'                                                         => 'ge',
    'Гуам'                                                             => 'gu',
    'Гърция'                                                         => 'gr',
    'Дания'                                                           => 'dk',
    'Джибути'                                                       => 'dj',
    'ДиегоГарсия'                                               => 'dg',
    'Доминика'                                                     => 'dm',
    'Доминиканскарепублика'                           => 'do',
    'Европа'                                                         => 150,
    'Европейскисъюз'                                         => 'eu',
    'Египет'                                                         => 'eg',
    'Еквадор'                                                       => 'ec',
    'ЕкваториалнаГвинея'                                 => 'gq',
    'ЕлСалвадор'                                                 => 'sv',
    'Еритрея'                                                       => 'er',
    'Естония'                                                       => 'ee',
    'Етиопия'                                                       => 'et',
    'Замбия'                                                         => 'zm',
    'ЗападнаАзия'                                               => 145,
    'ЗападнаАфирка'                                           => '011',
    'ЗападнаЕвропа'                                           => 155,
    'ЗападнаСахара'                                           => 'eh',
    'Земята'                                                         => '001',
    'Зимбабве'                                                     => 'zw',
    'Израел'                                                         => 'il',
    'ИзточенТимор'                                             => 'tl',
    'ИзточнаАзия'                                               => '030',
    'ИзточнаАфрика'                                           => '014',
    'ИзточнаЕвропа'                                           => 151,
    'Индия'                                                           => 'in',
    'Индонезия'                                                   => 'id',
    'Ирак'                                                             => 'iq',
    "Иран\,Ислямскарепублика"                         => 'ir',
    'Ирландия'                                                     => 'ie',
    'Исландия'                                                     => 'is',
    'Испания'                                                       => 'es',
    'Италия'                                                         => 'it',
    'Йемен'                                                           => 'ye',
    'Йордания'                                                     => 'jo',
    'КабоВерде'                                                   => 'cv',
    'Казахстан'                                                   => 'kz',
    'Каймановиострови'                                     => 'ky',
    'Камбоджа'                                                     => 'kh',
    'Камерун'                                                       => 'cm',
    'Канада'                                                         => 'ca',
    'Канарскиострови'                                       => 'ic',
    'Карибскиови'                                               => '029',
    'Катар'                                                           => 'qa',
    'Кения'                                                           => 'ke',
    'Кипър'                                                           => 'cy',
    'Киргизстан'                                                 => 'kg',
    'Кирибати'                                                     => 'ki',
    'Китай'                                                           => 'cn',
    'КокосовиКийлингострови'                         => 'cc',
    'Колумбия'                                                     => 'co',
    'Комори'                                                         => 'km',
    'КонгоДРК'                                                     => 'cd',
    'КонгоРепублика'                                         => 'cg',
    'КонтиненталнаФранция'                             => 'fx',
    "Корея\,Южна"                                                 => 'kr',
    'КостаРика'                                                   => 'cr',
    'КотдИвоар'                                                   => 'ci',
    'Куба'                                                             => 'cu',
    'Кувейт'                                                         => 'kw',
    'Латвия'                                                         => 'lv',
    'ЛатинскаАмерикаиКарибскибасейн'         => 419,
    'Лесото'                                                         => 'ls',
    'Либерия'                                                       => 'lr',
    'Либийскаарабскаджамахирия'                   => 'ly',
    'Ливан'                                                           => 'lb',
    'Литва'                                                           => 'lt',
    'Лихтенщайн'                                                 => 'li',
    'Люксембург'                                                 => 'lu',
    'Мавритания'                                                 => 'mr',
    'Мавриций'                                                     => 'mu',
    'Мадагаскар'                                                 => 'mg',
    'Макао'                                                           => 'mo',
    'МакедонияБЮРМ'                                           => 'mk',
    'Малави'                                                         => 'mw',
    'Малайзия'                                                     => 'my',
    'Малдиви'                                                       => 'mv',
    'Мали'                                                             => 'ml',
    'Малта'                                                           => 'mt',
    'Мароко'                                                         => 'ma',
    'Мартиника'                                                   => 'mq',
    'Маршаловиострови'                                     => 'mh',
    'Мейот'                                                           => 'yt',
    'Мексико'                                                       => 'mx',
    'Меланезия'                                                   => '054',
    'МианмарБирма'                                             => 'mm',
    'Микронезия'                                                 => '057',
    "Микронезия\,ОбединениЩати"                     => 'fm',
    'Мозамбик'                                                     => 'mz',
    "Молдова\,Република"                                   => 'md',
    'Монако'                                                         => 'mc',
    'Монголия'                                                     => 'mn',
    'Монсерат'                                                     => 'ms',
    'Намибия'                                                       => 'na',
    'НароднадемократичнарепубликаЛаос'     => 'la',
    'Науру'                                                           => 'nr',
    'Непал'                                                           => 'np',
    'Непознатаилинесъществуващаобласт'     => 'zz',
    'Нигер'                                                           => 'ne',
    'Нигерия'                                                       => 'ng',
    'Никарагуа'                                                   => 'ni',
    'Ниуе'                                                             => 'nu',
    'НоваЗеландия'                                             => 'nz',
    'НоваКаледония'                                           => 'nc',
    'Норвегия'                                                     => 'no',
    'Нормандскиови'                                           => 830,
    'Обединениарабскиемирства'                     => 'ae',
    'Обединенокралство'                                   => 'gb',
    'Общностнанезависимитедържави'             => 172,
    'Океания'                                                       => '009',
    'Океанияqo'                                                     => 'qo',
    'Оман'                                                             => 'om',
    'ОстровБуве'                                                 => 'bv',
    'ОстровВъзнесение'                                     => 'ac',
    'ОстровКлипертон'                                       => 'cp',
    'ОстровКристмас'                                         => 'cx',
    'ОстровНорфолк'                                           => 'nf',
    'ОстровХърдиОстровиМакдоналд'               => 'hm',
    'ОстровиКук'                                                 => 'ck',
    'ОстровиМан'                                                 => 'im',
    'ОстровиТурксиКайкос'                               => 'tc',
    'Пакистан'                                                     => 'pk',
    'Палау'                                                           => 'pw',
    'Палестинскитеритории'                             => 'ps',
    'Панама'                                                         => 'pa',
    'ПапуаНоваГвинея'                                       => 'pg',
    'Парагвай'                                                     => 'py',
    'Перу'                                                             => 'pe',
    'Питкайрн'                                                     => 'pn',
    'Полинезия'                                                   => '061',
    'Полша'                                                           => 'pl',
    'Португалия'                                                 => 'pt',
    'ПуертоРико'                                                 => 'pr',
    'Реюниън'                                                       => 're',
    'Руанда'                                                         => 'rw',
    'Румъния'                                                       => 'ro',
    'Рускафедерация'                                         => 'ru',
    'САЩ'                                                               => 'us',
    "САЩ\,Вирджинскиострови"                           => 'vi',
    'САЩвъншниострови'                                     => 'um',
    'Самоа'                                                           => 'ws',
    'СанМарино'                                                   => 'sm',
    'СаоТомеиПринципе'                                     => 'st',
    'СаудитскаАрабия'                                       => 'sa',
    'СвалбардиЯнМайен'                                     => 'sj',
    'СветаЕлена'                                                 => 'sh',
    'СвещеномореВатиканскадържава'             => 'va',
    'СевернаАмерика'                                         => '021',
    'СевернаАфрика'                                           => '015',
    'СевернаЕвропа'                                           => 154,
    'СевернаКорея'                                             => 'kp',
    'СеверниМарианскиОстрови'                       => 'mp',
    'Северноамериканскиконтинент'               => '003',
    'СейнтБартоломей'                                       => 'bl',
    'СейнтВинсънтиГренадини'                         => 'vc',
    'СейнтКитсиНевис'                                       => 'kn',
    'СейнтЛусия'                                                 => 'lc',
    'СейнтМартин'                                               => 'mf',
    'Сейшели'                                                       => 'sc',
    'СенПиериМигелон'                                       => 'pm',
    'Сенегал'                                                       => 'sn',
    'СеутаиМелия'                                               => 'ea',
    'СиераЛеоне'                                                 => 'sl',
    'Сингапур'                                                     => 'sg',
    'Сирийскаарабскарепублика'                     => 'sy',
    'Словакия'                                                     => 'sk',
    'Словения'                                                     => 'si',
    'Соломоновиострови'                                   => 'sb',
    'Сомалия'                                                       => 'so',
    'Суазиленд'                                                   => 'sz',
    'Судан'                                                           => 'sd',
    'Суринам'                                                       => 'sr',
    'Сърбия'                                                         => 'rs',
    'СърбияиЧернагора'                                     => 'cs',
    'Таджикистан'                                               => 'tj',
    'Тайван'                                                         => 'tw',
    'Тайланд'                                                       => 'th',
    'Танзания'                                                     => 'tz',
    'Того'                                                             => 'tg',
    'Токелау'                                                       => 'tk',
    'Тонга'                                                           => 'to',
    'ТринидадиТобаго'                                       => 'tt',
    'ТристандаКуня'                                           => 'ta',
    'Тувалу'                                                         => 'tv',
    'Тунис'                                                           => 'tn',
    'Туркменистан'                                             => 'tm',
    'Турция'                                                         => 'tr',
    'Уганда'                                                         => 'ug',
    'Узбекистан'                                                 => 'uz',
    'Украйна'                                                       => 'ua',
    'Унгария'                                                       => 'hu',
    'УолисиФутуна'                                             => 'wf',
    'Уругвай'                                                       => 'uy',
    'Фарьорскиострови'                                     => 'fo',
    'Фиджи'                                                           => 'fj',
    'Филипини'                                                     => 'ph',
    'Финландия'                                                   => 'fi',
    'ФолкландскиостровиМалвини'                   => 'fk',
    'Франция'                                                       => 'fr',
    'ФренскаГвиана'                                           => 'gf',
    'ФренскаПолинезия'                                     => 'pf',
    'Френскиюжнитеритории'                             => 'tf',
    'Хаити'                                                           => 'ht',
    'Холандия'                                                     => 'nl',
    'ХоландскиАнтили'                                       => 'an',
    'Хондурас'                                                     => 'hn',
    'Хонконг'                                                       => 'hk',
    'Хърватска'                                                   => 'hr',
    'ЦентралнаАзия'                                           => 143,
    'ЦентралнаАмерика'                                     => '013',
    'ЦентралнаАфрика'                                       => '017',
    'ЦентралноафриканскаРепублика'             => 'cf',
    'Чад'                                                               => 'td',
    'Чернагора'                                                   => 'me',
    'Чешкарепублика'                                         => 'cz',
    'Чили'                                                             => 'cl',
    'Швейцария'                                                   => 'ch',
    'Швеция'                                                         => 'se',
    'ШриЛанка'                                                     => 'lk',
    'ЮгоизточнаАзия'                                         => '035',
    'ЮжнаАзия'                                                     => '034',
    'ЮжнаАзия062'                                                  => '062',
    'ЮжнаАмерика'                                               => '005',
    'ЮжнаАфрика'                                                 => 'za',
    'ЮжнаДжорджияиЮжниСандвичевиОстрови' => 'gs',
    'ЮжнаЕвропа'                                                 => '039',
    'Южноафриканскирегион'                             => '018',
    'Ямайка'                                                         => 'jm',
    'Япония'                                                         => 'jp',
    "о\.Гърнзи"                                                     => 'gg',
    "о\.Джързи"                                                     => 'je',
);

1;

