package Locales::DB::Territory::eu;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::eu::VERSION = '0.09';

$Locales::DB::Territory::eu::cldr_version = '2.0';

%Locales::DB::Territory::eu::code_to_name = (
    '001' => 'Mundua',
    '002' => 'Afrika',
    '003' => "Ipar\ Amerika",
    '005' => "Hego\ Amerika",
    '009' => 'Ozeania',
    '011' => "Afrika\ mendebaldea",
    '013' => "Erdialdeko\ Amerika",
    '014' => "Afrika\ ekialdea",
    '015' => "Afrika\ iparraldea",
    '017' => "Erdialdeko\ Afrika",
    '018' => "Afrika\ hegoaldea",
    '019' => 'Amerika',
    '021' => "Amerika\ iparraldea",
    '029' => 'Karibea',
    '030' => "Asia\ ekialdea",
    '034' => "Asia\ hegoaldea",
    '035' => "Asia\ hego\-ekialdea",
    '039' => "Europa\ hegoaldea",
    '053' => "Australia\ eta\ Zeelanda\ Berria",
    '054' => 'Melanesiera',
    '057' => "Mikronesia\ eskualdea",
    '061' => 'Polinesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Asia\ erdialdea",
    145   => "Asia\ mendebaldea",
    150   => 'Europa',
    151   => "Europa\ ekialdea",
    154   => "Europa\ iparraldea",
    155   => "Europa\ mendebaldea",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => 'Latinoamerika',
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Uhartea",
    'ad'  => 'Andorra',
    'ae'  => "Arabiar\ Emirrerri\ Batuak",
    'af'  => 'Afganistan',
    'ag'  => "Antigua\ eta\ Barbuda",
    'ai'  => 'Angila',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Holandarren\ Antillak",
    'ao'  => 'Angola',
    'aq'  => 'Antartika',
    'ar'  => 'Argentina',
    'as'  => "Amerikar\ Samoa",
    'at'  => 'Austria',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => "Aland\ Uharteak",
    'az'  => 'Azerbaijan',
    'ba'  => "Bosnia\-Herzegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgika',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "San\ Bartolome",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolibia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasil',
    'bs'  => 'Bahamak',
    'bt'  => 'Bhutan',
    'bv'  => "Bouvet\ Uhartea",
    'bw'  => 'Botswana',
    'by'  => 'Bielorrusia',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ uharteak",
    'cd'  => "Kongo\ \[KED\]",
    'cf'  => "Afrika\ Erdiko\ Errepublika",
    'cg'  => "Kongo\ \[errepublika\]",
    'ch'  => 'Suitza',
    'ci'  => 'BK',
    'ck'  => "Cook\ uharteak",
    'cl'  => 'Txile',
    'cm'  => 'Kamerun',
    'cn'  => 'Txina',
    'co'  => 'Kolonbia',
    'cp'  => 'CP',
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ eta\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Cabo\ Verde",
    'cx'  => "Christmas\ uhartea",
    'cy'  => 'Zipre',
    'cz'  => "Txekiar\ errepublika",
    'dd'  => "East\ Germany",
    'de'  => 'Alemania',
    'dg'  => 'DG',
    'dj'  => 'Djibuti',
    'dk'  => 'Danimarka',
    'dm'  => 'Dominika',
    'do'  => "Dominikar\ Errepublika",
    'dz'  => 'Aljeria',
    'ea'  => "Ceuta\ eta\ Melilla",
    'ec'  => 'Ekuador',
    'ee'  => 'Estonia',
    'eg'  => 'Egipto',
    'eh'  => "Mendebaldeko\ Sahara",
    'er'  => 'Eritrea',
    'es'  => 'Espainia',
    'et'  => 'Etiopia',
    'eu'  => "Europar\ Batasuna",
    'fi'  => 'Finlandia',
    'fj'  => 'Fiji',
    'fk'  => 'FK',
    'fm'  => 'Mikronesia',
    'fo'  => "Faroe\ Uharteak",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frantzia',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => "Erresuma\ Batua",
    'gd'  => 'Grenada',
    'ge'  => 'Georgia',
    'gf'  => "Guyana\ Frantsesa",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Groenlandia',
    'gm'  => 'Gambia',
    'gn'  => 'Ginea',
    'gp'  => 'Guadalupe',
    'gq'  => "Ekuatore\ Ginea",
    'gr'  => 'Grezia',
    'gs'  => "Hegoaldeko\ Georgia\ eta\ Hegoaldeko\ Sandwich\ uharteak",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Ginea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ eta\ McDonald\ Uharteak",
    'hn'  => 'Honduras',
    'hr'  => 'Kroazia',
    'ht'  => 'Haiti',
    'hu'  => 'Hungaria',
    'ic'  => 'Kanariak',
    'id'  => 'Indonesia',
    'ie'  => 'Irlanda',
    'il'  => 'Israel',
    'im'  => "Man\ uhartea",
    'in'  => 'India',
    'io'  => "Indiako\ Ozeanoko\ Britainiar\ Lurraldea",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Islandia',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaika',
    'jo'  => 'Jordania',
    'jp'  => 'Japonia',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirgizistan',
    'kh'  => 'Kanbodia',
    'ki'  => 'Kiribati',
    'km'  => 'Komoreak',
    'kn'  => "Saint\ Kitts\ eta\ Nevis",
    'kp'  => "Ipar\ Korea",
    'kr'  => "Hego\ Korea",
    'kw'  => 'Kuwait',
    'ky'  => "Kaiman\ Uharteak",
    'kz'  => 'Kazakhstan',
    'la'  => 'Laos',
    'lb'  => 'Libano',
    'lc'  => "Santa\ Luzia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Lituania',
    'lu'  => 'Luxenburgo',
    'lv'  => 'Letonia',
    'ly'  => 'Libia',
    'ma'  => 'Maroko',
    'mc'  => 'Monako',
    'md'  => 'Moldavia',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Marshall\ uharteak",
    'mi'  => "Midway\ Islands",
    'mk'  => "Mazedonia\ \[FYROM\]",
    'ml'  => 'Mali',
    'mm'  => 'Birmania',
    'mn'  => 'Mongolia',
    'mo'  => 'Macau',
    'mp'  => "Iparraldeko\ Mariana\ uharteak",
    'mq'  => 'Martinika',
    'mr'  => 'Mauritania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Maurizio',
    'mv'  => 'Maldivak',
    'mw'  => 'Malawi',
    'mx'  => 'Mexiko',
    'my'  => 'Malasia',
    'mz'  => 'Mozambike',
    'na'  => 'Namibia',
    'nc'  => "Kaledonia\ Berria",
    'ne'  => 'Niger',
    'nf'  => "Norfolk\ uhartea",
    'ng'  => 'Nigeria',
    'ni'  => 'Nikaragua',
    'nl'  => 'Herbehereak',
    'no'  => 'Norvegia',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Zeelanda\ Berria",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polinesia\ Frantsesa",
    'pg'  => "Papua\ Ginea\ Berria",
    'ph'  => 'Filipinak',
    'pk'  => 'Pakistan',
    'pl'  => 'Polonia',
    'pm'  => "Saint\-Pierre\ eta\ Mikelune",
    'pn'  => "Pitcairn\ uharteak",
    'pr'  => "Puerto\ Rico",
    'ps'  => 'Palestina',
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Mugaz\ kanpoko\ Ozeania",
    're'  => 'Reunion',
    'ro'  => 'Errumania',
    'rs'  => 'Serbia',
    'ru'  => 'Errusia',
    'rw'  => 'Ruanda',
    'sa'  => "Saudi\ Arabia",
    'sb'  => "Salomon\ uharteak",
    'sc'  => 'Seychelleak',
    'sd'  => 'Sudan',
    'se'  => 'Suedia',
    'sg'  => 'Singapur',
    'sh'  => "Saint\ Helena",
    'si'  => 'Eslovenia',
    'sj'  => "Svalbard\ eta\ Jan\ Mayen\ uharteak",
    'sk'  => 'Eslovakia',
    'sl'  => "Sierra\ Leona",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "Sao\ Tome\ eta\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Siria',
    'sz'  => 'Swazilandia',
    'ta'  => 'TA',
    'tc'  => "Turk\ eta\ Caicos\ uharteak",
    'td'  => 'Txad',
    'tf'  => "Frantziaren\ Lurralde\ Australak",
    'tg'  => 'Togo',
    'th'  => 'Tailandia',
    'tj'  => 'Tadjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ ekialdea",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunisia',
    'to'  => 'Tonga',
    'tr'  => 'Turkia',
    'tt'  => "Trinidad\ eta\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukraina',
    'ug'  => 'Uganda',
    'um'  => "Estatu\ Batuetatik\ urruti\ dauden\ uharte\ txikiak",
    'us'  => "Ameriketako\ Estatu\ Batuak",
    'uy'  => 'Uruguai',
    'uz'  => 'Uzbekistan',
    'va'  => "Vatikano\ Hiria",
    'vc'  => "Saint\ Vincent\ eta\ Grenadinak",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Birjina\ uharte\ britainiarrak",
    'vi'  => "Birjina\ uharte\ amerikarrak",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ eta\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemen',
    'yt'  => 'Mayotte',
    'za'  => 'Hegoafrika',
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => 'ZZ',
);

%Locales::DB::Territory::eu::name_to_code = (
    'afganistan'                                     => 'af',
    'afrika'                                         => '002',
    'afrikaekialdea'                                 => '014',
    'afrikaerdikoerrepublika'                        => 'cf',
    'afrikahegoaldea'                                => '018',
    'afrikaiparraldea'                               => '015',
    'afrikamendebaldea'                              => '011',
    'alanduharteak'                                  => 'ax',
    'albania'                                        => 'al',
    'alemania'                                       => 'de',
    'aljeria'                                        => 'dz',
    'amerika'                                        => '019',
    'amerikaiparraldea'                              => '021',
    'amerikarsamoa'                                  => 'as',
    'ameriketakoestatubatuak'                        => 'us',
    'andorra'                                        => 'ad',
    'angila'                                         => 'ai',
    'angola'                                         => 'ao',
    'antartika'                                      => 'aq',
    'antiguaetabarbuda'                              => 'ag',
    'arabiaremirrerribatuak'                         => 'ae',
    'argentina'                                      => 'ar',
    'armenia'                                        => 'am',
    'aruba'                                          => 'aw',
    'ascensionuhartea'                               => 'ac',
    'asia'                                           => 142,
    'asiaekialdea'                                   => '030',
    'asiaerdialdea'                                  => 143,
    'asiahegoaldea'                                  => '034',
    'asiahegoekialdea'                               => '035',
    'asiamendebaldea'                                => 145,
    'australia'                                      => 'au',
    'australiaetazeelandaberria'                     => '053',
    'austria'                                        => 'at',
    'azerbaijan'                                     => 'az',
    'bahamak'                                        => 'bs',
    'bahrain'                                        => 'bh',
    'bangladesh'                                     => 'bd',
    'barbados'                                       => 'bb',
    'belgika'                                        => 'be',
    'belize'                                         => 'bz',
    'benin'                                          => 'bj',
    'bermuda'                                        => 'bm',
    'bhutan'                                         => 'bt',
    'bielorrusia'                                    => 'by',
    'birjinauharteamerikarrak'                       => 'vi',
    'birjinauhartebritainiarrak'                     => 'vg',
    'birmania'                                       => 'mm',
    'bk'                                             => 'ci',
    'bolibia'                                        => 'bo',
    'bosniaherzegovina'                              => 'ba',
    'botswana'                                       => 'bw',
    'bouvetuhartea'                                  => 'bv',
    'brasil'                                         => 'br',
    'britishantarcticterritory'                      => 'bq',
    'brunei'                                         => 'bn',
    'bulgaria'                                       => 'bg',
    'burkinafaso'                                    => 'bf',
    'burundi'                                        => 'bi',
    'caboverde'                                      => 'cv',
    'cantonandenderburyislands'                      => 'ct',
    'ceutaetamelilla'                                => 'ea',
    'channelislands'                                 => 830,
    'christmasuhartea'                               => 'cx',
    'cocosuharteak'                                  => 'cc',
    'commonwealthofindependentstates'                => 172,
    'cookuharteak'                                   => 'ck',
    'costarica'                                      => 'cr',
    'cp'                                             => 'cp',
    'czechoslovakia'                                 => 200,
    'danimarka'                                      => 'dk',
    'dg'                                             => 'dg',
    'djibuti'                                        => 'dj',
    'dominika'                                       => 'dm',
    'dominikarerrepublika'                           => 'do',
    'dronningmaudland'                               => 'nq',
    'eastgermany'                                    => 'dd',
    'egipto'                                         => 'eg',
    'ekuador'                                        => 'ec',
    'ekuatoreginea'                                  => 'gq',
    'elsalvador'                                     => 'sv',
    'erdialdekoafrika'                               => '017',
    'erdialdekoamerika'                              => '013',
    'eritrea'                                        => 'er',
    'erresumabatua'                                  => 'gb',
    'errumania'                                      => 'ro',
    'errusia'                                        => 'ru',
    'eslovakia'                                      => 'sk',
    'eslovenia'                                      => 'si',
    'espainia'                                       => 'es',
    'estatubatuetatikurrutidaudenuhartetxikiak'      => 'um',
    'estonia'                                        => 'ee',
    'etiopia'                                        => 'et',
    'europa'                                         => 150,
    'europaekialdea'                                 => 151,
    'europahegoaldea'                                => '039',
    'europaiparraldea'                               => 154,
    'europamendebaldea'                              => 155,
    'europarbatasuna'                                => 'eu',
    'faroeuharteak'                                  => 'fo',
    'fiji'                                           => 'fj',
    'filipinak'                                      => 'ph',
    'finlandia'                                      => 'fi',
    'fk'                                             => 'fk',
    'frantzia'                                       => 'fr',
    'frantziarenlurraldeaustralak'                   => 'tf',
    'frenchsouthernandantarcticterritories'          => 'fq',
    'gabon'                                          => 'ga',
    'gambia'                                         => 'gm',
    'georgia'                                        => 'ge',
    'ghana'                                          => 'gh',
    'gibraltar'                                      => 'gi',
    'ginea'                                          => 'gn',
    'gineabissau'                                    => 'gw',
    'grenada'                                        => 'gd',
    'grezia'                                         => 'gr',
    'groenlandia'                                    => 'gl',
    'guadalupe'                                      => 'gp',
    'guam'                                           => 'gu',
    'guatemala'                                      => 'gt',
    'guernsey'                                       => 'gg',
    'guyana'                                         => 'gy',
    'guyanafrantsesa'                                => 'gf',
    'haiti'                                          => 'ht',
    'heardetamcdonalduharteak'                       => 'hm',
    'hegoafrika'                                     => 'za',
    'hegoaldekogeorgiaetahegoaldekosandwichuharteak' => 'gs',
    'hegoamerika'                                    => '005',
    'hegokorea'                                      => 'kr',
    'herbehereak'                                    => 'nl',
    'holandarrenantillak'                            => 'an',
    'honduras'                                       => 'hn',
    'hongkong'                                       => 'hk',
    'hungaria'                                       => 'hu',
    'india'                                          => 'in',
    'indiakoozeanokobritainiarlurraldea'             => 'io',
    'indonesia'                                      => 'id',
    'iparamerika'                                    => '003',
    'iparkorea'                                      => 'kp',
    'iparraldekomarianauharteak'                     => 'mp',
    'irak'                                           => 'iq',
    'iran'                                           => 'ir',
    'irlanda'                                        => 'ie',
    'islandia'                                       => 'is',
    'israel'                                         => 'il',
    'italia'                                         => 'it',
    'jamaika'                                        => 'jm',
    'japonia'                                        => 'jp',
    'jersey'                                         => 'je',
    'johnstonisland'                                 => 'jt',
    'jordania'                                       => 'jo',
    'kaimanuharteak'                                 => 'ky',
    'kaledoniaberria'                                => 'nc',
    'kamerun'                                        => 'cm',
    'kanada'                                         => 'ca',
    'kanariak'                                       => 'ic',
    'kanbodia'                                       => 'kh',
    'karibea'                                        => '029',
    'katar'                                          => 'qa',
    'kazakhstan'                                     => 'kz',
    'kenia'                                          => 'ke',
    'kirgizistan'                                    => 'kg',
    'kiribati'                                       => 'ki',
    'kolonbia'                                       => 'co',
    'komoreak'                                       => 'km',
    'kongoerrepublika'                               => 'cg',
    'kongoked'                                       => 'cd',
    'kroazia'                                        => 'hr',
    'kuba'                                           => 'cu',
    'kuwait'                                         => 'kw',
    'laos'                                           => 'la',
    'latinoamerika'                                  => 419,
    'lesotho'                                        => 'ls',
    'letonia'                                        => 'lv',
    'libano'                                         => 'lb',
    'liberia'                                        => 'lr',
    'libia'                                          => 'ly',
    'liechtenstein'                                  => 'li',
    'lituania'                                       => 'lt',
    'luxenburgo'                                     => 'lu',
    'macau'                                          => 'mo',
    'madagaskar'                                     => 'mg',
    'malasia'                                        => 'my',
    'malawi'                                         => 'mw',
    'maldivak'                                       => 'mv',
    'mali'                                           => 'ml',
    'malta'                                          => 'mt',
    'manuhartea'                                     => 'im',
    'maroko'                                         => 'ma',
    'marshalluharteak'                               => 'mh',
    'martinika'                                      => 'mq',
    'mauritania'                                     => 'mr',
    'maurizio'                                       => 'mu',
    'mayotte'                                        => 'yt',
    'mazedoniafyrom'                                 => 'mk',
    'melanesiera'                                    => '054',
    'mendebaldekosahara'                             => 'eh',
    'metropolitanfrance'                             => 'fx',
    'mexiko'                                         => 'mx',
    'midwayislands'                                  => 'mi',
    'mikronesia'                                     => 'fm',
    'mikronesiaeskualdea'                            => '057',
    'moldavia'                                       => 'md',
    'monako'                                         => 'mc',
    'mongolia'                                       => 'mn',
    'montenegro'                                     => 'me',
    'montserrat'                                     => 'ms',
    'mozambike'                                      => 'mz',
    'mugazkanpokoozeania'                            => 'qo',
    'mundua'                                         => '001',
    'namibia'                                        => 'na',
    'nauru'                                          => 'nr',
    'nepal'                                          => 'np',
    'neutralzone'                                    => 'nt',
    'niger'                                          => 'ne',
    'nigeria'                                        => 'ng',
    'nikaragua'                                      => 'ni',
    'niue'                                           => 'nu',
    'norfolkuhartea'                                 => 'nf',
    'northvietnam'                                   => 'vd',
    'norvegia'                                       => 'no',
    'oman'                                           => 'om',
    'ozeania'                                        => '009',
    'pacificislandstrustterritory'                   => 'pc',
    'pakistan'                                       => 'pk',
    'palau'                                          => 'pw',
    'palestina'                                      => 'ps',
    'panama'                                         => 'pa',
    'panamacanalzone'                                => 'pz',
    'papuagineaberria'                               => 'pg',
    'paraguai'                                       => 'py',
    "people\â\\sdemocraticrepublicofyemen"      => 'yd',
    'peru'                                           => 'pe',
    'pitcairnuharteak'                               => 'pn',
    'polinesia'                                      => '061',
    'polinesiafrantsesa'                             => 'pf',
    'polonia'                                        => 'pl',
    'portugal'                                       => 'pt',
    'puertorico'                                     => 'pr',
    'reunion'                                        => 're',
    'ruanda'                                         => 'rw',
    'sainthelena'                                    => 'sh',
    'saintkittsetanevis'                             => 'kn',
    'saintmartin'                                    => 'mf',
    'saintpierreetamikelune'                         => 'pm',
    'saintvincentetagrenadinak'                      => 'vc',
    'salomonuharteak'                                => 'sb',
    'samoa'                                          => 'ws',
    'sanbartolome'                                   => 'bl',
    'sanmarino'                                      => 'sm',
    'santaluzia'                                     => 'lc',
    'saotomeetaprincipe'                             => 'st',
    'saudiarabia'                                    => 'sa',
    'senegal'                                        => 'sn',
    'serbia'                                         => 'rs',
    'serbiaetamontenegro'                            => 'cs',
    'seychelleak'                                    => 'sc',
    'sierraleona'                                    => 'sl',
    'singapur'                                       => 'sg',
    'siria'                                          => 'sy',
    'somalia'                                        => 'so',
    'southcentralasia'                               => '062',
    'srilanka'                                       => 'lk',
    'sudan'                                          => 'sd',
    'suedia'                                         => 'se',
    'suitza'                                         => 'ch',
    'surinam'                                        => 'sr',
    'svalbardetajanmayenuharteak'                    => 'sj',
    'swazilandia'                                    => 'sz',
    'ta'                                             => 'ta',
    'tadjikistan'                                    => 'tj',
    'tailandia'                                      => 'th',
    'taiwan'                                         => 'tw',
    'tanzania'                                       => 'tz',
    'timorekialdea'                                  => 'tl',
    'togo'                                           => 'tg',
    'tokelau'                                        => 'tk',
    'tonga'                                          => 'to',
    'trinidadetatobago'                              => 'tt',
    'tunisia'                                        => 'tn',
    'turketacaicosuharteak'                          => 'tc',
    'turkia'                                         => 'tr',
    'turkmenistan'                                   => 'tm',
    'tuvalu'                                         => 'tv',
    'txad'                                           => 'td',
    'txekiarerrepublika'                             => 'cz',
    'txile'                                          => 'cl',
    'txina'                                          => 'cn',
    "u\.s\.miscellaneouspacificislands"              => 'pu',
    'uganda'                                         => 'ug',
    'ukraina'                                        => 'ua',
    'unionofsovietsocialistrepublics'                => 'su',
    'uruguai'                                        => 'uy',
    'uzbekistan'                                     => 'uz',
    'vanuatu'                                        => 'vu',
    'vatikanohiria'                                  => 'va',
    'venezuela'                                      => 've',
    'vietnam'                                        => 'vn',
    'wakeisland'                                     => 'wk',
    'wallisetafutuna'                                => 'wf',
    'yemen'                                          => 'ye',
    'zambia'                                         => 'zm',
    'zeelandaberria'                                 => 'nz',
    'zimbabwe'                                       => 'zw',
    'zipre'                                          => 'cy',
    'zz'                                             => 'zz',
);

1;

