{"delimiters":{"quotation_start":"”","quotation_end":"”","alternate_quotation_start":"’","alternate_quotation_end":"’"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":{"draft":"unconfirmed","content":"ii"},"yesstr":{"draft":"unconfirmed","content":"jo"}},"plural_forms":{"category_list":["one","two","other"],"category_rules_function":null,"category_rules":{"one":"n is 1","two":"n is 2"},"category_rules_compiled":{"one":function (n) {if ( (( n == 1))) { return 'one'; } return;},"two":function (n) {if ( (( n == 2))) { return 'two'; } return;}}},"cldr_formats":{"territory":"Region: {0}","_decimal_format_decimal":",","language":"giella: {0}","percent":"#,##0 %","locale":"{0} ({1})","_decimal_format_group":" ","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} ja {1}","start":"{0}, {1}","end":"{0} ja {1}"}},"fallback":["nb","nn","sv","en"],"characters":{"more_information":"?"}}