{"delimiters":{"quotation_start":"“","quotation_end":"”","alternate_quotation_start":"‘","alternate_quotation_end":"’"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":{"draft":"contributed","content":"არა"},"yesstr":{"draft":"contributed","content":"დიახ"}},"plural_forms":{"category_list":["other"],"category_rules_function":null,"category_rules":{},"category_rules_compiled":{}},"cldr_formats":{"territory":"Region: {0}","_decimal_format_decimal":",","language":"Language: {0}","percent":"#,##0 %","locale":"{0} ({1})","_decimal_format_group":".","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} და {1}","start":"{0}, {1}","end":"{0} და {1}"}},"fallback":[],"characters":{"more_information":"?"}}