package Locales::DB::Territory::ar;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::ar::VERSION = '0.09';

$Locales::DB::Territory::ar::cldr_version = '2.0';

%Locales::DB::Territory::ar::code_to_name = (
    '001' => 'العالم',
    '002' => 'أفريقيا',
    '003' => "أمريكا\ الشمالية",
    '005' => "أمريكا\ الجنوبية",
    '009' => 'أوقيانوسيا',
    '011' => "غرب\ أفريقيا",
    '013' => "أمريكا\ الوسطى",
    '014' => "شرق\ أفريقيا",
    '015' => "شمال\ أفريقيا",
    '017' => "وسط\ أفريقيا",
    '018' => "أفريقيا\ الجنوبية",
    '019' => 'الأمريكتين',
    '021' => "شمال\ أمريكا",
    '029' => 'الكاريبي',
    '030' => "شرق\ آسيا",
    '034' => "جنوب\ آسيا",
    '035' => "جنوب\ شرق\ آسيا",
    '039' => "جنوب\ أوروبا",
    '053' => "أستراليا\ ونيوزيلندا",
    '054' => 'ميلانيزيا',
    '057' => "الجزر\ الميكرونيزية",
    '061' => 'بولينيزيا',
    '062' => "جنوب\ وسط\ آسيا",
    142   => 'آسيا',
    143   => "وسط\ آسيا",
    145   => "غرب\ آسيا",
    150   => 'أوروبا',
    151   => "شرق\ أوروبا",
    154   => "شمال\ أوروبا",
    155   => "غرب\ أوروبا",
    172   => "كومنولث\ الدول\ المستقلة",
    200   => 'Czechoslovakia',
    419   => "أمريكا\ اللاتينية",
    830   => "Channel\ Islands",
    'ac'  => "جزيرة\ أسينشيون",
    'ad'  => 'أندورا',
    'ae'  => "الإمارات\ العربية\ المتحدة",
    'af'  => 'أفغانستان',
    'ag'  => "أنتيغوا\ وبربودا",
    'ai'  => 'أنغويلا',
    'al'  => 'ألبانيا',
    'am'  => 'أرمينيا',
    'an'  => "جزر\ الأنتيل\ الهولندية",
    'ao'  => 'أنغولا',
    'aq'  => "القطب\ الجنوبي",
    'ar'  => 'الأرجنتين',
    'as'  => "ساموا\ الأمريكية",
    'at'  => 'النمسا',
    'au'  => 'أستراليا',
    'aw'  => 'آروبا',
    'ax'  => "جزر\ أولان",
    'az'  => 'أذربيجان',
    'ba'  => "البوسنة\ والهرسك",
    'bb'  => 'بربادوس',
    'bd'  => 'بنجلاديش',
    'be'  => 'بلجيكا',
    'bf'  => "بوركينا\ فاسو",
    'bg'  => 'بلغاريا',
    'bh'  => 'البحرين',
    'bi'  => 'بوروندي',
    'bj'  => 'بنين',
    'bl'  => "سان\ بارتليمي",
    'bm'  => 'برمودا',
    'bn'  => 'بروناي',
    'bo'  => 'بوليفيا',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'البرازيل',
    'bs'  => 'الباهاما',
    'bt'  => 'بوتان',
    'bv'  => "جزيرة\ بوفيه",
    'bw'  => 'بتسوانا',
    'by'  => "روسيا\ البيضاء",
    'bz'  => 'بليز',
    'ca'  => 'كندا',
    'cc'  => "جزر\ كوكوس",
    'cd'  => "جمهورية\ الكونغو\ الديمقراطية",
    'cf'  => "جمهورية\ أفريقيا\ الوسطى",
    'cg'  => "جمهورية\ الكونغو",
    'ch'  => 'سويسرا',
    'ci'  => "ساحل\ العاج",
    'ck'  => "جزر\ كوك",
    'cl'  => 'شيلي',
    'cm'  => 'الكاميرون',
    'cn'  => 'الصين',
    'co'  => 'كولومبيا',
    'cp'  => "جزيرة\ كليبيرتون",
    'cr'  => 'كوستاريكا',
    'cs'  => "صربيا\ والجبل\ الأسود",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'كوبا',
    'cv'  => "الرأس\ الأخضر",
    'cx'  => "جزيرة\ الكريسماس",
    'cy'  => 'قبرص',
    'cz'  => "جمهورية\ التشيك",
    'dd'  => "East\ Germany",
    'de'  => 'ألمانيا',
    'dg'  => "دييغو\ غارسيا",
    'dj'  => 'جيبوتي',
    'dk'  => 'الدانمرك',
    'dm'  => 'دومينيكا',
    'do'  => "جمهورية\ الدومينيك",
    'dz'  => 'الجزائر',
    'ea'  => "سيوتا\ وميليلا",
    'ec'  => 'الإكوادور',
    'ee'  => 'أستونيا',
    'eg'  => 'مصر',
    'eh'  => "الصحراء\ الغربية",
    'er'  => 'أريتريا',
    'es'  => 'إسبانيا',
    'et'  => 'إثيوبيا',
    'eu'  => "الاتحاد\ الأوروبي",
    'fi'  => 'فنلندا',
    'fj'  => 'فيجي',
    'fk'  => "جزر\ فوكلاند\ \-\ جزر\ مالفيناس",
    'fm'  => 'ميكرونيزيا',
    'fo'  => "جزر\ فارو",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'فرنسا',
    'fx'  => "ميتروبولويتان\ فرنسا",
    'ga'  => 'الجابون',
    'gb'  => "المملكة\ المتحدة",
    'gd'  => 'غرينادا',
    'ge'  => 'جورجيا',
    'gf'  => "غويانا\ الفرنسية",
    'gg'  => 'غيرنزي',
    'gh'  => 'غانا',
    'gi'  => "جبل\ طارق",
    'gl'  => 'غرينلاند',
    'gm'  => 'غامبيا',
    'gn'  => 'غينيا',
    'gp'  => 'جوادلوب',
    'gq'  => "غينيا\ الاستوائية",
    'gr'  => 'اليونان',
    'gs'  => "جورجيا\ الجنوبية\ وجزر\ ساندويتش\ الجنوبية",
    'gt'  => 'غواتيمالا',
    'gu'  => 'غوام',
    'gw'  => "غينيا\ بيساو",
    'gy'  => 'غيانا',
    'hk'  => "هونغ\ كونغ",
    'hm'  => "جزيرة\ هيرد\ وجزر\ ماكدونالد",
    'hn'  => 'هندوراس',
    'hr'  => 'كرواتيا',
    'ht'  => 'هايتي',
    'hu'  => 'هنغاريا',
    'ic'  => "جزر\ الكناري",
    'id'  => 'اندونيسيا',
    'ie'  => 'أيرلندا',
    'il'  => 'إسرائيل',
    'im'  => "جزيرة\ مان",
    'in'  => 'الهند',
    'io'  => "الإقليم\ البريطاني\ في\ المحيط\ الهندي",
    'iq'  => 'العراق',
    'ir'  => 'إيران',
    'is'  => 'أيسلندا',
    'it'  => 'إيطاليا',
    'je'  => 'جيرسي',
    'jm'  => 'جامايكا',
    'jo'  => 'الأردن',
    'jp'  => 'اليابان',
    'jt'  => "Johnston\ Island",
    'ke'  => 'كينيا',
    'kg'  => 'قرغيزستان',
    'kh'  => 'كمبوديا',
    'ki'  => 'كيريباتي',
    'km'  => "جزر\ القمر",
    'kn'  => "سانت\ كيتس\ ونيفيس",
    'kp'  => "كوريا\ الشمالية",
    'kr'  => "كوريا\ الجنوبية",
    'kw'  => 'الكويت',
    'ky'  => "جزر\ الكايمن",
    'kz'  => 'كازاخستان',
    'la'  => 'لاوس',
    'lb'  => 'لبنان',
    'lc'  => "سانت\ لوسيا",
    'li'  => 'ليختنشتاين',
    'lk'  => 'سريلانكا',
    'lr'  => 'ليبيريا',
    'ls'  => 'ليسوتو',
    'lt'  => 'ليتوانيا',
    'lu'  => 'لوكسمبورغ',
    'lv'  => 'لاتفيا',
    'ly'  => 'ليبيا',
    'ma'  => 'المغرب',
    'mc'  => 'موناكو',
    'md'  => 'مولدافيا',
    'me'  => "الجبل\ الأسود",
    'mf'  => "سانت\ مارتين",
    'mg'  => 'مدغشقر',
    'mh'  => "جزر\ المارشال",
    'mi'  => "Midway\ Islands",
    'mk'  => "مقدونيا\-\ جمهورية\ مقدونيا\ اليوغسلافية\ السابقة",
    'ml'  => 'مالي',
    'mm'  => "ميانمار\ \-بورما",
    'mn'  => 'منغوليا',
    'mo'  => 'ماكاو',
    'mp'  => "جزر\ ماريانا\ الشمالية",
    'mq'  => 'مارتينيك',
    'mr'  => 'موريتانيا',
    'ms'  => 'مونتسرات',
    'mt'  => 'مالطا',
    'mu'  => 'موريشيوس',
    'mv'  => "جزر\ المالديف",
    'mw'  => 'ملاوي',
    'mx'  => 'المكسيك',
    'my'  => 'ماليزيا',
    'mz'  => 'موزمبيق',
    'na'  => 'ناميبيا',
    'nc'  => "كاليدونيا\ الجديدة",
    'ne'  => 'النيجر',
    'nf'  => "جزيرة\ نورفوك",
    'ng'  => 'نيجيريا',
    'ni'  => 'نيكاراغوا',
    'nl'  => 'هولندا',
    'no'  => 'النرويج',
    'np'  => 'نيبال',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'ناورو',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'نيوي',
    'nz'  => 'نيوزيلاندا',
    'om'  => 'عُمان',
    'pa'  => 'بنما',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'بيرو',
    'pf'  => "بولينيزيا\ الفرنسية",
    'pg'  => "بابوا\ غينيا\ الجديدة",
    'ph'  => 'الفيلبين',
    'pk'  => 'باكستان',
    'pl'  => 'بولندا',
    'pm'  => "سانت\ بيير\ وميكولون",
    'pn'  => "جزر\ بيتكيرن",
    'pr'  => 'بورتوريكو',
    'ps'  => 'فلسطين',
    'pt'  => 'البرتغال',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'بالاو',
    'py'  => 'باراغواي',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'قطر',
    'qo'  => "أوقيانوسيا\ النائية",
    're'  => 'روينيون',
    'ro'  => 'رومانيا',
    'rs'  => 'صربيا',
    'ru'  => 'روسيا',
    'rw'  => 'رواندا',
    'sa'  => "المملكة\ العربية\ السعودية",
    'sb'  => "جزر\ سليمان",
    'sc'  => 'سيشل',
    'sd'  => 'السودان',
    'se'  => 'السويد',
    'sg'  => 'سنغافورة',
    'sh'  => "سانت\ هيلنا",
    'si'  => 'سلوفينيا',
    'sj'  => "سفالبارد\ وجان\ مايان",
    'sk'  => 'سلوفاكيا',
    'sl'  => 'سيراليون',
    'sm'  => "سان\ مارينو",
    'sn'  => 'السنغال',
    'so'  => 'الصومال',
    'sr'  => 'سورينام',
    'st'  => "ساو\ تومي\ وبرينسيبي",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'السلفادور',
    'sy'  => 'سوريا',
    'sz'  => 'سوازيلاند',
    'ta'  => "تريستان\ دي\ كونها",
    'tc'  => "جزر\ الترك\ وجايكوس",
    'td'  => 'تشاد',
    'tf'  => "المقاطعات\ الجنوبية\ الفرنسية",
    'tg'  => 'توجو',
    'th'  => 'تايلند',
    'tj'  => 'طاجكستان',
    'tk'  => 'توكيلو',
    'tl'  => "تيمور\ الشرقية",
    'tm'  => 'تركمانستان',
    'tn'  => 'تونس',
    'to'  => 'تونغا',
    'tr'  => 'تركيا',
    'tt'  => "ترينيداد\ وتوباغو",
    'tv'  => 'توفالو',
    'tw'  => 'تايوان',
    'tz'  => 'تانزانيا',
    'ua'  => 'أوكرانيا',
    'ug'  => 'أوغندا',
    'um'  => "جزر\ الولايات\ المتحدة\ البعيدة\ الصغيرة",
    'us'  => "الولايات\ المتحدة\ الأمريكية",
    'uy'  => 'أورغواي',
    'uz'  => 'أوزبكستان',
    'va'  => 'الفاتيكان',
    'vc'  => "سانت\ فنسنت\ وغرنادين",
    'vd'  => "North\ Vietnam",
    've'  => 'فنزويلا',
    'vg'  => "جزر\ فرجين\ البريطانية",
    'vi'  => "جزر\ فرجين\ الأمريكية",
    'vn'  => 'فيتنام',
    'vu'  => 'فانواتو',
    'wf'  => "جزر\ والس\ وفوتونا",
    'wk'  => "Wake\ Island",
    'ws'  => 'ساموا',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'اليمن',
    'yt'  => 'مايوت',
    'za'  => "جنوب\ أفريقيا",
    'zm'  => 'زامبيا',
    'zw'  => 'زيمبابوي',
    'zz'  => "منطقة\ غير\ معروفة",
);

%Locales::DB::Territory::ar::name_to_code = (
    'britishantarcticterritory'                                                      => 'bq',
    'cantonandenderburyislands'                                                      => 'ct',
    'channelislands'                                                                 => 830,
    'czechoslovakia'                                                                 => 200,
    'dronningmaudland'                                                               => 'nq',
    'eastgermany'                                                                    => 'dd',
    'frenchsouthernandantarcticterritories'                                          => 'fq',
    'johnstonisland'                                                                 => 'jt',
    'midwayislands'                                                                  => 'mi',
    'neutralzone'                                                                    => 'nt',
    'northvietnam'                                                                   => 'vd',
    'pacificislandstrustterritory'                                                   => 'pc',
    'panamacanalzone'                                                                => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                                      => 'yd',
    "u\.s\.miscellaneouspacificislands"                                              => 'pu',
    'unionofsovietsocialistrepublics'                                                => 'su',
    'wakeisland'                                                                     => 'wk',
    'آروبا'                                                                     => 'aw',
    'آسيا'                                                                       => 142,
    'أذربيجان'                                                               => 'az',
    'أرمينيا'                                                                 => 'am',
    'أريتريا'                                                                 => 'er',
    'أستراليا'                                                               => 'au',
    'أسترالياونيوزيلندا'                                           => '053',
    'أستونيا'                                                                 => 'ee',
    'أفريقيا'                                                                 => '002',
    'أفريقياالجنوبية'                                                 => '018',
    'أفغانستان'                                                             => 'af',
    'ألبانيا'                                                                 => 'al',
    'ألمانيا'                                                                 => 'de',
    'أمريكاالجنوبية'                                                   => '005',
    'أمريكاالشمالية'                                                   => '003',
    'أمريكااللاتينية'                                                 => 419,
    'أمريكاالوسطى'                                                       => '013',
    'أنتيغواوبربودا'                                                   => 'ag',
    'أندورا'                                                                   => 'ad',
    'أنغولا'                                                                   => 'ao',
    'أنغويلا'                                                                 => 'ai',
    'أورغواي'                                                                 => 'uy',
    'أوروبا'                                                                   => 150,
    'أوزبكستان'                                                             => 'uz',
    'أوغندا'                                                                   => 'ug',
    'أوقيانوسيا'                                                           => '009',
    'أوقيانوسياالنائية'                                             => 'qo',
    'أوكرانيا'                                                               => 'ua',
    'أيرلندا'                                                                 => 'ie',
    'أيسلندا'                                                                 => 'is',
    'إثيوبيا'                                                                 => 'et',
    'إسبانيا'                                                                 => 'es',
    'إسرائيل'                                                                 => 'il',
    'إيران'                                                                     => 'ir',
    'إيطاليا'                                                                 => 'it',
    'الأرجنتين'                                                             => 'ar',
    'الأردن'                                                                   => 'jo',
    'الأمريكتين'                                                           => '019',
    'الإقليمالبريطانيفيالمحيطالهندي'                   => 'io',
    'الإكوادور'                                                             => 'ec',
    'الإماراتالعربيةالمتحدة'                                   => 'ae',
    'الاتحادالأوروبي'                                                 => 'eu',
    'الباهاما'                                                               => 'bs',
    'البحرين'                                                                 => 'bh',
    'البرازيل'                                                               => 'br',
    'البرتغال'                                                               => 'pt',
    'البوسنةوالهرسك'                                                   => 'ba',
    'الجابون'                                                                 => 'ga',
    'الجبلالأسود'                                                         => 'me',
    'الجزائر'                                                                 => 'dz',
    'الجزرالميكرونيزية'                                             => '057',
    'الدانمرك'                                                               => 'dk',
    'الرأسالأخضر'                                                         => 'cv',
    'السلفادور'                                                             => 'sv',
    'السنغال'                                                                 => 'sn',
    'السودان'                                                                 => 'sd',
    'السويد'                                                                   => 'se',
    'الصحراءالغربية'                                                   => 'eh',
    'الصومال'                                                                 => 'so',
    'الصين'                                                                     => 'cn',
    'العالم'                                                                   => '001',
    'العراق'                                                                   => 'iq',
    'الفاتيكان'                                                             => 'va',
    'الفيلبين'                                                               => 'ph',
    'القطبالجنوبي'                                                       => 'aq',
    'الكاريبي'                                                               => '029',
    'الكاميرون'                                                             => 'cm',
    'الكويت'                                                                   => 'kw',
    'المغرب'                                                                   => 'ma',
    'المقاطعاتالجنوبيةالفرنسية'                             => 'tf',
    'المكسيك'                                                                 => 'mx',
    'المملكةالعربيةالسعودية'                                   => 'sa',
    'المملكةالمتحدة'                                                   => 'gb',
    'النرويج'                                                                 => 'no',
    'النمسا'                                                                   => 'at',
    'النيجر'                                                                   => 'ne',
    'الهند'                                                                     => 'in',
    'الولاياتالمتحدةالأمريكية'                               => 'us',
    'اليابان'                                                                 => 'jp',
    'اليمن'                                                                     => 'ye',
    'اليونان'                                                                 => 'gr',
    'اندونيسيا'                                                             => 'id',
    'بابواغينياالجديدة'                                             => 'pg',
    'باراغواي'                                                               => 'py',
    'باكستان'                                                                 => 'pk',
    'بالاو'                                                                     => 'pw',
    'بتسوانا'                                                                 => 'bw',
    'بربادوس'                                                                 => 'bb',
    'برمودا'                                                                   => 'bm',
    'بروناي'                                                                   => 'bn',
    'بلجيكا'                                                                   => 'be',
    'بلغاريا'                                                                 => 'bg',
    'بليز'                                                                       => 'bz',
    'بنجلاديش'                                                               => 'bd',
    'بنما'                                                                       => 'pa',
    'بنين'                                                                       => 'bj',
    'بوتان'                                                                     => 'bt',
    'بورتوريكو'                                                             => 'pr',
    'بوركينافاسو'                                                         => 'bf',
    'بوروندي'                                                                 => 'bi',
    'بولندا'                                                                   => 'pl',
    'بوليفيا'                                                                 => 'bo',
    'بولينيزيا'                                                             => '061',
    'بولينيزياالفرنسية'                                             => 'pf',
    'بيرو'                                                                       => 'pe',
    'تانزانيا'                                                               => 'tz',
    'تايلند'                                                                   => 'th',
    'تايوان'                                                                   => 'tw',
    'تركمانستان'                                                           => 'tm',
    'تركيا'                                                                     => 'tr',
    'تريستانديكونها'                                                   => 'ta',
    'ترينيدادوتوباغو'                                                 => 'tt',
    'تشاد'                                                                       => 'td',
    'توجو'                                                                       => 'tg',
    'توفالو'                                                                   => 'tv',
    'توكيلو'                                                                   => 'tk',
    'تونس'                                                                       => 'tn',
    'تونغا'                                                                     => 'to',
    'تيمورالشرقية'                                                       => 'tl',
    'جامايكا'                                                                 => 'jm',
    'جبلطارق'                                                                 => 'gi',
    'جزرأولان'                                                               => 'ax',
    'جزرالأنتيلالهولندية'                                         => 'an',
    'جزرالتركوجايكوس'                                                 => 'tc',
    'جزرالقمر'                                                               => 'km',
    'جزرالكايمن'                                                           => 'ky',
    'جزرالكناري'                                                           => 'ic',
    'جزرالمارشال'                                                         => 'mh',
    'جزرالمالديف'                                                         => 'mv',
    'جزرالولاياتالمتحدةالبعيدةالصغيرة'               => 'um',
    'جزربيتكيرن'                                                           => 'pn',
    'جزرسليمان'                                                             => 'sb',
    'جزرفارو'                                                                 => 'fo',
    'جزرفرجينالأمريكية'                                             => 'vi',
    'جزرفرجينالبريطانية'                                           => 'vg',
    'جزرفوكلاندجزرمالفيناس'                                     => 'fk',
    'جزركوك'                                                                   => 'ck',
    'جزركوكوس'                                                               => 'cc',
    'جزرمارياناالشمالية'                                           => 'mp',
    'جزروالسوفوتونا'                                                   => 'wf',
    'جزيرةأسينشيون'                                                     => 'ac',
    'جزيرةالكريسماس'                                                   => 'cx',
    'جزيرةبوفيه'                                                           => 'bv',
    'جزيرةكليبيرتون'                                                   => 'cp',
    'جزيرةمان'                                                               => 'im',
    'جزيرةنورفوك'                                                         => 'nf',
    'جزيرةهيردوجزرماكدونالد'                                   => 'hm',
    'جمهوريةأفريقياالوسطى'                                       => 'cf',
    'جمهوريةالتشيك'                                                     => 'cz',
    'جمهوريةالدومينيك'                                               => 'do',
    'جمهوريةالكونغو'                                                   => 'cg',
    'جمهوريةالكونغوالديمقراطية'                             => 'cd',
    'جنوبآسيا'                                                               => '034',
    'جنوبأفريقيا'                                                         => 'za',
    'جنوبأوروبا'                                                           => '039',
    'جنوبشرقآسيا'                                                         => '035',
    'جنوبوسطآسيا'                                                         => '062',
    'جوادلوب'                                                                 => 'gp',
    'جورجيا'                                                                   => 'ge',
    'جورجياالجنوبيةوجزرساندويتشالجنوبية'           => 'gs',
    'جيبوتي'                                                                   => 'dj',
    'جيرسي'                                                                     => 'je',
    'دومينيكا'                                                               => 'dm',
    'دييغوغارسيا'                                                         => 'dg',
    'رواندا'                                                                   => 'rw',
    'روسيا'                                                                     => 'ru',
    'روسياالبيضاء'                                                       => 'by',
    'رومانيا'                                                                 => 'ro',
    'روينيون'                                                                 => 're',
    'زامبيا'                                                                   => 'zm',
    'زيمبابوي'                                                               => 'zw',
    'ساحلالعاج'                                                             => 'ci',
    'ساموا'                                                                     => 'ws',
    'سامواالأمريكية'                                                   => 'as',
    'سانبارتليمي'                                                         => 'bl',
    'سانتبييروميكولون'                                               => 'pm',
    'سانتفنسنتوغرنادين'                                             => 'vc',
    'سانتكيتسونيفيس'                                                   => 'kn',
    'سانتلوسيا'                                                             => 'lc',
    'سانتمارتين'                                                           => 'mf',
    'سانتهيلنا'                                                             => 'sh',
    'سانمارينو'                                                             => 'sm',
    'ساوتوميوبرينسيبي'                                               => 'st',
    'سريلانكا'                                                               => 'lk',
    'سفالباردوجانمايان'                                             => 'sj',
    'سلوفاكيا'                                                               => 'sk',
    'سلوفينيا'                                                               => 'si',
    'سنغافورة'                                                               => 'sg',
    'سوازيلاند'                                                             => 'sz',
    'سوريا'                                                                     => 'sy',
    'سورينام'                                                                 => 'sr',
    'سويسرا'                                                                   => 'ch',
    'سيراليون'                                                               => 'sl',
    'سيشل'                                                                       => 'sc',
    'سيوتاوميليلا'                                                       => 'ea',
    'شرقآسيا'                                                                 => '030',
    'شرقأفريقيا'                                                           => '014',
    'شرقأوروبا'                                                             => 151,
    'شمالأفريقيا'                                                         => '015',
    'شمالأمريكا'                                                           => '021',
    'شمالأوروبا'                                                           => 154,
    'شيلي'                                                                       => 'cl',
    'صربيا'                                                                     => 'rs',
    'صربياوالجبلالأسود'                                             => 'cs',
    'طاجكستان'                                                               => 'tj',
    'عُمان'                                                                     => 'om',
    'غامبيا'                                                                   => 'gm',
    'غانا'                                                                       => 'gh',
    'غربآسيا'                                                                 => 145,
    'غربأفريقيا'                                                           => '011',
    'غربأوروبا'                                                             => 155,
    'غرينادا'                                                                 => 'gd',
    'غرينلاند'                                                               => 'gl',
    'غواتيمالا'                                                             => 'gt',
    'غوام'                                                                       => 'gu',
    'غوياناالفرنسية'                                                   => 'gf',
    'غيانا'                                                                     => 'gy',
    'غيرنزي'                                                                   => 'gg',
    'غينيا'                                                                     => 'gn',
    'غينياالاستوائية'                                                 => 'gq',
    'غينيابيساو'                                                           => 'gw',
    'فانواتو'                                                                 => 'vu',
    'فرنسا'                                                                     => 'fr',
    'فلسطين'                                                                   => 'ps',
    'فنزويلا'                                                                 => 've',
    'فنلندا'                                                                   => 'fi',
    'فيتنام'                                                                   => 'vn',
    'فيجي'                                                                       => 'fj',
    'قبرص'                                                                       => 'cy',
    'قرغيزستان'                                                             => 'kg',
    'قطر'                                                                         => 'qa',
    'كازاخستان'                                                             => 'kz',
    'كاليدونياالجديدة'                                               => 'nc',
    'كرواتيا'                                                                 => 'hr',
    'كمبوديا'                                                                 => 'kh',
    'كندا'                                                                       => 'ca',
    'كوبا'                                                                       => 'cu',
    'كورياالجنوبية'                                                     => 'kr',
    'كورياالشمالية'                                                     => 'kp',
    'كوستاريكا'                                                             => 'cr',
    'كولومبيا'                                                               => 'co',
    'كومنولثالدولالمستقلة'                                       => 172,
    'كيريباتي'                                                               => 'ki',
    'كينيا'                                                                     => 'ke',
    'لاتفيا'                                                                   => 'lv',
    'لاوس'                                                                       => 'la',
    'لبنان'                                                                     => 'lb',
    'لوكسمبورغ'                                                             => 'lu',
    'ليبيا'                                                                     => 'ly',
    'ليبيريا'                                                                 => 'lr',
    'ليتوانيا'                                                               => 'lt',
    'ليختنشتاين'                                                           => 'li',
    'ليسوتو'                                                                   => 'ls',
    'مارتينيك'                                                               => 'mq',
    'ماكاو'                                                                     => 'mo',
    'مالطا'                                                                     => 'mt',
    'مالي'                                                                       => 'ml',
    'ماليزيا'                                                                 => 'my',
    'مايوت'                                                                     => 'yt',
    'مدغشقر'                                                                   => 'mg',
    'مصر'                                                                         => 'eg',
    'مقدونياجمهوريةمقدونيااليوغسلافيةالسابقة' => 'mk',
    'ملاوي'                                                                     => 'mw',
    'منطقةغيرمعروفة'                                                   => 'zz',
    'منغوليا'                                                                 => 'mn',
    'موريتانيا'                                                             => 'mr',
    'موريشيوس'                                                               => 'mu',
    'موزمبيق'                                                                 => 'mz',
    'مولدافيا'                                                               => 'md',
    'موناكو'                                                                   => 'mc',
    'مونتسرات'                                                               => 'ms',
    'ميانماربورما'                                                       => 'mm',
    'ميتروبولويتانفرنسا'                                           => 'fx',
    'ميكرونيزيا'                                                           => 'fm',
    'ميلانيزيا'                                                             => '054',
    'ناميبيا'                                                                 => 'na',
    'ناورو'                                                                     => 'nr',
    'نيبال'                                                                     => 'np',
    'نيجيريا'                                                                 => 'ng',
    'نيكاراغوا'                                                             => 'ni',
    'نيوزيلاندا'                                                           => 'nz',
    'نيوي'                                                                       => 'nu',
    'هايتي'                                                                     => 'ht',
    'هندوراس'                                                                 => 'hn',
    'هنغاريا'                                                                 => 'hu',
    'هولندا'                                                                   => 'nl',
    'هونغكونغ'                                                               => 'hk',
    'وسطآسيا'                                                                 => 143,
    'وسطأفريقيا'                                                           => '017',
);

1;

