package Locales::DB::Territory::es_es;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::es_es::VERSION = '0.09';

$Locales::DB::Territory::es_es::cldr_version = '2.0';

%Locales::DB::Territory::es_es::code_to_name = (
    '001' => 'Mundo',
    '002' => 'África',
    '003' => "América\ del\ Norte",
    '005' => 'Suramérica',
    '009' => 'Oceanía',
    '011' => "África\ occidental",
    '013' => 'Centroamérica',
    '014' => "África\ oriental",
    '015' => "África\ septentrional",
    '017' => "África\ central",
    '018' => "África\ meridional",
    '019' => 'Américas',
    '021' => 'Norteamérica',
    '029' => 'Caribe',
    '030' => "Asia\ oriental",
    '034' => "Asia\ meridional",
    '035' => "Sudeste\ asiático",
    '039' => "Europa\ meridional",
    '053' => "Australia\ y\ Nueva\ Zelanda",
    '054' => 'Melanesia',
    '057' => "Micronesia\ \[057\]",
    '061' => 'Polinesia',
    '062' => "Asia\ centromeridional",
    142   => 'Asia',
    143   => "Asia\ central",
    145   => "Asia\ occidental",
    150   => 'Europa',
    151   => "Europa\ oriental",
    154   => "Europa\ septentrional",
    155   => "Europa\ occidental",
    172   => "Comunidad\ de\ Estados\ Independientes",
    200   => 'Czechoslovakia',
    419   => 'Latinoamérica',
    830   => "Channel\ Islands",
    'ac'  => "Isla\ de\ la\ Ascensión",
    'ad'  => 'Andorra',
    'ae'  => "Emiratos\ Árabes\ Unidos",
    'af'  => 'Afganistán',
    'ag'  => "Antigua\ y\ Barbuda",
    'ai'  => 'Anguila',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Antillas\ Neerlandesas",
    'ao'  => 'Angola',
    'aq'  => 'Antártida',
    'ar'  => 'Argentina',
    'as'  => "Samoa\ Americana",
    'at'  => 'Austria',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => "Islas\ Åland",
    'az'  => 'Azerbaiyán',
    'ba'  => "Bosnia\-Herzegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Bélgica',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahréin',
    'bi'  => 'Burundi',
    'bj'  => 'Benín',
    'bl'  => "San\ Bartolomé",
    'bm'  => 'Bermudas',
    'bn'  => 'Brunéi',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasil',
    'bs'  => 'Bahamas',
    'bt'  => 'Bután',
    'bv'  => "Isla\ Bouvet",
    'bw'  => 'Botsuana',
    'by'  => 'Bielorrusia',
    'bz'  => 'Belice',
    'ca'  => 'Canadá',
    'cc'  => "Islas\ Cocos",
    'cd'  => "Congo\ \[República\ Democrática\ del\ Congo\]",
    'cf'  => "República\ Centroafricana",
    'cg'  => "Congo\ \[República\]",
    'ch'  => 'Suiza',
    'ci'  => "Costa\ de\ Marfil",
    'ck'  => "Islas\ Cook",
    'cl'  => 'Chile',
    'cm'  => 'Camerún',
    'cn'  => 'China',
    'co'  => 'Colombia',
    'cp'  => "Isla\ Clipperton",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ y\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Cabo\ Verde",
    'cx'  => "Isla\ Christmas",
    'cy'  => 'Chipre',
    'cz'  => "República\ Checa",
    'dd'  => "East\ Germany",
    'de'  => 'Alemania',
    'dg'  => "Diego\ García",
    'dj'  => 'Yibuti',
    'dk'  => 'Dinamarca',
    'dm'  => 'Dominica',
    'do'  => "República\ Dominicana",
    'dz'  => 'Argelia',
    'ea'  => "Ceuta\ y\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estonia',
    'eg'  => 'Egipto',
    'eh'  => "Sáhara\ Occidental",
    'er'  => 'Eritrea',
    'es'  => 'España',
    'et'  => 'Etiopía',
    'eu'  => "Unión\ Europea",
    'fi'  => 'Finlandia',
    'fj'  => 'Fiyi',
    'fk'  => "Islas\ Malvinas\ \[Islas\ Falkland\]",
    'fm'  => 'Micronesia',
    'fo'  => "Islas\ Feroe",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Francia',
    'fx'  => "Francia\ metropolitana",
    'ga'  => 'Gabón',
    'gb'  => "Reino\ Unido",
    'gd'  => 'Granada',
    'ge'  => 'Georgia',
    'gf'  => "Guayana\ Francesa",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Groenlandia',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadalupe',
    'gq'  => "Guinea\ Ecuatorial",
    'gr'  => 'Grecia',
    'gs'  => "Islas\ Georgia\ del\ Sur\ y\ Sandwich\ del\ Sur",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Islas\ Heard\ y\ McDonald",
    'hn'  => 'Honduras',
    'hr'  => 'Croacia',
    'ht'  => 'Haití',
    'hu'  => 'Hungría',
    'ic'  => "Islas\ Canarias",
    'id'  => 'Indonesia',
    'ie'  => 'Irlanda',
    'il'  => 'Israel',
    'im'  => "Isla\ de\ Man",
    'in'  => 'India',
    'io'  => "Territorio\ Británico\ del\ Océano\ Índico",
    'iq'  => 'Iraq',
    'ir'  => 'Irán',
    'is'  => 'Islandia',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordania',
    'jp'  => 'Japón',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenia',
    'kg'  => 'Kirguistán',
    'kh'  => 'Camboya',
    'ki'  => 'Kiribati',
    'km'  => 'Comoras',
    'kn'  => "San\ Cristóbal\ y\ Nieves",
    'kp'  => "Corea\ del\ Norte",
    'kr'  => "Corea\ del\ Sur",
    'kw'  => 'Kuwait',
    'ky'  => "Islas\ Caimán",
    'kz'  => 'Kazajistán',
    'la'  => 'Laos',
    'lb'  => 'Líbano',
    'lc'  => "Santa\ Lucía",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesoto',
    'lt'  => 'Lituania',
    'lu'  => 'Luxemburgo',
    'lv'  => 'Letonia',
    'ly'  => 'Libia',
    'ma'  => 'Marruecos',
    'mc'  => 'Mónaco',
    'md'  => 'Moldavia',
    'me'  => 'Montenegro',
    'mf'  => "San\ Martín",
    'mg'  => 'Madagascar',
    'mh'  => "Islas\ Marshall",
    'mi'  => "Midway\ Islands",
    'mk'  => "Macedonia\ \[ERYM\]",
    'ml'  => 'Mali',
    'mm'  => "Myanmar\ \[Birmania\]",
    'mn'  => 'Mongolia',
    'mo'  => 'Macao',
    'mp'  => "Islas\ Marianas\ del\ Norte",
    'mq'  => 'Martinica',
    'mr'  => 'Mauritania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauricio',
    'mv'  => 'Maldivas',
    'mw'  => 'Malaui',
    'mx'  => 'México',
    'my'  => 'Malasia',
    'mz'  => 'Mozambique',
    'na'  => 'Namibia',
    'nc'  => "Nueva\ Caledonia",
    'ne'  => 'Níger',
    'nf'  => "Isla\ Norfolk",
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => "Países\ Bajos",
    'no'  => 'Noruega',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => "Isla\ Niue",
    'nz'  => "Nueva\ Zelanda",
    'om'  => 'Omán',
    'pa'  => 'Panamá',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Perú',
    'pf'  => "Polinesia\ Francesa",
    'pg'  => "Papúa\ Nueva\ Guinea",
    'ph'  => 'Filipinas',
    'pk'  => 'Pakistán',
    'pl'  => 'Polonia',
    'pm'  => "San\ Pedro\ y\ Miquelón",
    'pn'  => "Islas\ Pitcairn",
    'pr'  => "Puerto\ Rico",
    'ps'  => "Territorios\ Palestinos",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Territorios\ alejados\ de\ Oceanía",
    're'  => 'Reunión',
    'ro'  => 'Rumanía',
    'rs'  => 'Serbia',
    'ru'  => 'Rusia',
    'rw'  => 'Ruanda',
    'sa'  => "Arabia\ Saudí",
    'sb'  => "Islas\ Salomón",
    'sc'  => 'Seychelles',
    'sd'  => 'Sudán',
    'se'  => 'Suecia',
    'sg'  => 'Singapur',
    'sh'  => "Santa\ Elena",
    'si'  => 'Eslovenia',
    'sj'  => "Svalbard\ y\ Jan\ Mayen",
    'sk'  => 'Eslovaquia',
    'sl'  => "Sierra\ Leona",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "Santo\ Tomé\ y\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Siria',
    'sz'  => 'Suazilandia',
    'ta'  => "Tristán\ da\ Cunha",
    'tc'  => "Islas\ Turcas\ y\ Caicos",
    'td'  => 'Chad',
    'tf'  => "Territorios\ Australes\ Franceses",
    'tg'  => 'Togo',
    'th'  => 'Tailandia',
    'tj'  => 'Tayikistán',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ Oriental",
    'tm'  => 'Turkmenistán',
    'tn'  => 'Túnez',
    'to'  => 'Tonga',
    'tr'  => 'Turquía',
    'tt'  => "Trinidad\ y\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwán',
    'tz'  => 'Tanzania',
    'ua'  => 'Ucrania',
    'ug'  => 'Uganda',
    'um'  => "Islas\ menores\ alejadas\ de\ los\ Estados\ Unidos",
    'us'  => "Estados\ Unidos",
    'uy'  => 'Uruguay',
    'uz'  => 'Uzbekistán',
    'va'  => "Ciudad\ del\ Vaticano",
    'vc'  => "San\ Vicente\ y\ las\ Granadinas",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Islas\ Vírgenes\ Británicas",
    'vi'  => "Islas\ Vírgenes\ de\ los\ Estados\ Unidos",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ y\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemen',
    'yt'  => 'Mayotte',
    'za'  => 'Sudáfrica',
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabue',
    'zz'  => "Región\ desconocida",
);

%Locales::DB::Territory::es_es::name_to_code = (
    'afganistán'                               => 'af',
    'albania'                                   => 'al',
    'alemania'                                  => 'de',
    'américadelnorte'                          => '003',
    'américas'                                 => '019',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguila'                                   => 'ai',
    'antiguaybarbuda'                           => 'ag',
    'antillasneerlandesas'                      => 'an',
    'antártida'                                => 'aq',
    'arabiasaudí'                              => 'sa',
    'argelia'                                   => 'dz',
    'argentina'                                 => 'ar',
    'armenia'                                   => 'am',
    'aruba'                                     => 'aw',
    'asia'                                      => 142,
    'asiacentral'                               => 143,
    'asiacentromeridional'                      => '062',
    'asiameridional'                            => '034',
    'asiaoccidental'                            => 145,
    'asiaoriental'                              => '030',
    'australia'                                 => 'au',
    'australiaynuevazelanda'                    => '053',
    'austria'                                   => 'at',
    'azerbaiyán'                               => 'az',
    'bahamas'                                   => 'bs',
    'bahréin'                                  => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'belice'                                    => 'bz',
    'benín'                                    => 'bj',
    'bermudas'                                  => 'bm',
    'bielorrusia'                               => 'by',
    'bolivia'                                   => 'bo',
    'bosniaherzegovina'                         => 'ba',
    'botsuana'                                  => 'bw',
    'brasil'                                    => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brunéi'                                   => 'bn',
    'bulgaria'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'bután'                                    => 'bt',
    'bélgica'                                  => 'be',
    'caboverde'                                 => 'cv',
    'camboya'                                   => 'kh',
    'camerún'                                  => 'cm',
    'canadá'                                   => 'ca',
    'cantonandenderburyislands'                 => 'ct',
    'caribe'                                    => '029',
    'centroamérica'                            => '013',
    'ceutaymelilla'                             => 'ea',
    'chad'                                      => 'td',
    'channelislands'                            => 830,
    'chile'                                     => 'cl',
    'china'                                     => 'cn',
    'chipre'                                    => 'cy',
    'ciudaddelvaticano'                         => 'va',
    'colombia'                                  => 'co',
    'comoras'                                   => 'km',
    'comunidaddeestadosindependientes'          => 172,
    'congorepública'                           => 'cg',
    'congorepúblicademocráticadelcongo'       => 'cd',
    'coreadelnorte'                             => 'kp',
    'coreadelsur'                               => 'kr',
    'costademarfil'                             => 'ci',
    'costarica'                                 => 'cr',
    'croacia'                                   => 'hr',
    'cuba'                                      => 'cu',
    'czechoslovakia'                            => 200,
    'diegogarcía'                              => 'dg',
    'dinamarca'                                 => 'dk',
    'dominica'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egipto'                                    => 'eg',
    'elsalvador'                                => 'sv',
    'emiratosÁrabesunidos'                     => 'ae',
    'eritrea'                                   => 'er',
    'eslovaquia'                                => 'sk',
    'eslovenia'                                 => 'si',
    'españa'                                   => 'es',
    'estadosunidos'                             => 'us',
    'estonia'                                   => 'ee',
    'etiopía'                                  => 'et',
    'europa'                                    => 150,
    'europameridional'                          => '039',
    'europaoccidental'                          => 155,
    'europaoriental'                            => 151,
    'europaseptentrional'                       => 154,
    'filipinas'                                 => 'ph',
    'finlandia'                                 => 'fi',
    'fiyi'                                      => 'fj',
    'francia'                                   => 'fr',
    'franciametropolitana'                      => 'fx',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabón'                                    => 'ga',
    'gambia'                                    => 'gm',
    'georgia'                                   => 'ge',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'granada'                                   => 'gd',
    'grecia'                                    => 'gr',
    'groenlandia'                               => 'gl',
    'guadalupe'                                 => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guayanafrancesa'                           => 'gf',
    'guernsey'                                  => 'gg',
    'guinea'                                    => 'gn',
    'guineabissau'                              => 'gw',
    'guineaecuatorial'                          => 'gq',
    'guyana'                                    => 'gy',
    'haití'                                    => 'ht',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hungría'                                  => 'hu',
    'india'                                     => 'in',
    'indonesia'                                 => 'id',
    'iraq'                                      => 'iq',
    'irlanda'                                   => 'ie',
    'irán'                                     => 'ir',
    'islabouvet'                                => 'bv',
    'islachristmas'                             => 'cx',
    'islaclipperton'                            => 'cp',
    'isladelaascensión'                        => 'ac',
    'islademan'                                 => 'im',
    'islandia'                                  => 'is',
    'islaniue'                                  => 'nu',
    'islanorfolk'                               => 'nf',
    'islascaimán'                              => 'ky',
    'islascanarias'                             => 'ic',
    'islascocos'                                => 'cc',
    'islascook'                                 => 'ck',
    'islasferoe'                                => 'fo',
    'islasgeorgiadelsurysandwichdelsur'         => 'gs',
    'islasheardymcdonald'                       => 'hm',
    'islasmalvinasislasfalkland'                => 'fk',
    'islasmarianasdelnorte'                     => 'mp',
    'islasmarshall'                             => 'mh',
    'islasmenoresalejadasdelosestadosunidos'    => 'um',
    'islaspitcairn'                             => 'pn',
    'islassalomón'                             => 'sb',
    'islasturcasycaicos'                        => 'tc',
    'islasvírgenesbritánicas'                 => 'vg',
    'islasvírgenesdelosestadosunidos'          => 'vi',
    'islasÅland'                               => 'ax',
    'israel'                                    => 'il',
    'italia'                                    => 'it',
    'jamaica'                                   => 'jm',
    'japón'                                    => 'jp',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordania'                                  => 'jo',
    'kazajistán'                               => 'kz',
    'kenia'                                     => 'ke',
    'kirguistán'                               => 'kg',
    'kiribati'                                  => 'ki',
    'kuwait'                                    => 'kw',
    'laos'                                      => 'la',
    'latinoamérica'                            => 419,
    'lesoto'                                    => 'ls',
    'letonia'                                   => 'lv',
    'liberia'                                   => 'lr',
    'libia'                                     => 'ly',
    'liechtenstein'                             => 'li',
    'lituania'                                  => 'lt',
    'luxemburgo'                                => 'lu',
    'líbano'                                   => 'lb',
    'macao'                                     => 'mo',
    'macedoniaerym'                             => 'mk',
    'madagascar'                                => 'mg',
    'malasia'                                   => 'my',
    'malaui'                                    => 'mw',
    'maldivas'                                  => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'marruecos'                                 => 'ma',
    'martinica'                                 => 'mq',
    'mauricio'                                  => 'mu',
    'mauritania'                                => 'mr',
    'mayotte'                                   => 'yt',
    'melanesia'                                 => '054',
    'micronesia'                                => 'fm',
    'micronesia057'                             => '057',
    'midwayislands'                             => 'mi',
    'moldavia'                                  => 'md',
    'mongolia'                                  => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mozambique'                                => 'mz',
    'mundo'                                     => '001',
    'myanmarbirmania'                           => 'mm',
    'méxico'                                   => 'mx',
    'mónaco'                                   => 'mc',
    'namibia'                                   => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'nigeria'                                   => 'ng',
    'norteamérica'                             => '021',
    'northvietnam'                              => 'vd',
    'noruega'                                   => 'no',
    'nuevacaledonia'                            => 'nc',
    'nuevazelanda'                              => 'nz',
    'níger'                                    => 'ne',
    'oceanía'                                  => '009',
    'omán'                                     => 'om',
    'pacificislandstrustterritory'              => 'pc',
    'pakistán'                                 => 'pk',
    'palau'                                     => 'pw',
    'panamacanalzone'                           => 'pz',
    'panamá'                                   => 'pa',
    'papúanuevaguinea'                         => 'pg',
    'paraguay'                                  => 'py',
    'paísesbajos'                              => 'nl',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'perú'                                     => 'pe',
    'polinesia'                                 => '061',
    'polinesiafrancesa'                         => 'pf',
    'polonia'                                   => 'pl',
    'portugal'                                  => 'pt',
    'puertorico'                                => 'pr',
    'qatar'                                     => 'qa',
    'regióndesconocida'                        => 'zz',
    'reinounido'                                => 'gb',
    'repúblicacentroafricana'                  => 'cf',
    'repúblicacheca'                           => 'cz',
    'repúblicadominicana'                      => 'do',
    'reunión'                                  => 're',
    'ruanda'                                    => 'rw',
    'rumanía'                                  => 'ro',
    'rusia'                                     => 'ru',
    'samoa'                                     => 'ws',
    'samoaamericana'                            => 'as',
    'sanbartolomé'                             => 'bl',
    'sancristóbalynieves'                      => 'kn',
    'sanmarino'                                 => 'sm',
    'sanmartín'                                => 'mf',
    'sanpedroymiquelón'                        => 'pm',
    'santaelena'                                => 'sh',
    'santalucía'                               => 'lc',
    'santotoméypríncipe'                      => 'st',
    'sanvicenteylasgranadinas'                  => 'vc',
    'senegal'                                   => 'sn',
    'serbia'                                    => 'rs',
    'serbiaymontenegro'                         => 'cs',
    'seychelles'                                => 'sc',
    'sierraleona'                               => 'sl',
    'singapur'                                  => 'sg',
    'siria'                                     => 'sy',
    'somalia'                                   => 'so',
    'srilanka'                                  => 'lk',
    'suazilandia'                               => 'sz',
    'sudesteasiático'                          => '035',
    'sudáfrica'                                => 'za',
    'sudán'                                    => 'sd',
    'suecia'                                    => 'se',
    'suiza'                                     => 'ch',
    'suramérica'                               => '005',
    'surinam'                                   => 'sr',
    'svalbardyjanmayen'                         => 'sj',
    'sáharaoccidental'                         => 'eh',
    'tailandia'                                 => 'th',
    'taiwán'                                   => 'tw',
    'tanzania'                                  => 'tz',
    'tayikistán'                               => 'tj',
    'territoriobritánicodelocéanoÍndico'     => 'io',
    'territoriosalejadosdeoceanía'             => 'qo',
    'territoriosaustralesfranceses'             => 'tf',
    'territoriospalestinos'                     => 'ps',
    'timororiental'                             => 'tl',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadytobago'                           => 'tt',
    'tristándacunha'                           => 'ta',
    'turkmenistán'                             => 'tm',
    'turquía'                                  => 'tr',
    'tuvalu'                                    => 'tv',
    'túnez'                                    => 'tn',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ucrania'                                   => 'ua',
    'uganda'                                    => 'ug',
    'unionofsovietsocialistrepublics'           => 'su',
    'unióneuropea'                             => 'eu',
    'uruguay'                                   => 'uy',
    'uzbekistán'                               => 'uz',
    'vanuatu'                                   => 'vu',
    'venezuela'                                 => 've',
    'vietnam'                                   => 'vn',
    'wakeisland'                                => 'wk',
    'wallisyfutuna'                             => 'wf',
    'yemen'                                     => 'ye',
    'yibuti'                                    => 'dj',
    'zambia'                                    => 'zm',
    'zimbabue'                                  => 'zw',
    'África'                                   => '002',
    'Áfricacentral'                            => '017',
    'Áfricameridional'                         => '018',
    'Áfricaoccidental'                         => '011',
    'Áfricaoriental'                           => '014',
    'Áfricaseptentrional'                      => '015',
);

1;

