package Locales::DB::Territory::rm;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::rm::VERSION = '0.09';

$Locales::DB::Territory::rm::cldr_version = '2.0';

%Locales::DB::Territory::rm::code_to_name = (
    '001' => 'mund',
    '002' => 'Africa',
    '003' => "America\ dal\ Nord",
    '005' => "America\ dal\ Sid",
    '009' => 'Oceania',
    '011' => "Africa\ dal\ Vest",
    '013' => "America\ Centrala",
    '014' => "Africa\ da\ l\'Ost",
    '015' => "Africa\ dal\ Nord",
    '017' => "Africa\ Centrala",
    '018' => "Africa\ Meridiunala",
    '019' => "America\ dal\ Nord\,\ America\ Centrala\ ed\ America\ dal\ Sid",
    '021' => "Northern\ America",
    '029' => 'Caribica',
    '030' => "Asia\ da\ l\'Ost",
    '034' => "Asia\ dal\ Sid",
    '035' => "Asia\ dal\ Sidost",
    '039' => "Europa\ dal\ Sid",
    '053' => "Australia\ e\ Nova\ Zelanda",
    '054' => 'Melanesia',
    '057' => "Regiun\ Micronesica",
    '061' => 'Polinesia',
    '062' => "Asia\ Centrala\ dal\ Sid",
    142   => 'Asia',
    143   => "Asia\ Centrala",
    145   => "Asia\ dal\ Vest",
    150   => 'Europa',
    151   => "Europa\ Orientala",
    154   => "Europa\ dal\ Nord",
    155   => "Europa\ dal\ Vest",
    172   => "Communitad\ dals\ Stadis\ Independents",
    200   => 'Tschecoslovachia',
    419   => "America\ Latina\ e\ Caribica",
    830   => "Inslas\ dal\ Chanal\ da\ la\ Mongia",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andorra',
    'ae'  => "Emirats\ Arabs\ Unids",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ e\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albania',
    'am'  => 'Armenia',
    'an'  => "Antillas\ Ollandaisas",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Argentinia',
    'as'  => "Samoa\ Americana",
    'at'  => 'Austria',
    'au'  => 'Australia',
    'aw'  => 'Aruba',
    'ax'  => "Inslas\ Aland",
    'az'  => 'Aserbaidschan',
    'ba'  => "Bosnia\ ed\ Erzegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesch',
    'be'  => 'Belgia',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgaria',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Son\ Barthélemy",
    'bm'  => 'Bermudas',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "Territori\ Antarctic\ Britannic",
    'br'  => 'Brasila',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhutan',
    'bv'  => "Insla\ Bouvet",
    'bw'  => 'Botswana',
    'by'  => 'Bielorussia',
    'bz'  => 'Belize',
    'ca'  => 'Canada',
    'cc'  => "Inslas\ Cocos",
    'cd'  => "Republica\ Democratica\ dal\ Congo",
    'cf'  => "Republica\ Centralafricana",
    'cg'  => 'Congo',
    'ch'  => 'Svizra',
    'ci'  => "Costa\ d\'Ivur",
    'ck'  => "Inslas\ Cook",
    'cl'  => 'Chile',
    'cm'  => 'Camerun',
    'cn'  => 'China',
    'co'  => 'Columbia',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbia\ e\ Montenegro",
    'ct'  => "Inslas\ Canton\ ed\ Enderbury",
    'cu'  => 'Cuba',
    'cv'  => "Cap\ Verd",
    'cx'  => "Insla\ da\ Christmas",
    'cy'  => 'Cipra',
    'cz'  => "Republica\ Tscheca",
    'dd'  => "Germania\ da\ l\'Ost",
    'de'  => 'Germania',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Dschibuti',
    'dk'  => 'Danemarc',
    'dm'  => 'Dominica',
    'do'  => "Republica\ Dominicana",
    'dz'  => 'Algeria',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estonia',
    'eg'  => 'Egipta',
    'eh'  => "Sahara\ Occidentala",
    'er'  => 'Eritrea',
    'es'  => 'Spagna',
    'et'  => 'Etiopia',
    'eu'  => "Uniun\ europeica",
    'fi'  => 'Finlanda',
    'fj'  => 'Fidschi',
    'fk'  => "Inslas\ dal\ Falkland",
    'fm'  => 'Micronesia',
    'fo'  => "Inslas\ Feroe",
    'fq'  => "Territoris\ Meridiunals\ ed\ Antarctics\ Franzos",
    'fr'  => 'Frantscha',
    'fx'  => "Frantscha\ Metropolitana",
    'ga'  => 'Gabun',
    'gb'  => "Reginavel\ Unì",
    'gd'  => 'Grenada',
    'ge'  => 'Georgia',
    'gf'  => "Guyana\ Franzosa",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grönlanda',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => "Guinea\ Equatoriala",
    'gr'  => 'Grezia',
    'gs'  => "Georgia\ dal\ Sid\ e\ las\ Inslas\ Sandwich\ dal\ Sid",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => "Regiun\ d\'administraziun\ speziala\ da\ Hongkong\,\ China",
    'hm'  => "Inslas\ da\ Heard\ e\ da\ McDonlad",
    'hn'  => 'Honduras',
    'hr'  => 'Croazia',
    'ht'  => 'Haiti',
    'hu'  => 'Ungaria',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonesia',
    'ie'  => 'Irlanda',
    'il'  => 'Israel',
    'im'  => "Insla\ da\ Man",
    'in'  => 'India',
    'io'  => "Territori\ Britannic\ en\ l\'Ocean\ Indic",
    'iq'  => 'Irac',
    'ir'  => 'Iran',
    'is'  => 'Islanda',
    'it'  => 'Italia',
    'je'  => 'Jersey',
    'jm'  => 'Giamaica',
    'jo'  => 'Jordania',
    'jp'  => 'Giapun',
    'jt'  => "Atoll\ Johnston",
    'ke'  => 'Kenia',
    'kg'  => 'Kirghisistan',
    'kh'  => 'Cambodscha',
    'ki'  => 'Kiribati',
    'km'  => 'Comoras',
    'kn'  => "Saint\ Kitts\ e\ Nevis",
    'kp'  => "Corea\ dal\ Nord",
    'kr'  => "Corea\ dal\ Sid",
    'kw'  => 'Kuwait',
    'ky'  => "Inslas\ Cayman",
    'kz'  => 'Kasachstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Lituania',
    'lu'  => 'Luxemburg',
    'lv'  => 'Lettonia',
    'ly'  => 'Libia',
    'ma'  => 'Maroc',
    'mc'  => 'Monaco',
    'md'  => 'Moldavia',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagascar',
    'mh'  => "Inslas\ da\ Marshall",
    'mi'  => "Inslas\ da\ Midway",
    'mk'  => 'Macedonia',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongolia',
    'mo'  => "Regiun\ d\'administraziun\ speziala\ Macao\,\ China",
    'mp'  => "Inslas\ Mariannas\ dal\ Nord",
    'mq'  => 'Martinique',
    'mr'  => 'Mauretania',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Maldivas',
    'mw'  => 'Malawi',
    'mx'  => 'Mexico',
    'my'  => 'Malaisia',
    'mz'  => 'Mosambic',
    'na'  => 'Namibia',
    'nc'  => "Nova\ Caledonia",
    'ne'  => 'Niger',
    'nf'  => "Insla\ Norfolk",
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => "Pajais\ Bass",
    'no'  => 'Norvegia',
    'np'  => 'Nepal',
    'nq'  => "Terra\ da\ la\ Regina\ Maud",
    'nr'  => 'Nauru',
    'nt'  => "Zona\ neutrala",
    'nu'  => 'Niue',
    'nz'  => "Nova\ Zelanda",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Territori\ fiduziar\ da\ las\ Inslas\ dal\ Pacific",
    'pe'  => 'Peru',
    'pf'  => "Polinesia\ Franzosa",
    'pg'  => "Papua\ Nova\ Guinea",
    'ph'  => 'Filippinas',
    'pk'  => 'Pakistan',
    'pl'  => 'Pologna',
    'pm'  => "Saint\ Pierre\ e\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Territori\ Palestinais",
    'pt'  => 'Portugal',
    'pu'  => "Diversas\ inslas\ dals\ Stadis\ Unids\ da\ l\'America\ en\ il\ Pacific",
    'pw'  => 'Palau',
    'py'  => 'Paraguai',
    'pz'  => "Zona\ dal\ Canal\ da\ Panama",
    'qa'  => 'Katar',
    'qo'  => "Oceania\ Periferica",
    're'  => 'Réunion',
    'ro'  => 'Rumenia',
    'rs'  => 'Serbia',
    'ru'  => 'Russia',
    'rw'  => 'Ruanda',
    'sa'  => "Arabia\ Saudita",
    'sb'  => 'Salomonas',
    'sc'  => 'Seychellas',
    'sd'  => 'Sudan',
    'se'  => 'Svezia',
    'sg'  => 'Singapur',
    'sh'  => "Sontg\'Elena",
    'si'  => 'Slovenia',
    'sj'  => "Svalbard\ e\ Jan\ Mayen",
    'sk'  => 'Slovachia',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "São\ Tomé\ e\ Principe",
    'su'  => "Uniun\ Sovietica",
    'sv'  => "El\ Salvador",
    'sy'  => 'Siria',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Inslas\ Turks\ e\ Caicos",
    'td'  => 'Tschad',
    'tf'  => "Territoris\ Franzos\ Meridiunals",
    'tg'  => 'Togo',
    'th'  => 'Tailanda',
    'tj'  => 'Tadschikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ da\ l\'Ost",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunesia',
    'to'  => 'Tonga',
    'tr'  => 'Tirchia',
    'tt'  => "Trinidad\ e\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tansania',
    'ua'  => 'Ucraina',
    'ug'  => 'Uganda',
    'um'  => "Inslas\ pitschnas\ perifericas\ dals\ Stadis\ Unids\ da\ l\'America",
    'us'  => "Stadis\ Unids\ da\ l\'America",
    'uy'  => 'Uruguay',
    'uz'  => 'Usbekistan',
    'va'  => "Citad\ dal\ Vatican",
    'vc'  => "Saint\ Vincent\ e\ las\ Grenadinas",
    'vd'  => "Vietnam\ dal\ Nord",
    've'  => 'Venezuela',
    'vg'  => "Inslas\ Verginas\ Britannicas",
    'vi'  => "Inslas\ Verginas\ Americanas",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ e\ Futuna",
    'wk'  => "Insla\ Wake",
    'ws'  => 'Samoa',
    'yd'  => "Republica\ Democratica\ Populara\ da\ Jemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => "Africa\ dal\ Sid",
    'zm'  => 'Sambia',
    'zw'  => 'Simbabwe',
    'zz'  => "Regiun\ betg\ encouschenta\ u\ nunvalaivla",
);

%Locales::DB::Territory::rm::name_to_code = (
    'afghanistan'                                         => 'af',
    'africa'                                              => '002',
    'africacentrala'                                      => '017',
    'africadalnord'                                       => '015',
    'africadalost'                                        => '014',
    'africadalsid'                                        => 'za',
    'africadalvest'                                       => '011',
    'africameridiunala'                                   => '018',
    'albania'                                             => 'al',
    'algeria'                                             => 'dz',
    'americacentrala'                                     => '013',
    'americadalnord'                                      => '003',
    "americadalnord\,americacentralaedamericadalsid"      => '019',
    'americadalsid'                                       => '005',
    'americalatinaecaribica'                              => 419,
    'andorra'                                             => 'ad',
    'angola'                                              => 'ao',
    'anguilla'                                            => 'ai',
    'antarctica'                                          => 'aq',
    'antiguaebarbuda'                                     => 'ag',
    'antillasollandaisas'                                 => 'an',
    'arabiasaudita'                                       => 'sa',
    'argentinia'                                          => 'ar',
    'armenia'                                             => 'am',
    'aruba'                                               => 'aw',
    'ascensionisland'                                     => 'ac',
    'aserbaidschan'                                       => 'az',
    'asia'                                                => 142,
    'asiacentrala'                                        => 143,
    'asiacentraladalsid'                                  => '062',
    'asiadalost'                                          => '030',
    'asiadalsid'                                          => '034',
    'asiadalsidost'                                       => '035',
    'asiadalvest'                                         => 145,
    'atolljohnston'                                       => 'jt',
    'australia'                                           => 'au',
    'australiaenovazelanda'                               => '053',
    'austria'                                             => 'at',
    'bahamas'                                             => 'bs',
    'bahrain'                                             => 'bh',
    'bangladesch'                                         => 'bd',
    'barbados'                                            => 'bb',
    'belgia'                                              => 'be',
    'belize'                                              => 'bz',
    'benin'                                               => 'bj',
    'bermudas'                                            => 'bm',
    'bhutan'                                              => 'bt',
    'bielorussia'                                         => 'by',
    'bolivia'                                             => 'bo',
    'bosniaederzegovina'                                  => 'ba',
    'botswana'                                            => 'bw',
    'brasila'                                             => 'br',
    'brunei'                                              => 'bn',
    'bulgaria'                                            => 'bg',
    'burkinafaso'                                         => 'bf',
    'burundi'                                             => 'bi',
    'cambodscha'                                          => 'kh',
    'camerun'                                             => 'cm',
    'canada'                                              => 'ca',
    'canaryislands'                                       => 'ic',
    'capverd'                                             => 'cv',
    'caribica'                                            => '029',
    'ceutaandmelilla'                                     => 'ea',
    'chile'                                               => 'cl',
    'china'                                               => 'cn',
    'cipra'                                               => 'cy',
    'citaddalvatican'                                     => 'va',
    'clippertonisland'                                    => 'cp',
    'columbia'                                            => 'co',
    'communitaddalsstadisindependents'                    => 172,
    'comoras'                                             => 'km',
    'congo'                                               => 'cg',
    'coreadalnord'                                        => 'kp',
    'coreadalsid'                                         => 'kr',
    'costadivur'                                          => 'ci',
    'costarica'                                           => 'cr',
    'croazia'                                             => 'hr',
    'cuba'                                                => 'cu',
    'danemarc'                                            => 'dk',
    'diegogarcia'                                         => 'dg',
    'diversasinslasdalsstadisunidsdalamericaenilpacific'  => 'pu',
    'dominica'                                            => 'dm',
    'dschibuti'                                           => 'dj',
    'ecuador'                                             => 'ec',
    'egipta'                                              => 'eg',
    'elsalvador'                                          => 'sv',
    'emiratsarabsunids'                                   => 'ae',
    'eritrea'                                             => 'er',
    'estonia'                                             => 'ee',
    'etiopia'                                             => 'et',
    'europa'                                              => 150,
    'europadalnord'                                       => 154,
    'europadalsid'                                        => '039',
    'europadalvest'                                       => 155,
    'europaorientala'                                     => 151,
    'fidschi'                                             => 'fj',
    'filippinas'                                          => 'ph',
    'finlanda'                                            => 'fi',
    'frantscha'                                           => 'fr',
    'frantschametropolitana'                              => 'fx',
    'gabun'                                               => 'ga',
    'gambia'                                              => 'gm',
    'georgia'                                             => 'ge',
    'georgiadalsidelasinslassandwichdalsid'               => 'gs',
    'germania'                                            => 'de',
    'germaniadalost'                                      => 'dd',
    'ghana'                                               => 'gh',
    'giamaica'                                            => 'jm',
    'giapun'                                              => 'jp',
    'gibraltar'                                           => 'gi',
    'grenada'                                             => 'gd',
    'grezia'                                              => 'gr',
    'grönlanda'                                          => 'gl',
    'guadeloupe'                                          => 'gp',
    'guam'                                                => 'gu',
    'guatemala'                                           => 'gt',
    'guernsey'                                            => 'gg',
    'guinea'                                              => 'gn',
    'guineabissau'                                        => 'gw',
    'guineaequatoriala'                                   => 'gq',
    'guyana'                                              => 'gy',
    'guyanafranzosa'                                      => 'gf',
    'haiti'                                               => 'ht',
    'honduras'                                            => 'hn',
    'india'                                               => 'in',
    'indonesia'                                           => 'id',
    'inslabouvet'                                         => 'bv',
    'insladachristmas'                                    => 'cx',
    'insladaman'                                          => 'im',
    'inslanorfolk'                                        => 'nf',
    'inslasaland'                                         => 'ax',
    'inslascantonedenderbury'                             => 'ct',
    'inslascayman'                                        => 'ky',
    'inslascocos'                                         => 'cc',
    'inslascook'                                          => 'ck',
    'inslasdaheardedamcdonlad'                            => 'hm',
    'inslasdalchanaldalamongia'                           => 830,
    'inslasdalfalkland'                                   => 'fk',
    'inslasdamarshall'                                    => 'mh',
    'inslasdamidway'                                      => 'mi',
    'inslasferoe'                                         => 'fo',
    'inslasmariannasdalnord'                              => 'mp',
    'inslaspitschnasperifericasdalsstadisunidsdalamerica' => 'um',
    'inslasturksecaicos'                                  => 'tc',
    'inslasverginasamericanas'                            => 'vi',
    'inslasverginasbritannicas'                           => 'vg',
    'inslawake'                                           => 'wk',
    'irac'                                                => 'iq',
    'iran'                                                => 'ir',
    'irlanda'                                             => 'ie',
    'islanda'                                             => 'is',
    'israel'                                              => 'il',
    'italia'                                              => 'it',
    'jemen'                                               => 'ye',
    'jersey'                                              => 'je',
    'jordania'                                            => 'jo',
    'kasachstan'                                          => 'kz',
    'katar'                                               => 'qa',
    'kenia'                                               => 'ke',
    'kirghisistan'                                        => 'kg',
    'kiribati'                                            => 'ki',
    'kuwait'                                              => 'kw',
    'laos'                                                => 'la',
    'lesotho'                                             => 'ls',
    'lettonia'                                            => 'lv',
    'libanon'                                             => 'lb',
    'liberia'                                             => 'lr',
    'libia'                                               => 'ly',
    'liechtenstein'                                       => 'li',
    'lituania'                                            => 'lt',
    'luxemburg'                                           => 'lu',
    'macedonia'                                           => 'mk',
    'madagascar'                                          => 'mg',
    'malaisia'                                            => 'my',
    'malawi'                                              => 'mw',
    'maldivas'                                            => 'mv',
    'mali'                                                => 'ml',
    'malta'                                               => 'mt',
    'maroc'                                               => 'ma',
    'martinique'                                          => 'mq',
    'mauretania'                                          => 'mr',
    'mauritius'                                           => 'mu',
    'mayotte'                                             => 'yt',
    'melanesia'                                           => '054',
    'mexico'                                              => 'mx',
    'micronesia'                                          => 'fm',
    'moldavia'                                            => 'md',
    'monaco'                                              => 'mc',
    'mongolia'                                            => 'mn',
    'montenegro'                                          => 'me',
    'montserrat'                                          => 'ms',
    'mosambic'                                            => 'mz',
    'mund'                                                => '001',
    'myanmar'                                             => 'mm',
    'namibia'                                             => 'na',
    'nauru'                                               => 'nr',
    'nepal'                                               => 'np',
    'nicaragua'                                           => 'ni',
    'niger'                                               => 'ne',
    'nigeria'                                             => 'ng',
    'niue'                                                => 'nu',
    'northernamerica'                                     => '021',
    'norvegia'                                            => 'no',
    'novacaledonia'                                       => 'nc',
    'novazelanda'                                         => 'nz',
    'oceania'                                             => '009',
    'oceaniaperiferica'                                   => 'qo',
    'oman'                                                => 'om',
    'pajaisbass'                                          => 'nl',
    'pakistan'                                            => 'pk',
    'palau'                                               => 'pw',
    'panama'                                              => 'pa',
    'papuanovaguinea'                                     => 'pg',
    'paraguai'                                            => 'py',
    'peru'                                                => 'pe',
    'pitcairn'                                            => 'pn',
    'polinesia'                                           => '061',
    'polinesiafranzosa'                                   => 'pf',
    'pologna'                                             => 'pl',
    'portugal'                                            => 'pt',
    'puertorico'                                          => 'pr',
    'reginavelunì'                                       => 'gb',
    'regiunbetgencouschentaununvalaivla'                  => 'zz',
    "regiundadministraziunspezialadahongkong\,china"      => 'hk',
    "regiundadministraziunspezialamacao\,china"           => 'mo',
    'regiunmicronesica'                                   => '057',
    'republicacentralafricana'                            => 'cf',
    'republicademocraticadalcongo'                        => 'cd',
    'republicademocraticapopularadajemen'                 => 'yd',
    'republicadominicana'                                 => 'do',
    'republicatscheca'                                    => 'cz',
    'ruanda'                                              => 'rw',
    'rumenia'                                             => 'ro',
    'russia'                                              => 'ru',
    'réunion'                                            => 're',
    'saharaoccidentala'                                   => 'eh',
    'saintkittsenevis'                                    => 'kn',
    'saintlucia'                                          => 'lc',
    'saintmartin'                                         => 'mf',
    'saintpierreemiquelon'                                => 'pm',
    'saintvincentelasgrenadinas'                          => 'vc',
    'salomonas'                                           => 'sb',
    'sambia'                                              => 'zm',
    'samoa'                                               => 'ws',
    'samoaamericana'                                      => 'as',
    'sanmarino'                                           => 'sm',
    'senegal'                                             => 'sn',
    'serbia'                                              => 'rs',
    'serbiaemontenegro'                                   => 'cs',
    'seychellas'                                          => 'sc',
    'sierraleone'                                         => 'sl',
    'simbabwe'                                            => 'zw',
    'singapur'                                            => 'sg',
    'siria'                                               => 'sy',
    'slovachia'                                           => 'sk',
    'slovenia'                                            => 'si',
    'somalia'                                             => 'so',
    'sonbarthélemy'                                      => 'bl',
    'sontgelena'                                          => 'sh',
    'spagna'                                              => 'es',
    'srilanka'                                            => 'lk',
    'stadisunidsdalamerica'                               => 'us',
    'sudan'                                               => 'sd',
    'surinam'                                             => 'sr',
    'svalbardejanmayen'                                   => 'sj',
    'svezia'                                              => 'se',
    'svizra'                                              => 'ch',
    'swaziland'                                           => 'sz',
    'sãotoméeprincipe'                                  => 'st',
    'tadschikistan'                                       => 'tj',
    'tailanda'                                            => 'th',
    'taiwan'                                              => 'tw',
    'tansania'                                            => 'tz',
    'terradalareginamaud'                                 => 'nq',
    'territoriantarcticbritannic'                         => 'bq',
    'territoribritannicenloceanindic'                     => 'io',
    'territorifiduziardalasinslasdalpacific'              => 'pc',
    'territoripalestinais'                                => 'ps',
    'territorisfranzosmeridiunals'                        => 'tf',
    'territorismeridiunalsedantarcticsfranzos'            => 'fq',
    'timordalost'                                         => 'tl',
    'tirchia'                                             => 'tr',
    'togo'                                                => 'tg',
    'tokelau'                                             => 'tk',
    'tonga'                                               => 'to',
    'trinidadetobago'                                     => 'tt',
    'tristandacunha'                                      => 'ta',
    'tschad'                                              => 'td',
    'tschecoslovachia'                                    => 200,
    'tunesia'                                             => 'tn',
    'turkmenistan'                                        => 'tm',
    'tuvalu'                                              => 'tv',
    'ucraina'                                             => 'ua',
    'uganda'                                              => 'ug',
    'ungaria'                                             => 'hu',
    'uniuneuropeica'                                      => 'eu',
    'uniunsovietica'                                      => 'su',
    'uruguay'                                             => 'uy',
    'usbekistan'                                          => 'uz',
    'vanuatu'                                             => 'vu',
    'venezuela'                                           => 've',
    'vietnam'                                             => 'vn',
    'vietnamdalnord'                                      => 'vd',
    'wallisefutuna'                                       => 'wf',
    'zonadalcanaldapanama'                                => 'pz',
    'zonaneutrala'                                        => 'nt',
);

1;

