package Locales::DB::Territory::nyn;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::nyn::VERSION = '0.09';

$Locales::DB::Territory::nyn::cldr_version = '2.0';

%Locales::DB::Territory::nyn::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andora',
    'ae'  => "Amahanga\ ga\ Buharabu\ ageeteereine",
    'af'  => 'Afuganistani',
    'ag'  => "Angiguwa\ na\ Babuda",
    'ai'  => 'Angwira',
    'al'  => 'Arubania',
    'am'  => 'Arimeniya',
    'an'  => "Antiri\ za\ Hoorandi",
    'ao'  => 'Angora',
    'aq'  => 'Antarctica',
    'ar'  => 'Arigentina',
    'as'  => "Samowa\ ya\ Ameerika",
    'at'  => 'Osituria',
    'au'  => 'Ositureeriya',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azabagyani',
    'ba'  => "Boziniya\ na\ Hezegovina",
    'bb'  => 'Babadosi',
    'bd'  => 'Bangaradeshi',
    'be'  => 'Bubirigi',
    'bf'  => "Bokina\ Faso",
    'bg'  => 'Burugariya',
    'bh'  => 'Bahareni',
    'bi'  => 'Burundi',
    'bj'  => 'Benini',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Berimuda',
    'bn'  => 'Burunei',
    'bo'  => 'Boriiviya',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Buraziiri',
    'bs'  => 'Bahama',
    'bt'  => 'Butani',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswana',
    'by'  => 'Bararusi',
    'bz'  => 'Berize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Demokoratika\ Ripaaburika\ ya\ Kongo",
    'cf'  => "Eihanga\ rya\ Rwagati\ ya\ Afirika",
    'cg'  => 'Kongo',
    'ch'  => 'Swisi',
    'ci'  => "Aivore\ Kositi",
    'ck'  => "Ebizinga\ bya\ Kuuku",
    'cl'  => 'Chile',
    'cm'  => 'Kameruuni',
    'cn'  => 'China',
    'co'  => 'Korombiya',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kositarika',
    'cs'  => "Saabiya\ na\ Monteneguro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Ebizinga\ bya\ Kepuvade",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Saipurasi',
    'cz'  => "Ripaaburika\ ya\ Zeeki",
    'dd'  => "East\ Germany",
    'de'  => 'Bugirimaani',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Gyibuti',
    'dk'  => 'Deenimaaka',
    'dm'  => 'Dominika',
    'do'  => "Ripaaburika\ ya\ Dominica",
    'dz'  => 'Arigyeriya',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ikweda',
    'ee'  => 'Esitoniya',
    'eg'  => 'Misiri',
    'eh'  => "Western\ Sahara",
    'er'  => 'Eriteriya',
    'es'  => 'Sipeyini',
    'et'  => 'Ethiyopiya',
    'eu'  => "European\ Union",
    'fi'  => 'Bufini',
    'fj'  => 'Figyi',
    'fk'  => "Ebizinga\ bya\ Faakilanda",
    'fm'  => 'Mikironesiya',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Bufaransa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabooni',
    'gb'  => 'Bungyereza',
    'gd'  => 'Gurenada',
    'ge'  => 'Gyogiya',
    'gf'  => "Guyana\ ya\ Bufaransa",
    'gg'  => 'Guernsey',
    'gh'  => 'Gana',
    'gi'  => 'Giburaata',
    'gl'  => 'Guriinirandi',
    'gm'  => 'Gambiya',
    'gn'  => 'Gine',
    'gp'  => 'Gwaderupe',
    'gq'  => 'Guni',
    'gr'  => 'Guriisi',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatemara',
    'gu'  => 'Gwamu',
    'gw'  => 'Ginebisau',
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hondurasi',
    'hr'  => 'Korasiya',
    'ht'  => 'Haiti',
    'hu'  => 'Hangare',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indoneeziya',
    'ie'  => 'Irerandi',
    'il'  => 'Isirairi',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Indiya',
    'io'  => "Ebizinga\ bya\ Indian\ ebya\ Bungyereza",
    'iq'  => 'Iraaka',
    'ir'  => 'Iraani',
    'is'  => 'Aisilandi',
    'it'  => 'Itare',
    'je'  => 'Jersey',
    'jm'  => 'Gyamaika',
    'jo'  => 'Yorudaani',
    'jp'  => 'Gyapaani',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirigizistani',
    'kh'  => 'Kambodiya',
    'ki'  => 'Kiribati',
    'km'  => 'Koromo',
    'kn'  => "Senti\ Kittis\ na\ Nevisi",
    'kp'  => "Koreya\ Amatemba",
    'kr'  => "Koreya\ Amashuuma",
    'kw'  => 'Kuweiti',
    'ky'  => "Ebizinga\ bya\ Kayimani",
    'kz'  => 'Kazakisitani',
    'la'  => 'Layosi',
    'lb'  => 'Lebanoni',
    'lc'  => "Senti\ Rusiya",
    'li'  => 'Lishenteni',
    'lk'  => 'Siriranka',
    'lr'  => 'Liberiya',
    'ls'  => 'Lesotho',
    'lt'  => 'Lithuania',
    'lu'  => 'Lakizembaaga',
    'lv'  => 'Latviya',
    'ly'  => 'Libya',
    'ma'  => 'Morocco',
    'mc'  => 'Monaco',
    'md'  => 'Moridova',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagasika',
    'mh'  => "Ebizinga\ bya\ Marshaa",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedoonia',
    'ml'  => 'Mari',
    'mm'  => 'Myanamar',
    'mn'  => 'Mongoria',
    'mo'  => 'Macau',
    'mp'  => "Ebizinga\ by\'amatemba\ ga\ Mariana",
    'mq'  => 'Martinique',
    'mr'  => 'Mauriteeniya',
    'ms'  => 'Montserrati',
    'mt'  => 'Marita',
    'mu'  => 'Maurishiasi',
    'mv'  => 'Maridives',
    'mw'  => 'Marawi',
    'mx'  => 'Mexico',
    'my'  => 'marayizia',
    'mz'  => 'Mozambique',
    'na'  => 'Namibiya',
    'nc'  => 'Niukaredonia',
    'ne'  => 'Naigya',
    'nf'  => "Ekizinga\ Norifoko",
    'ng'  => 'Naigyeriya',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Hoorandi',
    'no'  => 'Noorwe',
    'np'  => 'Nepo',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => 'Niuzirandi',
    'om'  => 'Omaani',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polinesia\ ya\ Bufaransa",
    'pg'  => 'Papua',
    'ph'  => 'Firipino',
    'pk'  => 'Pakisitaani',
    'pl'  => 'Poorandi',
    'pm'  => "Senti\ Piyerre\ na\ Mikweron",
    'pn'  => 'Pitkaini',
    'pr'  => 'Pwetoriko',
    'ps'  => "Parestiina\ na\ Gaza",
    'pt'  => 'Pocugo',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palaawu',
    'py'  => 'Paragwai',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Kata',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Riyuniyoni',
    'ro'  => 'Romaniya',
    'rs'  => 'Serbia',
    'ru'  => 'Rrasha',
    'rw'  => 'Rwanda',
    'sa'  => "Saudi\ Areebiya",
    'sb'  => "Ebizinga\ bya\ Surimaani",
    'sc'  => 'Shesheresi',
    'sd'  => 'Sudani',
    'se'  => 'Swideni',
    'sg'  => 'Singapo',
    'sh'  => "Senti\ Herena",
    'si'  => 'Sirovaaniya',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Sirovaakiya',
    'sl'  => "Sirra\ Riyooni",
    'sm'  => 'Samarino',
    'sn'  => 'Senego',
    'so'  => 'Somaariya',
    'sr'  => 'Surinaamu',
    'st'  => "Sawo\ Tome\ na\ Purinsipo",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "Eri\ Salivado",
    'sy'  => 'Siriya',
    'sz'  => 'Swazirandi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Ebizinga\ bya\ Buturuki\ na\ Kaiko",
    'td'  => 'Chadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Tairandi',
    'tj'  => 'Tajikisitani',
    'tk'  => 'Tokerawu',
    'tl'  => "Burugweizooba\ bwa\ Timori",
    'tm'  => 'Turukimenisitani',
    'tn'  => 'Tunizia',
    'to'  => 'Tonga',
    'tr'  => "Buturuki\ \/Take",
    'tt'  => "Turinidad\ na\ Tobago",
    'tv'  => 'Tuvaru',
    'tw'  => 'Tayiwaani',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukureini',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Amerika',
    'uy'  => 'Urugwai',
    'uz'  => 'Uzibekisitani',
    'va'  => 'Vatikani',
    'vc'  => "Senti\ Vinsent\ na\ Gurenadini",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuwera',
    'vg'  => "Ebizinga\ bya\ Virigini\ ebya\ Bungyereza",
    'vi'  => "Ebizinga\ bya\ Virigini\ ebya\ Amerika",
    'vn'  => 'Viyetinaamu',
    'vu'  => 'Vanuatu',
    'wf'  => "Warris\ na\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samowa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemeni',
    'yt'  => 'Mayote',
    'za'  => "Sausi\ Afirika",
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::nyn::name_to_code = (
    'africa'                                    => '002',
    'afuganistani'                              => 'af',
    'aisilandi'                                 => 'is',
    'aivorekositi'                              => 'ci',
    'amahangagabuharabuageeteereine'            => 'ae',
    'americas'                                  => '019',
    'amerika'                                   => 'us',
    'andora'                                    => 'ad',
    'angiguwanababuda'                          => 'ag',
    'angora'                                    => 'ao',
    'angwira'                                   => 'ai',
    'antarctica'                                => 'aq',
    'antirizahoorandi'                          => 'an',
    'arigentina'                                => 'ar',
    'arigyeriya'                                => 'dz',
    'arimeniya'                                 => 'am',
    'aruba'                                     => 'aw',
    'arubania'                                  => 'al',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'azabagyani'                                => 'az',
    'babadosi'                                  => 'bb',
    'bahama'                                    => 'bs',
    'bahareni'                                  => 'bh',
    'bangaradeshi'                              => 'bd',
    'bararusi'                                  => 'by',
    'benini'                                    => 'bj',
    'berimuda'                                  => 'bm',
    'berize'                                    => 'bz',
    'bokinafaso'                                => 'bf',
    'boriiviya'                                 => 'bo',
    'botswana'                                  => 'bw',
    'bouvetisland'                              => 'bv',
    'boziniyanahezegovina'                      => 'ba',
    'britishantarcticterritory'                 => 'bq',
    'bubirigi'                                  => 'be',
    'bufaransa'                                 => 'fr',
    'bufini'                                    => 'fi',
    'bugirimaani'                               => 'de',
    'bungyereza'                                => 'gb',
    'buraziiri'                                 => 'br',
    'burugariya'                                => 'bg',
    'burugweizoobabwatimori'                    => 'tl',
    'burundi'                                   => 'bi',
    'burunei'                                   => 'bn',
    'butani'                                    => 'bt',
    "buturuki\/take"                            => 'tr',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'chadi'                                     => 'td',
    'channelislands'                            => 830,
    'chile'                                     => 'cl',
    'china'                                     => 'cn',
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'cuba'                                      => 'cu',
    'czechoslovakia'                            => 200,
    'deenimaaka'                                => 'dk',
    'demokoratikaripaaburikayakongo'            => 'cd',
    'diegogarcia'                               => 'dg',
    'dominika'                                  => 'dm',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ebizingabyabuturukinakaiko'                => 'tc',
    'ebizingabyafaakilanda'                     => 'fk',
    'ebizingabyaindianebyabungyereza'           => 'io',
    'ebizingabyakayimani'                       => 'ky',
    'ebizingabyakepuvade'                       => 'cv',
    'ebizingabyakuuku'                          => 'ck',
    'ebizingabyamarshaa'                        => 'mh',
    'ebizingabyamatembagamariana'               => 'mp',
    'ebizingabyasurimaani'                      => 'sb',
    'ebizingabyaviriginiebyaamerika'            => 'vi',
    'ebizingabyaviriginiebyabungyereza'         => 'vg',
    'eihangaryarwagatiyaafirika'                => 'cf',
    'ekizinganorifoko'                          => 'nf',
    'erisalivado'                               => 'sv',
    'eriteriya'                                 => 'er',
    'esitoniya'                                 => 'ee',
    'ethiyopiya'                                => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'figyi'                                     => 'fj',
    'firipino'                                  => 'ph',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabooni'                                   => 'ga',
    'gambiya'                                   => 'gm',
    'gana'                                      => 'gh',
    'giburaata'                                 => 'gi',
    'gine'                                      => 'gn',
    'ginebisau'                                 => 'gw',
    'guernsey'                                  => 'gg',
    'guni'                                      => 'gq',
    'gurenada'                                  => 'gd',
    'guriinirandi'                              => 'gl',
    'guriisi'                                   => 'gr',
    'guyana'                                    => 'gy',
    'guyanayabufaransa'                         => 'gf',
    'gwaderupe'                                 => 'gp',
    'gwamu'                                     => 'gu',
    'gwatemara'                                 => 'gt',
    'gyamaika'                                  => 'jm',
    'gyapaani'                                  => 'jp',
    'gyibuti'                                   => 'dj',
    'gyogiya'                                   => 'ge',
    'haiti'                                     => 'ht',
    'hangare'                                   => 'hu',
    'heardislandandmcdonaldislands'             => 'hm',
    'hondurasi'                                 => 'hn',
    'hongkong'                                  => 'hk',
    'hoorandi'                                  => 'nl',
    'ikweda'                                    => 'ec',
    'indiya'                                    => 'in',
    'indoneeziya'                               => 'id',
    'iraaka'                                    => 'iq',
    'iraani'                                    => 'ir',
    'irerandi'                                  => 'ie',
    'isirairi'                                  => 'il',
    'isleofman'                                 => 'im',
    'itare'                                     => 'it',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'kambodiya'                                 => 'kh',
    'kameruuni'                                 => 'cm',
    'kanada'                                    => 'ca',
    'kata'                                      => 'qa',
    'kazakisitani'                              => 'kz',
    'kenya'                                     => 'ke',
    'kiribati'                                  => 'ki',
    'kirigizistani'                             => 'kg',
    'kongo'                                     => 'cg',
    'korasiya'                                  => 'hr',
    'koreyaamashuuma'                           => 'kr',
    'koreyaamatemba'                            => 'kp',
    'korombiya'                                 => 'co',
    'koromo'                                    => 'km',
    'kositarika'                                => 'cr',
    'kuweiti'                                   => 'kw',
    'lakizembaaga'                              => 'lu',
    'latinamerica'                              => 419,
    'latviya'                                   => 'lv',
    'layosi'                                    => 'la',
    'lebanoni'                                  => 'lb',
    'lesotho'                                   => 'ls',
    'liberiya'                                  => 'lr',
    'libya'                                     => 'ly',
    'lishenteni'                                => 'li',
    'lithuania'                                 => 'lt',
    'macau'                                     => 'mo',
    'madagasika'                                => 'mg',
    'marawi'                                    => 'mw',
    'marayizia'                                 => 'my',
    'mari'                                      => 'ml',
    'maridives'                                 => 'mv',
    'marita'                                    => 'mt',
    'martinique'                                => 'mq',
    'masedoonia'                                => 'mk',
    'maurishiasi'                               => 'mu',
    'mauriteeniya'                              => 'mr',
    'mayote'                                    => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'mexico'                                    => 'mx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikironesiya'                              => 'fm',
    'misiri'                                    => 'eg',
    'monaco'                                    => 'mc',
    'mongoria'                                  => 'mn',
    'montenegro'                                => 'me',
    'montserrati'                               => 'ms',
    'moridova'                                  => 'md',
    'morocco'                                   => 'ma',
    'mozambique'                                => 'mz',
    'myanamar'                                  => 'mm',
    'naigya'                                    => 'ne',
    'naigyeriya'                                => 'ng',
    'namibiya'                                  => 'na',
    'nauru'                                     => 'nr',
    'nepo'                                      => 'np',
    'neutralzone'                               => 'nt',
    'nikaragwa'                                 => 'ni',
    'niue'                                      => 'nu',
    'niukaredonia'                              => 'nc',
    'niuzirandi'                                => 'nz',
    'noorwe'                                    => 'no',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'oceania'                                   => '009',
    'omaani'                                    => 'om',
    'ositureeriya'                              => 'au',
    'osituria'                                  => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakisitaani'                               => 'pk',
    'palaawu'                                   => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papua'                                     => 'pg',
    'paragwai'                                  => 'py',
    'parestiinanagaza'                          => 'ps',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitkaini'                                  => 'pn',
    'pocugo'                                    => 'pt',
    'polinesiayabufaransa'                      => 'pf',
    'polynesia'                                 => '061',
    'poorandi'                                  => 'pl',
    'pwetoriko'                                 => 'pr',
    'ripaaburikayadominica'                     => 'do',
    'ripaaburikayazeeki'                        => 'cz',
    'riyuniyoni'                                => 're',
    'romaniya'                                  => 'ro',
    'rrasha'                                    => 'ru',
    'rwanda'                                    => 'rw',
    'saabiyanamonteneguro'                      => 'cs',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'saipurasi'                                 => 'cy',
    'samarino'                                  => 'sm',
    'samowa'                                    => 'ws',
    'samowayaameerika'                          => 'as',
    'saudiareebiya'                             => 'sa',
    'sausiafirika'                              => 'za',
    'sawotomenapurinsipo'                       => 'st',
    'senego'                                    => 'sn',
    'sentiherena'                               => 'sh',
    'sentikittisnanevisi'                       => 'kn',
    'sentipiyerrenamikweron'                    => 'pm',
    'sentirusiya'                               => 'lc',
    'sentivinsentnagurenadini'                  => 'vc',
    'serbia'                                    => 'rs',
    'shesheresi'                                => 'sc',
    'singapo'                                   => 'sg',
    'sipeyini'                                  => 'es',
    'siriranka'                                 => 'lk',
    'siriya'                                    => 'sy',
    'sirovaakiya'                               => 'sk',
    'sirovaaniya'                               => 'si',
    'sirrariyooni'                              => 'sl',
    'somaariya'                                 => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'sudani'                                    => 'sd',
    'surinaamu'                                 => 'sr',
    'svalbardandjanmayen'                       => 'sj',
    'swazirandi'                                => 'sz',
    'swideni'                                   => 'se',
    'swisi'                                     => 'ch',
    'tairandi'                                  => 'th',
    'tajikisitani'                              => 'tj',
    'tanzania'                                  => 'tz',
    'tayiwaani'                                 => 'tw',
    'togo'                                      => 'tg',
    'tokerawu'                                  => 'tk',
    'tonga'                                     => 'to',
    'tristandacunha'                            => 'ta',
    'tunizia'                                   => 'tn',
    'turinidadnatobago'                         => 'tt',
    'turukimenisitani'                          => 'tm',
    'tuvaru'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukureini'                                  => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'urugwai'                                   => 'uy',
    'uzibekisitani'                             => 'uz',
    'vanuatu'                                   => 'vu',
    'vatikani'                                  => 'va',
    'venezuwera'                                => 've',
    'viyetinaamu'                               => 'vn',
    'wakeisland'                                => 'wk',
    'warrisnafutuna'                            => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yemeni'                                    => 'ye',
    'yorudaani'                                 => 'jo',
    'zambia'                                    => 'zm',
    'zimbabwe'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
);

1;

