package Locales::DB::Territory::mfe;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::mfe::VERSION = '0.09';

$Locales::DB::Territory::mfe::cldr_version = '2.0';

%Locales::DB::Territory::mfe::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andor',
    'ae'  => "Emira\ arab\ ini",
    'af'  => 'Afganistan',
    'ag'  => "Antigua\-ek\-Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albani',
    'am'  => 'Armeni',
    'an'  => "Antiy\ neerlande",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Larzantinn',
    'as'  => "Samoa\ amerikin",
    'at'  => 'Lostris',
    'au'  => 'Lostrali',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerbaïdjan',
    'ba'  => "Bosni\-Herzegovinn",
    'bb'  => 'Barbad',
    'bd'  => 'Banglades',
    'be'  => 'Belzik',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bilgari',
    'bh'  => 'Bahreïn',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermid',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivi',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brezil',
    'bs'  => 'Bahamas',
    'bt'  => 'Boutan',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswana',
    'by'  => 'Belaris',
    'bz'  => 'Beliz',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Repiblik\ demokratik\ Kongo",
    'cf'  => "Repiblik\ Lafrik\ Santral",
    'cg'  => 'Kongo',
    'ch'  => 'Laswis',
    'ci'  => "Côte\ d\'Ivoire",
    'ck'  => "Zil\ Cook",
    'cl'  => 'Shili',
    'cm'  => 'Kamerounn',
    'cn'  => 'Lasinn',
    'co'  => 'Kolonbi',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbi\-ek\-Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Kap\-Ver",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Cyprus',
    'cz'  => "Repiblik\ Chek",
    'dd'  => "East\ Germany",
    'de'  => 'Almagn',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Dannmark',
    'dm'  => 'Dominik',
    'do'  => "Repiblik\ dominikin",
    'dz'  => 'Alzeri',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwater',
    'ee'  => 'Estoni',
    'eg'  => 'Lezipt',
    'eh'  => "Western\ Sahara",
    'er'  => 'Erythre',
    'es'  => 'Lespagn',
    'et'  => 'Letiopi',
    'eu'  => "European\ Union",
    'fi'  => 'Finland',
    'fj'  => 'Fidji',
    'fk'  => "Zil\ malwinn",
    'fm'  => 'Mikronezi',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Lafrans',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => "United\ Kingdom",
    'gd'  => 'Grenad',
    'ge'  => 'Zeorzi',
    'gf'  => "Gwiyann\ franse",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Zibraltar',
    'gl'  => 'Greenland',
    'gm'  => 'Gambi',
    'gn'  => 'Gine',
    'gp'  => 'Guadloup',
    'gq'  => "Gine\ ekwatoryal",
    'gr'  => 'Gres',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Gine\-Bisau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Honduras',
    'hr'  => 'Kroasi',
    'ht'  => 'Ayti',
    'hu'  => 'Ongri',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonezi',
    'ie'  => 'Irland',
    'il'  => 'Izrael',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Lenn',
    'io'  => "Teritwar\ Britanik\ Losean\ Indien",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Itali',
    'je'  => 'Jersey',
    'jm'  => 'Zamaik',
    'jo'  => 'Zordani',
    'jp'  => 'Zapon',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirghizistan',
    'kh'  => 'Kambodj',
    'ki'  => 'Kiribati',
    'km'  => 'Komor',
    'kn'  => "Saint\-Christophe\-ek\-Niévès",
    'kp'  => "Lakore\-dinor",
    'kr'  => "Lakore\-disid",
    'kw'  => 'Koweit',
    'ky'  => "Zil\ Kayman",
    'kz'  => 'Kazakstan',
    'la'  => 'Laos',
    'lb'  => 'Liban',
    'lc'  => "Sainte\-Lucie",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lezoto',
    'lt'  => 'Lituani',
    'lu'  => 'Luxembourg',
    'lv'  => 'Letoni',
    'ly'  => 'Libi',
    'ma'  => 'Marok',
    'mc'  => 'Monako',
    'md'  => 'Moldavi',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => "Zil\ Marshall",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedwann',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongoli',
    'mo'  => 'Macau',
    'mp'  => "Zil\ Maryann\ dinor",
    'mq'  => 'Martinik',
    'mr'  => 'Moritani',
    'ms'  => 'Montsera',
    'mt'  => 'Malt',
    'mu'  => 'Moris',
    'mv'  => 'Maldiv',
    'mw'  => 'Malawi',
    'mx'  => 'Mexik',
    'my'  => 'Malezi',
    'mz'  => 'Mozambik',
    'na'  => 'Namibi',
    'nc'  => "Nouvel\-Kaledoni",
    'ne'  => 'Nizer',
    'nf'  => "Lil\ Norfolk",
    'ng'  => 'Nizeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Oland',
    'no'  => 'Norvez',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niowe',
    'nz'  => "Nouvel\ Zeland",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Perou',
    'pf'  => "Polinezi\ franse",
    'pg'  => "Papouazi\-Nouvel\-Gine",
    'ph'  => 'Filipinn',
    'pk'  => 'Pakistan',
    'pl'  => 'Pologn',
    'pm'  => "Saint\-Pierre\-ek\-Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Porto\ Rico",
    'ps'  => "Teritwar\ Palestinn",
    'pt'  => 'Portigal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katar',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Larenion',
    'ro'  => 'Roumani',
    'rs'  => 'Serbia',
    'ru'  => 'Larisi',
    'rw'  => 'Rwanda',
    'sa'  => "Larabi\ Saoudit",
    'sb'  => "Zil\ Salomon",
    'sc'  => 'Sesel',
    'sd'  => 'Soudan',
    'se'  => 'Laswed',
    'sg'  => 'Singapour',
    'sh'  => "Sainte\-Hélène",
    'si'  => 'Sloveni',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slovaki',
    'sl'  => "Sierra\ Leone",
    'sm'  => "Saint\-Marin",
    'sn'  => 'Senegal',
    'so'  => 'Somali',
    'sr'  => 'Surinam',
    'st'  => "São\ Tome\-ek\-Prínsip",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvador',
    'sy'  => 'Lasiri',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Zil\ Tirk\ ek\ Caïcos",
    'td'  => 'Tchad',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Thayland',
    'tj'  => 'Tadjikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ oriantal",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tinizi',
    'to'  => 'Tonga',
    'tr'  => 'Tirki',
    'tt'  => "Trinite\-ek\-Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzani',
    'ua'  => 'Ikrenn',
    'ug'  => 'Ouganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Lamerik',
    'uy'  => 'Uruguay',
    'uz'  => 'Ouzbekistan',
    'va'  => "Lata\ Vatikan",
    'vc'  => "Saint\-Vincent\-ek\-Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Zil\ vierz\ britanik",
    'vi'  => "Zil\ Vierz\ Lamerik",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\-ek\-Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemenn',
    'yt'  => 'Mayot',
    'za'  => "Sid\-Afrik",
    'zm'  => 'Zambi',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::mfe::name_to_code = (
    'afganistan'                                => 'af',
    'africa'                                    => '002',
    'albani'                                    => 'al',
    'almagn'                                    => 'de',
    'alzeri'                                    => 'dz',
    'americas'                                  => '019',
    'andor'                                     => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarctica'                                => 'aq',
    'antiguaekbarbuda'                          => 'ag',
    'antiyneerlande'                            => 'an',
    'armeni'                                    => 'am',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'ayti'                                      => 'ht',
    'azerbaïdjan'                              => 'az',
    'bahamas'                                   => 'bs',
    'bahreïn'                                  => 'bh',
    'banglades'                                 => 'bd',
    'barbad'                                    => 'bb',
    'belaris'                                   => 'by',
    'beliz'                                     => 'bz',
    'belzik'                                    => 'be',
    'benin'                                     => 'bj',
    'bermid'                                    => 'bm',
    'bilgari'                                   => 'bg',
    'bolivi'                                    => 'bo',
    'bosniherzegovinn'                          => 'ba',
    'botswana'                                  => 'bw',
    'boutan'                                    => 'bt',
    'bouvetisland'                              => 'bv',
    'brezil'                                    => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brunei'                                    => 'bn',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'costarica'                                 => 'cr',
    'cuba'                                      => 'cu',
    'cyprus'                                    => 'cy',
    'czechoslovakia'                            => 200,
    'côtedivoire'                              => 'ci',
    'dannmark'                                  => 'dk',
    'diegogarcia'                               => 'dg',
    'djibouti'                                  => 'dj',
    'dominik'                                   => 'dm',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekwater'                                   => 'ec',
    'emiraarabini'                              => 'ae',
    'erythre'                                   => 'er',
    'estoni'                                    => 'ee',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'fidji'                                     => 'fj',
    'filipinn'                                  => 'ph',
    'finland'                                   => 'fi',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gabon'                                     => 'ga',
    'gambi'                                     => 'gm',
    'ghana'                                     => 'gh',
    'gine'                                      => 'gn',
    'ginebisau'                                 => 'gw',
    'gineekwatoryal'                            => 'gq',
    'greenland'                                 => 'gl',
    'grenad'                                    => 'gd',
    'gres'                                      => 'gr',
    'guadloup'                                  => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guyana'                                    => 'gy',
    'gwiyannfranse'                             => 'gf',
    'heardislandandmcdonaldislands'             => 'hm',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'ikrenn'                                    => 'ua',
    'indonezi'                                  => 'id',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'irland'                                    => 'ie',
    'island'                                    => 'is',
    'isleofman'                                 => 'im',
    'itali'                                     => 'it',
    'izrael'                                    => 'il',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'kambodj'                                   => 'kh',
    'kamerounn'                                 => 'cm',
    'kanada'                                    => 'ca',
    'kapver'                                    => 'cv',
    'katar'                                     => 'qa',
    'kazakstan'                                 => 'kz',
    'kenya'                                     => 'ke',
    'kirghizistan'                              => 'kg',
    'kiribati'                                  => 'ki',
    'kolonbi'                                   => 'co',
    'komor'                                     => 'km',
    'kongo'                                     => 'cg',
    'koweit'                                    => 'kw',
    'kroasi'                                    => 'hr',
    'lafrans'                                   => 'fr',
    'lakoredinor'                               => 'kp',
    'lakoredisid'                               => 'kr',
    'lamerik'                                   => 'us',
    'laos'                                      => 'la',
    'larabisaoudit'                             => 'sa',
    'larenion'                                  => 're',
    'larisi'                                    => 'ru',
    'larzantinn'                                => 'ar',
    'lasinn'                                    => 'cn',
    'lasiri'                                    => 'sy',
    'laswed'                                    => 'se',
    'laswis'                                    => 'ch',
    'latavatikan'                               => 'va',
    'latinamerica'                              => 419,
    'lenn'                                      => 'in',
    'lespagn'                                   => 'es',
    'letiopi'                                   => 'et',
    'letoni'                                    => 'lv',
    'lezipt'                                    => 'eg',
    'lezoto'                                    => 'ls',
    'liban'                                     => 'lb',
    'liberia'                                   => 'lr',
    'libi'                                      => 'ly',
    'liechtenstein'                             => 'li',
    'lilnorfolk'                                => 'nf',
    'lituani'                                   => 'lt',
    'lostrali'                                  => 'au',
    'lostris'                                   => 'at',
    'luxembourg'                                => 'lu',
    'macau'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'malawi'                                    => 'mw',
    'maldiv'                                    => 'mv',
    'malezi'                                    => 'my',
    'mali'                                      => 'ml',
    'malt'                                      => 'mt',
    'marok'                                     => 'ma',
    'martinik'                                  => 'mq',
    'masedwann'                                 => 'mk',
    'mayot'                                     => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'mexik'                                     => 'mx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikronezi'                                 => 'fm',
    'moldavi'                                   => 'md',
    'monako'                                    => 'mc',
    'mongoli'                                   => 'mn',
    'montenegro'                                => 'me',
    'montsera'                                  => 'ms',
    'moris'                                     => 'mu',
    'moritani'                                  => 'mr',
    'mozambik'                                  => 'mz',
    'myanmar'                                   => 'mm',
    'namibi'                                    => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'niowe'                                     => 'nu',
    'nizer'                                     => 'ne',
    'nizeria'                                   => 'ng',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'norvez'                                    => 'no',
    'nouvelkaledoni'                            => 'nc',
    'nouvelzeland'                              => 'nz',
    'oceania'                                   => '009',
    'oland'                                     => 'nl',
    'oman'                                      => 'om',
    'ongri'                                     => 'hu',
    'ouganda'                                   => 'ug',
    'outlyingoceania'                           => 'qo',
    'ouzbekistan'                               => 'uz',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papouazinouvelgine'                        => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'perou'                                     => 'pe',
    'pitcairn'                                  => 'pn',
    'polinezifranse'                            => 'pf',
    'pologn'                                    => 'pl',
    'polynesia'                                 => '061',
    'portigal'                                  => 'pt',
    'portorico'                                 => 'pr',
    'repiblikchek'                              => 'cz',
    'repiblikdemokratikkongo'                   => 'cd',
    'repiblikdominikin'                         => 'do',
    'repibliklafriksantral'                     => 'cf',
    'roumani'                                   => 'ro',
    'rwanda'                                    => 'rw',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintchristopheekniévès'                 => 'kn',
    'saintehélène'                            => 'sh',
    'saintelucie'                               => 'lc',
    'saintmarin'                                => 'sm',
    'saintmartin'                               => 'mf',
    'saintpierreekmiquelon'                     => 'pm',
    'saintvincentekgrenadines'                  => 'vc',
    'salvador'                                  => 'sv',
    'samoa'                                     => 'ws',
    'samoaamerikin'                             => 'as',
    'senegal'                                   => 'sn',
    'serbia'                                    => 'rs',
    'serbiekmontenegro'                         => 'cs',
    'sesel'                                     => 'sc',
    'shili'                                     => 'cl',
    'sidafrik'                                  => 'za',
    'sierraleone'                               => 'sl',
    'singapour'                                 => 'sg',
    'slovaki'                                   => 'sk',
    'sloveni'                                   => 'si',
    'somali'                                    => 'so',
    'soudan'                                    => 'sd',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'srilanka'                                  => 'lk',
    'surinam'                                   => 'sr',
    'svalbardandjanmayen'                       => 'sj',
    'swaziland'                                 => 'sz',
    'sãotomeekprínsip'                        => 'st',
    'tadjikistan'                               => 'tj',
    'taiwan'                                    => 'tw',
    'tanzani'                                   => 'tz',
    'tchad'                                     => 'td',
    'teritwarbritanikloseanindien'              => 'io',
    'teritwarpalestinn'                         => 'ps',
    'thayland'                                  => 'th',
    'timororiantal'                             => 'tl',
    'tinizi'                                    => 'tn',
    'tirki'                                     => 'tr',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'triniteektobago'                           => 'tt',
    'tristandacunha'                            => 'ta',
    'turkmenistan'                              => 'tm',
    'tuvalu'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'unionofsovietsocialistrepublics'           => 'su',
    'unitedkingdom'                             => 'gb',
    'unknownregion'                             => 'zz',
    'uruguay'                                   => 'uy',
    'vanuatu'                                   => 'vu',
    'venezuela'                                 => 've',
    'vietnam'                                   => 'vn',
    'wakeisland'                                => 'wk',
    'wallisekfutuna'                            => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yemenn'                                    => 'ye',
    'zamaik'                                    => 'jm',
    'zambi'                                     => 'zm',
    'zapon'                                     => 'jp',
    'zeorzi'                                    => 'ge',
    'zibraltar'                                 => 'gi',
    'zilcook'                                   => 'ck',
    'zilkayman'                                 => 'ky',
    'zilmalwinn'                                => 'fk',
    'zilmarshall'                               => 'mh',
    'zilmaryanndinor'                           => 'mp',
    'zilsalomon'                                => 'sb',
    'ziltirkekcaïcos'                          => 'tc',
    'zilvierzbritanik'                          => 'vg',
    'zilvierzlamerik'                           => 'vi',
    'zimbabwe'                                  => 'zw',
    'zordani'                                   => 'jo',
    "\Ã\landislands"                         => 'ax',
);

1;

