package Locales::DB::Territory::he;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::he::VERSION = '0.09';

$Locales::DB::Territory::he::cldr_version = '2.0';

%Locales::DB::Territory::he::code_to_name = (
    '001' => 'העולם',
    '002' => 'אפריקה',
    '003' => "צפון\ אמריקה",
    '005' => "דרום\ אמריקה",
    '009' => 'אוקיאניה',
    '011' => "מערב\ אפריקה",
    '013' => "מרכז\ אמריקה",
    '014' => "מזרח\ אפריקה",
    '015' => "צפון\ אפריקה",
    '017' => "מרכז\ אפריקה",
    '018' => "דרום\ יבשת\ אפריקה",
    '019' => 'אמריקה',
    '021' => "אמריקה\ הצפונית",
    '029' => 'קריביים',
    '030' => "מזרח\ אסיה",
    '034' => "דרום\ אסיה",
    '035' => "דרום־מזרח\ אסיה",
    '039' => "דרום\ אירופה",
    '053' => "אוסטרליה\ וניו־זילנד",
    '054' => 'מלנסיה',
    '057' => "אזור\ מיקרונזיה",
    '061' => 'פולינזיה',
    '062' => "דרום־מרכז\ אסיה",
    142   => 'אסיה',
    143   => "מרכז\ אסיה",
    145   => "מערב\ אסיה",
    150   => 'אירופה',
    151   => "מזרח\ אירופה",
    154   => "צפון\ אירופה",
    155   => "מערב\ אירופה",
    172   => "חבר\ המדינות\ העצמאיות",
    200   => 'Czechoslovakia',
    419   => "אמריקה\ הלטינית",
    830   => "איי\ התעלה",
    'ac'  => "האי\ אסנשן",
    'ad'  => 'אנדורה',
    'ae'  => "איחוד\ האמירויות\ הערביות",
    'af'  => 'אפגניסטן',
    'ag'  => "אנטיגואה\ וברבודה",
    'ai'  => 'אנגילה',
    'al'  => 'אלבניה',
    'am'  => 'ארמניה',
    'an'  => "אנטילים\ הולנדיים",
    'ao'  => 'אנגולה',
    'aq'  => 'אנטארקטיקה',
    'ar'  => 'ארגנטינה',
    'as'  => "סמואה\ האמריקנית",
    'at'  => 'אוסטריה',
    'au'  => 'אוסטרליה',
    'aw'  => 'ארובה',
    'ax'  => "איי\ אלנד",
    'az'  => 'אזרביג׳ן',
    'ba'  => "בוסניה\ והרצגובינה",
    'bb'  => 'ברבדוס',
    'bd'  => 'בנגלדש',
    'be'  => 'בלגיה',
    'bf'  => "בורקינה\ פאסו",
    'bg'  => 'בולגריה',
    'bh'  => 'בחריין',
    'bi'  => 'בורונדי',
    'bj'  => 'בנין',
    'bl'  => "סנט\ ברתולומיאו",
    'bm'  => 'ברמודה',
    'bn'  => 'ברוניי',
    'bo'  => 'בוליביה',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'ברזיל',
    'bs'  => "איי\ בהאמה",
    'bt'  => 'בהוטן',
    'bv'  => "איי\ בובה",
    'bw'  => 'בוטסוואנה',
    'by'  => 'בלארוס',
    'bz'  => 'בליז',
    'ca'  => 'קנדה',
    'cc'  => "איי\ קוקוס",
    'cd'  => "קונגו\ \[הרפובליקה\ הדמוקרטית\ של\ קונגו\]",
    'cf'  => "הרפובליקה\ של\ מרכז\ אפריקה",
    'cg'  => "קונגו\ \[רפובליקה\]",
    'ch'  => 'שווייץ',
    'ci'  => "חוף\ השנהב",
    'ck'  => "איי\ קוק",
    'cl'  => 'צ׳ילה',
    'cm'  => 'קמרון',
    'cn'  => 'סין',
    'co'  => 'קולומביה',
    'cp'  => "האי\ קליפרטון",
    'cr'  => "קוסטה\ ריקה",
    'cs'  => "סרביה\ ומונטנגרו",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'קובה',
    'cv'  => "כף\ ורדה",
    'cx'  => "איי\ כריסטמס",
    'cy'  => 'קפריסין',
    'cz'  => 'צ׳כיה',
    'dd'  => "East\ Germany",
    'de'  => 'גרמניה',
    'dg'  => "דייגו\ גרסיה",
    'dj'  => 'ג׳יבוטי',
    'dk'  => 'דנמרק',
    'dm'  => 'דומיניקה',
    'do'  => "הרפובליקה\ הדומיניקנית",
    'dz'  => 'אלג׳יריה',
    'ea'  => "סאוטה\ ומלייה",
    'ec'  => 'אקוודור',
    'ee'  => 'אסטוניה',
    'eg'  => 'מצרים',
    'eh'  => "סהרה\ המערבית",
    'er'  => 'אריתראה',
    'es'  => 'ספרד',
    'et'  => 'אתיופיה',
    'eu'  => "האיחוד\ האירופי",
    'fi'  => 'פינלנד',
    'fj'  => 'פיג׳י',
    'fk'  => "איי\ פוקלנד\ \[איי\ מלווינס\]",
    'fm'  => 'מיקרונזיה',
    'fo'  => "איי\ פארו",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'צרפת',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'גאבון',
    'gb'  => 'בריטניה',
    'gd'  => 'גרנדה',
    'ge'  => 'גאורגיה',
    'gf'  => "גיאנה\ הצרפתית",
    'gg'  => 'גרנסי',
    'gh'  => 'גאנה',
    'gi'  => 'גיברלטר',
    'gl'  => 'גרינלנד',
    'gm'  => 'גמביה',
    'gn'  => 'גיניאה',
    'gp'  => 'גוואדלופ',
    'gq'  => "גיניאה\ המשוונית",
    'gr'  => 'יוון',
    'gs'  => "ג׳ורג׳יה\ הדרומית\ ואיי\ סנדוויץ׳\ הדרומיים",
    'gt'  => 'גואטמלה',
    'gu'  => 'גואם',
    'gw'  => "גיניאה\-ביסאו",
    'gy'  => 'גיאנה',
    'hk'  => "הונג\ קונג",
    'hm'  => "איי\ הרד\ ואיי\ מקדונלנד",
    'hn'  => 'הונדורס',
    'hr'  => 'קרואטיה',
    'ht'  => 'האיטי',
    'hu'  => 'הונגריה',
    'ic'  => "האיים\ הקנריים",
    'id'  => 'אינדונזיה',
    'ie'  => 'אירלנד',
    'il'  => 'ישראל',
    'im'  => "האי\ מאן",
    'in'  => 'הודו',
    'io'  => "טריטוריה\ בריטית\ באוקיאנוס\ ההודי",
    'iq'  => 'עיראק',
    'ir'  => 'איראן',
    'is'  => 'איסלנד',
    'it'  => 'איטליה',
    'je'  => 'ג׳רסי',
    'jm'  => 'ג׳מייקה',
    'jo'  => 'ירדן',
    'jp'  => 'יפן',
    'jt'  => "Johnston\ Island",
    'ke'  => 'קניה',
    'kg'  => 'קירגיזסטן',
    'kh'  => 'קמבודיה',
    'ki'  => 'קיריבאטי',
    'km'  => 'קומורוס',
    'kn'  => "סנט\ קיטס\ ונוויס",
    'kp'  => "צפון\ קוריאה",
    'kr'  => "דרום\ קוריאה",
    'kw'  => 'כווית',
    'ky'  => "איי\ קיימן",
    'kz'  => 'קזחסטן',
    'la'  => 'לאוס',
    'lb'  => 'לבנון',
    'lc'  => "סנט\ לוסיה",
    'li'  => 'ליכטנשטיין',
    'lk'  => "סרי\ לנקה",
    'lr'  => 'ליבריה',
    'ls'  => 'לסוטו',
    'lt'  => 'ליטא',
    'lu'  => 'לוקסמבורג',
    'lv'  => 'לטביה',
    'ly'  => 'לוב',
    'ma'  => 'מרוקו',
    'mc'  => 'מונקו',
    'md'  => 'מולדובה',
    'me'  => 'מונטנגרו',
    'mf'  => "סנט\ מרטין",
    'mg'  => 'מדגסקר',
    'mh'  => "איי\ מרשל",
    'mi'  => "Midway\ Islands",
    'mk'  => "מקדוניה\ \[הרפובליקה\ היוגוסלבית\ לשעבר\ מקדוניה\]",
    'ml'  => 'מאלי',
    'mm'  => 'מייאנמאר',
    'mn'  => 'מונגוליה',
    'mo'  => 'מקאו',
    'mp'  => "איי\ מריאנה\ הצפוניים",
    'mq'  => 'מרטיניק',
    'mr'  => 'מאוריטניה',
    'ms'  => 'מונסראט',
    'mt'  => 'מלטה',
    'mu'  => 'מאוריציוס',
    'mv'  => 'מלדיבים',
    'mw'  => 'מלאווי',
    'mx'  => 'מקסיקו',
    'my'  => 'מלזיה',
    'mz'  => 'מוזמביק',
    'na'  => 'נמיביה',
    'nc'  => "קלדוניה\ החדשה",
    'ne'  => 'ניז׳ר',
    'nf'  => "איי\ נורפוק",
    'ng'  => 'ניגריה',
    'ni'  => 'ניקרגואה',
    'nl'  => 'הולנד',
    'no'  => 'נורווגיה',
    'np'  => 'נפאל',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'נאורו',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'ניווה',
    'nz'  => "ניו\ זילנד",
    'om'  => 'עומאן',
    'pa'  => 'פנמה',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'פרו',
    'pf'  => "פולינזיה\ הצרפתית",
    'pg'  => "פפואה\ גיניאה\ החדשה",
    'ph'  => 'פיליפינים',
    'pk'  => 'פקיסטן',
    'pl'  => 'פולין',
    'pm'  => "סנט\ פייר\ ומיקלון",
    'pn'  => 'פיטקרן',
    'pr'  => "פורטו\ ריקו",
    'ps'  => "השטחים\ הפלסטיניים",
    'pt'  => 'פורטוגל',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'פאלאו',
    'py'  => 'פרגוואי',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'קטאר',
    'qo'  => "אוקיאניה\ פרושה",
    're'  => 'ראוניון',
    'ro'  => 'רומניה',
    'rs'  => 'סרביה',
    'ru'  => 'רוסיה',
    'rw'  => 'רואנדה',
    'sa'  => "ערב\ הסעודית",
    'sb'  => "איי\ שלמה",
    'sc'  => "איי\ סיישל",
    'sd'  => 'סודן',
    'se'  => 'שוודיה',
    'sg'  => 'סינגפור',
    'sh'  => "סנט\ הלנה",
    'si'  => 'סלובניה',
    'sj'  => "סוולבארד\ וז׳אן\ מאיין",
    'sk'  => 'סלובקיה',
    'sl'  => "סיירה\ לאונה",
    'sm'  => "סן\ מרינו",
    'sn'  => 'סנגל',
    'so'  => 'סומליה',
    'sr'  => 'סורינם',
    'st'  => "סאו\ טומה\ ופרינסיפה",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "אל\ סלבדור",
    'sy'  => 'סוריה',
    'sz'  => 'סווזילנד',
    'ta'  => "טריסטן\ דה\ קונה",
    'tc'  => "איי\ טורקס\ וקאיקוס",
    'td'  => 'צ׳אד',
    'tf'  => "טריטוריות\ דרומיות\ של\ צרפת",
    'tg'  => 'טוגו',
    'th'  => 'תאילנד',
    'tj'  => 'טג׳יקיסטן',
    'tk'  => 'טוקלאו',
    'tl'  => "מזרח\ טימור",
    'tm'  => 'טורקמניסטן',
    'tn'  => 'תוניסיה',
    'to'  => 'טונגה',
    'tr'  => 'טורקיה',
    'tt'  => "טרינידד\ וטובגו",
    'tv'  => 'טובלו',
    'tw'  => 'טייוואן',
    'tz'  => 'טנזניה',
    'ua'  => 'אוקראינה',
    'ug'  => 'אוגנדה',
    'um'  => "איים\ קטנים\ שלחוף\ ארצות\ הברית",
    'us'  => "ארצות\ הברית",
    'uy'  => 'אורוגוואי',
    'uz'  => 'אוזבקיסטן',
    'va'  => 'הוותיקן',
    'vc'  => "סנט\ וינסנט\ והגרנדינים",
    'vd'  => "North\ Vietnam",
    've'  => 'ונצואלה',
    'vg'  => "איי\ הבתולה\ הבריטיים",
    'vi'  => "איי\ הבתולה\ האמריקניים",
    'vn'  => 'וייטנאם',
    'vu'  => 'ונואטו',
    'wf'  => "איי\ ווליס\ ופוטונה",
    'wk'  => "Wake\ Island",
    'ws'  => 'סמואה',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'תימן',
    'yt'  => 'מאיוט',
    'za'  => "דרום\ אפריקה",
    'zm'  => 'זמביה',
    'zw'  => 'זימבאבווה',
    'zz'  => "אזור\ לא\ ידוע\ או\ לא\ תקין",
);

%Locales::DB::Territory::he::name_to_code = (
    'britishantarcticterritory'                                                    => 'bq',
    'cantonandenderburyislands'                                                    => 'ct',
    'czechoslovakia'                                                               => 200,
    'dronningmaudland'                                                             => 'nq',
    'eastgermany'                                                                  => 'dd',
    'frenchsouthernandantarcticterritories'                                        => 'fq',
    'johnstonisland'                                                               => 'jt',
    'metropolitanfrance'                                                           => 'fx',
    'midwayislands'                                                                => 'mi',
    'neutralzone'                                                                  => 'nt',
    'northvietnam'                                                                 => 'vd',
    'pacificislandstrustterritory'                                                 => 'pc',
    'panamacanalzone'                                                              => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                                    => 'yd',
    "u\.s\.miscellaneouspacificislands"                                            => 'pu',
    'unionofsovietsocialistrepublics'                                              => 'su',
    'wakeisland'                                                                   => 'wk',
    'אוגנדה'                                                                 => 'ug',
    'אוזבקיסטן'                                                           => 'uz',
    'אוסטריה'                                                               => 'at',
    'אוסטרליה'                                                             => 'au',
    'אוסטרליהוניו־זילנד'                                         => '053',
    'אוקיאניה'                                                             => '009',
    'אוקיאניהפרושה'                                                   => 'qo',
    'אוקראינה'                                                             => 'ua',
    'אורוגוואי'                                                           => 'uy',
    'אזורלאידועאולאתקין'                                         => 'zz',
    'אזורמיקרונזיה'                                                   => '057',
    'אזרביג׳ן'                                                             => 'az',
    'איחודהאמירויותהערביות'                                   => 'ae',
    'איטליה'                                                                 => 'it',
    'אייאלנד'                                                               => 'ax',
    'אייבהאמה'                                                             => 'bs',
    'אייבובה'                                                               => 'bv',
    'אייהבתולההאמריקניים'                                       => 'vi',
    'אייהבתולההבריטיים'                                           => 'vg',
    'אייהרדואיימקדונלנד'                                         => 'hm',
    'אייהתעלה'                                                             => 830,
    'אייווליסופוטונה'                                               => 'wf',
    'אייטורקסוקאיקוס'                                               => 'tc',
    'אייכריסטמס'                                                         => 'cx',
    'אייםקטניםשלחוףארצותהברית'                             => 'um',
    'איימריאנההצפוניים'                                           => 'mp',
    'איימרשל'                                                               => 'mh',
    'איינורפוק'                                                           => 'nf',
    'אייסיישל'                                                             => 'sc',
    'אייפארו'                                                               => 'fo',
    'אייפוקלנדאיימלווינס'                                       => 'fk',
    'אייקוק'                                                                 => 'ck',
    'אייקוקוס'                                                             => 'cc',
    'אייקיימן'                                                             => 'ky',
    'איישלמה'                                                               => 'sb',
    'אינדונזיה'                                                           => 'id',
    'איסלנד'                                                                 => 'is',
    'איראן'                                                                   => 'ir',
    'אירופה'                                                                 => 150,
    'אירלנד'                                                                 => 'ie',
    'אלבניה'                                                                 => 'al',
    'אלג׳יריה'                                                             => 'dz',
    'אלסלבדור'                                                             => 'sv',
    'אמריקה'                                                                 => '019',
    'אמריקההלטינית'                                                   => 419,
    'אמריקההצפונית'                                                   => '021',
    'אנגולה'                                                                 => 'ao',
    'אנגילה'                                                                 => 'ai',
    'אנדורה'                                                                 => 'ad',
    'אנטארקטיקה'                                                         => 'aq',
    'אנטיגואהוברבודה'                                               => 'ag',
    'אנטיליםהולנדיים'                                               => 'an',
    'אסטוניה'                                                               => 'ee',
    'אסיה'                                                                     => 142,
    'אפגניסטן'                                                             => 'af',
    'אפריקה'                                                                 => '002',
    'אקוודור'                                                               => 'ec',
    'ארגנטינה'                                                             => 'ar',
    'ארובה'                                                                   => 'aw',
    'אריתראה'                                                               => 'er',
    'ארמניה'                                                                 => 'am',
    'ארצותהברית'                                                         => 'us',
    'אתיופיה'                                                               => 'et',
    'בהוטן'                                                                   => 'bt',
    'בוטסוואנה'                                                           => 'bw',
    'בולגריה'                                                               => 'bg',
    'בוליביה'                                                               => 'bo',
    'בוסניהוהרצגובינה'                                             => 'ba',
    'בורונדי'                                                               => 'bi',
    'בורקינהפאסו'                                                       => 'bf',
    'בחריין'                                                                 => 'bh',
    'בלארוס'                                                                 => 'by',
    'בלגיה'                                                                   => 'be',
    'בליז'                                                                     => 'bz',
    'בנגלדש'                                                                 => 'bd',
    'בנין'                                                                     => 'bj',
    'ברבדוס'                                                                 => 'bb',
    'ברוניי'                                                                 => 'bn',
    'ברזיל'                                                                   => 'br',
    'בריטניה'                                                               => 'gb',
    'ברמודה'                                                                 => 'bm',
    'גאבון'                                                                   => 'ga',
    'גאורגיה'                                                               => 'ge',
    'גאנה'                                                                     => 'gh',
    'גואטמלה'                                                               => 'gt',
    'גואם'                                                                     => 'gu',
    'גוואדלופ'                                                             => 'gp',
    'גיאנה'                                                                   => 'gy',
    'גיאנההצרפתית'                                                     => 'gf',
    'גיברלטר'                                                               => 'gi',
    'גיניאה'                                                                 => 'gn',
    'גיניאהביסאו'                                                       => 'gw',
    'גיניאההמשוונית'                                                 => 'gq',
    'גמביה'                                                                   => 'gm',
    'גרינלנד'                                                               => 'gl',
    'גרמניה'                                                                 => 'de',
    'גרנדה'                                                                   => 'gd',
    'גרנסי'                                                                   => 'gg',
    'ג׳ורג׳יההדרומיתואייסנדוויץ׳הדרומיים'       => 'gs',
    'ג׳יבוטי'                                                               => 'dj',
    'ג׳מייקה'                                                               => 'jm',
    'ג׳רסי'                                                                   => 'je',
    'דומיניקה'                                                             => 'dm',
    'דייגוגרסיה'                                                         => 'dg',
    'דנמרק'                                                                   => 'dk',
    'דרום־מזרחאסיה'                                                   => '035',
    'דרום־מרכזאסיה'                                                   => '062',
    'דרוםאירופה'                                                         => '039',
    'דרוםאמריקה'                                                         => '005',
    'דרוםאסיה'                                                             => '034',
    'דרוםאפריקה'                                                         => 'za',
    'דרוםיבשתאפריקה'                                                 => '018',
    'דרוםקוריאה'                                                         => 'kr',
    'האיאסנשן'                                                             => 'ac',
    'האיחודהאירופי'                                                   => 'eu',
    'האיטי'                                                                   => 'ht',
    'האייםהקנריים'                                                     => 'ic',
    'האימאן'                                                                 => 'im',
    'האיקליפרטון'                                                       => 'cp',
    'הודו'                                                                     => 'in',
    'הוותיקן'                                                               => 'va',
    'הולנד'                                                                   => 'nl',
    'הונגקונג'                                                             => 'hk',
    'הונגריה'                                                               => 'hu',
    'הונדורס'                                                               => 'hn',
    'העולם'                                                                   => '001',
    'הרפובליקההדומיניקנית'                                     => 'do',
    'הרפובליקהשלמרכזאפריקה'                                   => 'cf',
    'השטחיםהפלסטיניים'                                             => 'ps',
    'וייטנאם'                                                               => 'vn',
    'ונואטו'                                                                 => 'vu',
    'ונצואלה'                                                               => 've',
    'זימבאבווה'                                                           => 'zw',
    'זמביה'                                                                   => 'zm',
    'חברהמדינותהעצמאיות'                                         => 172,
    'חוףהשנהב'                                                             => 'ci',
    'טג׳יקיסטן'                                                           => 'tj',
    'טובלו'                                                                   => 'tv',
    'טוגו'                                                                     => 'tg',
    'טונגה'                                                                   => 'to',
    'טוקלאו'                                                                 => 'tk',
    'טורקיה'                                                                 => 'tr',
    'טורקמניסטן'                                                         => 'tm',
    'טייוואן'                                                               => 'tw',
    'טנזניה'                                                                 => 'tz',
    'טריטוריהבריטיתבאוקיאנוסההודי'                     => 'io',
    'טריטוריותדרומיותשלצרפת'                                 => 'tf',
    'טרינידדוטובגו'                                                   => 'tt',
    'טריסטןדהקונה'                                                     => 'ta',
    'יוון'                                                                     => 'gr',
    'יפן'                                                                       => 'jp',
    'ירדן'                                                                     => 'jo',
    'ישראל'                                                                   => 'il',
    'כווית'                                                                   => 'kw',
    'כףורדה'                                                                 => 'cv',
    'לאוס'                                                                     => 'la',
    'לבנון'                                                                   => 'lb',
    'לוב'                                                                       => 'ly',
    'לוקסמבורג'                                                           => 'lu',
    'לטביה'                                                                   => 'lv',
    'ליבריה'                                                                 => 'lr',
    'ליטא'                                                                     => 'lt',
    'ליכטנשטיין'                                                         => 'li',
    'לסוטו'                                                                   => 'ls',
    'מאוריטניה'                                                           => 'mr',
    'מאוריציוס'                                                           => 'mu',
    'מאיוט'                                                                   => 'yt',
    'מאלי'                                                                     => 'ml',
    'מדגסקר'                                                                 => 'mg',
    'מוזמביק'                                                               => 'mz',
    'מולדובה'                                                               => 'md',
    'מונגוליה'                                                             => 'mn',
    'מונטנגרו'                                                             => 'me',
    'מונסראט'                                                               => 'ms',
    'מונקו'                                                                   => 'mc',
    'מזרחאירופה'                                                         => 151,
    'מזרחאסיה'                                                             => '030',
    'מזרחאפריקה'                                                         => '014',
    'מזרחטימור'                                                           => 'tl',
    'מייאנמאר'                                                             => 'mm',
    'מיקרונזיה'                                                           => 'fm',
    'מלאווי'                                                                 => 'mw',
    'מלדיבים'                                                               => 'mv',
    'מלזיה'                                                                   => 'my',
    'מלטה'                                                                     => 'mt',
    'מלנסיה'                                                                 => '054',
    'מערבאירופה'                                                         => 155,
    'מערבאסיה'                                                             => 145,
    'מערבאפריקה'                                                         => '011',
    'מצרים'                                                                   => 'eg',
    'מקאו'                                                                     => 'mo',
    'מקדוניההרפובליקההיוגוסלביתלשעברמקדוניה' => 'mk',
    'מקסיקו'                                                                 => 'mx',
    'מרוקו'                                                                   => 'ma',
    'מרטיניק'                                                               => 'mq',
    'מרכזאמריקה'                                                         => '013',
    'מרכזאסיה'                                                             => 143,
    'מרכזאפריקה'                                                         => '017',
    'נאורו'                                                                   => 'nr',
    'נורווגיה'                                                             => 'no',
    'ניגריה'                                                                 => 'ng',
    'ניווה'                                                                   => 'nu',
    'ניוזילנד'                                                             => 'nz',
    'ניז׳ר'                                                                   => 'ne',
    'ניקרגואה'                                                             => 'ni',
    'נמיביה'                                                                 => 'na',
    'נפאל'                                                                     => 'np',
    'סאוטהומלייה'                                                       => 'ea',
    'סאוטומהופרינסיפה'                                             => 'st',
    'סהרההמערבית'                                                       => 'eh',
    'סודן'                                                                     => 'sd',
    'סווזילנד'                                                             => 'sz',
    'סוולבארדוז׳אןמאיין'                                         => 'sj',
    'סומליה'                                                                 => 'so',
    'סוריה'                                                                   => 'sy',
    'סורינם'                                                                 => 'sr',
    'סיירהלאונה'                                                         => 'sl',
    'סין'                                                                       => 'cn',
    'סינגפור'                                                               => 'sg',
    'סלובניה'                                                               => 'si',
    'סלובקיה'                                                               => 'sk',
    'סמואה'                                                                   => 'ws',
    'סמואההאמריקנית'                                                 => 'as',
    'סןמרינו'                                                               => 'sm',
    'סנגל'                                                                     => 'sn',
    'סנטברתולומיאו'                                                   => 'bl',
    'סנטהלנה'                                                               => 'sh',
    'סנטוינסנטוהגרנדינים'                                       => 'vc',
    'סנטלוסיה'                                                             => 'lc',
    'סנטמרטין'                                                             => 'mf',
    'סנטפיירומיקלון'                                                 => 'pm',
    'סנטקיטסונוויס'                                                   => 'kn',
    'ספרד'                                                                     => 'es',
    'סרביה'                                                                   => 'rs',
    'סרביהומונטנגרו'                                                 => 'cs',
    'סרילנקה'                                                               => 'lk',
    'עומאן'                                                                   => 'om',
    'עיראק'                                                                   => 'iq',
    'ערבהסעודית'                                                         => 'sa',
    'פאלאו'                                                                   => 'pw',
    'פולין'                                                                   => 'pl',
    'פולינזיה'                                                             => '061',
    'פולינזיההצרפתית'                                               => 'pf',
    'פורטוגל'                                                               => 'pt',
    'פורטוריקו'                                                           => 'pr',
    'פיג׳י'                                                                   => 'fj',
    'פיטקרן'                                                                 => 'pn',
    'פיליפינים'                                                           => 'ph',
    'פינלנד'                                                                 => 'fi',
    'פנמה'                                                                     => 'pa',
    'פפואהגיניאההחדשה'                                             => 'pg',
    'פקיסטן'                                                                 => 'pk',
    'פרגוואי'                                                               => 'py',
    'פרו'                                                                       => 'pe',
    'צפוןאירופה'                                                         => 154,
    'צפוןאמריקה'                                                         => '003',
    'צפוןאפריקה'                                                         => '015',
    'צפוןקוריאה'                                                         => 'kp',
    'צרפת'                                                                     => 'fr',
    'צ׳אד'                                                                     => 'td',
    'צ׳ילה'                                                                   => 'cl',
    'צ׳כיה'                                                                   => 'cz',
    'קובה'                                                                     => 'cu',
    'קולומביה'                                                             => 'co',
    'קומורוס'                                                               => 'km',
    'קונגוהרפובליקההדמוקרטיתשלקונגו'                 => 'cd',
    'קונגורפובליקה'                                                   => 'cg',
    'קוסטהריקה'                                                           => 'cr',
    'קזחסטן'                                                                 => 'kz',
    'קטאר'                                                                     => 'qa',
    'קירגיזסטן'                                                           => 'kg',
    'קיריבאטי'                                                             => 'ki',
    'קלדוניההחדשה'                                                     => 'nc',
    'קמבודיה'                                                               => 'kh',
    'קמרון'                                                                   => 'cm',
    'קנדה'                                                                     => 'ca',
    'קניה'                                                                     => 'ke',
    'קפריסין'                                                               => 'cy',
    'קרואטיה'                                                               => 'hr',
    'קריביים'                                                               => '029',
    'ראוניון'                                                               => 're',
    'רואנדה'                                                                 => 'rw',
    'רומניה'                                                                 => 'ro',
    'רוסיה'                                                                   => 'ru',
    'שוודיה'                                                                 => 'se',
    'שווייץ'                                                                 => 'ch',
    'תאילנד'                                                                 => 'th',
    'תוניסיה'                                                               => 'tn',
    'תימן'                                                                     => 'ye',
);

1;

