package Locales::DB::Territory::wal;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::wal::VERSION = '0.09';

$Locales::DB::Territory::wal::cldr_version = '2.0';

%Locales::DB::Territory::wal::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'አንዶራ',
    'ae'  => "የተባበሩት\ አረብ\ ኤምሬትስ",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ and\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'አልባኒያ',
    'am'  => 'አርሜኒያ',
    'an'  => "ኔዘርላንድስ\ አንቲልስ",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'አርጀንቲና',
    'as'  => "American\ Samoa",
    'at'  => 'ኦስትሪያ',
    'au'  => 'አውስትሬሊያ',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'አዘርባጃን',
    'ba'  => "ቦስኒያ\ እና\ ሄርዞጎቪኒያ",
    'bb'  => 'ባርቤዶስ',
    'bd'  => 'Bangladesh',
    'be'  => 'ቤልጄም',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'ቡልጌሪያ',
    'bh'  => 'ባህሬን',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'ቤርሙዳ',
    'bn'  => 'Brunei',
    'bo'  => 'ቦሊቪያ',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'ብራዚል',
    'bs'  => 'Bahamas',
    'bt'  => 'ቡህታን',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswana',
    'by'  => 'ቤላሩስ',
    'bz'  => 'ቤሊዘ',
    'ca'  => 'Canada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => 'ኮንጎ',
    'cf'  => "የመካከለኛው\ አፍሪካ\ ሪፐብሊክ",
    'cg'  => "Congo\ \[Republic\]",
    'ch'  => 'ስዊዘርላንድ',
    'ci'  => "Ivory\ Coast",
    'ck'  => "Cook\ Islands",
    'cl'  => 'ቺሊ',
    'cm'  => 'ካሜሩን',
    'cn'  => 'ቻይና',
    'co'  => 'ኮሎምቢያ',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Costa\ Rica",
    'cs'  => 'ሰርቢያ',
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "ኬፕ\ ቬርዴ",
    'cx'  => "Christmas\ Island",
    'cy'  => 'ሳይፕረስ',
    'cz'  => "ቼክ\ ሪፑብሊክ",
    'dd'  => "East\ Germany",
    'de'  => 'ጀርመን',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'ዴንማርክ',
    'dm'  => 'ዶሚኒካ',
    'do'  => "ዶሚኒክ\ ሪፑብሊክ",
    'dz'  => 'አልጄሪያ',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'ኢኳዶር',
    'ee'  => 'ኤስቶኒያ',
    'eg'  => 'ግብጽ',
    'eh'  => "ምዕራባዊ\ ሳህራ",
    'er'  => 'ኤርትራ',
    'es'  => 'ስፔን',
    'et'  => 'ኢትዮጵያ',
    'eu'  => "European\ Union",
    'fi'  => 'ፊንላንድ',
    'fj'  => 'ፊጂ',
    'fk'  => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm'  => 'ሚክሮኔዢያ',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'ፈረንሳይ',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => 'እንግሊዝ',
    'gd'  => 'Grenada',
    'ge'  => 'ጆርጂያ',
    'gf'  => "የፈረንሳይ\ ጉዊአና",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Greenland',
    'gm'  => 'ጋምቢያ',
    'gn'  => 'ጊኒ',
    'gp'  => 'Guadeloupe',
    'gq'  => "ኢኳቶሪያል\ ጊኒ",
    'gr'  => 'ግሪክ',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => 'ቢሳዎ',
    'gy'  => 'ጉያና',
    'hk'  => "ሆንግ\ ኮንግ",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Honduras',
    'hr'  => 'ክሮኤሽያ',
    'ht'  => 'ሀይቲ',
    'hu'  => 'ሀንጋሪ',
    'ic'  => "Canary\ Islands",
    'id'  => 'ኢንዶኔዢያ',
    'ie'  => 'አየርላንድ',
    'il'  => 'እስራኤል',
    'im'  => "Isle\ of\ Man",
    'in'  => 'ህንድ',
    'io'  => "British\ Indian\ Ocean\ Territory",
    'iq'  => 'ኢራቅ',
    'ir'  => 'Iran',
    'is'  => 'አይስላንድ',
    'it'  => 'ጣሊያን',
    'je'  => 'Jersey',
    'jm'  => 'ጃማይካ',
    'jo'  => 'ጆርዳን',
    'jp'  => 'ጃፓን',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kyrgyzstan',
    'kh'  => 'ካምቦዲያ',
    'ki'  => 'Kiribati',
    'km'  => 'ኮሞሮስ',
    'kn'  => "Saint\ Kitts\ and\ Nevis",
    'kp'  => "ደቡብ\ ኮሪያ",
    'kr'  => "ሰሜን\ ኮሪያ",
    'kw'  => 'ክዌት',
    'ky'  => "Cayman\ Islands",
    'kz'  => 'Kazakhstan',
    'la'  => 'Laos',
    'lb'  => 'ሊባኖስ',
    'lc'  => "Saint\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'ሊቱዌኒያ',
    'lu'  => 'Luxembourg',
    'lv'  => 'ላትቪያ',
    'ly'  => 'ሊቢያ',
    'ma'  => 'ሞሮኮ',
    'mc'  => 'Monaco',
    'md'  => 'ሞልዶቫ',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagascar',
    'mh'  => "Marshall\ Islands",
    'mi'  => "Midway\ Islands",
    'mk'  => 'ማከዶኒያ',
    'ml'  => 'Mali',
    'mm'  => "Myanmar\ \[Burma\]",
    'mn'  => 'ሞንጎሊያ',
    'mo'  => 'ማካዎ',
    'mp'  => "Northern\ Mariana\ Islands",
    'mq'  => 'Martinique',
    'mr'  => 'ሞሪቴኒያ',
    'ms'  => 'Montserrat',
    'mt'  => 'ማልታ',
    'mu'  => 'ማሩሸስ',
    'mv'  => 'Maldives',
    'mw'  => 'Malawi',
    'mx'  => 'ሜክሲኮ',
    'my'  => 'ማሌዢያ',
    'mz'  => 'Mozambique',
    'na'  => 'ናሚቢያ',
    'nc'  => "ኒው\ ካሌዶኒያ",
    'ne'  => 'Niger',
    'nf'  => "Norfolk\ Island",
    'ng'  => 'ናይጄሪያ',
    'ni'  => 'Nicaragua',
    'nl'  => 'ኔዘርላንድ',
    'no'  => 'ኖርዌ',
    'np'  => 'ኔፓል',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "ኒው\ ዚላንድ",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'ፔሩ',
    'pf'  => "የፈረንሳይ\ ፖሊኔዢያ",
    'pg'  => "ፓፑዋ\ ኒው\ ጊኒ",
    'ph'  => 'Philippines',
    'pk'  => 'Pakistan',
    'pl'  => 'ፖላንድ',
    'pm'  => "Saint\ Pierre\ and\ Miquelon",
    'pn'  => "Pitcairn\ Islands",
    'pr'  => "ፖርታ\ ሪኮ",
    'ps'  => "Palestinian\ Territories",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Outlying\ Oceania",
    're'  => "R\Ã\©union",
    'ro'  => 'ሮሜኒያ',
    'rs'  => 'Serbia',
    'ru'  => 'ራሺያ',
    'rw'  => 'Rwanda',
    'sa'  => 'ሳውድአረቢያ',
    'sb'  => "Solomon\ Islands",
    'sc'  => 'Seychelles',
    'sd'  => 'ሱዳን',
    'se'  => 'ስዊድን',
    'sg'  => 'ሲንጋፖር',
    'sh'  => "Saint\ Helena",
    'si'  => 'ስሎቬኒያ',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'ስሎቫኪያ',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'ሴኔጋል',
    'so'  => 'ሱማሌ',
    'sr'  => 'Suriname',
    'st'  => "S\Ã\£o\ Tom\Ã\©\ and\ Pr\Ã\­ncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'ሲሪያ',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ and\ Caicos\ Islands",
    'td'  => 'ቻድ',
    'tf'  => "የፈረንሳይ\ ደቡባዊ\ ግዛቶች",
    'tg'  => 'Togo',
    'th'  => 'ታይላንድ',
    'tj'  => 'ታጃኪስታን',
    'tk'  => 'Tokelau',
    'tl'  => "ምስራቅ\ ቲሞር",
    'tm'  => 'Turkmenistan',
    'tn'  => 'ቱኒዚያ',
    'to'  => 'Tonga',
    'tr'  => 'ቱርክ',
    'tt'  => "ትሪኒዳድ\ እና\ ቶባጎ",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'ታንዛኒያ',
    'ua'  => 'Ukraine',
    'ug'  => 'ዩጋንዳ',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'አሜሪካ',
    'uy'  => 'Uruguay',
    'uz'  => 'ዩዝበኪስታን',
    'va'  => "Vatican\ City",
    'vc'  => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd'  => "North\ Vietnam",
    've'  => 'ቬንዙዌላ',
    'vg'  => "የእንግሊዝ\ ድንግል\ ደሴቶች",
    'vi'  => "የአሜሪካ\ ቨርጂን\ ደሴቶች",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ and\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'የመን',
    'yt'  => 'Mayotte',
    'za'  => "ደቡብ\ አፍሪካ",
    'zm'  => 'ዛምቢያ',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::wal::name_to_code = (
    'afghanistan'                                      => 'af',
    'africa'                                           => '002',
    'americansamoa'                                    => 'as',
    'americas'                                         => '019',
    'angola'                                           => 'ao',
    'anguilla'                                         => 'ai',
    'antarctica'                                       => 'aq',
    'antiguaandbarbuda'                                => 'ag',
    'aruba'                                            => 'aw',
    'ascensionisland'                                  => 'ac',
    'asia'                                             => 142,
    'australiaandnewzealand'                           => '053',
    'bahamas'                                          => 'bs',
    'bangladesh'                                       => 'bd',
    'benin'                                            => 'bj',
    'botswana'                                         => 'bw',
    'bouvetisland'                                     => 'bv',
    'britishantarcticterritory'                        => 'bq',
    'britishindianoceanterritory'                      => 'io',
    'brunei'                                           => 'bn',
    'burkinafaso'                                      => 'bf',
    'burundi'                                          => 'bi',
    'canada'                                           => 'ca',
    'canaryislands'                                    => 'ic',
    'cantonandenderburyislands'                        => 'ct',
    'caribbean'                                        => '029',
    'caymanislands'                                    => 'ky',
    'centralamerica'                                   => '013',
    'centralasia'                                      => 143,
    'ceutaandmelilla'                                  => 'ea',
    'channelislands'                                   => 830,
    'christmasisland'                                  => 'cx',
    'clippertonisland'                                 => 'cp',
    'cocoskeelingislands'                              => 'cc',
    'commonwealthofindependentstates'                  => 172,
    'congorepublic'                                    => 'cg',
    'cookislands'                                      => 'ck',
    'costarica'                                        => 'cr',
    'cuba'                                             => 'cu',
    'czechoslovakia'                                   => 200,
    'diegogarcia'                                      => 'dg',
    'djibouti'                                         => 'dj',
    'dronningmaudland'                                 => 'nq',
    'easternafrica'                                    => '014',
    'easternasia'                                      => '030',
    'easterneurope'                                    => 151,
    'eastgermany'                                      => 'dd',
    'elsalvador'                                       => 'sv',
    'europe'                                           => 150,
    'europeanunion'                                    => 'eu',
    'falklandislandsislasmalvinas'                     => 'fk',
    'faroeislands'                                     => 'fo',
    'frenchsouthernandantarcticterritories'            => 'fq',
    'gabon'                                            => 'ga',
    'ghana'                                            => 'gh',
    'gibraltar'                                        => 'gi',
    'greenland'                                        => 'gl',
    'grenada'                                          => 'gd',
    'guadeloupe'                                       => 'gp',
    'guam'                                             => 'gu',
    'guatemala'                                        => 'gt',
    'guernsey'                                         => 'gg',
    'heardislandandmcdonaldislands'                    => 'hm',
    'honduras'                                         => 'hn',
    'iran'                                             => 'ir',
    'isleofman'                                        => 'im',
    'ivorycoast'                                       => 'ci',
    'jersey'                                           => 'je',
    'johnstonisland'                                   => 'jt',
    'kazakhstan'                                       => 'kz',
    'kenya'                                            => 'ke',
    'kiribati'                                         => 'ki',
    'kyrgyzstan'                                       => 'kg',
    'laos'                                             => 'la',
    'latinamerica'                                     => 419,
    'lesotho'                                          => 'ls',
    'liberia'                                          => 'lr',
    'liechtenstein'                                    => 'li',
    'luxembourg'                                       => 'lu',
    'madagascar'                                       => 'mg',
    'malawi'                                           => 'mw',
    'maldives'                                         => 'mv',
    'mali'                                             => 'ml',
    'marshallislands'                                  => 'mh',
    'martinique'                                       => 'mq',
    'mayotte'                                          => 'yt',
    'melanesia'                                        => '054',
    'metropolitanfrance'                               => 'fx',
    'micronesianregion'                                => '057',
    'middleafrica'                                     => '017',
    'midwayislands'                                    => 'mi',
    'monaco'                                           => 'mc',
    'montenegro'                                       => 'me',
    'montserrat'                                       => 'ms',
    'mozambique'                                       => 'mz',
    'myanmarburma'                                     => 'mm',
    'nauru'                                            => 'nr',
    'neutralzone'                                      => 'nt',
    'nicaragua'                                        => 'ni',
    'niger'                                            => 'ne',
    'niue'                                             => 'nu',
    'norfolkisland'                                    => 'nf',
    'northamerica'                                     => '003',
    'northernafrica'                                   => '015',
    'northernamerica'                                  => '021',
    'northerneurope'                                   => 154,
    'northernmarianaislands'                           => 'mp',
    'northvietnam'                                     => 'vd',
    'oceania'                                          => '009',
    'oman'                                             => 'om',
    'outlyingoceania'                                  => 'qo',
    'pacificislandstrustterritory'                     => 'pc',
    'pakistan'                                         => 'pk',
    'palau'                                            => 'pw',
    'palestinianterritories'                           => 'ps',
    'panama'                                           => 'pa',
    'panamacanalzone'                                  => 'pz',
    'paraguay'                                         => 'py',
    "people\â\\sdemocraticrepublicofyemen"        => 'yd',
    'philippines'                                      => 'ph',
    'pitcairnislands'                                  => 'pn',
    'polynesia'                                        => '061',
    'portugal'                                         => 'pt',
    'qatar'                                            => 'qa',
    'rwanda'                                           => 'rw',
    "r\Ã\©union"                                     => 're',
    "saintbarth\Ã\©lemy"                             => 'bl',
    'sainthelena'                                      => 'sh',
    'saintkittsandnevis'                               => 'kn',
    'saintlucia'                                       => 'lc',
    'saintmartin'                                      => 'mf',
    'saintpierreandmiquelon'                           => 'pm',
    'saintvincentandthegrenadines'                     => 'vc',
    'samoa'                                            => 'ws',
    'sanmarino'                                        => 'sm',
    'serbia'                                           => 'rs',
    'seychelles'                                       => 'sc',
    'sierraleone'                                      => 'sl',
    'solomonislands'                                   => 'sb',
    'southamerica'                                     => '005',
    'southcentralasia'                                 => '062',
    'southeasternasia'                                 => '035',
    'southernafrica'                                   => '018',
    'southernasia'                                     => '034',
    'southerneurope'                                   => '039',
    'southgeorgiaandthesouthsandwichislands'           => 'gs',
    'srilanka'                                         => 'lk',
    'suriname'                                         => 'sr',
    'svalbardandjanmayen'                              => 'sj',
    'swaziland'                                        => 'sz',
    "s\Ã\£otom\Ã\©andpr\Ã\­ncipe"                => 'st',
    'taiwan'                                           => 'tw',
    'togo'                                             => 'tg',
    'tokelau'                                          => 'tk',
    'tonga'                                            => 'to',
    'tristandacunha'                                   => 'ta',
    'turkmenistan'                                     => 'tm',
    'turksandcaicosislands'                            => 'tc',
    'tuvalu'                                           => 'tv',
    "u\.s\.minoroutlyingislands"                       => 'um',
    "u\.s\.miscellaneouspacificislands"                => 'pu',
    'ukraine'                                          => 'ua',
    'unionofsovietsocialistrepublics'                  => 'su',
    'unknownregion'                                    => 'zz',
    'uruguay'                                          => 'uy',
    'vanuatu'                                          => 'vu',
    'vaticancity'                                      => 'va',
    'vietnam'                                          => 'vn',
    'wakeisland'                                       => 'wk',
    'wallisandfutuna'                                  => 'wf',
    'westernafrica'                                    => '011',
    'westernasia'                                      => 145,
    'westerneurope'                                    => 155,
    'world'                                            => '001',
    'zimbabwe'                                         => 'zw',
    "\Ã\landislands"                                => 'ax',
    'ሀንጋሪ'                                     => 'hu',
    'ሀይቲ'                                        => 'ht',
    'ህንድ'                                        => 'in',
    'ሆንግኮንግ'                               => 'hk',
    'ሊቢያ'                                        => 'ly',
    'ሊባኖስ'                                     => 'lb',
    'ሊቱዌኒያ'                                  => 'lt',
    'ላትቪያ'                                     => 'lv',
    'ሚክሮኔዢያ'                               => 'fm',
    'ማሌዢያ'                                     => 'my',
    'ማልታ'                                        => 'mt',
    'ማሩሸስ'                                     => 'mu',
    'ማከዶኒያ'                                  => 'mk',
    'ማካዎ'                                        => 'mo',
    'ሜክሲኮ'                                     => 'mx',
    'ምስራቅቲሞር'                            => 'tl',
    'ምዕራባዊሳህራ'                         => 'eh',
    'ሞልዶቫ'                                     => 'md',
    'ሞሪቴኒያ'                                  => 'mr',
    'ሞሮኮ'                                        => 'ma',
    'ሞንጎሊያ'                                  => 'mn',
    'ራሺያ'                                        => 'ru',
    'ሮሜኒያ'                                     => 'ro',
    'ሰሜንኮሪያ'                               => 'kr',
    'ሰርቢያ'                                     => 'cs',
    'ሱማሌ'                                        => 'so',
    'ሱዳን'                                        => 'sd',
    'ሲሪያ'                                        => 'sy',
    'ሲንጋፖር'                                  => 'sg',
    'ሳውድአረቢያ'                            => 'sa',
    'ሳይፕረስ'                                  => 'cy',
    'ሴኔጋል'                                     => 'sn',
    'ስሎቫኪያ'                                  => 'sk',
    'ስሎቬኒያ'                                  => 'si',
    'ስዊዘርላንድ'                            => 'ch',
    'ስዊድን'                                     => 'se',
    'ስፔን'                                        => 'es',
    'ቡህታን'                                     => 'bt',
    'ቡልጌሪያ'                                  => 'bg',
    'ቢሳዎ'                                        => 'gw',
    'ባህሬን'                                     => 'bh',
    'ባርቤዶስ'                                  => 'bb',
    'ቤሊዘ'                                        => 'bz',
    'ቤላሩስ'                                     => 'by',
    'ቤልጄም'                                     => 'be',
    'ቤርሙዳ'                                     => 'bm',
    'ብራዚል'                                     => 'br',
    'ቦሊቪያ'                                     => 'bo',
    'ቦስኒያእናሄርዞጎቪኒያ'          => 'ba',
    'ቬንዙዌላ'                                  => 've',
    'ቱርክ'                                        => 'tr',
    'ቱኒዚያ'                                     => 'tn',
    'ታንዛኒያ'                                  => 'tz',
    'ታይላንድ'                                  => 'th',
    'ታጃኪስታን'                               => 'tj',
    'ትሪኒዳድእናቶባጎ'                   => 'tt',
    'ቺሊ'                                           => 'cl',
    'ቻይና'                                        => 'cn',
    'ቻድ'                                           => 'td',
    'ቼክሪፑብሊክ'                            => 'cz',
    'ኒውካሌዶኒያ'                            => 'nc',
    'ኒውዚላንድ'                               => 'nz',
    'ናሚቢያ'                                     => 'na',
    'ናይጄሪያ'                                  => 'ng',
    'ኔዘርላንድ'                               => 'nl',
    'ኔዘርላንድስአንቲልስ'             => 'an',
    'ኔፓል'                                        => 'np',
    'ኖርዌ'                                        => 'no',
    'አልባኒያ'                                  => 'al',
    'አልጄሪያ'                                  => 'dz',
    'አሜሪካ'                                     => 'us',
    'አርሜኒያ'                                  => 'am',
    'አርጀንቲና'                               => 'ar',
    'አንዶራ'                                     => 'ad',
    'አውስትሬሊያ'                            => 'au',
    'አዘርባጃን'                               => 'az',
    'አየርላንድ'                               => 'ie',
    'አይስላንድ'                               => 'is',
    'ኢራቅ'                                        => 'iq',
    'ኢትዮጵያ'                                  => 'et',
    'ኢንዶኔዢያ'                               => 'id',
    'ኢኳቶሪያልጊኒ'                         => 'gq',
    'ኢኳዶር'                                     => 'ec',
    'ኤርትራ'                                     => 'er',
    'ኤስቶኒያ'                                  => 'ee',
    'እስራኤል'                                  => 'il',
    'እንግሊዝ'                                  => 'gb',
    'ኦስትሪያ'                                  => 'at',
    'ካሜሩን'                                     => 'cm',
    'ካምቦዲያ'                                  => 'kh',
    'ኬፕቬርዴ'                                  => 'cv',
    'ክሮኤሽያ'                                  => 'hr',
    'ክዌት'                                        => 'kw',
    'ኮሎምቢያ'                                  => 'co',
    'ኮሞሮስ'                                     => 'km',
    'ኮንጎ'                                        => 'cd',
    'ዛምቢያ'                                     => 'zm',
    'የመን'                                        => 'ye',
    'የመካከለኛውአፍሪካሪፐብሊክ' => 'cf',
    'የተባበሩትአረብኤምሬትስ'       => 'ae',
    'የአሜሪካቨርጂንደሴቶች'          => 'vi',
    'የእንግሊዝድንግልደሴቶች'       => 'vg',
    'የፈረንሳይደቡባዊግዛቶች'       => 'tf',
    'የፈረንሳይጉዊአና'                   => 'gf',
    'የፈረንሳይፖሊኔዢያ'                => 'pf',
    'ዩዝበኪስታን'                            => 'uz',
    'ዩጋንዳ'                                     => 'ug',
    'ደቡብአፍሪካ'                            => 'za',
    'ደቡብኮሪያ'                               => 'kp',
    'ዴንማርክ'                                  => 'dk',
    'ዶሚኒካ'                                     => 'dm',
    'ዶሚኒክሪፑብሊክ'                      => 'do',
    'ጀርመን'                                     => 'de',
    'ጃማይካ'                                     => 'jm',
    'ጃፓን'                                        => 'jp',
    'ጆርዳን'                                     => 'jo',
    'ጆርጂያ'                                     => 'ge',
    'ጉያና'                                        => 'gy',
    'ጊኒ'                                           => 'gn',
    'ጋምቢያ'                                     => 'gm',
    'ግሪክ'                                        => 'gr',
    'ግብጽ'                                        => 'eg',
    'ጣሊያን'                                     => 'it',
    'ፈረንሳይ'                                  => 'fr',
    'ፊንላንድ'                                  => 'fi',
    'ፊጂ'                                           => 'fj',
    'ፓፑዋኒውጊኒ'                            => 'pg',
    'ፔሩ'                                           => 'pe',
    'ፖላንድ'                                     => 'pl',
    'ፖርታሪኮ'                                  => 'pr',
);

1;

