package Locales::DB::Territory::lu;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::lu::VERSION = '0.09';

$Locales::DB::Territory::lu::cldr_version = '2.0';

%Locales::DB::Territory::lu::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andore',
    'ae'  => "Lemila\ alabu",
    'af'  => 'Afuganisita',
    'ag'  => "Antiga\ ne\ Barbuda",
    'ai'  => 'Angiye',
    'al'  => 'Alubani',
    'am'  => 'Ameni',
    'an'  => "Antiye\ wa\ Olande",
    'ao'  => 'Angola',
    'aq'  => 'Antarctica',
    'ar'  => 'Alijantine',
    'as'  => "Samoa\ wa\ Ameriki",
    'at'  => 'Otilisi',
    'au'  => 'Ositali',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Ajelbayidja',
    'ba'  => "Mbosini\ ne\ Hezegovine",
    'bb'  => 'Barebade',
    'bd'  => 'Benguladeshi',
    'be'  => 'Belejiki',
    'bf'  => 'Bukinafaso',
    'bg'  => 'Biligari',
    'bh'  => 'Bahrene',
    'bi'  => 'Burundi',
    'bj'  => 'Bene',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brineyi',
    'bo'  => 'Mbolivi',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Mnulezile',
    'bs'  => 'Bahamase',
    'bt'  => 'Butani',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Mbotswana',
    'by'  => 'Byelorisi',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Ditunga\ wa\ Kongu",
    'cf'  => "Ditunga\ dya\ Afrika\ wa\ munkatshi",
    'cg'  => 'Kongu',
    'ch'  => 'Swise',
    'ci'  => 'Kotedivuale',
    'ck'  => "Lutanda\ lua\ Kookɛ",
    'cl'  => 'Shili',
    'cm'  => 'Kamerune',
    'cn'  => 'Shine',
    'co'  => 'Kolombi',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kositarika',
    'cs'  => "Nsebi\ ne\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Lutanda\ lua\ Kapevele",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Shipele',
    'cz'  => "Ditunga\ dya\ Tsheka",
    'dd'  => "East\ Germany",
    'de'  => 'Alemanu',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibuti',
    'dk'  => 'Danemalaku',
    'dm'  => 'Duminiku',
    'do'  => "Ditunga\ wa\ Duminiku",
    'dz'  => 'Alijeri',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwatele',
    'ee'  => 'Esitoni',
    'eg'  => 'Mushidi',
    'eh'  => "Western\ Sahara",
    'er'  => 'Elitele',
    'es'  => 'Nsipani',
    'et'  => 'Etshiopi',
    'eu'  => "European\ Union",
    'fi'  => 'Filande',
    'fj'  => 'Fuji',
    'fk'  => "Lutanda\ lua\ Maluni",
    'fm'  => 'Mikronezi',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Nfalanse',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Ngabu',
    'gb'  => 'Angeletele',
    'gd'  => 'Ngelenade',
    'ge'  => 'Joriji',
    'gf'  => "Giyane\ wa\ Nfalanse",
    'gg'  => 'Guernsey',
    'gh'  => 'Ngana',
    'gi'  => 'Jibeletale',
    'gl'  => 'Ngowelande',
    'gm'  => 'Gambi',
    'gn'  => 'Ngine',
    'gp'  => 'Ngwadelupe',
    'gq'  => "Gine\ Ekwatele",
    'gr'  => 'Ngeleka',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Ngwatemala',
    'gu'  => 'Ngwame',
    'gw'  => 'Nginebisau',
    'gy'  => 'Ngiyane',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Ondurase',
    'hr'  => 'Krowasi',
    'ht'  => 'Ayiti',
    'hu'  => 'Ongili',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indonezi',
    'ie'  => 'Irelande',
    'il'  => 'Isirayele',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Inde',
    'io'  => "Lutanda\ lwa\ Angeletele\ ku\ mbu\ wa\ Indiya",
    'iq'  => 'Iraki',
    'ir'  => 'Ira',
    'is'  => 'Isilande',
    'it'  => 'Itali',
    'je'  => 'Jersey',
    'jm'  => 'Jamaiki',
    'jo'  => 'Jodani',
    'jp'  => 'Japu',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kigizisita',
    'kh'  => 'Kambodza',
    'ki'  => 'Kiribati',
    'km'  => 'Komoru',
    'kn'  => "Santu\ krístofe\ ne\ Neves",
    'kp'  => "Kore\ wa\ muulu",
    'kr'  => "Kore\ wa\ mwinshi",
    'kw'  => 'Koweti',
    'ky'  => "Lutanda\ lua\ Kayima",
    'kz'  => 'Kazakusita',
    'la'  => 'Lawosi',
    'lb'  => 'Liba',
    'lc'  => "Santu\ lisi",
    'li'  => 'Lishuteni',
    'lk'  => 'Sirilanka',
    'lr'  => 'Liberiya',
    'ls'  => 'Lesoto',
    'lt'  => 'Litwani',
    'lu'  => 'Likisambulu',
    'lv'  => 'Letoni',
    'ly'  => 'Libi',
    'ma'  => 'Maroke',
    'mc'  => 'Monaku',
    'md'  => 'Molidavi',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagasikari',
    'mh'  => "Lutanda\ lua\ Marishale",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Masedwane',
    'ml'  => 'Mali',
    'mm'  => 'Myamare',
    'mn'  => 'Mongoli',
    'mo'  => 'Macau',
    'mp'  => "Lutanda\ lua\ Mariane\ wa\ muulu",
    'mq'  => 'Martiniki',
    'mr'  => 'Moritani',
    'ms'  => 'Musera',
    'mt'  => 'Malite',
    'mu'  => 'Morise',
    'mv'  => 'Madive',
    'mw'  => 'Malawi',
    'mx'  => 'Meksike',
    'my'  => 'Malezi',
    'mz'  => 'Mozambiki',
    'na'  => 'Namibi',
    'nc'  => "Kaledoni\ wa\ mumu",
    'ne'  => 'Nijere',
    'nf'  => "Lutanda\ lua\ Norfok",
    'ng'  => 'Nijerya',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Olandɛ',
    'no'  => 'Noriveje',
    'np'  => 'Nepálɛ',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Nyue',
    'nz'  => "Zelanda\ wa\ mumu",
    'om'  => 'Omane',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Polinezi\ wa\ Nfalanse",
    'pg'  => "Papwazi\ wa\ Nginɛ\ wa\ mumu",
    'ph'  => 'Nfilipi',
    'pk'  => 'Pakisita',
    'pl'  => 'Mpoloni',
    'pm'  => "Santu\ pététo\ ne\ Mikelu",
    'pn'  => 'Pikairni',
    'pr'  => 'Mpotoriku',
    'ps'  => 'Palesine',
    'pt'  => 'Mputulugeshi',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Palagwei',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katari',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Lenyo',
    'ro'  => 'Romani',
    'rs'  => 'Serbia',
    'ru'  => 'Risi',
    'rw'  => 'Rwanda',
    'sa'  => "Alabu\ Nsawudi",
    'sb'  => "Lutanda\ lua\ Solomu",
    'sc'  => 'Seshele',
    'sd'  => 'Suda',
    'se'  => 'Suwedi',
    'sg'  => 'Singapure',
    'sh'  => "Santu\ eleni",
    'si'  => 'Siloveni',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Silovaki',
    'sl'  => "Siera\ Leone",
    'sm'  => "Santu\ Marine",
    'sn'  => 'Senegale',
    'so'  => 'Somali',
    'sr'  => 'Suriname',
    'st'  => "Sao\ Tome\ ne\ Presipɛ",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Savadore',
    'sy'  => 'Siri',
    'sz'  => 'Swazilandi',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Lutanda\ lua\ Tuluki\ ne\ Kaiko",
    'td'  => 'Tshadi',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togu',
    'th'  => 'Tayilanda',
    'tj'  => 'Tazikisita',
    'tk'  => 'Tokelau',
    'tl'  => "Timoru\ wa\ diboku",
    'tm'  => 'Tukemenisita',
    'tn'  => 'Tinizi',
    'to'  => 'Tonga',
    'tr'  => 'Tuluki',
    'tt'  => "Tinidade\ ne\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwani',
    'tz'  => 'Tanzani',
    'ua'  => 'Ukreni',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'Ameriki',
    'uy'  => 'Irigwei',
    'uz'  => 'Uzibekisita',
    'va'  => 'Nvatika',
    'vc'  => "Santu\ vesa\ ne\ Ngelenadine",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Lutanda\ lua\ Vierzi\ wa\ Angeletele",
    'vi'  => "Lutanda\ lua\ Vierzi\ wa\ Ameriki",
    'vn'  => 'Viyetiname',
    'vu'  => 'Vanuatu',
    'wf'  => "Walise\ ne\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemenu',
    'yt'  => 'Mayote',
    'za'  => "Afrika\ ya\ Súdi",
    'zm'  => 'Zambi',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::lu::name_to_code = (
    'africa'                                    => '002',
    'afrikayasúdi'                             => 'za',
    'afuganisita'                               => 'af',
    'ajelbayidja'                               => 'az',
    'alabunsawudi'                              => 'sa',
    'alemanu'                                   => 'de',
    'alijantine'                                => 'ar',
    'alijeri'                                   => 'dz',
    'alubani'                                   => 'al',
    'ameni'                                     => 'am',
    'americas'                                  => '019',
    'ameriki'                                   => 'us',
    'andore'                                    => 'ad',
    'angeletele'                                => 'gb',
    'angiye'                                    => 'ai',
    'angola'                                    => 'ao',
    'antarctica'                                => 'aq',
    'antiganebarbuda'                           => 'ag',
    'antiyewaolande'                            => 'an',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'ayiti'                                     => 'ht',
    'bahamase'                                  => 'bs',
    'bahrene'                                   => 'bh',
    'barebade'                                  => 'bb',
    'belejiki'                                  => 'be',
    'belize'                                    => 'bz',
    'bene'                                      => 'bj',
    'benguladeshi'                              => 'bd',
    'bermuda'                                   => 'bm',
    'biligari'                                  => 'bg',
    'bouvetisland'                              => 'bv',
    'brineyi'                                   => 'bn',
    'britishantarcticterritory'                 => 'bq',
    'bukinafaso'                                => 'bf',
    'burundi'                                   => 'bi',
    'butani'                                    => 'bt',
    'byelorisi'                                 => 'by',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danemalaku'                                => 'dk',
    'diegogarcia'                               => 'dg',
    'ditungadyaafrikawamunkatshi'               => 'cf',
    'ditungadyatsheka'                          => 'cz',
    'ditungawaduminiku'                         => 'do',
    'ditungawakongu'                            => 'cd',
    'djibuti'                                   => 'dj',
    'dronningmaudland'                          => 'nq',
    'duminiku'                                  => 'dm',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekwatele'                                  => 'ec',
    'elitele'                                   => 'er',
    'esitoni'                                   => 'ee',
    'etshiopi'                                  => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'filande'                                   => 'fi',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'fuji'                                      => 'fj',
    'gambi'                                     => 'gm',
    'gineekwatele'                              => 'gq',
    'giyanewanfalanse'                          => 'gf',
    'guernsey'                                  => 'gg',
    'heardislandandmcdonaldislands'             => 'hm',
    'hongkong'                                  => 'hk',
    'inde'                                      => 'in',
    'indonezi'                                  => 'id',
    'ira'                                       => 'ir',
    'iraki'                                     => 'iq',
    'irelande'                                  => 'ie',
    'irigwei'                                   => 'uy',
    'isilande'                                  => 'is',
    'isirayele'                                 => 'il',
    'isleofman'                                 => 'im',
    'itali'                                     => 'it',
    'jamaiki'                                   => 'jm',
    'japu'                                      => 'jp',
    'jersey'                                    => 'je',
    'jibeletale'                                => 'gi',
    'jodani'                                    => 'jo',
    'johnstonisland'                            => 'jt',
    'joriji'                                    => 'ge',
    'kaledoniwamumu'                            => 'nc',
    'kambodza'                                  => 'kh',
    'kamerune'                                  => 'cm',
    'kanada'                                    => 'ca',
    'katari'                                    => 'qa',
    'kazakusita'                                => 'kz',
    'kenya'                                     => 'ke',
    'kigizisita'                                => 'kg',
    'kiribati'                                  => 'ki',
    'kolombi'                                   => 'co',
    'komoru'                                    => 'km',
    'kongu'                                     => 'cg',
    'korewamuulu'                               => 'kp',
    'korewamwinshi'                             => 'kr',
    'kositarika'                                => 'cr',
    'kotedivuale'                               => 'ci',
    'koweti'                                    => 'kw',
    'krowasi'                                   => 'hr',
    'kuba'                                      => 'cu',
    'latinamerica'                              => 419,
    'lawosi'                                    => 'la',
    'lemilaalabu'                               => 'ae',
    'lenyo'                                     => 're',
    'lesoto'                                    => 'ls',
    'letoni'                                    => 'lv',
    'liba'                                      => 'lb',
    'liberiya'                                  => 'lr',
    'libi'                                      => 'ly',
    'likisambulu'                               => 'lu',
    'lishuteni'                                 => 'li',
    'litwani'                                   => 'lt',
    'lutandaluakapevele'                        => 'cv',
    'lutandaluakayima'                          => 'ky',
    'lutandaluakookɛ'                          => 'ck',
    'lutandaluamaluni'                          => 'fk',
    'lutandaluamarianewamuulu'                  => 'mp',
    'lutandaluamarishale'                       => 'mh',
    'lutandaluanorfok'                          => 'nf',
    'lutandaluasolomu'                          => 'sb',
    'lutandaluatulukinekaiko'                   => 'tc',
    'lutandaluavierziwaameriki'                 => 'vi',
    'lutandaluavierziwaangeletele'              => 'vg',
    'lutandalwaangeletelekumbuwaindiya'         => 'io',
    'macau'                                     => 'mo',
    'madagasikari'                              => 'mg',
    'madive'                                    => 'mv',
    'malawi'                                    => 'mw',
    'malezi'                                    => 'my',
    'mali'                                      => 'ml',
    'malite'                                    => 'mt',
    'maroke'                                    => 'ma',
    'martiniki'                                 => 'mq',
    'masedwane'                                 => 'mk',
    'mayote'                                    => 'yt',
    'mbolivi'                                   => 'bo',
    'mbosininehezegovine'                       => 'ba',
    'mbotswana'                                 => 'bw',
    'meksike'                                   => 'mx',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikronezi'                                 => 'fm',
    'mnulezile'                                 => 'br',
    'molidavi'                                  => 'md',
    'monaku'                                    => 'mc',
    'mongoli'                                   => 'mn',
    'montenegro'                                => 'me',
    'morise'                                    => 'mu',
    'moritani'                                  => 'mr',
    'mozambiki'                                 => 'mz',
    'mpoloni'                                   => 'pl',
    'mpotoriku'                                 => 'pr',
    'mputulugeshi'                              => 'pt',
    'musera'                                    => 'ms',
    'mushidi'                                   => 'eg',
    'myamare'                                   => 'mm',
    'namibi'                                    => 'na',
    'nauru'                                     => 'nr',
    'nepálɛ'                                  => 'np',
    'neutralzone'                               => 'nt',
    'nfalanse'                                  => 'fr',
    'nfilipi'                                   => 'ph',
    'ngabu'                                     => 'ga',
    'ngana'                                     => 'gh',
    'ngeleka'                                   => 'gr',
    'ngelenade'                                 => 'gd',
    'ngine'                                     => 'gn',
    'nginebisau'                                => 'gw',
    'ngiyane'                                   => 'gy',
    'ngowelande'                                => 'gl',
    'ngwadelupe'                                => 'gp',
    'ngwame'                                    => 'gu',
    'ngwatemala'                                => 'gt',
    'nijere'                                    => 'ne',
    'nijerya'                                   => 'ng',
    'nikaragwa'                                 => 'ni',
    'noriveje'                                  => 'no',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'nsebinemontenegro'                         => 'cs',
    'nsipani'                                   => 'es',
    'nvatika'                                   => 'va',
    'nyue'                                      => 'nu',
    'oceania'                                   => '009',
    'olandɛ'                                   => 'nl',
    'omane'                                     => 'om',
    'ondurase'                                  => 'hn',
    'ongili'                                    => 'hu',
    'ositali'                                   => 'au',
    'otilisi'                                   => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakisita'                                  => 'pk',
    'palagwei'                                  => 'py',
    'palau'                                     => 'pw',
    'palesine'                                  => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papwaziwanginɛwamumu'                     => 'pg',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pikairni'                                  => 'pn',
    'polineziwanfalanse'                        => 'pf',
    'polynesia'                                 => '061',
    'risi'                                      => 'ru',
    'romani'                                    => 'ro',
    'rwanda'                                    => 'rw',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'samoa'                                     => 'ws',
    'samoawaameriki'                            => 'as',
    'santueleni'                                => 'sh',
    'santukrístofeneneves'                     => 'kn',
    'santulisi'                                 => 'lc',
    'santumarine'                               => 'sm',
    'santupététonemikelu'                     => 'pm',
    'santuvesanengelenadine'                    => 'vc',
    'saotomenepresipɛ'                         => 'st',
    'savadore'                                  => 'sv',
    'senegale'                                  => 'sn',
    'serbia'                                    => 'rs',
    'seshele'                                   => 'sc',
    'shili'                                     => 'cl',
    'shine'                                     => 'cn',
    'shipele'                                   => 'cy',
    'sieraleone'                                => 'sl',
    'silovaki'                                  => 'sk',
    'siloveni'                                  => 'si',
    'singapure'                                 => 'sg',
    'siri'                                      => 'sy',
    'sirilanka'                                 => 'lk',
    'somali'                                    => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'suda'                                      => 'sd',
    'suriname'                                  => 'sr',
    'suwedi'                                    => 'se',
    'svalbardandjanmayen'                       => 'sj',
    'swazilandi'                                => 'sz',
    'swise'                                     => 'ch',
    'taiwani'                                   => 'tw',
    'tanzani'                                   => 'tz',
    'tayilanda'                                 => 'th',
    'tazikisita'                                => 'tj',
    'timoruwadiboku'                            => 'tl',
    'tinidadenetobago'                          => 'tt',
    'tinizi'                                    => 'tn',
    'togu'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'tristandacunha'                            => 'ta',
    'tshadi'                                    => 'td',
    'tukemenisita'                              => 'tm',
    'tuluki'                                    => 'tr',
    'tuvalu'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukreni'                                    => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'uzibekisita'                               => 'uz',
    'vanuatu'                                   => 'vu',
    'venezuela'                                 => 've',
    'viyetiname'                                => 'vn',
    'wakeisland'                                => 'wk',
    'walisenefutuna'                            => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yemenu'                                    => 'ye',
    'zambi'                                     => 'zm',
    'zelandawamumu'                             => 'nz',
    'zimbabwe'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
);

1;

