{"delimiters":{"quotation_start":"„","quotation_end":"“","alternate_quotation_start":"„","alternate_quotation_end":"“"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":"ne:n","yesstr":"taip:t"},"plural_forms":{"category_list":["one","few","other"],"category_rules_function":null,"category_rules":{"one":"n mod 10 is 1 and n mod 100 not in 11..19","few":"n mod 10 in 2..9 and n mod 100 not in 11..19"},"category_rules_compiled":{"one":function (n) {if ( (( (n % 10) == 1) && ( parseInt(n) != n || (n % 100) < 11 || (n % 100) > 19 ))) { return 'one'; } return;},"few":function (n) {if ( (( parseInt(n) == n && (n % 10) >= 2 && (n % 10) <= 9 ) && ( parseInt(n) != n || (n % 100) < 11 || (n % 100) > 19 ))) { return 'few'; } return;}}},"cldr_formats":{"territory":"Sritis: {0}","_decimal_format_decimal":".","language":"Kalba: {0}","percent":"#,##0 %","locale":"{0} ({1})","_decimal_format_group":",","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} ir {1}","start":"{0}, {1}","end":"{0} ir {1}"}},"fallback":[],"characters":{"more_information":"?"}}