package Locales::DB::Territory::hy;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::hy::VERSION = '0.09';

$Locales::DB::Territory::hy::cldr_version = '2.0';

%Locales::DB::Territory::hy::code_to_name = (
    '001' => 'Աշխարհ',
    '002' => 'Աֆրիկա',
    '003' => "North\ America",
    '005' => "Հարավային\ Ամերիկա",
    '009' => 'Oceania',
    '011' => "Արևմտյան\ Աֆրիկա",
    '013' => "Central\ America",
    '014' => "Արևելյան\ Աֆրիկա",
    '015' => "Հյուսիսային\ Աֆրիկա",
    '017' => "Middle\ Africa",
    '018' => "Հարավային\ Աֆրիկա\ \[018\]",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Անդորա',
    'ae'  => "Միացյալ\ Արաբական\ Էմիրաթներ",
    'af'  => 'Աֆղանստան',
    'ag'  => "Անտիգուա\-Բարբուդա",
    'ai'  => 'Anguilla',
    'al'  => 'Ալբանիա',
    'am'  => "Հայաստանի\ Հանրապետութիւն",
    'an'  => "Netherlands\ Antilles",
    'ao'  => 'Անգոլա',
    'aq'  => 'Antarctica',
    'ar'  => 'Արգենտինա',
    'as'  => "American\ Samoa",
    'at'  => 'Ավստրիա',
    'au'  => 'Ավստրալիա',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Ադրբեջան',
    'ba'  => "Բոսնիա\-Հերցեգովինա",
    'bb'  => 'Բարբադոս',
    'bd'  => 'Բանգլադեշ',
    'be'  => 'Բելգիա',
    'bf'  => "Բուրկինա\ Ֆասո",
    'bg'  => 'Բուլղարիա',
    'bh'  => 'Բահրեյն',
    'bi'  => 'Բուրունդի',
    'bj'  => 'Բենին',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Բրունեյ',
    'bo'  => 'Բոլիվիա',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Բրազիլիա',
    'bs'  => 'Բահամներ',
    'bt'  => 'Բուտան',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Բոտսվանա',
    'by'  => 'Բելոռուս',
    'bz'  => 'Բելիզ',
    'ca'  => 'Կանադա',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Congo\ \[DRC\]",
    'cf'  => "Կենտրոնական\ Աֆրիկյան\ Հանրապետություն",
    'cg'  => 'Կոնգո',
    'ch'  => 'Շվեյցարիա',
    'ci'  => "Փղոսկրի\ Ափ",
    'ck'  => "Cook\ Islands",
    'cl'  => 'Չիլի',
    'cm'  => 'Կամերուն',
    'cn'  => 'Չինաստան',
    'co'  => 'Կոլումբիա',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Կոստա\-Ռիկա",
    'cs'  => "Սերբիա\ և\ Մոնտենեգրո",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Կուբա',
    'cv'  => "Կաբո\-Վերդե",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Կիպրոս',
    'cz'  => "Չեխիայի\ Հանրապետություն",
    'dd'  => "East\ Germany",
    'de'  => 'Գերմանիա',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Ջիբուտի',
    'dk'  => 'Դանիա',
    'dm'  => 'Դոմինիկա',
    'do'  => "Դոմինիկյան\ Հանրապետություն",
    'dz'  => 'Ալժիր',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Էկվադոր',
    'ee'  => 'Էստոնիա',
    'eg'  => 'Եգիպտոս',
    'eh'  => "Արեվմտյան\ Սահարա",
    'er'  => 'Էրիտրեա',
    'es'  => 'Իսպանիա',
    'et'  => 'Եթովպիա',
    'eu'  => "European\ Union",
    'fi'  => 'Ֆինլանդիա',
    'fj'  => 'Ֆիջի',
    'fk'  => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm'  => 'Միկրոնեզիա',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Ֆրանսիա',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Գաբոն',
    'gb'  => "Մեծ\ Բրիտանիա",
    'gd'  => 'Գրենադա',
    'ge'  => 'Վրաստան',
    'gf'  => "French\ Guiana",
    'gg'  => 'Guernsey',
    'gh'  => 'Գանա',
    'gi'  => 'Gibraltar',
    'gl'  => 'Greenland',
    'gm'  => 'Գամբիա',
    'gn'  => 'Գվինեա',
    'gp'  => 'Guadeloupe',
    'gq'  => "Հասարակածային\ Գվինեա",
    'gr'  => 'Հունաստան',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Գվատեմալա',
    'gu'  => 'Guam',
    'gw'  => "Գվինեա\-Բիսաու",
    'gy'  => 'Գայանա',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Հոնդուրաս',
    'hr'  => 'Հորվաթիա',
    'ht'  => 'Հաիթի',
    'hu'  => 'Հունգարիա',
    'ic'  => "Canary\ Islands",
    'id'  => 'Ինդոնեզիա',
    'ie'  => 'Իռլանդիա',
    'il'  => 'Իսրայել',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Հնդկաստան',
    'io'  => "British\ Indian\ Ocean\ Territory",
    'iq'  => 'Իրաք',
    'ir'  => 'Իրան',
    'is'  => 'Իսլանդիա',
    'it'  => 'Իտալիա',
    'je'  => 'Jersey',
    'jm'  => 'Ջամայկա',
    'jo'  => 'Հորդանան',
    'jp'  => 'Ճապոնիա',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Քենիա',
    'kg'  => 'Կիրգիզստան',
    'kh'  => 'Կամբոջա',
    'ki'  => 'Կիրիբատի',
    'km'  => 'Կոմորոս',
    'kn'  => "Սենտ\ Կիտս\-Նեվիս",
    'kp'  => "Հյուսիսային\ Կորեա",
    'kr'  => "Հարավային\ Կորեա",
    'kw'  => 'Քուվեյթ',
    'ky'  => "Cayman\ Islands",
    'kz'  => 'Ղազախստան',
    'la'  => 'Լաոս',
    'lb'  => 'Լիբանան',
    'lc'  => "Սանտա\ Լուչիա",
    'li'  => 'Լիխտենշտեյն',
    'lk'  => "Շրի\ Լանկա",
    'lr'  => 'Լիբերիա',
    'ls'  => 'Լեսոտո',
    'lt'  => 'Լիտվա',
    'lu'  => 'Լյուքսեմբուրգ',
    'lv'  => 'Լատվիա',
    'ly'  => 'Լիբիա',
    'ma'  => 'Մարոկո',
    'mc'  => 'Մոնակո',
    'md'  => 'Մոլդովա',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Մադագասկար',
    'mh'  => "Մարշալյան\ կղզիներ",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Մակեդոնիա',
    'ml'  => 'Մալի',
    'mm'  => 'Մյանմա',
    'mn'  => 'Մոնղոլիա',
    'mo'  => 'Macau',
    'mp'  => "Northern\ Mariana\ Islands",
    'mq'  => 'Martinique',
    'mr'  => 'Մավրիտանիա',
    'ms'  => 'Montserrat',
    'mt'  => 'Մալթա',
    'mu'  => 'Մավրիտոս',
    'mv'  => 'Մալդիվներ',
    'mw'  => 'Մալավի',
    'mx'  => 'Մեքսիկա',
    'my'  => 'Մալայզիա',
    'mz'  => 'Մոզամբիկ',
    'na'  => 'Նամիբիա',
    'nc'  => "New\ Caledonia",
    'ne'  => 'Նիգեր',
    'nf'  => "Norfolk\ Island",
    'ng'  => 'Նիգերիա',
    'ni'  => 'Նիկարագուա',
    'nl'  => 'Նիդերլանդեր',
    'no'  => 'Նորվեգիա',
    'np'  => 'Նեպալ',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Նաուրու',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Նոր\ Զելանդիա",
    'om'  => 'Օման',
    'pa'  => 'Պանամա',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Պերու',
    'pf'  => "French\ Polynesia",
    'pg'  => "Պապուա\ Նոր\ Գվինեա",
    'ph'  => 'Ֆիլիպիններ',
    'pk'  => 'Պակիստան',
    'pl'  => 'Լեհաստան',
    'pm'  => "Saint\ Pierre\ and\ Miquelon",
    'pn'  => "Pitcairn\ Islands",
    'pr'  => "Puerto\ Rico",
    'ps'  => "Palestinian\ Territories",
    'pt'  => 'Պորտուգալիա',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Պալաու',
    'py'  => 'Պարագվայ',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Կատար',
    'qo'  => "Outlying\ Oceania",
    're'  => "R\Ã\©union",
    'ro'  => 'Ռումինիա',
    'rs'  => 'Serbia',
    'ru'  => 'Ռուսաստան',
    'rw'  => 'Ռուանդա',
    'sa'  => "Սաուդիան\ Արաբիա",
    'sb'  => "Սոլոմոնյան\ կղզիներ",
    'sc'  => 'Սեյշելներ',
    'sd'  => 'Սուդան',
    'se'  => 'Շվեդիա',
    'sg'  => 'Սինգապուր',
    'sh'  => "Saint\ Helena",
    'si'  => 'Սլովենիա',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Սլովակիա',
    'sl'  => "Սյերա\-Լեոնե",
    'sm'  => "Սան\ Մարինո",
    'sn'  => 'Սենեգալ',
    'so'  => 'Սոմալի',
    'sr'  => 'Սուրինամ',
    'st'  => "Սան\-Թոմե\-Փրինսիպի",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Սալվադոր',
    'sy'  => 'Սիրիա',
    'sz'  => 'Սվազիլենդ',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\ and\ Caicos\ Islands",
    'td'  => 'Չադ',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Տոգո',
    'th'  => 'Թաիլանդ',
    'tj'  => 'Տաճիկստան',
    'tk'  => 'Tokelau',
    'tl'  => "East\ Timor",
    'tm'  => 'Թուրքմենստան',
    'tn'  => 'Թունիս',
    'to'  => 'Տոնգա',
    'tr'  => 'Թուրքիա',
    'tt'  => "Տրինիդադ\-Տոբագո",
    'tv'  => 'Տուվալու',
    'tw'  => 'Թայվան',
    'tz'  => 'Տանզանիա',
    'ua'  => 'Ուկրաինա',
    'ug'  => 'Ուգանդա',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Ամէրիկայի\ Միացյալ\ Նահանգնէր",
    'uy'  => 'Ուրուգվայ',
    'uz'  => 'Ուզբեկստան',
    'va'  => 'Վատիկան',
    'vc'  => "Սենտ\ Վիսենտ\-Գրենադիններ",
    'vd'  => "North\ Vietnam",
    've'  => 'Վենեսուելա',
    'vg'  => "British\ Virgin\ Islands",
    'vi'  => "U\.S\.\ Virgin\ Islands",
    'vn'  => 'Վիետնամ',
    'vu'  => 'Վանուատու',
    'wf'  => "Wallis\ and\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Սամոա',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Եմեն',
    'yt'  => 'Mayotte',
    'za'  => "Հարավային\ Աֆրիկա",
    'zm'  => 'Զամբիա',
    'zw'  => 'Զիմբաբվե',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::hy::name_to_code = (
    'americansamoa'                                                        => 'as',
    'americas'                                                             => '019',
    'anguilla'                                                             => 'ai',
    'antarctica'                                                           => 'aq',
    'aruba'                                                                => 'aw',
    'ascensionisland'                                                      => 'ac',
    'asia'                                                                 => 142,
    'australiaandnewzealand'                                               => '053',
    'bermuda'                                                              => 'bm',
    'bouvetisland'                                                         => 'bv',
    'britishantarcticterritory'                                            => 'bq',
    'britishindianoceanterritory'                                          => 'io',
    'britishvirginislands'                                                 => 'vg',
    'canaryislands'                                                        => 'ic',
    'cantonandenderburyislands'                                            => 'ct',
    'caribbean'                                                            => '029',
    'caymanislands'                                                        => 'ky',
    'centralamerica'                                                       => '013',
    'centralasia'                                                          => 143,
    'ceutaandmelilla'                                                      => 'ea',
    'channelislands'                                                       => 830,
    'christmasisland'                                                      => 'cx',
    'clippertonisland'                                                     => 'cp',
    'cocoskeelingislands'                                                  => 'cc',
    'commonwealthofindependentstates'                                      => 172,
    'congodrc'                                                             => 'cd',
    'cookislands'                                                          => 'ck',
    'czechoslovakia'                                                       => 200,
    'diegogarcia'                                                          => 'dg',
    'dronningmaudland'                                                     => 'nq',
    'easternasia'                                                          => '030',
    'easterneurope'                                                        => 151,
    'eastgermany'                                                          => 'dd',
    'easttimor'                                                            => 'tl',
    'europe'                                                               => 150,
    'europeanunion'                                                        => 'eu',
    'falklandislandsislasmalvinas'                                         => 'fk',
    'faroeislands'                                                         => 'fo',
    'frenchguiana'                                                         => 'gf',
    'frenchpolynesia'                                                      => 'pf',
    'frenchsouthernandantarcticterritories'                                => 'fq',
    'frenchsouthernterritories'                                            => 'tf',
    'gibraltar'                                                            => 'gi',
    'greenland'                                                            => 'gl',
    'guadeloupe'                                                           => 'gp',
    'guam'                                                                 => 'gu',
    'guernsey'                                                             => 'gg',
    'heardislandandmcdonaldislands'                                        => 'hm',
    'hongkong'                                                             => 'hk',
    'isleofman'                                                            => 'im',
    'jersey'                                                               => 'je',
    'johnstonisland'                                                       => 'jt',
    'latinamerica'                                                         => 419,
    'macau'                                                                => 'mo',
    'martinique'                                                           => 'mq',
    'mayotte'                                                              => 'yt',
    'melanesia'                                                            => '054',
    'metropolitanfrance'                                                   => 'fx',
    'micronesianregion'                                                    => '057',
    'middleafrica'                                                         => '017',
    'midwayislands'                                                        => 'mi',
    'montenegro'                                                           => 'me',
    'montserrat'                                                           => 'ms',
    'netherlandsantilles'                                                  => 'an',
    'neutralzone'                                                          => 'nt',
    'newcaledonia'                                                         => 'nc',
    'niue'                                                                 => 'nu',
    'norfolkisland'                                                        => 'nf',
    'northamerica'                                                         => '003',
    'northernamerica'                                                      => '021',
    'northerneurope'                                                       => 154,
    'northernmarianaislands'                                               => 'mp',
    'northvietnam'                                                         => 'vd',
    'oceania'                                                              => '009',
    'outlyingoceania'                                                      => 'qo',
    'pacificislandstrustterritory'                                         => 'pc',
    'palestinianterritories'                                               => 'ps',
    'panamacanalzone'                                                      => 'pz',
    "people\â\\sdemocraticrepublicofyemen"                            => 'yd',
    'pitcairnislands'                                                      => 'pn',
    'polynesia'                                                            => '061',
    'puertorico'                                                           => 'pr',
    "r\Ã\©union"                                                         => 're',
    "saintbarth\Ã\©lemy"                                                 => 'bl',
    'sainthelena'                                                          => 'sh',
    'saintmartin'                                                          => 'mf',
    'saintpierreandmiquelon'                                               => 'pm',
    'serbia'                                                               => 'rs',
    'southcentralasia'                                                     => '062',
    'southeasternasia'                                                     => '035',
    'southernasia'                                                         => '034',
    'southerneurope'                                                       => '039',
    'southgeorgiaandthesouthsandwichislands'                               => 'gs',
    'svalbardandjanmayen'                                                  => 'sj',
    'tokelau'                                                              => 'tk',
    'tristandacunha'                                                       => 'ta',
    'turksandcaicosislands'                                                => 'tc',
    "u\.s\.minoroutlyingislands"                                           => 'um',
    "u\.s\.miscellaneouspacificislands"                                    => 'pu',
    "u\.s\.virginislands"                                                  => 'vi',
    'unionofsovietsocialistrepublics'                                      => 'su',
    'unknownregion'                                                        => 'zz',
    'wakeisland'                                                           => 'wk',
    'wallisandfutuna'                                                      => 'wf',
    'westernasia'                                                          => 145,
    'westerneurope'                                                        => 155,
    "\Ã\landislands"                                                    => 'ax',
    'Ադրբեջան'                                                     => 'az',
    'Ալբանիա'                                                       => 'al',
    'Ալժիր'                                                           => 'dz',
    'ԱմէրիկայիՄիացյալՆահանգնէր'                   => 'us',
    'Անգոլա'                                                         => 'ao',
    'Անդորա'                                                         => 'ad',
    'ԱնտիգուաԲարբուդա'                                     => 'ag',
    'Աշխարհ'                                                         => '001',
    'Ավստրալիա'                                                   => 'au',
    'Ավստրիա'                                                       => 'at',
    'Արգենտինա'                                                   => 'ar',
    'ԱրեվմտյանՍահարա'                                       => 'eh',
    'ԱրևելյանԱֆրիկա'                                         => '014',
    'ԱրևմտյանԱֆրիկա'                                         => '011',
    'Աֆղանստան'                                                   => 'af',
    'Աֆրիկա'                                                         => '002',
    'Բահամներ'                                                     => 'bs',
    'Բահրեյն'                                                       => 'bh',
    'Բանգլադեշ'                                                   => 'bd',
    'Բարբադոս'                                                     => 'bb',
    'Բելգիա'                                                         => 'be',
    'Բելիզ'                                                           => 'bz',
    'Բելոռուս'                                                     => 'by',
    'Բենին'                                                           => 'bj',
    'Բոլիվիա'                                                       => 'bo',
    'ԲոսնիաՀերցեգովինա'                                   => 'ba',
    'Բոտսվանա'                                                     => 'bw',
    'Բուլղարիա'                                                   => 'bg',
    'Բուտան'                                                         => 'bt',
    'ԲուրկինաՖասո'                                             => 'bf',
    'Բուրունդի'                                                   => 'bi',
    'Բրազիլիա'                                                     => 'br',
    'Բրունեյ'                                                       => 'bn',
    'Գաբոն'                                                           => 'ga',
    'Գամբիա'                                                         => 'gm',
    'Գայանա'                                                         => 'gy',
    'Գանա'                                                             => 'gh',
    'Գերմանիա'                                                     => 'de',
    'Գվատեմալա'                                                   => 'gt',
    'Գվինեա'                                                         => 'gn',
    'ԳվինեաԲիսաու'                                             => 'gw',
    'Գրենադա'                                                       => 'gd',
    'Դանիա'                                                           => 'dk',
    'Դոմինիկա'                                                     => 'dm',
    'ԴոմինիկյանՀանրապետություն'                   => 'do',
    'Եգիպտոս'                                                       => 'eg',
    'Եթովպիա'                                                       => 'et',
    'Եմեն'                                                             => 'ye',
    'Զամբիա'                                                         => 'zm',
    'Զիմբաբվե'                                                     => 'zw',
    'Էկվադոր'                                                       => 'ec',
    'Էստոնիա'                                                       => 'ee',
    'Էրիտրեա'                                                       => 'er',
    'Թաիլանդ'                                                       => 'th',
    'Թայվան'                                                         => 'tw',
    'Թունիս'                                                         => 'tn',
    'Թուրքիա'                                                       => 'tr',
    'Թուրքմենստան'                                             => 'tm',
    'Ինդոնեզիա'                                                   => 'id',
    'Իռլանդիա'                                                     => 'ie',
    'Իսլանդիա'                                                     => 'is',
    'Իսպանիա'                                                       => 'es',
    'Իսրայել'                                                       => 'il',
    'Իտալիա'                                                         => 'it',
    'Իրան'                                                             => 'ir',
    'Իրաք'                                                             => 'iq',
    'Լաոս'                                                             => 'la',
    'Լատվիա'                                                         => 'lv',
    'Լեհաստան'                                                     => 'pl',
    'Լեսոտո'                                                         => 'ls',
    'Լիբանան'                                                       => 'lb',
    'Լիբերիա'                                                       => 'lr',
    'Լիբիա'                                                           => 'ly',
    'Լիխտենշտեյն'                                               => 'li',
    'Լիտվա'                                                           => 'lt',
    'Լյուքսեմբուրգ'                                           => 'lu',
    'ԿաբոՎերդե'                                                   => 'cv',
    'Կամբոջա'                                                       => 'kh',
    'Կամերուն'                                                     => 'cm',
    'Կանադա'                                                         => 'ca',
    'Կատար'                                                           => 'qa',
    'ԿենտրոնականԱֆրիկյանՀանրապետություն' => 'cf',
    'Կիպրոս'                                                         => 'cy',
    'Կիրգիզստան'                                                 => 'kg',
    'Կիրիբատի'                                                     => 'ki',
    'Կոլումբիա'                                                   => 'co',
    'Կոմորոս'                                                       => 'km',
    'Կոնգո'                                                           => 'cg',
    'ԿոստաՌիկա'                                                   => 'cr',
    'Կուբա'                                                           => 'cu',
    'Հաիթի'                                                           => 'ht',
    'ՀայաստանիՀանրապետութիւն'                       => 'am',
    'ՀասարակածայինԳվինեա'                               => 'gq',
    'ՀարավայինԱմերիկա'                                     => '005',
    'ՀարավայինԱֆրիկա'                                       => 'za',
    'ՀարավայինԱֆրիկա018'                                    => '018',
    'ՀարավայինԿորեա'                                         => 'kr',
    'ՀյուսիսայինԱֆրիկա'                                   => '015',
    'ՀյուսիսայինԿորեա'                                     => 'kp',
    'Հնդկաստան'                                                   => 'in',
    'Հոնդուրաս'                                                   => 'hn',
    'Հորդանան'                                                     => 'jo',
    'Հորվաթիա'                                                     => 'hr',
    'Հունաստան'                                                   => 'gr',
    'Հունգարիա'                                                   => 'hu',
    'Ղազախստան'                                                   => 'kz',
    'Ճապոնիա'                                                       => 'jp',
    'Մադագասկար'                                                 => 'mg',
    'Մալայզիա'                                                     => 'my',
    'Մալավի'                                                         => 'mw',
    'Մալդիվներ'                                                   => 'mv',
    'Մալթա'                                                           => 'mt',
    'Մալի'                                                             => 'ml',
    'Մակեդոնիա'                                                   => 'mk',
    'Մավրիտանիա'                                                 => 'mr',
    'Մավրիտոս'                                                     => 'mu',
    'Մարշալյանկղզիներ'                                     => 'mh',
    'Մարոկո'                                                         => 'ma',
    'ՄեծԲրիտանիա'                                               => 'gb',
    'Մեքսիկա'                                                       => 'mx',
    'ՄիացյալԱրաբականԷմիրաթներ'                     => 'ae',
    'Միկրոնեզիա'                                                 => 'fm',
    'Մյանմա'                                                         => 'mm',
    'Մոզամբիկ'                                                     => 'mz',
    'Մոլդովա'                                                       => 'md',
    'Մոնակո'                                                         => 'mc',
    'Մոնղոլիա'                                                     => 'mn',
    'Նամիբիա'                                                       => 'na',
    'Նաուրու'                                                       => 'nr',
    'Նեպալ'                                                           => 'np',
    'Նիգեր'                                                           => 'ne',
    'Նիգերիա'                                                       => 'ng',
    'Նիդերլանդեր'                                               => 'nl',
    'Նիկարագուա'                                                 => 'ni',
    'ՆորԶելանդիա'                                               => 'nz',
    'Նորվեգիա'                                                     => 'no',
    'Շվեդիա'                                                         => 'se',
    'Շվեյցարիա'                                                   => 'ch',
    'ՇրիԼանկա'                                                     => 'lk',
    'Ուգանդա'                                                       => 'ug',
    'Ուզբեկստան'                                                 => 'uz',
    'Ուկրաինա'                                                     => 'ua',
    'Ուրուգվայ'                                                   => 'uy',
    'Չադ'                                                               => 'td',
    'ՉեխիայիՀանրապետություն'                         => 'cz',
    'Չիլի'                                                             => 'cl',
    'Չինաստան'                                                     => 'cn',
    'Պալաու'                                                         => 'pw',
    'Պակիստան'                                                     => 'pk',
    'Պանամա'                                                         => 'pa',
    'ՊապուաՆորԳվինեա'                                       => 'pg',
    'Պարագվայ'                                                     => 'py',
    'Պերու'                                                           => 'pe',
    'Պորտուգալիա'                                               => 'pt',
    'Ջամայկա'                                                       => 'jm',
    'Ջիբուտի'                                                       => 'dj',
    'Ռուանդա'                                                       => 'rw',
    'Ռումինիա'                                                     => 'ro',
    'Ռուսաստան'                                                   => 'ru',
    'Սալվադոր'                                                     => 'sv',
    'Սամոա'                                                           => 'ws',
    'ՍանԹոմեՓրինսիպի'                                       => 'st',
    'ՍանՄարինո'                                                   => 'sm',
    'ՍանտաԼուչիա'                                               => 'lc',
    'ՍաուդիանԱրաբիա'                                         => 'sa',
    'Սեյշելներ'                                                   => 'sc',
    'Սենեգալ'                                                       => 'sn',
    'ՍենտԿիտսՆեվիս'                                           => 'kn',
    'ՍենտՎիսենտԳրենադիններ'                           => 'vc',
    'ՍերբիաևՄոնտենեգրո'                                   => 'cs',
    'Սինգապուր'                                                   => 'sg',
    'Սիրիա'                                                           => 'sy',
    'Սլովակիա'                                                     => 'sk',
    'Սլովենիա'                                                     => 'si',
    'ՍյերաԼեոնե'                                                 => 'sl',
    'Սոլոմոնյանկղզիներ'                                   => 'sb',
    'Սոմալի'                                                         => 'so',
    'Սուդան'                                                         => 'sd',
    'Սուրինամ'                                                     => 'sr',
    'Սվազիլենդ'                                                   => 'sz',
    'Վանուատու'                                                   => 'vu',
    'Վատիկան'                                                       => 'va',
    'Վենեսուելա'                                                 => 've',
    'Վիետնամ'                                                       => 'vn',
    'Վրաստան'                                                       => 'ge',
    'Տաճիկստան'                                                   => 'tj',
    'Տանզանիա'                                                     => 'tz',
    'Տոգո'                                                             => 'tg',
    'Տոնգա'                                                           => 'to',
    'Տուվալու'                                                     => 'tv',
    'ՏրինիդադՏոբագո'                                         => 'tt',
    'ՓղոսկրիԱփ'                                                   => 'ci',
    'Քենիա'                                                           => 'ke',
    'Քուվեյթ'                                                       => 'kw',
    'Օման'                                                             => 'om',
    'Ֆիլիպիններ'                                                 => 'ph',
    'Ֆինլանդիա'                                                   => 'fi',
    'Ֆիջի'                                                             => 'fj',
    'Ֆրանսիա'                                                       => 'fr',
);

1;

