package Locales::DB::Territory::yav;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::yav::VERSION = '0.09';

$Locales::DB::Territory::yav::cldr_version = '2.0';

%Locales::DB::Territory::yav::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Aŋtúla',
    'ae'  => "imiláat\ i\ paaláap",
    'af'  => 'Afkanistáŋ',
    'ag'  => "Aŋtíka\ na\ Palpúta",
    'ai'  => 'Aŋkíla',
    'al'  => 'Alpaní',
    'am'  => 'Almanía',
    'an'  => "andíiy\ u\ nitililáand",
    'ao'  => 'Aŋkúla',
    'aq'  => 'Antarctica',
    'ar'  => 'Alsaŋtín',
    'as'  => "Sámua\ u\ Amelíka",
    'at'  => 'Otilís',
    'au'  => 'Otalalí',
    'aw'  => 'Alúpa',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Asɛlpaisáŋ',
    'ba'  => "Pusiní\-ɛlkofína",
    'bb'  => 'Palpatós',
    'bd'  => 'Paŋkalatɛs',
    'be'  => 'Pɛlsíik',
    'bf'  => 'Pulikínafásó',
    'bg'  => 'Pulukalíi',
    'bh'  => 'Palɛŋ',
    'bi'  => 'Púlúndí',
    'bj'  => 'Penɛŋ',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Pɛlmúta',
    'bn'  => 'Pulunéy',
    'bo'  => 'Polífia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Pilesíl',
    'bs'  => 'Pahámas',
    'bt'  => 'Putaŋ',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Posuána',
    'by'  => 'Pelalús',
    'bz'  => 'Pelíse',
    'ca'  => 'Kánáta',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "kitɔŋ\ kí\ kongó",
    'cf'  => 'Santalafilíik',
    'cg'  => 'Kongó',
    'ch'  => 'suwíis',
    'ci'  => 'Kótifualɛ',
    'ck'  => 'Kúuke',
    'cl'  => 'Silí',
    'cm'  => 'Kemelún',
    'cn'  => 'Síine',
    'co'  => 'Kɔlɔ́mbía',
    'cp'  => "Clipperton\ Island",
    'cr'  => 'Kóstálíka',
    'cs'  => "sɛlpí\ e\ mɔ́ŋténékolo",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'kúpa',
    'cv'  => 'Kápfɛl',
    'cx'  => "Christmas\ Island",
    'cy'  => 'síplɛ',
    'cz'  => "kitɔŋ\ kí\ cɛ́k",
    'dd'  => "East\ Germany",
    'de'  => 'nsáman',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'síputí',
    'dk'  => 'tanemálk',
    'dm'  => 'túmúnéke',
    'do'  => "kitɔŋ\ kí\ tumunikɛ́ŋ",
    'dz'  => 'Alselí',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'ekuatɛ́l',
    'ee'  => 'ɛstoni',
    'eg'  => 'isípit',
    'eh'  => "Western\ Sahara",
    'er'  => 'elitée',
    'es'  => 'panyá',
    'et'  => 'etiopí',
    'eu'  => "European\ Union",
    'fi'  => 'fɛnlánd',
    'fj'  => 'físi',
    'fk'  => 'maluwín',
    'fm'  => 'mikolonesí',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'felensí',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'kapɔ́ŋ',
    'gb'  => 'ingilíís',
    'gd'  => 'kelenáat',
    'ge'  => 'sɔlsíi',
    'gf'  => "kuyáan\ u\ felensí",
    'gg'  => 'Guernsey',
    'gh'  => 'kaná',
    'gi'  => 'sílpalatáal',
    'gl'  => 'kuluɛnlánd',
    'gm'  => 'kambíi',
    'gn'  => 'kiiné',
    'gp'  => 'kuatelúup',
    'gq'  => 'kinéekuatolial',
    'gr'  => 'kilɛ́ɛk',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'kuatemalá',
    'gu'  => 'kuamiɛ',
    'gw'  => 'kiinépisaó',
    'gy'  => 'kuyáan',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'ɔndúlas',
    'hr'  => 'Kolowasíi',
    'ht'  => 'ayíti',
    'hu'  => 'ɔngilí',
    'ic'  => "Canary\ Islands",
    'id'  => 'ɛndonesí',
    'ie'  => 'ililánd',
    'il'  => 'ísilayɛ́l',
    'im'  => "Isle\ of\ Man",
    'in'  => 'ɛ́ɛnd',
    'io'  => "Kɔɔ́m\ kí\ ndián\ yi\ ngilís",
    'iq'  => 'ilák',
    'ir'  => 'iláŋ',
    'is'  => 'isláand',
    'it'  => 'italí',
    'je'  => 'Jersey',
    'jm'  => 'samayíik',
    'jo'  => 'sɔltaní',
    'jp'  => 'sapɔ́ɔŋ',
    'jt'  => "Johnston\ Island",
    'ke'  => 'kénia',
    'kg'  => 'kilikisistáŋ',
    'kh'  => 'Kámbóse',
    'ki'  => 'kilipatí',
    'km'  => 'Kɔmɔ́ɔl',
    'kn'  => "sɛ́ŋkilistɔ́f\ eniɛ́f",
    'kp'  => "kɔlé\ u\ muɛnɛ́",
    'kr'  => "kɔlé\ wu\ mbát",
    'kw'  => 'kowéet',
    'ky'  => 'Káyímanɛ',
    'kz'  => 'kasaksitáŋ',
    'la'  => 'lawós',
    'lb'  => 'lipáŋ',
    'lc'  => 'sɛ́ŋtɛ́lusí',
    'li'  => 'lístɛ́nsitáyin',
    'lk'  => 'silíláŋka',
    'lr'  => 'lipélia',
    'ls'  => 'lesotó',
    'lt'  => 'litiyaní',
    'lu'  => 'liksambúul',
    'lv'  => 'letoní',
    'ly'  => 'lipíi',
    'ma'  => 'malóok',
    'mc'  => 'monakó',
    'md'  => 'moltafí',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'matakaskáal',
    'mh'  => 'ílmalasáal',
    'mi'  => "Midway\ Islands",
    'mk'  => 'masetuán',
    'ml'  => 'malí',
    'mm'  => 'miaŋmáal',
    'mn'  => 'mongolí',
    'mo'  => 'Macau',
    'mp'  => "il\ maliyanɛ\ u\ muɛnɛ́",
    'mq'  => 'maltiníik',
    'mr'  => 'molitaní',
    'ms'  => 'mɔŋsilá',
    'mt'  => 'málɛ́t',
    'mu'  => 'molís',
    'mv'  => 'maletíif',
    'mw'  => 'malawí',
    'mx'  => 'mɛksíik',
    'my'  => 'malesí',
    'mz'  => 'mosambík',
    'na'  => 'namipí',
    'nc'  => "nufɛ́l\ kaletoní",
    'ne'  => 'nisɛ́ɛl',
    'nf'  => "il\ nɔ́lfɔ́lɔk",
    'ng'  => 'nisélia',
    'ni'  => 'nikalaká',
    'nl'  => 'nitililáand',
    'no'  => 'nɔlfɛ́ɛs',
    'np'  => 'nepáal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'nawulú',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'niyuwé',
    'nz'  => "nufɛ́l\ seláand",
    'om'  => 'omáŋ',
    'pa'  => 'panamá',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'pelú',
    'pf'  => "polinesí\ u\ felensí",
    'pg'  => "papuasí\ nufɛ́l\ kiiné",
    'ph'  => 'filipíin',
    'pk'  => 'pakistáŋ',
    'pl'  => 'pɔlɔ́ɔny',
    'pm'  => "sɛ́ŋpiɛ́l\ e\ mikelɔ́ŋ",
    'pn'  => 'pitikɛ́ɛlínɛ́',
    'pr'  => 'pólótolíko',
    'ps'  => "kitɔŋ\ ki\ palɛstíin",
    'pt'  => 'pɔltukáal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'palawú',
    'py'  => 'palakúé',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'katáal',
    'qo'  => "Outlying\ Oceania",
    're'  => 'elewuniɔ́ŋ',
    'ro'  => 'ulumaní',
    'rs'  => 'Serbia',
    'ru'  => 'ulusí',
    'rw'  => 'uluándá',
    'sa'  => 'alapísawutíit',
    'sb'  => "il\ salomɔ́ŋ",
    'sc'  => 'sesɛ́ɛl',
    'sd'  => 'sutáaŋ',
    'se'  => 'suɛ́t',
    'sg'  => 'singapúul',
    'sh'  => "sɛ́ŋtɛ́\ elɛ́ɛnɛ",
    'si'  => 'silofení',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'silofakí',
    'sl'  => 'sieláleyɔ́ɔn',
    'sm'  => "san\ malíno",
    'sn'  => 'senekáal',
    'so'  => 'somalí',
    'sr'  => 'sulináam',
    'st'  => "sáwó\ tomé\ e\ pelensípe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'salfatɔ́ɔl',
    'sy'  => 'Syria',
    'sz'  => 'suasiláand',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "túluk\ na\ káyiik",
    'td'  => 'Sáat',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'tokó',
    'th'  => 'tayiláand',
    'tj'  => 'tasikistáaŋ',
    'tk'  => 'tokeló',
    'tl'  => "timɔ́ɔl\ u\ nipálɛ́n",
    'tm'  => 'tulukmenisitáaŋ',
    'tn'  => 'tunusí',
    'to'  => 'tɔ́ŋka',
    'tr'  => 'tulukíi',
    'tt'  => "tilinitáat\ na\ tupákɔ",
    'tv'  => 'tufalú',
    'tw'  => 'tayiwáan',
    'tz'  => 'taŋsaní',
    'ua'  => 'ukilɛ́ɛn',
    'ug'  => 'ukánda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => 'amálíka',
    'uy'  => 'ulukuéy',
    'uz'  => 'usupekistáaŋ',
    'va'  => 'fatikáaŋ',
    'vc'  => "sɛ́ŋ\ fɛŋsáŋ\ elekelenatíin",
    'vd'  => "North\ Vietnam",
    've'  => 'fenesuwelá',
    'vg'  => "Filisíin\ ungilís",
    'vi'  => "pindisúlɛ́\ pi\ amálíka",
    'vn'  => 'fiɛtnáam',
    'vu'  => 'fanuatú',
    'wf'  => "walíis\ na\ futúna",
    'wk'  => "Wake\ Island",
    'ws'  => 'samowá',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'yémɛn',
    'yt'  => 'mayɔ́ɔt',
    'za'  => "afilí\ mbátɛ́",
    'zm'  => 'saambíi',
    'zw'  => 'simbapuwé',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::yav::name_to_code = (
    'afilímbátɛ́'                           => 'za',
    'afkanistáŋ'                              => 'af',
    'africa'                                    => '002',
    'alapísawutíit'                           => 'sa',
    'almanía'                                  => 'am',
    'alpaní'                                   => 'al',
    'alsaŋtín'                                => 'ar',
    'alselí'                                   => 'dz',
    'alúpa'                                    => 'aw',
    'americas'                                  => '019',
    'amálíka'                                 => 'us',
    'andíiyunitililáand'                      => 'an',
    'antarctica'                                => 'aq',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'asɛlpaisáŋ'                             => 'az',
    'australiaandnewzealand'                    => '053',
    'ayíti'                                    => 'ht',
    'aŋkíla'                                  => 'ai',
    'aŋkúla'                                  => 'ao',
    'aŋtíkanapalpúta'                        => 'ag',
    'aŋtúla'                                  => 'ad',
    'bouvetisland'                              => 'bv',
    'britishantarcticterritory'                 => 'bq',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'diegogarcia'                               => 'dg',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekuatɛ́l'                                => 'ec',
    'elewuniɔ́ŋ'                             => 're',
    'elitée'                                   => 'er',
    'etiopí'                                   => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'fanuatú'                                  => 'vu',
    'faroeislands'                              => 'fo',
    'fatikáaŋ'                                => 'va',
    'felensí'                                  => 'fr',
    'fenesuwelá'                               => 've',
    'filipíin'                                 => 'ph',
    'filisíinungilís'                         => 'vg',
    'fiɛtnáam'                                => 'vn',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'físi'                                     => 'fj',
    'fɛnlánd'                                 => 'fi',
    'guernsey'                                  => 'gg',
    'heardislandandmcdonaldislands'             => 'hm',
    'hongkong'                                  => 'hk',
    'ililánd'                                  => 'ie',
    'ilmaliyanɛumuɛnɛ́'                     => 'mp',
    'ilnɔ́lfɔ́lɔk'                         => 'nf',
    'ilsalomɔ́ŋ'                             => 'sb',
    'ilák'                                     => 'iq',
    'iláŋ'                                    => 'ir',
    'imiláatipaaláap'                         => 'ae',
    'ingilíís'                                => 'gb',
    'isleofman'                                 => 'im',
    'isláand'                                  => 'is',
    'isípit'                                   => 'eg',
    'italí'                                    => 'it',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'kambíi'                                   => 'gm',
    'kaná'                                     => 'gh',
    'kapɔ́ŋ'                                 => 'ga',
    'kasaksitáŋ'                              => 'kz',
    'katáal'                                   => 'qa',
    'kelenáat'                                 => 'gd',
    'kemelún'                                  => 'cm',
    'kiiné'                                    => 'gn',
    'kiinépisaó'                              => 'gw',
    'kilikisistáŋ'                            => 'kg',
    'kilipatí'                                 => 'ki',
    'kilɛ́ɛk'                                => 'gr',
    'kinéekuatolial'                           => 'gq',
    'kitɔŋkipalɛstíin'                      => 'ps',
    'kitɔŋkícɛ́k'                          => 'cz',
    'kitɔŋkíkongó'                          => 'cd',
    'kitɔŋkítumunikɛ́ŋ'                   => 'do',
    'kolowasíi'                                => 'hr',
    'kongó'                                    => 'cg',
    'kowéet'                                   => 'kw',
    'kuamiɛ'                                   => 'gu',
    'kuatelúup'                                => 'gp',
    'kuatemalá'                                => 'gt',
    'kuluɛnlánd'                              => 'gl',
    'kuyáan'                                   => 'gy',
    'kuyáanufelensí'                          => 'gf',
    'kámbóse'                                 => 'kh',
    'kánáta'                                  => 'ca',
    'kápfɛl'                                  => 'cv',
    'káyímanɛ'                               => 'ky',
    'kénia'                                    => 'ke',
    'kóstálíka'                              => 'cr',
    'kótifualɛ'                               => 'ci',
    'kúpa'                                     => 'cu',
    'kúuke'                                    => 'ck',
    'kɔléumuɛnɛ́'                          => 'kp',
    'kɔléwumbát'                             => 'kr',
    'kɔlɔ́mbía'                             => 'co',
    'kɔmɔ́ɔl'                               => 'km',
    'kɔɔ́mkíndiányingilís'                => 'io',
    'latinamerica'                              => 419,
    'lawós'                                    => 'la',
    'lesotó'                                   => 'ls',
    'letoní'                                   => 'lv',
    'liksambúul'                               => 'lu',
    'lipáŋ'                                   => 'lb',
    'lipélia'                                  => 'lr',
    'lipíi'                                    => 'ly',
    'litiyaní'                                 => 'lt',
    'lístɛ́nsitáyin'                        => 'li',
    'macau'                                     => 'mo',
    'malawí'                                   => 'mw',
    'malesí'                                   => 'my',
    'maletíif'                                 => 'mv',
    'maltiníik'                                => 'mq',
    'maluwín'                                  => 'fk',
    'malí'                                     => 'ml',
    'malóok'                                   => 'ma',
    'masetuán'                                 => 'mk',
    'matakaskáal'                              => 'mg',
    'mayɔ́ɔt'                                => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'miaŋmáal'                                => 'mm',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikolonesí'                               => 'fm',
    'molitaní'                                 => 'mr',
    'moltafí'                                  => 'md',
    'molís'                                    => 'mu',
    'monakó'                                   => 'mc',
    'mongolí'                                  => 'mn',
    'montenegro'                                => 'me',
    'mosambík'                                 => 'mz',
    'málɛ́t'                                 => 'mt',
    'mɔŋsilá'                                => 'ms',
    'mɛksíik'                                 => 'mx',
    'namipí'                                   => 'na',
    'nawulú'                                   => 'nr',
    'nepáal'                                   => 'np',
    'neutralzone'                               => 'nt',
    'nikalaká'                                 => 'ni',
    'nisélia'                                  => 'ng',
    'nisɛ́ɛl'                                => 'ne',
    'nitililáand'                              => 'nl',
    'niyuwé'                                   => 'nu',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'nsáman'                                   => 'de',
    'nufɛ́lkaletoní'                         => 'nc',
    'nufɛ́lseláand'                          => 'nz',
    'nɔlfɛ́ɛs'                              => 'no',
    'oceania'                                   => '009',
    'omáŋ'                                    => 'om',
    'otalalí'                                  => 'au',
    'otilís'                                   => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pahámas'                                  => 'bs',
    'pakistáŋ'                                => 'pk',
    'palakúé'                                 => 'py',
    'palawú'                                   => 'pw',
    'palpatós'                                 => 'bb',
    'palɛŋ'                                   => 'bh',
    'panamacanalzone'                           => 'pz',
    'panamá'                                   => 'pa',
    'panyá'                                    => 'es',
    'papuasínufɛ́lkiiné'                    => 'pg',
    'paŋkalatɛs'                              => 'bd',
    'pelalús'                                  => 'by',
    'pelíse'                                   => 'bz',
    'pelú'                                     => 'pe',
    'penɛŋ'                                   => 'bj',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'pilesíl'                                  => 'br',
    'pindisúlɛ́piamálíka'                  => 'vi',
    'pitikɛ́ɛlínɛ́'                       => 'pn',
    'polinesíufelensí'                        => 'pf',
    'polynesia'                                 => '061',
    'polífia'                                  => 'bo',
    'posuána'                                  => 'bw',
    'pulikínafásó'                           => 'bf',
    'pulukalíi'                                => 'bg',
    'pulunéy'                                  => 'bn',
    'pusiníɛlkofína'                         => 'ba',
    'putaŋ'                                    => 'bt',
    'pólótolíko'                             => 'pr',
    'púlúndí'                                => 'bi',
    'pɔltukáal'                               => 'pt',
    'pɔlɔ́ɔny'                              => 'pl',
    'pɛlmúta'                                 => 'bm',
    'pɛlsíik'                                 => 'be',
    'saambíi'                                  => 'zm',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'salfatɔ́ɔl'                             => 'sv',
    'samayíik'                                 => 'jm',
    'samowá'                                   => 'ws',
    'sanmalíno'                                => 'sm',
    'santalafilíik'                            => 'cf',
    'sapɔ́ɔŋ'                               => 'jp',
    'senekáal'                                 => 'sn',
    'serbia'                                    => 'rs',
    'sesɛ́ɛl'                                => 'sc',
    'sieláleyɔ́ɔn'                          => 'sl',
    'silofakí'                                 => 'sk',
    'silofení'                                 => 'si',
    'silí'                                     => 'cl',
    'silíláŋka'                              => 'lk',
    'simbapuwé'                                => 'zw',
    'singapúul'                                => 'sg',
    'somalí'                                   => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'suasiláand'                               => 'sz',
    'sulináam'                                 => 'sr',
    'sutáaŋ'                                  => 'sd',
    'suwíis'                                   => 'ch',
    'suɛ́t'                                   => 'se',
    'svalbardandjanmayen'                       => 'sj',
    'syria'                                     => 'sy',
    'sáat'                                     => 'td',
    'sámuauamelíka'                           => 'as',
    'sáwótoméepelensípe'                    => 'st',
    'síine'                                    => 'cn',
    'sílpalatáal'                             => 'gi',
    'síplɛ'                                   => 'cy',
    'síputí'                                  => 'dj',
    'sɔlsíi'                                  => 'ge',
    'sɔltaní'                                 => 'jo',
    'sɛlpíemɔ́ŋténékolo'                 => 'cs',
    'sɛ́ŋfɛŋsáŋelekelenatíin'           => 'vc',
    'sɛ́ŋkilistɔ́feniɛ́f'                => 'kn',
    'sɛ́ŋpiɛ́lemikelɔ́ŋ'                => 'pm',
    'sɛ́ŋtɛ́elɛ́ɛnɛ'                   => 'sh',
    'sɛ́ŋtɛ́lusí'                         => 'lc',
    'tanemálk'                                 => 'dk',
    'tasikistáaŋ'                             => 'tj',
    'tayiláand'                                => 'th',
    'tayiwáan'                                 => 'tw',
    'taŋsaní'                                 => 'tz',
    'tilinitáatnatupákɔ'                     => 'tt',
    'timɔ́ɔlunipálɛ́n'                    => 'tl',
    'tokeló'                                   => 'tk',
    'tokó'                                     => 'tg',
    'tristandacunha'                            => 'ta',
    'tufalú'                                   => 'tv',
    'tulukmenisitáaŋ'                         => 'tm',
    'tulukíi'                                  => 'tr',
    'tunusí'                                   => 'tn',
    'túluknakáyiik'                           => 'tc',
    'túmúnéke'                               => 'dm',
    'tɔ́ŋka'                                 => 'to',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ukilɛ́ɛn'                               => 'ua',
    'ukánda'                                   => 'ug',
    'ulukuéy'                                  => 'uy',
    'ulumaní'                                  => 'ro',
    'ulusí'                                    => 'ru',
    'uluándá'                                 => 'rw',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'usupekistáaŋ'                            => 'uz',
    'wakeisland'                                => 'wk',
    'walíisnafutúna'                          => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yémɛn'                                   => 'ye',
    "\Ã\landislands"                         => 'ax',
    'ílmalasáal'                              => 'mh',
    'ísilayɛ́l'                              => 'il',
    'ɔndúlas'                                 => 'hn',
    'ɔngilí'                                  => 'hu',
    'ɛndonesí'                                => 'id',
    'ɛstoni'                                   => 'ee',
    'ɛ́ɛnd'                                  => 'in',
);

1;

