package Locales::DB::Territory::khq;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::khq::VERSION = '0.09';

$Locales::DB::Territory::khq::cldr_version = '2.0';

%Locales::DB::Territory::khq::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andoora',
    'ae'  => "Laaraw\ Imaarawey\ Margantey",
    'af'  => 'Afgaanistan',
    'ag'  => "Antigua\ nda\ Barbuuda",
    'ai'  => 'Angiiya',
    'al'  => 'Albaani',
    'am'  => 'Armeeni',
    'an'  => "Hollandu\ Antiiyey\ Laboo",
    'ao'  => 'Angoola',
    'aq'  => 'Antarctica',
    'ar'  => 'Argentine',
    'as'  => "Ameriki\ Samoa",
    'at'  => 'Otriši',
    'au'  => 'Ostraali',
    'aw'  => 'Aruuba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerbaayijaŋ',
    'ba'  => "Bosni\ nda\ Herzegovine",
    'bb'  => 'Barbaados',
    'bd'  => 'Bangladeši',
    'be'  => 'Belgiiki',
    'bf'  => "Burkina\ faso",
    'bg'  => 'Bulgaari',
    'bh'  => 'Bahareen',
    'bi'  => 'Burundi',
    'bj'  => 'Beniŋ',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Bruunee',
    'bo'  => 'Boolivi',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Breezil',
    'bs'  => 'Bahamas',
    'bt'  => 'Buutaŋ',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswaana',
    'by'  => 'Biloriši',
    'bz'  => 'Beliizi',
    'ca'  => 'Kanaada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Kongoo\ demookaratiki\ laboo",
    'cf'  => "Centraafriki\ koyra",
    'cg'  => 'Kongoo',
    'ch'  => 'Swisu',
    'ci'  => 'Kudwar',
    'ck'  => "Kuuk\ gungey",
    'cl'  => 'Šiili',
    'cm'  => 'Kameruun',
    'cn'  => 'Šiin',
    'co'  => 'Kolombi',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kosta\ rika",
    'cs'  => "Serbi\ nda\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuuba',
    'cv'  => "Kapuver\ gungey",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Šiipur',
    'cz'  => "Cek\ labo",
    'dd'  => "East\ Germany",
    'de'  => 'Almaaɲe',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Jibuuti',
    'dk'  => 'Danemark',
    'dm'  => 'Doominiki',
    'do'  => "Doominiki\ laboo",
    'dz'  => 'Alžeeri',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekwateer',
    'ee'  => 'Estooni',
    'eg'  => 'Misra',
    'eh'  => "Western\ Sahara",
    'er'  => 'Eritree',
    'es'  => 'Espaaɲe',
    'et'  => 'Ecioopi',
    'eu'  => "European\ Union",
    'fi'  => 'Finlandu',
    'fj'  => 'Fiji',
    'fk'  => "Kalkan\ gungey",
    'fm'  => 'Mikronezi',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Faransi',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gaabon',
    'gb'  => "Albaasalaama\ Marganta",
    'gd'  => 'Grenaada',
    'ge'  => 'Gorgi',
    'gf'  => "Faransi\ Guyaan",
    'gg'  => 'Guernsey',
    'gh'  => 'Gaana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grinland',
    'gm'  => 'Gambi',
    'gn'  => 'Gine',
    'gp'  => 'Gwadeluup',
    'gq'  => "Ginee\ Ekwatorial",
    'gr'  => 'Greece',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatemaala',
    'gu'  => 'Guam',
    'gw'  => "Gine\-Bisso",
    'gy'  => 'Guyaane',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Honduras',
    'hr'  => 'Krwaasi',
    'ht'  => 'Haiti',
    'hu'  => 'Hungaari',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indoneezi',
    'ie'  => 'Irlandu',
    'il'  => 'Israyel',
    'im'  => "Isle\ of\ Man",
    'in'  => "Indu\ laboo",
    'io'  => "Britiši\ Indu\ teekoo\ laama",
    'iq'  => 'Iraak',
    'ir'  => 'Iraan',
    'is'  => 'Ayceland',
    'it'  => 'Itaali',
    'je'  => 'Jersey',
    'jm'  => 'Jamaayik',
    'jo'  => 'Urdun',
    'jp'  => 'Jaapoŋ',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Keeniya',
    'kg'  => 'Kyrgyzstan',
    'kh'  => 'Kamboogi',
    'ki'  => 'Kiribaati',
    'km'  => 'Komoor',
    'kn'  => "Seŋ\ Kitts\ nda\ Nevis",
    'kp'  => "Kooree\,\ Gurma",
    'kr'  => "Kooree\,\ Hawsa",
    'kw'  => 'Kuweet',
    'ky'  => "Kayman\ gungey",
    'kz'  => 'Kaazakstan',
    'la'  => 'Laawos',
    'lb'  => 'Lubnaan',
    'lc'  => "Seŋ\ Lussia",
    'li'  => 'Liechtenstein',
    'lk'  => 'Srilanka',
    'lr'  => 'Liberia',
    'ls'  => 'Leesoto',
    'lt'  => 'Lituaani',
    'lu'  => 'Luxembourg',
    'lv'  => 'Letooni',
    'ly'  => 'Liibi',
    'ma'  => 'Maarok',
    'mc'  => 'Monako',
    'md'  => 'Moldovi',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagascar',
    'mh'  => "Maršal\ gungey",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Maacedooni',
    'ml'  => 'Maali',
    'mm'  => 'Maynamar',
    'mn'  => 'Mongooli',
    'mo'  => 'Macau',
    'mp'  => "Mariana\ Gurma\ Gungey",
    'mq'  => 'Martiniiki',
    'mr'  => 'Mooritaani',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => "Mooris\ gungey",
    'mv'  => 'Maldiivu',
    'mw'  => 'Malaawi',
    'mx'  => 'Mexiki',
    'my'  => 'Maleezi',
    'mz'  => 'Mozambik',
    'na'  => 'Naamibi',
    'nc'  => "Kaaledooni\ Taagaa",
    'ne'  => 'Nižer',
    'nf'  => "Norfolk\ Gungoo",
    'ng'  => 'Naajiriia',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Hollandu',
    'no'  => 'Norveej',
    'np'  => 'Neepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Zeelandu\ Taaga",
    'om'  => 'Omaan',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peeru',
    'pf'  => "Faransi\ Polineezi",
    'pg'  => "Papua\ Ginee\ Taaga",
    'ph'  => 'Filipine',
    'pk'  => 'Paakistan',
    'pl'  => 'Poloɲe',
    'pm'  => "Seŋ\ Piyer\ nda\ Mikelon",
    'pn'  => 'Pitikarin',
    'pr'  => "Porto\ Riko",
    'ps'  => "Palestine\ Dangay\ nda\ Gaaza",
    'pt'  => 'Portugaal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palu',
    'py'  => 'Paraguwey',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Kataar',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Reenioŋ',
    'ro'  => 'Rumaani',
    'rs'  => 'Serbia',
    'ru'  => "Iriši\ laboo",
    'rw'  => 'Rwanda',
    'sa'  => 'Saudiya',
    'sb'  => "Solomon\ Gungey",
    'sc'  => 'Seešel',
    'sd'  => 'Suudaŋ',
    'se'  => 'Sweede',
    'sg'  => 'Singapur',
    'sh'  => "Seŋ\ Helena",
    'si'  => 'Sloveeni',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Slovaaki',
    'sl'  => "Seera\ Leon",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somaali',
    'sr'  => 'Surinaam',
    'st'  => "Sao\ Tome\ nda\ Prinsipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "Salvador\ laboo",
    'sy'  => 'Suuria',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turk\ nda\ Kayikos\ Gungey",
    'td'  => 'Caadu',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togo',
    'th'  => 'Taayiland',
    'tj'  => 'Taažikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timoor\ hawsa",
    'tm'  => 'Turkmenistaŋ',
    'tn'  => 'Tunizi',
    'to'  => 'Tonga',
    'tr'  => 'Turki',
    'tt'  => "Trinidad\ nda\ Tobaago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taayiwan',
    'tz'  => 'Tanzaani',
    'ua'  => 'Ukreen',
    'ug'  => 'Uganda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Ameriki\ Laabu\ Margantey",
    'uy'  => 'Uruguwey',
    'uz'  => 'Uzbeekistan',
    'va'  => "Vaatikan\ Laama",
    'vc'  => "Seŋvinsaŋ\ nda\ Grenadine",
    'vd'  => "North\ Vietnam",
    've'  => 'Veneezuyeela',
    'vg'  => "Britiši\ Virgin\ gungey",
    'vi'  => "Ameerik\ Virgin\ Gungey",
    'vn'  => 'Vietnaam',
    'vu'  => 'Vanautu',
    'wf'  => "Wallis\ nda\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yaman',
    'yt'  => 'Mayooti',
    'za'  => "Hawsa\ Afriki\ Laboo",
    'zm'  => 'Zambi',
    'zw'  => 'Zimbabwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::khq::name_to_code = (
    'afgaanistan'                               => 'af',
    'africa'                                    => '002',
    'albaani'                                   => 'al',
    'albaasalaamamarganta'                      => 'gb',
    'almaaɲe'                                  => 'de',
    'alžeeri'                                  => 'dz',
    'ameerikvirgingungey'                       => 'vi',
    'americas'                                  => '019',
    'amerikilaabumargantey'                     => 'us',
    'amerikisamoa'                              => 'as',
    'andoora'                                   => 'ad',
    'angiiya'                                   => 'ai',
    'angoola'                                   => 'ao',
    'antarctica'                                => 'aq',
    'antiguandabarbuuda'                        => 'ag',
    'argentine'                                 => 'ar',
    'armeeni'                                   => 'am',
    'aruuba'                                    => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'ayceland'                                  => 'is',
    'azerbaayijaŋ'                             => 'az',
    'bahamas'                                   => 'bs',
    'bahareen'                                  => 'bh',
    'bangladeši'                               => 'bd',
    'barbaados'                                 => 'bb',
    'belgiiki'                                  => 'be',
    'beliizi'                                   => 'bz',
    'beniŋ'                                    => 'bj',
    'bermuda'                                   => 'bm',
    'biloriši'                                 => 'by',
    'boolivi'                                   => 'bo',
    'bosnindaherzegovine'                       => 'ba',
    'botswaana'                                 => 'bw',
    'bouvetisland'                              => 'bv',
    'breezil'                                   => 'br',
    'britishantarcticterritory'                 => 'bq',
    'britišiinduteekoolaama'                   => 'io',
    'britišivirgingungey'                      => 'vg',
    'bruunee'                                   => 'bn',
    'bulgaari'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'buutaŋ'                                   => 'bt',
    'caadu'                                     => 'td',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'ceklabo'                                   => 'cz',
    'centraafrikikoyra'                         => 'cf',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danemark'                                  => 'dk',
    'diegogarcia'                               => 'dg',
    'doominiki'                                 => 'dm',
    'doominikilaboo'                            => 'do',
    'dronningmaudland'                          => 'nq',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ecioopi'                                   => 'et',
    'ekwateer'                                  => 'ec',
    'eritree'                                   => 'er',
    'espaaɲe'                                  => 'es',
    'estooni'                                   => 'ee',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faransi'                                   => 'fr',
    'faransiguyaan'                             => 'gf',
    'faransipolineezi'                          => 'pf',
    'faroeislands'                              => 'fo',
    'fiji'                                      => 'fj',
    'filipine'                                  => 'ph',
    'finlandu'                                  => 'fi',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'gaabon'                                    => 'ga',
    'gaana'                                     => 'gh',
    'gambi'                                     => 'gm',
    'gibraltar'                                 => 'gi',
    'gine'                                      => 'gn',
    'ginebisso'                                 => 'gw',
    'gineeekwatorial'                           => 'gq',
    'gorgi'                                     => 'ge',
    'greece'                                    => 'gr',
    'grenaada'                                  => 'gd',
    'grinland'                                  => 'gl',
    'guam'                                      => 'gu',
    'guernsey'                                  => 'gg',
    'guyaane'                                   => 'gy',
    'gwadeluup'                                 => 'gp',
    'gwatemaala'                                => 'gt',
    'haiti'                                     => 'ht',
    'hawsaafrikilaboo'                          => 'za',
    'heardislandandmcdonaldislands'             => 'hm',
    'hollandu'                                  => 'nl',
    'hollanduantiiyeylaboo'                     => 'an',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hungaari'                                  => 'hu',
    'indoneezi'                                 => 'id',
    'indulaboo'                                 => 'in',
    'iraak'                                     => 'iq',
    'iraan'                                     => 'ir',
    'irišilaboo'                               => 'ru',
    'irlandu'                                   => 'ie',
    'isleofman'                                 => 'im',
    'israyel'                                   => 'il',
    'itaali'                                    => 'it',
    'jaapoŋ'                                   => 'jp',
    'jamaayik'                                  => 'jm',
    'jersey'                                    => 'je',
    'jibuuti'                                   => 'dj',
    'johnstonisland'                            => 'jt',
    'kaaledoonitaagaa'                          => 'nc',
    'kaazakstan'                                => 'kz',
    'kalkangungey'                              => 'fk',
    'kamboogi'                                  => 'kh',
    'kameruun'                                  => 'cm',
    'kanaada'                                   => 'ca',
    'kapuvergungey'                             => 'cv',
    'kataar'                                    => 'qa',
    'kaymangungey'                              => 'ky',
    'keeniya'                                   => 'ke',
    'kiribaati'                                 => 'ki',
    'kolombi'                                   => 'co',
    'komoor'                                    => 'km',
    'kongoo'                                    => 'cg',
    'kongoodemookaratikilaboo'                  => 'cd',
    "kooree\,gurma"                             => 'kp',
    "kooree\,hawsa"                             => 'kr',
    'kostarika'                                 => 'cr',
    'krwaasi'                                   => 'hr',
    'kudwar'                                    => 'ci',
    'kuuba'                                     => 'cu',
    'kuukgungey'                                => 'ck',
    'kuweet'                                    => 'kw',
    'kyrgyzstan'                                => 'kg',
    'laarawimaaraweymargantey'                  => 'ae',
    'laawos'                                    => 'la',
    'latinamerica'                              => 419,
    'leesoto'                                   => 'ls',
    'letooni'                                   => 'lv',
    'liberia'                                   => 'lr',
    'liechtenstein'                             => 'li',
    'liibi'                                     => 'ly',
    'lituaani'                                  => 'lt',
    'lubnaan'                                   => 'lb',
    'luxembourg'                                => 'lu',
    'maacedooni'                                => 'mk',
    'maali'                                     => 'ml',
    'maarok'                                    => 'ma',
    'macau'                                     => 'mo',
    'madagascar'                                => 'mg',
    'malaawi'                                   => 'mw',
    'maldiivu'                                  => 'mv',
    'maleezi'                                   => 'my',
    'malta'                                     => 'mt',
    'marianagurmagungey'                        => 'mp',
    'martiniiki'                                => 'mq',
    'maršalgungey'                             => 'mh',
    'maynamar'                                  => 'mm',
    'mayooti'                                   => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'mexiki'                                    => 'mx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikronezi'                                 => 'fm',
    'misra'                                     => 'eg',
    'moldovi'                                   => 'md',
    'monako'                                    => 'mc',
    'mongooli'                                  => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'moorisgungey'                              => 'mu',
    'mooritaani'                                => 'mr',
    'mozambik'                                  => 'mz',
    'naajiriia'                                 => 'ng',
    'naamibi'                                   => 'na',
    'nauru'                                     => 'nr',
    'neepal'                                    => 'np',
    'neutralzone'                               => 'nt',
    'nikaragwa'                                 => 'ni',
    'niue'                                      => 'nu',
    'nižer'                                    => 'ne',
    'norfolkgungoo'                             => 'nf',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'norveej'                                   => 'no',
    'oceania'                                   => '009',
    'omaan'                                     => 'om',
    'ostraali'                                  => 'au',
    'otriši'                                   => 'at',
    'outlyingoceania'                           => 'qo',
    'paakistan'                                 => 'pk',
    'pacificislandstrustterritory'              => 'pc',
    'palestinedangayndagaaza'                   => 'ps',
    'palu'                                      => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuagineetaaga'                           => 'pg',
    'paraguwey'                                 => 'py',
    'peeru'                                     => 'pe',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'pitikarin'                                 => 'pn',
    'poloɲe'                                   => 'pl',
    'polynesia'                                 => '061',
    'portoriko'                                 => 'pr',
    'portugaal'                                 => 'pt',
    'reenioŋ'                                  => 're',
    'rumaani'                                   => 'ro',
    'rwanda'                                    => 'rw',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'salvadorlaboo'                             => 'sv',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saotomendaprinsipe'                        => 'st',
    'saudiya'                                   => 'sa',
    'seeraleon'                                 => 'sl',
    'seešel'                                   => 'sc',
    'senegal'                                   => 'sn',
    'serbia'                                    => 'rs',
    'serbindamontenegro'                        => 'cs',
    'seŋhelena'                                => 'sh',
    'seŋkittsndanevis'                         => 'kn',
    'seŋlussia'                                => 'lc',
    'seŋpiyerndamikelon'                       => 'pm',
    'seŋvinsaŋndagrenadine'                   => 'vc',
    'singapur'                                  => 'sg',
    'slovaaki'                                  => 'sk',
    'sloveeni'                                  => 'si',
    'solomongungey'                             => 'sb',
    'somaali'                                   => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'srilanka'                                  => 'lk',
    'surinaam'                                  => 'sr',
    'suudaŋ'                                   => 'sd',
    'suuria'                                    => 'sy',
    'svalbardandjanmayen'                       => 'sj',
    'swaziland'                                 => 'sz',
    'sweede'                                    => 'se',
    'swisu'                                     => 'ch',
    'taayiland'                                 => 'th',
    'taayiwan'                                  => 'tw',
    'taažikistan'                              => 'tj',
    'tanzaani'                                  => 'tz',
    'timoorhawsa'                               => 'tl',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadndatobaago'                        => 'tt',
    'tristandacunha'                            => 'ta',
    'tunizi'                                    => 'tn',
    'turki'                                     => 'tr',
    'turkmenistaŋ'                             => 'tm',
    'turkndakayikosgungey'                      => 'tc',
    'tuvalu'                                    => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukreen'                                    => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'urdun'                                     => 'jo',
    'uruguwey'                                  => 'uy',
    'uzbeekistan'                               => 'uz',
    'vaatikanlaama'                             => 'va',
    'vanautu'                                   => 'vu',
    'veneezuyeela'                              => 've',
    'vietnaam'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'wallisndafutuna'                           => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yaman'                                     => 'ye',
    'zambi'                                     => 'zm',
    'zeelandutaaga'                             => 'nz',
    'zimbabwe'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
    'Šiili'                                    => 'cl',
    'Šiin'                                     => 'cn',
    'Šiipur'                                   => 'cy',
);

1;

