package Locales::DB::Territory::sg;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::sg::VERSION = '0.09';

$Locales::DB::Territory::sg::cldr_version = '2.0';

%Locales::DB::Territory::sg::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andôro',
    'ae'  => "Arâbo\ Emirâti\ Ôko",
    'af'  => "Faganïta\,\ Afganïstäan",
    'ag'  => "Antîgua\ na\ Barbûda",
    'ai'  => 'Angûîla',
    'al'  => 'Albanïi',
    'am'  => 'Armenïi',
    'an'  => "Antîyi\ tî\ Holânde",
    'ao'  => 'Angoläa',
    'aq'  => 'Antarctica',
    'ar'  => 'Arzantîna',
    'as'  => "Samöa\ tî\ Amerîka",
    'at'  => 'Otrîsi',
    'au'  => "Ostralïi\,\ Sotralïi",
    'aw'  => 'Arûba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => "Zerebaidyäan\,\ Azerbaidyäan\,",
    'ba'  => "Bosnïi\ na\ Herzegovînni",
    'bb'  => 'Barabâda',
    'bd'  => 'Bengladêshi',
    'be'  => "Bêleze\,\ Belezîki",
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulugarïi',
    'bh'  => 'Bahrâina',
    'bi'  => 'Burundïi',
    'bj'  => 'Benëen',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Beremûda',
    'bn'  => 'Brunêi',
    'bo'  => 'Bolivïi',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brezîli',
    'bs'  => 'Bahâmasa',
    'bt'  => 'Butäan',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Botswana',
    'by'  => 'Belarüsi',
    'bz'  => 'Belîzi',
    'ca'  => 'Kanadäa',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Ködörösêse\ tî\ Ngunuhalëzo\ tî\ kongö",
    'cf'  => "Ködörösêse\ tî\ Bêafrîka",
    'cg'  => 'Kongö',
    'ch'  => 'Sûîsi',
    'ci'  => 'Kôdivüära',
    'ck'  => "âzûâ\ Kûku",
    'cl'  => 'Shilïi',
    'cm'  => 'Kamerûne',
    'cn'  => 'Shîna',
    'co'  => 'Kolombïi',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kôsta\ Rîka",
    'cs'  => "Serbïi\ na\ Möntënegröo",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kubäa',
    'cv'  => "Azûâ\ tî\ Kâpo\-Vêre",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Sîpri',
    'cz'  => "Ködörösêse\ tî\ Tyêki",
    'dd'  => "East\ Germany",
    'de'  => 'Zâmani',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Dibutùii',
    'dk'  => 'Danemêrke',
    'dm'  => 'Dömïnîka',
    'do'  => "Ködörösêse\ tî\ Dominîka",
    'dz'  => 'Alzerïi',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ekuatëre',
    'ee'  => 'Estonïi',
    'eg'  => 'Kâmitâ',
    'eh'  => "Western\ Sahara",
    'er'  => 'Eritrëe',
    'es'  => 'Espânye',
    'et'  => 'Etiopïi',
    'eu'  => "European\ Union",
    'fi'  => 'Fëlânde',
    'fj'  => 'Fidyïi',
    'fk'  => "Âzûâ\ tî\ Mälüîni",
    'fm'  => 'Mikronezïi',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Farânzi',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gaböon',
    'gb'  => "Ködörögbïä\-\-Ôko",
    'gd'  => 'Grenâda',
    'ge'  => 'Zorzïi',
    'gf'  => "Güyâni\ tî\ farânzi",
    'gg'  => 'Guernsey',
    'gh'  => 'Ganäa',
    'gi'  => "Zibraltära\,\ Zibaratära",
    'gl'  => 'Gorolânde',
    'gm'  => 'Gambïi',
    'gn'  => 'Ginëe',
    'gp'  => 'Guadelûpu',
    'gq'  => "Ginëe\ tî\ Ekuatëre",
    'gr'  => 'Gerêsi',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Guatêmälä',
    'gu'  => 'Guâm',
    'gw'  => "Gninëe\-Bisau",
    'gy'  => 'Gayâna',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Honduräsi',
    'hr'  => 'Kroasïi',
    'ht'  => 'Haitïi',
    'hu'  => 'Hongirùii',
    'ic'  => "Canary\ Islands",
    'id'  => 'Ênndonezïi',
    'ie'  => 'Irlânde',
    'il'  => 'Israëli',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Ênnde',
    'io'  => "Sêse\ tî\ Anglëe\ na\ Ngûyämä\ tî\ Ênnde",
    'iq'  => 'Irâki',
    'ir'  => 'Iräan',
    'is'  => 'Islânde',
    'it'  => 'Italùii',
    'je'  => 'Jersey',
    'jm'  => 'Zamaîka',
    'jo'  => 'Zordanïi',
    'jp'  => 'Zapöon',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenyäa',
    'kg'  => 'Kirigizitùaan',
    'kh'  => 'Kämbôzi',
    'ki'  => 'Kiribati',
    'km'  => 'Kömôro',
    'kn'  => "Sên\-Krïstôfo\-na\-Nevîsi",
    'kp'  => "Korëe\ tî\ Banga",
    'kr'  => "Korëe\ tî\ Mbongo",
    'kw'  => 'Köwêti',
    'ky'  => "Âzûâ\ Ngundë\,\ Kaimäni",
    'kz'  => 'Kazakisitäan',
    'la'  => 'Lùaôsi',
    'lb'  => 'Libùaan',
    'lc'  => "Sênt\-Lisïi",
    'li'  => "Liechtenstein\,",
    'lk'  => "Sirî\-Lanka",
    'lr'  => 'Liberïa',
    'ls'  => 'Lesôtho',
    'lt'  => 'Lituanïi',
    'lu'  => 'Lugzambûru',
    'lv'  => 'Letonùii',
    'ly'  => 'Libïi',
    'ma'  => 'Marôko',
    'mc'  => 'Monaköo',
    'md'  => 'Moldavùii',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madagaskära',
    'mh'  => "Âzûâ\ Märshâl",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Maseduäni',
    'ml'  => 'Malïi',
    'mm'  => 'Myämâra',
    'mn'  => 'Mongolïi',
    'mo'  => 'Macau',
    'mp'  => "Âzûâ\ Märïâni\ tî\ Banga",
    'mq'  => 'Märtïnîki',
    'mr'  => 'Moritanïi',
    'ms'  => 'Monserâte',
    'mt'  => 'Mâlta',
    'mu'  => 'Mörîsi',
    'mv'  => 'Maldîva',
    'mw'  => 'Malawïi',
    'mx'  => 'Mekisîki',
    'my'  => 'Malezïi',
    'mz'  => 'Mözämbîka',
    'na'  => 'Namibùii',
    'nc'  => "Finî\ Kaledonïi",
    'ne'  => 'Nizëre',
    'nf'  => "Zûâ\ Nôrfôlko",
    'ng'  => 'Nizerïa',
    'ni'  => 'Nikaragua',
    'nl'  => 'Holände',
    'no'  => 'Nörvêzi',
    'np'  => 'Nëpâli',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Finî\ Zelânde",
    'om'  => 'Omâni',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Perüu',
    'pf'  => "Polinezïi\ tî\ farânzi",
    'pg'  => "Papû\ Finî\ Ginëe\,\ Papuazïi",
    'ph'  => 'Filipîni',
    'pk'  => 'Pakistäan',
    'pl'  => 'Pölôni',
    'pm'  => "Sên\-Pyêre\ na\ Mikelöon",
    'pn'  => 'Pitikêrni',
    'pr'  => "Porto\ Rîko",
    'ps'  => "Sêse\ tî\ Palestîni",
    'pt'  => "Pörtugäle\,\ Ködörö\ Pûra",
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguëe',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Katära',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Reinïon',
    'ro'  => 'Rumanïi',
    'rs'  => 'Serbia',
    'ru'  => 'Rusïi',
    'rw'  => 'Ruandäa',
    'sa'  => "Saûdi\ Arabïi",
    'sb'  => "Zûâ\ Salomöon",
    'sc'  => 'Sëyshêle',
    'sd'  => 'Sudäan',
    'se'  => 'Suêde',
    'sg'  => 'Sïngäpûru',
    'sh'  => "Sênt\-Helêna",
    'si'  => 'Solovenïi',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Solovakïi',
    'sl'  => "Sierä\-Leône",
    'sm'  => "Sên\-Marëen",
    'sn'  => 'Senegäle',
    'so'  => 'Somalïi',
    'sr'  => 'Surinäm',
    'st'  => "Sâô\ Tömê\ na\ Prinsîpe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvadöro',
    'sy'  => 'Sirïi',
    'sz'  => 'Swäzïlânde',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Âzûâ\ Turku\ na\ Kaîki",
    'td'  => 'Tyâde',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Togö',
    'th'  => 'Tailânde',
    'tj'  => 'Taazikiistäan',
    'tk'  => 'Tokelau',
    'tl'  => "Timôro\ tî\ Tö",
    'tm'  => 'Turkumenistäan',
    'tn'  => 'Tunizïi',
    'to'  => 'Tonga',
    'tr'  => 'Turukïi',
    'tt'  => "Trinitùee\ na\ Tobagö",
    'tv'  => 'Tüvalü',
    'tw'  => 'Tâiwâni',
    'tz'  => 'Tanzanïi',
    'ua'  => 'Ukrêni',
    'ug'  => 'Ugandäa',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "ÂLeaa\-Ôko\ tî\ Amerika",
    'uy'  => 'Uruguëe',
    'uz'  => 'Uzbekistäan',
    'va'  => "Letëe\ tî\ Vatikäan",
    'vc'  => "Sên\-Vensäan\ na\ âGrenadîni",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezueläa',
    'vg'  => "Âzôâ\ Viîrîggo\ tî\ Anglëe",
    'vi'  => "Âzûâ\ Virîgo\ tî\ Amerîka",
    'vn'  => 'Vietnäm',
    'vu'  => 'Vanuatü',
    'wf'  => "Walîsi\ na\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoäa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yëmêni',
    'yt'  => 'Mäyôte',
    'za'  => "Mbongo\-Afrîka",
    'zm'  => 'Zambïi',
    'zw'  => 'Zimbäbwe',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::sg::name_to_code = (
    'africa'                                    => '002',
    'albanïi'                                  => 'al',
    'alzerïi'                                  => 'dz',
    'americas'                                  => '019',
    'andôro'                                   => 'ad',
    'angoläa'                                  => 'ao',
    'angûîla'                                 => 'ai',
    'antarctica'                                => 'aq',
    'antîguanabarbûda'                        => 'ag',
    'antîyitîholânde'                        => 'an',
    'armenïi'                                  => 'am',
    'arzantîna'                                => 'ar',
    'arâboemirâtiÔko'                        => 'ae',
    'arûba'                                    => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'azûâtîkâpovêre'                       => 'cv',
    'bahrâina'                                 => 'bh',
    'bahâmasa'                                 => 'bs',
    'barabâda'                                 => 'bb',
    'belarüsi'                                 => 'by',
    'belîzi'                                   => 'bz',
    'bengladêshi'                              => 'bd',
    'benëen'                                   => 'bj',
    'beremûda'                                 => 'bm',
    'bolivïi'                                  => 'bo',
    'bosnïinaherzegovînni'                    => 'ba',
    'botswana'                                  => 'bw',
    'bouvetisland'                              => 'bv',
    'brezîli'                                  => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brunêi'                                   => 'bn',
    'bulugarïi'                                => 'bg',
    'burkinafaso'                               => 'bf',
    'burundïi'                                 => 'bi',
    'butäan'                                   => 'bt',
    "bêleze\,belezîki"                        => 'be',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danemêrke'                                => 'dk',
    'dibutùii'                                 => 'dj',
    'diegogarcia'                               => 'dg',
    'dronningmaudland'                          => 'nq',
    'dömïnîka'                               => 'dm',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'ekuatëre'                                 => 'ec',
    'eritrëe'                                  => 'er',
    'espânye'                                  => 'es',
    'estonïi'                                  => 'ee',
    'etiopïi'                                  => 'et',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    "faganïta\,afganïstäan"                  => 'af',
    'faroeislands'                              => 'fo',
    'farânzi'                                  => 'fr',
    'fidyïi'                                   => 'fj',
    'filipîni'                                 => 'ph',
    'finîkaledonïi'                           => 'nc',
    'finîzelânde'                             => 'nz',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'fëlânde'                                 => 'fi',
    'gaböon'                                   => 'ga',
    'gambïi'                                   => 'gm',
    'ganäa'                                    => 'gh',
    'gayâna'                                   => 'gy',
    'gerêsi'                                   => 'gr',
    'ginëe'                                    => 'gn',
    'ginëetîekuatëre'                        => 'gq',
    'gninëebisau'                              => 'gw',
    'gorolânde'                                => 'gl',
    'grenâda'                                  => 'gd',
    'guadelûpu'                                => 'gp',
    'guatêmälä'                              => 'gt',
    'guernsey'                                  => 'gg',
    'guâm'                                     => 'gu',
    'güyânitîfarânzi'                       => 'gf',
    'haitïi'                                   => 'ht',
    'heardislandandmcdonaldislands'             => 'hm',
    'holände'                                  => 'nl',
    'honduräsi'                                => 'hn',
    'hongirùii'                                => 'hu',
    'hongkong'                                  => 'hk',
    'irlânde'                                  => 'ie',
    'irâki'                                    => 'iq',
    'iräan'                                    => 'ir',
    'isleofman'                                 => 'im',
    'islânde'                                  => 'is',
    'israëli'                                  => 'il',
    'italùii'                                  => 'it',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'kamerûne'                                 => 'cm',
    'kanadäa'                                  => 'ca',
    'katära'                                   => 'qa',
    'kazakisitäan'                             => 'kz',
    'kenyäa'                                   => 'ke',
    'kiribati'                                  => 'ki',
    'kirigizitùaan'                            => 'kg',
    'kolombïi'                                 => 'co',
    'kongö'                                    => 'cg',
    'korëetîbanga'                            => 'kp',
    'korëetîmbongo'                           => 'kr',
    'kroasïi'                                  => 'hr',
    'kubäa'                                    => 'cu',
    'kâmitâ'                                  => 'eg',
    'kämbôzi'                                 => 'kh',
    'kôdivüära'                              => 'ci',
    'kôstarîka'                               => 'cr',
    'ködörögbïäÔko'                       => 'gb',
    'ködörösêsetîbêafrîka'               => 'cf',
    'ködörösêsetîdominîka'                => 'do',
    'ködörösêsetîngunuhalëzotîkongö'    => 'cd',
    'ködörösêsetîtyêki'                   => 'cz',
    'kömôro'                                  => 'km',
    'köwêti'                                  => 'kw',
    'latinamerica'                              => 419,
    'lesôtho'                                  => 'ls',
    'letonùii'                                 => 'lv',
    'letëetîvatikäan'                        => 'va',
    'liberïa'                                  => 'lr',
    'libïi'                                    => 'ly',
    'libùaan'                                  => 'lb',
    "liechtenstein\,"                           => 'li',
    'lituanïi'                                 => 'lt',
    'lugzambûru'                               => 'lu',
    'lùaôsi'                                  => 'la',
    'macau'                                     => 'mo',
    'madagaskära'                              => 'mg',
    'malawïi'                                  => 'mw',
    'maldîva'                                  => 'mv',
    'malezïi'                                  => 'my',
    'malïi'                                    => 'ml',
    'marôko'                                   => 'ma',
    'maseduäni'                                => 'mk',
    'mbongoafrîka'                             => 'za',
    'mekisîki'                                 => 'mx',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikronezïi'                               => 'fm',
    'moldavùii'                                => 'md',
    'monaköo'                                  => 'mc',
    'mongolïi'                                 => 'mn',
    'monserâte'                                => 'ms',
    'montenegro'                                => 'me',
    'moritanïi'                                => 'mr',
    'myämâra'                                 => 'mm',
    'mâlta'                                    => 'mt',
    'märtïnîki'                              => 'mq',
    'mäyôte'                                  => 'yt',
    'mörîsi'                                  => 'mu',
    'mözämbîka'                              => 'mz',
    'namibùii'                                 => 'na',
    'nauru'                                     => 'nr',
    'neutralzone'                               => 'nt',
    'nikaragua'                                 => 'ni',
    'niue'                                      => 'nu',
    'nizerïa'                                  => 'ng',
    'nizëre'                                   => 'ne',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'nëpâli'                                  => 'np',
    'nörvêzi'                                 => 'no',
    'oceania'                                   => '009',
    'omâni'                                    => 'om',
    "ostralïi\,sotralïi"                      => 'au',
    'otrîsi'                                   => 'at',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakistäan'                                => 'pk',
    'palau'                                     => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    "papûfinîginëe\,papuazïi"               => 'pg',
    'paraguëe'                                 => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'perüu'                                    => 'pe',
    'pitikêrni'                                => 'pn',
    'polinezïitîfarânzi'                     => 'pf',
    'polynesia'                                 => '061',
    'portorîko'                                => 'pr',
    'pölôni'                                  => 'pl',
    "pörtugäle\,ködöröpûra"               => 'pt',
    'reinïon'                                  => 're',
    'ruandäa'                                  => 'rw',
    'rumanïi'                                  => 'ro',
    'rusïi'                                    => 'ru',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'salvadöro'                                => 'sv',
    'samoäa'                                   => 'ws',
    'samöatîamerîka'                         => 'as',
    'saûdiarabïi'                             => 'sa',
    'senegäle'                                 => 'sn',
    'serbia'                                    => 'rs',
    'serbïinamöntënegröo'                   => 'cs',
    'shilïi'                                   => 'cl',
    'shîna'                                    => 'cn',
    'sieräleône'                              => 'sl',
    'sirîlanka'                                => 'lk',
    'sirïi'                                    => 'sy',
    'solovakïi'                                => 'sk',
    'solovenïi'                                => 'si',
    'somalïi'                                  => 'so',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'sudäan'                                   => 'sd',
    'surinäm'                                  => 'sr',
    'suêde'                                    => 'se',
    'svalbardandjanmayen'                       => 'sj',
    'swäzïlânde'                             => 'sz',
    'sâôtömênaprinsîpe'                    => 'st',
    'sênkrïstôfonanevîsi'                   => 'kn',
    'sênmarëen'                               => 'sm',
    'sênpyêrenamikelöon'                     => 'pm',
    'sênthelêna'                              => 'sh',
    'sêntlisïi'                               => 'lc',
    'sênvensäannaâgrenadîni'                => 'vc',
    'sêsetîanglëenangûyämätîÊnnde'      => 'io',
    'sêsetîpalestîni'                        => 'ps',
    'sëyshêle'                                => 'sc',
    'sîpri'                                    => 'cy',
    'sïngäpûru'                              => 'sg',
    'sûîsi'                                   => 'ch',
    'taazikiistäan'                            => 'tj',
    'tailânde'                                 => 'th',
    'tanzanïi'                                 => 'tz',
    'timôrotîtö'                             => 'tl',
    'togö'                                     => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinitùeenatobagö'                       => 'tt',
    'tristandacunha'                            => 'ta',
    'tunizïi'                                  => 'tn',
    'turkumenistäan'                           => 'tm',
    'turukïi'                                  => 'tr',
    'tyâde'                                    => 'td',
    'tâiwâni'                                 => 'tw',
    'tüvalü'                                  => 'tv',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ugandäa'                                  => 'ug',
    'ukrêni'                                   => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'uruguëe'                                  => 'uy',
    'uzbekistäan'                              => 'uz',
    'vanuatü'                                  => 'vu',
    'venezueläa'                               => 've',
    'vietnäm'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'walîsinafutuna'                           => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yëmêni'                                  => 'ye',
    'zamaîka'                                  => 'jm',
    'zambïi'                                   => 'zm',
    'zapöon'                                   => 'jp',
    "zerebaidyäan\,azerbaidyäan\,"            => 'az',
    "zibraltära\,zibaratära"                  => 'gi',
    'zimbäbwe'                                 => 'zw',
    'zordanïi'                                 => 'jo',
    'zorzïi'                                   => 'ge',
    'zâmani'                                   => 'de',
    'zûânôrfôlko'                           => 'nf',
    'zûâsalomöon'                            => 'sb',
    'ÂleaaÔkotîamerika'                      => 'us',
    'Âzôâviîrîggotîanglëe'               => 'vg',
    'Âzûâmärshâl'                          => 'mh',
    'Âzûâmärïânitîbanga'                 => 'mp',
    "Âzûângundë\,kaimäni"                  => 'ky',
    'Âzûâturkunakaîki'                      => 'tc',
    'Âzûâtîmälüîni'                      => 'fk',
    'Âzûâvirîgotîamerîka'                 => 'vi',
    "\Ã\landislands"                         => 'ax',
    'Ênnde'                                    => 'in',
    'Ênndonezïi'                              => 'id',
    'âzûâkûku'                              => 'ck',
);

1;

