package Locales::DB::Territory::sv;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::sv::VERSION = '0.09';

$Locales::DB::Territory::sv::cldr_version = '2.0';

%Locales::DB::Territory::sv::code_to_name = (
    '001' => 'världen',
    '002' => 'Afrika',
    '003' => 'Nordamerika',
    '005' => 'Sydamerika',
    '009' => 'Oceanien',
    '011' => 'Västafrika',
    '013' => 'Centralamerika',
    '014' => 'Östafrika',
    '015' => 'Nordafrika',
    '017' => 'Centralafrika',
    '018' => "södra\ Afrika",
    '019' => "Nord\-\ och\ Sydamerika",
    '021' => "norra\ Amerika",
    '029' => 'Karibien',
    '030' => 'Östasien',
    '034' => "södra\ Asien",
    '035' => 'Sydostasien',
    '039' => 'Sydeuropa',
    '053' => "Australien\ och\ Nya\ Zeeland",
    '054' => 'Melanesien',
    '057' => "Mikronesiska\ öarna",
    '061' => 'Polynesien',
    '062' => "södra\ Centralasien",
    142   => 'Asien',
    143   => 'Centralasien',
    145   => 'Västasien',
    150   => 'Europa',
    151   => 'Östeuropa',
    154   => 'Nordeuropa',
    155   => 'Västeuropa',
    172   => "Oberoende\ staters\ samvälde",
    200   => 'Czechoslovakia',
    419   => 'Latinamerika',
    830   => 'Kanalöarna',
    'ac'  => 'Ascension',
    'ad'  => 'Andorra',
    'ae'  => "Förenade\ Arabemiraten",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ och\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albanien',
    'am'  => 'Armenien',
    'an'  => "Nederländska\ Antillerna",
    'ao'  => 'Angola',
    'aq'  => 'Antarktis',
    'ar'  => 'Argentina',
    'as'  => "Amerikanska\ Samoa",
    'at'  => 'Österrike',
    'au'  => 'Australien',
    'aw'  => 'Aruba',
    'ax'  => 'Åland',
    'az'  => 'Azerbajdzjan',
    'ba'  => "Bosnien\ och\ Hercegovina",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgien',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgarien',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "S\:t\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivia',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasilien',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhutan',
    'bv'  => 'Bouvetön',
    'bw'  => 'Botswana',
    'by'  => 'Vitryssland',
    'bz'  => 'Belize',
    'ca'  => 'Kanada',
    'cc'  => 'Kokosöarna',
    'cd'  => "Kongo\-Kinshasa",
    'cf'  => "Centralafrikanska\ republiken",
    'cg'  => "Kongo\-Brazzaville",
    'ch'  => 'Schweiz',
    'ci'  => 'Elfenbenskusten',
    'ck'  => 'Cooköarna',
    'cl'  => 'Chile',
    'cm'  => 'Kamerun',
    'cn'  => 'Kina',
    'co'  => 'Colombia',
    'cp'  => 'Clippertonön',
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbien\ och\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Kuba',
    'cv'  => "Kap\ Verde",
    'cx'  => 'Julön',
    'cy'  => 'Cypern',
    'cz'  => 'Tjeckien',
    'dd'  => "East\ Germany",
    'de'  => 'Tyskland',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Djibouti',
    'dk'  => 'Danmark',
    'dm'  => 'Dominica',
    'do'  => "Dominikanska\ republiken",
    'dz'  => 'Algeriet',
    'ea'  => "Ceuta\ och\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estland',
    'eg'  => 'Egypten',
    'eh'  => 'Västsahara',
    'er'  => 'Eritrea',
    'es'  => 'Spanien',
    'et'  => 'Etiopien',
    'eu'  => "Europeiska\ unionen",
    'fi'  => 'Finland',
    'fj'  => 'Fiji',
    'fk'  => 'Falklandsöarna',
    'fm'  => 'Mikronesien',
    'fo'  => 'Färöarna',
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Frankrike',
    'fx'  => "Europeiska\ Frankrike",
    'ga'  => 'Gabon',
    'gb'  => 'Storbritannien',
    'gd'  => 'Grenada',
    'ge'  => 'Georgien',
    'gf'  => "Franska\ Guyana",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gibraltar',
    'gl'  => 'Grönland',
    'gm'  => 'Gambia',
    'gn'  => 'Guinea',
    'gp'  => 'Guadeloupe',
    'gq'  => 'Ekvatorialguinea',
    'gr'  => 'Grekland',
    'gs'  => "Sydgeorgien\ och\ Sydsandwichöarna",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => 'Hongkong',
    'hm'  => "Heard\-\ och\ McDonaldöarna",
    'hn'  => 'Honduras',
    'hr'  => 'Kroatien',
    'ht'  => 'Haiti',
    'hu'  => 'Ungern',
    'ic'  => 'Kanarieöarna',
    'id'  => 'Indonesien',
    'ie'  => 'Irland',
    'il'  => 'Israel',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Indien',
    'io'  => "Brittiska\ Indiska\ oceanöarna",
    'iq'  => 'Irak',
    'ir'  => 'Iran',
    'is'  => 'Island',
    'it'  => 'Italien',
    'je'  => 'Jersey',
    'jm'  => 'Jamaica',
    'jo'  => 'Jordanien',
    'jp'  => 'Japan',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirgizistan',
    'kh'  => 'Kambodja',
    'ki'  => 'Kiribati',
    'km'  => 'Komorerna',
    'kn'  => "S\:t\ Kitts\ och\ Nevis",
    'kp'  => 'Nordkorea',
    'kr'  => 'Sydkorea',
    'kw'  => 'Kuwait',
    'ky'  => 'Caymanöarna',
    'kz'  => 'Kazakstan',
    'la'  => 'Laos',
    'lb'  => 'Libanon',
    'lc'  => "S\:t\ Lucia",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberia',
    'ls'  => 'Lesotho',
    'lt'  => 'Litauen',
    'lu'  => 'Luxemburg',
    'lv'  => 'Lettland',
    'ly'  => 'Libyen',
    'ma'  => 'Marocko',
    'mc'  => 'Monaco',
    'md'  => 'Moldavien',
    'me'  => 'Montenegro',
    'mf'  => "S\:t\ Martin",
    'mg'  => 'Madagaskar',
    'mh'  => 'Marshallöarna',
    'mi'  => "Midway\ Islands",
    'mk'  => 'Makedonien',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Mongoliet',
    'mo'  => 'Macao',
    'mp'  => 'Nordmarianerna',
    'mq'  => 'Martinique',
    'mr'  => 'Mauretanien',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Mauritius',
    'mv'  => 'Maldiverna',
    'mw'  => 'Malawi',
    'mx'  => 'Mexiko',
    'my'  => 'Malaysia',
    'mz'  => 'Moçambique',
    'na'  => 'Namibia',
    'nc'  => "Nya\ Kaledonien",
    'ne'  => 'Niger',
    'nf'  => 'Norfolkön',
    'ng'  => 'Nigeria',
    'ni'  => 'Nicaragua',
    'nl'  => 'Nederländerna',
    'no'  => 'Norge',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Nya\ Zeeland",
    'om'  => 'Oman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Peru',
    'pf'  => "Franska\ Polynesien",
    'pg'  => "Papua\ Nya\ Guinea",
    'ph'  => 'Filippinerna',
    'pk'  => 'Pakistan',
    'pl'  => 'Polen',
    'pm'  => "S\:t\ Pierre\ och\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Puerto\ Rico",
    'ps'  => "Palestinska\ territoriet",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Yttre\ öar\ i\ Oceanien",
    're'  => 'Réunion',
    'ro'  => 'Rumänien',
    'rs'  => 'Serbien',
    'ru'  => 'Ryssland',
    'rw'  => 'Rwanda',
    'sa'  => 'Saudiarabien',
    'sb'  => 'Salomonöarna',
    'sc'  => 'Seychellerna',
    'sd'  => 'Sudan',
    'se'  => 'Sverige',
    'sg'  => 'Singapore',
    'sh'  => "S\:t\ Helena",
    'si'  => 'Slovenien',
    'sj'  => "Svalbard\ och\ Jan\ Mayen",
    'sk'  => 'Slovakien',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marino",
    'sn'  => 'Senegal',
    'so'  => 'Somalia',
    'sr'  => 'Surinam',
    'st'  => "São\ Tomé\ och\ Príncipe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Syrien',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Turks\-\ och\ Caicosöarna",
    'td'  => 'Tchad',
    'tf'  => "Franska\ Sydterritorierna",
    'tg'  => 'Togo',
    'th'  => 'Thailand',
    'tj'  => 'Tadzjikistan',
    'tk'  => 'Tokelau',
    'tl'  => 'Östtimor',
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunisien',
    'to'  => 'Tonga',
    'tr'  => 'Turkiet',
    'tt'  => "Trinidad\ och\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzania',
    'ua'  => 'Ukraina',
    'ug'  => 'Uganda',
    'um'  => "USA\:s\ yttre\ öar",
    'us'  => 'USA',
    'uy'  => 'Uruguay',
    'uz'  => 'Uzbekistan',
    'va'  => 'Vatikanstaten',
    'vc'  => "S\:t\ Vincent\ och\ Grenadinerna",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Brittiska\ Jungfruöarna",
    'vi'  => "Amerikanska\ Jungfruöarna",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\-\ och\ Futunaöarna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Jemen',
    'yt'  => 'Mayotte',
    'za'  => 'Sydafrika',
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "okänd\ eller\ ogiltig\ regionkod",
);

%Locales::DB::Territory::sv::name_to_code = (
    'afghanistan'                               => 'af',
    'afrika'                                    => '002',
    'albanien'                                  => 'al',
    'algeriet'                                  => 'dz',
    'amerikanskajungfruöarna'                  => 'vi',
    'amerikanskasamoa'                          => 'as',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antarktis'                                 => 'aq',
    'antiguaochbarbuda'                         => 'ag',
    'argentina'                                 => 'ar',
    'armenien'                                  => 'am',
    'aruba'                                     => 'aw',
    'ascension'                                 => 'ac',
    'asien'                                     => 142,
    'australien'                                => 'au',
    'australienochnyazeeland'                   => '053',
    'azerbajdzjan'                              => 'az',
    'bahamas'                                   => 'bs',
    'bahrain'                                   => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgien'                                   => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhutan'                                    => 'bt',
    'bolivia'                                   => 'bo',
    'bosnienochhercegovina'                     => 'ba',
    'botswana'                                  => 'bw',
    'bouvetön'                                 => 'bv',
    'brasilien'                                 => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brittiskaindiskaoceanöarna'               => 'io',
    'brittiskajungfruöarna'                    => 'vg',
    'brunei'                                    => 'bn',
    'bulgarien'                                 => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'cantonandenderburyislands'                 => 'ct',
    'caymanöarna'                              => 'ky',
    'centralafrika'                             => '017',
    'centralafrikanskarepubliken'               => 'cf',
    'centralamerika'                            => '013',
    'centralasien'                              => 143,
    'ceutaochmelilla'                           => 'ea',
    'chile'                                     => 'cl',
    'clippertonön'                             => 'cp',
    'colombia'                                  => 'co',
    'cooköarna'                                => 'ck',
    'costarica'                                 => 'cr',
    'cypern'                                    => 'cy',
    'czechoslovakia'                            => 200,
    'danmark'                                   => 'dk',
    'diegogarcia'                               => 'dg',
    'djibouti'                                  => 'dj',
    'dominica'                                  => 'dm',
    'dominikanskarepubliken'                    => 'do',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egypten'                                   => 'eg',
    'ekvatorialguinea'                          => 'gq',
    'elfenbenskusten'                           => 'ci',
    'elsalvador'                                => 'sv',
    'eritrea'                                   => 'er',
    'estland'                                   => 'ee',
    'etiopien'                                  => 'et',
    'europa'                                    => 150,
    'europeiskafrankrike'                       => 'fx',
    'europeiskaunionen'                         => 'eu',
    'falklandsöarna'                           => 'fk',
    'fiji'                                      => 'fj',
    'filippinerna'                              => 'ph',
    'finland'                                   => 'fi',
    'frankrike'                                 => 'fr',
    'franskaguyana'                             => 'gf',
    'franskapolynesien'                         => 'pf',
    'franskasydterritorierna'                   => 'tf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'färöarna'                                => 'fo',
    'förenadearabemiraten'                     => 'ae',
    'gabon'                                     => 'ga',
    'gambia'                                    => 'gm',
    'georgien'                                  => 'ge',
    'ghana'                                     => 'gh',
    'gibraltar'                                 => 'gi',
    'grekland'                                  => 'gr',
    'grenada'                                   => 'gd',
    'grönland'                                 => 'gl',
    'guadeloupe'                                => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guinea'                                    => 'gn',
    'guineabissau'                              => 'gw',
    'guyana'                                    => 'gy',
    'haiti'                                     => 'ht',
    'heardochmcdonaldöarna'                    => 'hm',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'indien'                                    => 'in',
    'indonesien'                                => 'id',
    'irak'                                      => 'iq',
    'iran'                                      => 'ir',
    'irland'                                    => 'ie',
    'island'                                    => 'is',
    'isleofman'                                 => 'im',
    'israel'                                    => 'il',
    'italien'                                   => 'it',
    'jamaica'                                   => 'jm',
    'japan'                                     => 'jp',
    'jemen'                                     => 'ye',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordanien'                                 => 'jo',
    'julön'                                    => 'cx',
    'kambodja'                                  => 'kh',
    'kamerun'                                   => 'cm',
    'kanada'                                    => 'ca',
    'kanalöarna'                               => 830,
    'kanarieöarna'                             => 'ic',
    'kapverde'                                  => 'cv',
    'karibien'                                  => '029',
    'kazakstan'                                 => 'kz',
    'kenya'                                     => 'ke',
    'kina'                                      => 'cn',
    'kirgizistan'                               => 'kg',
    'kiribati'                                  => 'ki',
    'kokosöarna'                               => 'cc',
    'komorerna'                                 => 'km',
    'kongobrazzaville'                          => 'cg',
    'kongokinshasa'                             => 'cd',
    'kroatien'                                  => 'hr',
    'kuba'                                      => 'cu',
    'kuwait'                                    => 'kw',
    'laos'                                      => 'la',
    'latinamerika'                              => 419,
    'lesotho'                                   => 'ls',
    'lettland'                                  => 'lv',
    'libanon'                                   => 'lb',
    'liberia'                                   => 'lr',
    'libyen'                                    => 'ly',
    'liechtenstein'                             => 'li',
    'litauen'                                   => 'lt',
    'luxemburg'                                 => 'lu',
    'macao'                                     => 'mo',
    'madagaskar'                                => 'mg',
    'makedonien'                                => 'mk',
    'malawi'                                    => 'mw',
    'malaysia'                                  => 'my',
    'maldiverna'                                => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'marocko'                                   => 'ma',
    'marshallöarna'                            => 'mh',
    'martinique'                                => 'mq',
    'mauretanien'                               => 'mr',
    'mauritius'                                 => 'mu',
    'mayotte'                                   => 'yt',
    'melanesien'                                => '054',
    'mexiko'                                    => 'mx',
    'midwayislands'                             => 'mi',
    'mikronesien'                               => 'fm',
    'mikronesiskaöarna'                        => '057',
    'moldavien'                                 => 'md',
    'monaco'                                    => 'mc',
    'mongoliet'                                 => 'mn',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'moçambique'                               => 'mz',
    'myanmar'                                   => 'mm',
    'namibia'                                   => 'na',
    'nauru'                                     => 'nr',
    'nederländerna'                            => 'nl',
    'nederländskaantillerna'                   => 'an',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'niger'                                     => 'ne',
    'nigeria'                                   => 'ng',
    'niue'                                      => 'nu',
    'nordafrika'                                => '015',
    'nordamerika'                               => '003',
    'nordeuropa'                                => 154,
    'nordkorea'                                 => 'kp',
    'nordmarianerna'                            => 'mp',
    'nordochsydamerika'                         => '019',
    'norfolkön'                                => 'nf',
    'norge'                                     => 'no',
    'norraamerika'                              => '021',
    'northvietnam'                              => 'vd',
    'nyakaledonien'                             => 'nc',
    'nyazeeland'                                => 'nz',
    'oberoendestaterssamvälde'                 => 172,
    'oceanien'                                  => '009',
    'okändellerogiltigregionkod'               => 'zz',
    'oman'                                      => 'om',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'palestinskaterritoriet'                    => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuanyaguinea'                            => 'pg',
    'paraguay'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'peru'                                      => 'pe',
    'pitcairn'                                  => 'pn',
    'polen'                                     => 'pl',
    'polynesien'                                => '061',
    'portugal'                                  => 'pt',
    'puertorico'                                => 'pr',
    'qatar'                                     => 'qa',
    'rumänien'                                 => 'ro',
    'rwanda'                                    => 'rw',
    'ryssland'                                  => 'ru',
    'réunion'                                  => 're',
    "s\:tbarthélemy"                           => 'bl',
    "s\:thelena"                                => 'sh',
    "s\:tkittsochnevis"                         => 'kn',
    "s\:tlucia"                                 => 'lc',
    "s\:tmartin"                                => 'mf',
    "s\:tpierreochmiquelon"                     => 'pm',
    "s\:tvincentochgrenadinerna"                => 'vc',
    'salomonöarna'                             => 'sb',
    'samoa'                                     => 'ws',
    'sanmarino'                                 => 'sm',
    'saudiarabien'                              => 'sa',
    'schweiz'                                   => 'ch',
    'senegal'                                   => 'sn',
    'serbien'                                   => 'rs',
    'serbienochmontenegro'                      => 'cs',
    'seychellerna'                              => 'sc',
    'sierraleone'                               => 'sl',
    'singapore'                                 => 'sg',
    'slovakien'                                 => 'sk',
    'slovenien'                                 => 'si',
    'somalia'                                   => 'so',
    'spanien'                                   => 'es',
    'srilanka'                                  => 'lk',
    'storbritannien'                            => 'gb',
    'sudan'                                     => 'sd',
    'surinam'                                   => 'sr',
    'svalbardochjanmayen'                       => 'sj',
    'sverige'                                   => 'se',
    'swaziland'                                 => 'sz',
    'sydafrika'                                 => 'za',
    'sydamerika'                                => '005',
    'sydeuropa'                                 => '039',
    'sydgeorgienochsydsandwichöarna'           => 'gs',
    'sydkorea'                                  => 'kr',
    'sydostasien'                               => '035',
    'syrien'                                    => 'sy',
    'sãotoméochpríncipe'                     => 'st',
    'södraafrika'                              => '018',
    'södraasien'                               => '034',
    'södracentralasien'                        => '062',
    'tadzjikistan'                              => 'tj',
    'taiwan'                                    => 'tw',
    'tanzania'                                  => 'tz',
    'tchad'                                     => 'td',
    'thailand'                                  => 'th',
    'tjeckien'                                  => 'cz',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadochtobago'                         => 'tt',
    'tristandacunha'                            => 'ta',
    'tunisien'                                  => 'tn',
    'turkiet'                                   => 'tr',
    'turkmenistan'                              => 'tm',
    'turksochcaicosöarna'                      => 'tc',
    'tuvalu'                                    => 'tv',
    'tyskland'                                  => 'de',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukraina'                                   => 'ua',
    'ungern'                                    => 'hu',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    'usa'                                       => 'us',
    "usa\:syttreöar"                           => 'um',
    'uzbekistan'                                => 'uz',
    'vanuatu'                                   => 'vu',
    'vatikanstaten'                             => 'va',
    'venezuela'                                 => 've',
    'vietnam'                                   => 'vn',
    'vitryssland'                               => 'by',
    'världen'                                  => '001',
    'västafrika'                               => '011',
    'västasien'                                => 145,
    'västeuropa'                               => 155,
    'västsahara'                               => 'eh',
    'wakeisland'                                => 'wk',
    'wallisochfutunaöarna'                     => 'wf',
    'yttreöarioceanien'                        => 'qo',
    'zambia'                                    => 'zm',
    'zimbabwe'                                  => 'zw',
    'Åland'                                    => 'ax',
    'Östafrika'                                => '014',
    'Östasien'                                 => '030',
    'Österrike'                                => 'at',
    'Östeuropa'                                => 151,
    'Östtimor'                                 => 'tl',
);

1;

