{"delimiters":{"quotation_start":"«","quotation_end":"»","alternate_quotation_start":"„","alternate_quotation_end":"”"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":"uhu:u","yesstr":"yyih:y"},"plural_forms":{"category_list":["one","few","other"],"category_rules_function":null,"category_rules":{"one":"n within 0..1","few":"n in 2..10"},"category_rules_compiled":{"one":function (n) {if ( (( n >= 0 && n <= 1 ))) { return 'one'; } return;},"few":function (n) {if ( (( parseInt(n) == n && n >= 2 && n <= 10 ))) { return 'few'; } return;}}},"cldr_formats":{"territory":"Region: {0}","_decimal_format_decimal":",","language":"Language: {0}","percent":"#,##0%","locale":"{0} ({1})","_decimal_format_group":" ","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}…{1}","final":"{0}…","initial":"…{0}"},"list":{"middle":"{0}, {1}","2":"{0} and {1}","start":"{0}, {1}","end":"{0}, and {1}"}},"fallback":[],"characters":{"more_information":"?"}}