{"delimiters":{"quotation_start":"«","quotation_end":"»","alternate_quotation_start":"“","alternate_quotation_end":"”"},"orientation":{"lines":"top-to-bottom","characters":"left-to-right"},"posix":{"nostr":"non:n","yesstr":"oui:o"},"plural_forms":{"category_list":["one","other"],"category_rules_function":null,"category_rules":{"one":"n within 0..2 and n is not 2"},"category_rules_compiled":{"one":function (n) {if ( (( n >= 0 && n <= 2 ) && ( n != 2))) { return 'one'; } return;}}},"cldr_formats":{"territory":"région : {0}","_decimal_format_decimal":",","language":"langue : {0}","percent":"#,##0 %","locale":"{0} ({1})","_decimal_format_group":" ","_percent_format_percent":"%","decimal":"#,##0.###","ellipsis":{"medial":"{0}...{1}","final":"{0}...","initial":"...{0}"},"list":{"middle":"{0}, {1}","2":"{0} et {1}","start":"{0}, {1}","end":"{0} et {1}"}},"fallback":[],"characters":{"more_information":"?"}}