package Locales::DB::Territory::tzm;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::tzm::VERSION = '0.09';

$Locales::DB::Territory::tzm::cldr_version = '2.0';

%Locales::DB::Territory::tzm::code_to_name = (
    '001' => 'World',
    '002' => 'Africa',
    '003' => "North\ America",
    '005' => "South\ America",
    '009' => 'Oceania',
    '011' => "Western\ Africa",
    '013' => "Central\ America",
    '014' => "Eastern\ Africa",
    '015' => "Northern\ Africa",
    '017' => "Middle\ Africa",
    '018' => "Southern\ Africa",
    '019' => 'Americas',
    '021' => "Northern\ America",
    '029' => 'Caribbean',
    '030' => "Eastern\ Asia",
    '034' => "Southern\ Asia",
    '035' => "South\-Eastern\ Asia",
    '039' => "Southern\ Europe",
    '053' => "Australia\ and\ New\ Zealand",
    '054' => 'Melanesia',
    '057' => "Micronesian\ Region",
    '061' => 'Polynesia',
    '062' => "South\-Central\ Asia",
    142   => 'Asia',
    143   => "Central\ Asia",
    145   => "Western\ Asia",
    150   => 'Europe',
    151   => "Eastern\ Europe",
    154   => "Northern\ Europe",
    155   => "Western\ Europe",
    172   => "Commonwealth\ of\ Independent\ States",
    200   => 'Czechoslovakia',
    419   => "Latin\ America",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Anḍurra',
    'ae'  => "Imarat\ Tiεrabin\ Tidduklin",
    'af'  => 'Afɣanistan',
    'ag'  => "Antigwa\ d\ Barbuda",
    'ai'  => 'Angwilla',
    'al'  => 'Albanya',
    'am'  => 'Arminya',
    'an'  => "Antil\ Tihulanḍiyyin",
    'ao'  => 'Angula',
    'aq'  => 'Antarctica',
    'ar'  => 'Arjuntin',
    'as'  => "Samwa\ Imirikaniyyin",
    'at'  => 'Ustriyya',
    'au'  => 'Usṭralya',
    'aw'  => 'Aruba',
    'ax'  => "\Ã\land\ Islands",
    'az'  => 'Azerbiǧan',
    'ba'  => "Busna\-d\-Hirsik",
    'bb'  => 'Barbadus',
    'bd'  => 'Bangladic',
    'be'  => 'Beljika',
    'bf'  => "Burkina\ Fasu",
    'bg'  => 'Belɣarya',
    'bh'  => 'Baḥrayn',
    'bi'  => 'Burundi',
    'bj'  => 'Binin',
    'bl'  => "Saint\ Barth\Ã\©lemy",
    'bm'  => 'Birmuda',
    'bn'  => 'Brunay',
    'bo'  => 'Bulivya',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Bṛazil',
    'bs'  => 'Bahamas',
    'bt'  => 'Buṭan',
    'bv'  => "Bouvet\ Island",
    'bw'  => 'Butswana',
    'by'  => 'Bilarusya',
    'bz'  => 'Biliz',
    'ca'  => 'Kanada',
    'cc'  => "Cocos\ \[Keeling\]\ Islands",
    'cd'  => "Tagduda\ Tadimuqraṭit\ n\ Kungu",
    'cf'  => "Tagduda\ n\ Afrika\ Wammas",
    'cg'  => 'Kungu',
    'ch'  => 'Swisra',
    'ci'  => "Taɣazut\ n\ Uszer",
    'ck'  => "Tigzirin\ n\ Kuk",
    'cl'  => 'Ccili',
    'cm'  => 'Kamerun',
    'cn'  => 'Ṣṣin',
    'co'  => 'Kulumbya',
    'cp'  => "Clipperton\ Island",
    'cr'  => "Kusṭa\ Rika",
    'cs'  => "Ṣiṛbya\ d\ Muntinigru",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'kuba',
    'cv'  => "Tigzirin\ n\ Iɣf\ Uzegzaw",
    'cx'  => "Christmas\ Island",
    'cy'  => 'Qubrus',
    'cz'  => "Tagduda\ n\ Čik",
    'dd'  => "East\ Germany",
    'de'  => 'Almanya',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Ǧibuti',
    'dk'  => 'Danmark',
    'dm'  => 'Ḍuminika',
    'do'  => "Tagduda\ n\ Ḍuminikan",
    'dz'  => 'Dzayer',
    'ea'  => "Ceuta\ and\ Melilla",
    'ec'  => 'Ikwaḍur',
    'ee'  => 'Isṭunya',
    'eg'  => 'Miṣr',
    'eh'  => "Western\ Sahara",
    'er'  => 'Iritrya',
    'es'  => 'Sbanya',
    'et'  => 'Ityupya',
    'eu'  => "European\ Union",
    'fi'  => 'Finlanḍa',
    'fj'  => 'Fiji',
    'fk'  => "Tigzirin\ n\ Falkland",
    'fm'  => 'Mikrunizya',
    'fo'  => "Faroe\ Islands",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'Fṛansa',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabun',
    'gb'  => "Tagelda\ Taddukelt",
    'gd'  => 'Grinada',
    'ge'  => 'Jyurjya',
    'gf'  => "Guyana\ Tafransist",
    'gg'  => 'Guernsey',
    'gh'  => 'Ɣana',
    'gi'  => 'Jibralṭar',
    'gl'  => 'Grinlanḍa',
    'gm'  => 'Gambya',
    'gn'  => 'Ɣinya',
    'gp'  => 'Gwadalup',
    'gq'  => "Ɣinya\ Tikwaṭur\ it",
    'gr'  => 'Yunan',
    'gs'  => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'  => 'Gwatimala',
    'gu'  => 'Gwam',
    'gw'  => "Ɣinya\-Bissaw",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'  => 'Hinduras',
    'hr'  => 'Krwatya',
    'ht'  => 'Hayti',
    'hu'  => 'Henɣarya',
    'ic'  => "Canary\ Islands",
    'id'  => 'Indunizya',
    'ie'  => 'Irlanḍa',
    'il'  => 'Israeil',
    'im'  => "Isle\ of\ Man",
    'in'  => 'Hind',
    'io'  => "Amur\ n\ Agaraw\ Uhindi\ Ubṛiṭani",
    'iq'  => 'Ɛiraq',
    'ir'  => 'Iran',
    'is'  => 'Islanḍa',
    'it'  => 'Iṭalya',
    'je'  => 'Jersey',
    'jm'  => 'Jamayka',
    'jo'  => 'Urḍun',
    'jp'  => 'Jjappun',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kinya',
    'kg'  => 'Kirɣistan',
    'kh'  => 'Kambudj',
    'ki'  => 'Kiribati',
    'km'  => 'Qumur',
    'kn'  => "Santekits\ d\ Nivis",
    'kp'  => "Kurya\ Tugafat",
    'kr'  => "Kurya\ Tunẓult",
    'kw'  => 'Kuwwayt',
    'ky'  => "Tigzirin\ n\ Kayman",
    'kz'  => 'Kazaxistan',
    'la'  => 'Laws',
    'lb'  => 'Lubnan',
    'lc'  => 'Santelusya',
    'li'  => 'Lictencṭayn',
    'lk'  => 'Srilanka',
    'lr'  => 'Libirya',
    'ls'  => 'Lisuṭu',
    'lt'  => 'Litwanya',
    'lu'  => 'Liksumburg',
    'lv'  => 'Liṭṭunya',
    'ly'  => 'Libya',
    'ma'  => 'Meṛṛuk',
    'mc'  => 'Munaku',
    'md'  => 'Mulḍavya',
    'me'  => 'Montenegro',
    'mf'  => "Saint\ Martin",
    'mg'  => 'Madaɣacqar',
    'mh'  => "Tigzirin\ n\ Marcal",
    'mi'  => "Midway\ Islands",
    'mk'  => 'Maqdunya',
    'ml'  => 'Mali',
    'mm'  => 'Myanmar',
    'mn'  => 'Manɣulya',
    'mo'  => 'Macau',
    'mp'  => "Tigzirin\ n\ Maryana\ Tugafat",
    'mq'  => 'Martinik',
    'mr'  => 'Muritanya',
    'ms'  => 'Muntsirra',
    'mt'  => 'Malṭa',
    'mu'  => 'Muris',
    'mv'  => 'Maldiv',
    'mw'  => 'Malawi',
    'mx'  => 'Miksik',
    'my'  => 'Malizya',
    'mz'  => 'Muzambiq',
    'na'  => 'Namibya',
    'nc'  => "kalidunya\ Tamaynut",
    'ne'  => 'Nnijer',
    'nf'  => "Tigzirt\ Nurfulk",
    'ng'  => 'Nijiria',
    'ni'  => 'Nikaragwa',
    'nl'  => 'Hulanḍa',
    'no'  => 'Nnurwij',
    'np'  => 'Nippal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nawru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niwi',
    'nz'  => "Zilanḍa\ Tamaynut",
    'om'  => 'Ɛumman',
    'pa'  => 'Panama',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Piru',
    'pf'  => "Pulinizya\ Tafransist",
    'pg'  => "Papwa\ Ɣinya\ Tamaynut",
    'ph'  => 'Filippin',
    'pk'  => 'Pakistan',
    'pl'  => 'Pulunya',
    'pm'  => "Santepyir\ d\ Mikelun",
    'pn'  => 'Pitkirn',
    'pr'  => 'Purturiku',
    'ps'  => "Agemmaḍ\ Ugut\ d\ Ɣazza\ Ifilisṭiniyen",
    'pt'  => 'Purtuɣal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palu',
    'py'  => 'Paragway',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qaṭar',
    'qo'  => "Outlying\ Oceania",
    're'  => 'Riyyunyun',
    'ro'  => 'Ṛumanya',
    'rs'  => 'Serbia',
    'ru'  => 'Rusya',
    'rw'  => 'Ruwwanḍa',
    'sa'  => "Ssaεudiyya\ Taεrabt",
    'sb'  => "Tigzirin\ n\ Salumun",
    'sc'  => 'Ssicil',
    'sd'  => 'Ssudan',
    'se'  => 'Ssewwid',
    'sg'  => 'Sanɣafura',
    'sh'  => 'Santehilin',
    'si'  => 'Sluvinya',
    'sj'  => "Svalbard\ and\ Jan\ Mayen",
    'sk'  => 'Sluvakya',
    'sl'  => 'Siralyun',
    'sm'  => 'Sanmarinu',
    'sn'  => 'Ssiniɣal',
    'so'  => 'Ṣṣumal',
    'sr'  => 'Surinam',
    'st'  => "Sawṭumi\ d\ Prinsip",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => 'Salvaḍur',
    'sy'  => 'Surya',
    'sz'  => 'Swazilanḍa',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Tigzirin\ Turkiyyin\ d\ Tikaykusin",
    'td'  => 'Tcad',
    'tf'  => "French\ Southern\ Territories",
    'tg'  => 'Ṭṭugu',
    'th'  => 'Ṭaylanḍa',
    'tj'  => 'Ṭaǧikistan',
    'tk'  => 'Tuklu',
    'tl'  => "Timur\ Tagmuṭ",
    'tm'  => 'Turkmanistan',
    'tn'  => 'Tunes',
    'to'  => 'Ṭunga',
    'tr'  => 'Turkya',
    'tt'  => "Trinidad\ d\ Ṭubagu",
    'tv'  => 'Ṭuvalu',
    'tw'  => 'Ṭaywan',
    'tz'  => 'Ṭanzanya',
    'ua'  => 'Ukranya',
    'ug'  => 'Uɣanda',
    'um'  => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'  => "Iwunak\ Idduklen\ n\ Amirika",
    'uy'  => 'Urugway',
    'uz'  => 'Uzbakistan',
    'va'  => "Awank\ iɣrem\ n\ Vatikan",
    'vc'  => "Santevinsent\ d\ Grinadin",
    'vd'  => "North\ Vietnam",
    've'  => 'Vinzwilla',
    'vg'  => "Tigzirin\ \(Virgin\)\ Tibṛiṭaniyin",
    'vi'  => "Tigzirin\ n\ Virjin\ n\ Iwunak\ Yedduklen",
    'vn'  => 'Viṭnam',
    'vu'  => 'Vanwatu',
    'wf'  => "Walis\ d\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samwa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yaman',
    'yt'  => 'Mayuṭ',
    'za'  => "Tafrikt\ Tunẓul",
    'zm'  => 'Zambya',
    'zw'  => 'Zimbabwi',
    'zz'  => "Unknown\ Region",
);

%Locales::DB::Territory::tzm::name_to_code = (
    'africa'                                    => '002',
    'afɣanistan'                               => 'af',
    'agemmaḍugutdƔazzaifilisṭiniyen'       => 'ps',
    'albanya'                                   => 'al',
    'almanya'                                   => 'de',
    'americas'                                  => '019',
    'amurnagarawuhindiubṛiṭani'             => 'io',
    'angula'                                    => 'ao',
    'angwilla'                                  => 'ai',
    'antarctica'                                => 'aq',
    'antigwadbarbuda'                           => 'ag',
    'antiltihulanḍiyyin'                      => 'an',
    'anḍurra'                                 => 'ad',
    'arjuntin'                                  => 'ar',
    'arminya'                                   => 'am',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asia'                                      => 142,
    'australiaandnewzealand'                    => '053',
    'awankiɣremnvatikan'                       => 'va',
    'azerbiǧan'                                => 'az',
    'bahamas'                                   => 'bs',
    'bangladic'                                 => 'bd',
    'barbadus'                                  => 'bb',
    'baḥrayn'                                 => 'bh',
    'beljika'                                   => 'be',
    'belɣarya'                                 => 'bg',
    'bilarusya'                                 => 'by',
    'biliz'                                     => 'bz',
    'binin'                                     => 'bj',
    'birmuda'                                   => 'bm',
    'bouvetisland'                              => 'bv',
    'britishantarcticterritory'                 => 'bq',
    'brunay'                                    => 'bn',
    'bulivya'                                   => 'bo',
    'burkinafasu'                               => 'bf',
    'burundi'                                   => 'bi',
    'busnadhirsik'                              => 'ba',
    'butswana'                                  => 'bw',
    'buṭan'                                   => 'bt',
    'bṛazil'                                  => 'br',
    'canaryislands'                             => 'ic',
    'cantonandenderburyislands'                 => 'ct',
    'caribbean'                                 => '029',
    'ccili'                                     => 'cl',
    'centralamerica'                            => '013',
    'centralasia'                               => 143,
    'ceutaandmelilla'                           => 'ea',
    'channelislands'                            => 830,
    'christmasisland'                           => 'cx',
    'clippertonisland'                          => 'cp',
    'cocoskeelingislands'                       => 'cc',
    'commonwealthofindependentstates'           => 172,
    'czechoslovakia'                            => 200,
    'danmark'                                   => 'dk',
    'diegogarcia'                               => 'dg',
    'dronningmaudland'                          => 'nq',
    'dzayer'                                    => 'dz',
    'easternafrica'                             => '014',
    'easternasia'                               => '030',
    'easterneurope'                             => 151,
    'eastgermany'                               => 'dd',
    'europe'                                    => 150,
    'europeanunion'                             => 'eu',
    'faroeislands'                              => 'fo',
    'fiji'                                      => 'fj',
    'filippin'                                  => 'ph',
    'finlanḍa'                                => 'fi',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'frenchsouthernterritories'                 => 'tf',
    'fṛansa'                                  => 'fr',
    'gabun'                                     => 'ga',
    'gambya'                                    => 'gm',
    'grinada'                                   => 'gd',
    'grinlanḍa'                               => 'gl',
    'guernsey'                                  => 'gg',
    'guyana'                                    => 'gy',
    'guyanatafransist'                          => 'gf',
    'gwadalup'                                  => 'gp',
    'gwam'                                      => 'gu',
    'gwatimala'                                 => 'gt',
    'hayti'                                     => 'ht',
    'heardislandandmcdonaldislands'             => 'hm',
    'henɣarya'                                 => 'hu',
    'hind'                                      => 'in',
    'hinduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'hulanḍa'                                 => 'nl',
    'ikwaḍur'                                 => 'ec',
    'imarattiεrabintidduklin'                  => 'ae',
    'indunizya'                                 => 'id',
    'iran'                                      => 'ir',
    'iritrya'                                   => 'er',
    'irlanḍa'                                 => 'ie',
    'islanḍa'                                 => 'is',
    'isleofman'                                 => 'im',
    'israeil'                                   => 'il',
    'isṭunya'                                 => 'ee',
    'ityupya'                                   => 'et',
    'iwunakidduklennamirika'                    => 'us',
    'iṭalya'                                  => 'it',
    'jamayka'                                   => 'jm',
    'jersey'                                    => 'je',
    'jibralṭar'                               => 'gi',
    'jjappun'                                   => 'jp',
    'johnstonisland'                            => 'jt',
    'jyurjya'                                   => 'ge',
    'kalidunyatamaynut'                         => 'nc',
    'kambudj'                                   => 'kh',
    'kamerun'                                   => 'cm',
    'kanada'                                    => 'ca',
    'kazaxistan'                                => 'kz',
    'kinya'                                     => 'ke',
    'kiribati'                                  => 'ki',
    'kirɣistan'                                => 'kg',
    'krwatya'                                   => 'hr',
    'kuba'                                      => 'cu',
    'kulumbya'                                  => 'co',
    'kungu'                                     => 'cg',
    'kuryatugafat'                              => 'kp',
    'kuryatunẓult'                            => 'kr',
    'kusṭarika'                               => 'cr',
    'kuwwayt'                                   => 'kw',
    'latinamerica'                              => 419,
    'laws'                                      => 'la',
    'libirya'                                   => 'lr',
    'libya'                                     => 'ly',
    'lictencṭayn'                             => 'li',
    'liksumburg'                                => 'lu',
    'lisuṭu'                                  => 'ls',
    'litwanya'                                  => 'lt',
    'liṭṭunya'                              => 'lv',
    'lubnan'                                    => 'lb',
    'macau'                                     => 'mo',
    'madaɣacqar'                               => 'mg',
    'malawi'                                    => 'mw',
    'maldiv'                                    => 'mv',
    'mali'                                      => 'ml',
    'malizya'                                   => 'my',
    'malṭa'                                   => 'mt',
    'manɣulya'                                 => 'mn',
    'maqdunya'                                  => 'mk',
    'martinik'                                  => 'mq',
    'mayuṭ'                                   => 'yt',
    'melanesia'                                 => '054',
    'metropolitanfrance'                        => 'fx',
    'meṛṛuk'                                => 'ma',
    'micronesianregion'                         => '057',
    'middleafrica'                              => '017',
    'midwayislands'                             => 'mi',
    'mikrunizya'                                => 'fm',
    'miksik'                                    => 'mx',
    'miṣr'                                    => 'eg',
    'montenegro'                                => 'me',
    'mulḍavya'                                => 'md',
    'munaku'                                    => 'mc',
    'muntsirra'                                 => 'ms',
    'muris'                                     => 'mu',
    'muritanya'                                 => 'mr',
    'muzambiq'                                  => 'mz',
    'myanmar'                                   => 'mm',
    'namibya'                                   => 'na',
    'nawru'                                     => 'nr',
    'neutralzone'                               => 'nt',
    'nijiria'                                   => 'ng',
    'nikaragwa'                                 => 'ni',
    'nippal'                                    => 'np',
    'niwi'                                      => 'nu',
    'nnijer'                                    => 'ne',
    'nnurwij'                                   => 'no',
    'northamerica'                              => '003',
    'northernafrica'                            => '015',
    'northernamerica'                           => '021',
    'northerneurope'                            => 154,
    'northvietnam'                              => 'vd',
    'oceania'                                   => '009',
    'outlyingoceania'                           => 'qo',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palu'                                      => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papwaƔinyatamaynut'                       => 'pg',
    'paragway'                                  => 'py',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'piru'                                      => 'pe',
    'pitkirn'                                   => 'pn',
    'polynesia'                                 => '061',
    'pulinizyatafransist'                       => 'pf',
    'pulunya'                                   => 'pl',
    'purturiku'                                 => 'pr',
    'purtuɣal'                                 => 'pt',
    'qaṭar'                                   => 'qa',
    'qubrus'                                    => 'cy',
    'qumur'                                     => 'km',
    'riyyunyun'                                 => 're',
    'rusya'                                     => 'ru',
    'ruwwanḍa'                                => 'rw',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintmartin'                               => 'mf',
    'salvaḍur'                                => 'sv',
    'samwa'                                     => 'ws',
    'samwaimirikaniyyin'                        => 'as',
    'sanmarinu'                                 => 'sm',
    'santehilin'                                => 'sh',
    'santekitsdnivis'                           => 'kn',
    'santelusya'                                => 'lc',
    'santepyirdmikelun'                         => 'pm',
    'santevinsentdgrinadin'                     => 'vc',
    'sanɣafura'                                => 'sg',
    'sawṭumidprinsip'                         => 'st',
    'sbanya'                                    => 'es',
    'serbia'                                    => 'rs',
    'siralyun'                                  => 'sl',
    'sluvakya'                                  => 'sk',
    'sluvinya'                                  => 'si',
    'southamerica'                              => '005',
    'southcentralasia'                          => '062',
    'southeasternasia'                          => '035',
    'southernafrica'                            => '018',
    'southernasia'                              => '034',
    'southerneurope'                            => '039',
    'southgeorgiaandthesouthsandwichislands'    => 'gs',
    'srilanka'                                  => 'lk',
    'ssaεudiyyataεrabt'                       => 'sa',
    'ssewwid'                                   => 'se',
    'ssicil'                                    => 'sc',
    'ssiniɣal'                                 => 'sn',
    'ssudan'                                    => 'sd',
    'surinam'                                   => 'sr',
    'surya'                                     => 'sy',
    'svalbardandjanmayen'                       => 'sj',
    'swazilanḍa'                              => 'sz',
    'swisra'                                    => 'ch',
    'tafrikttunẓul'                           => 'za',
    'tagdudanafrikawammas'                      => 'cf',
    'tagdudanČik'                              => 'cz',
    'tagdudanḌuminikan'                       => 'do',
    'tagdudatadimuqraṭitnkungu'               => 'cd',
    'tageldataddukelt'                          => 'gb',
    'taɣazutnuszer'                            => 'ci',
    'tcad'                                      => 'td',
    'tigzirinnfalkland'                         => 'fk',
    'tigzirinniɣfuzegzaw'                      => 'cv',
    'tigzirinnkayman'                           => 'ky',
    'tigzirinnkuk'                              => 'ck',
    'tigzirinnmarcal'                           => 'mh',
    'tigzirinnmaryanatugafat'                   => 'mp',
    'tigzirinnsalumun'                          => 'sb',
    'tigzirinnvirjinniwunakyedduklen'           => 'vi',
    'tigzirinturkiyyindtikaykusin'              => 'tc',
    'tigzirinvirgintibṛiṭaniyin'            => 'vg',
    'tigzirtnurfulk'                            => 'nf',
    'timurtagmuṭ'                             => 'tl',
    'trinidaddṬubagu'                         => 'tt',
    'tristandacunha'                            => 'ta',
    'tuklu'                                     => 'tk',
    'tunes'                                     => 'tn',
    'turkmanistan'                              => 'tm',
    'turkya'                                    => 'tr',
    "u\.s\.minoroutlyingislands"                => 'um',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ukranya'                                   => 'ua',
    'unionofsovietsocialistrepublics'           => 'su',
    'unknownregion'                             => 'zz',
    'urugway'                                   => 'uy',
    'urḍun'                                   => 'jo',
    'ustriyya'                                  => 'at',
    'usṭralya'                                => 'au',
    'uzbakistan'                                => 'uz',
    'uɣanda'                                   => 'ug',
    'vanwatu'                                   => 'vu',
    'vinzwilla'                                 => 've',
    'viṭnam'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'walisdfutuna'                              => 'wf',
    'westernafrica'                             => '011',
    'westernasia'                               => 145,
    'westerneurope'                             => 155,
    'westernsahara'                             => 'eh',
    'world'                                     => '001',
    'yaman'                                     => 'ye',
    'yunan'                                     => 'gr',
    'zambya'                                    => 'zm',
    'zilanḍatamaynut'                         => 'nz',
    'zimbabwi'                                  => 'zw',
    "\Ã\landislands"                         => 'ax',
    'Ɛiraq'                                    => 'iq',
    'Ɛumman'                                   => 'om',
    'Ɣana'                                     => 'gh',
    'Ɣinya'                                    => 'gn',
    'Ɣinyabissaw'                              => 'gw',
    'Ɣinyatikwaṭurit'                        => 'gq',
    'Ǧibuti'                                   => 'dj',
    'Ḍuminika'                                => 'dm',
    'Ṛumanya'                                 => 'ro',
    'Ṣiṛbyadmuntinigru'                     => 'cs',
    'Ṣṣin'                                  => 'cn',
    'Ṣṣumal'                                => 'so',
    'Ṭanzanya'                                => 'tz',
    'Ṭaylanḍa'                              => 'th',
    'Ṭaywan'                                  => 'tw',
    'Ṭaǧikistan'                             => 'tj',
    'Ṭunga'                                   => 'to',
    'Ṭuvalu'                                  => 'tv',
    'Ṭṭugu'                                 => 'tg',
);

1;

