package Locales::DB::Territory::fur;

use strict;
use warnings;

# Auto generated from CLDR
use if $Locales::_UNICODE_STRINGS, 'utf8';

$Locales::DB::Territory::fur::VERSION = '0.09';

$Locales::DB::Territory::fur::cldr_version = '2.0';

%Locales::DB::Territory::fur::code_to_name = (
    '001' => 'Mont',
    '002' => 'Afriche',
    '003' => "Americhe\ dal\ Nord",
    '005' => "Americhe\ meridionâl",
    '009' => 'Oceanie',
    '011' => "Afriche\ ocidentâl",
    '013' => "Americhe\ centrâl",
    '014' => "Afriche\ orientâl",
    '015' => "Afriche\ setentrionâl",
    '017' => "Afriche\ di\ mieç",
    '018' => "Afriche\ meridionâl",
    '019' => 'Americhis',
    '021' => "Americhe\ setentrionâl",
    '029' => 'caraibic',
    '030' => "Asie\ orientâl",
    '034' => "Asie\ meridionâl",
    '035' => "Asie\ sud\ orientâl",
    '039' => "Europe\ meridionâl",
    '053' => "Australie\ e\ Gnove\ Zelande",
    '054' => 'Melanesie',
    '057' => "Regjon\ de\ Micronesie",
    '061' => 'Polinesie',
    '062' => "South\-Central\ Asia",
    142   => 'Asie',
    143   => "Asie\ centrâl",
    145   => "Asie\ ocidentâl",
    150   => 'Europe',
    151   => "Europe\ orientâl",
    154   => "Europe\ setentrionâl",
    155   => "Europe\ ocidentâl",
    172   => "Commonwealth\ dai\ stâts\ indipendents",
    200   => 'Czechoslovakia',
    419   => "Americhe\ latine\ e\ caraibiche",
    830   => "Channel\ Islands",
    'ac'  => "Ascension\ Island",
    'ad'  => 'Andorra',
    'ae'  => "Emirâts\ araps\ unîts",
    'af'  => 'Afghanistan',
    'ag'  => "Antigua\ e\ Barbuda",
    'ai'  => 'Anguilla',
    'al'  => 'Albanie',
    'am'  => 'Armenie',
    'an'  => "Antilis\ olandesis",
    'ao'  => 'Angola',
    'aq'  => 'Antartic',
    'ar'  => 'Argjentine',
    'as'  => "Samoa\ merecanis",
    'at'  => 'Austrie',
    'au'  => 'Australie',
    'aw'  => 'Aruba',
    'ax'  => "Isulis\ Aland",
    'az'  => 'Azerbaigian',
    'ba'  => "Bosnie\ e\ Ercegovine",
    'bb'  => 'Barbados',
    'bd'  => 'Bangladesh',
    'be'  => 'Belgjiche',
    'bf'  => "Burkina\ Faso",
    'bg'  => 'Bulgarie',
    'bh'  => 'Bahrain',
    'bi'  => 'Burundi',
    'bj'  => 'Benin',
    'bl'  => "Sant\ Barthélemy",
    'bm'  => 'Bermuda',
    'bn'  => 'Brunei',
    'bo'  => 'Bolivie',
    'bq'  => "British\ Antarctic\ Territory",
    'br'  => 'Brasîl',
    'bs'  => 'Bahamas',
    'bt'  => 'Bhutan',
    'bv'  => "Isule\ Bouvet",
    'bw'  => 'Botswana',
    'by'  => 'Bielorussie',
    'bz'  => 'Belize',
    'ca'  => 'Canade',
    'cc'  => "Isulis\ Cocos",
    'cd'  => "Congo\ \[RDC\]",
    'cf'  => "Republiche\ centri\ africane",
    'cg'  => "Congo\ \[Republiche\]",
    'ch'  => 'Svuizare',
    'ci'  => "Cueste\ di\ Avoli",
    'ck'  => "Isulis\ Cook",
    'cl'  => 'Cile',
    'cm'  => 'Camerun',
    'cn'  => 'Cine',
    'co'  => 'Colombie',
    'cp'  => "Isule\ Clipperton",
    'cr'  => "Costa\ Rica",
    'cs'  => "Serbie\ e\ Montenegro",
    'ct'  => "Canton\ and\ Enderbury\ Islands",
    'cu'  => 'Cuba',
    'cv'  => "Cjâf\ vert",
    'cx'  => "Isule\ Christmas",
    'cy'  => 'Cipri',
    'cz'  => "Republiche\ ceche",
    'dd'  => "East\ Germany",
    'de'  => 'Gjermanie',
    'dg'  => "Diego\ Garcia",
    'dj'  => 'Gibuti',
    'dk'  => 'Danimarcje',
    'dm'  => 'Dominiche',
    'do'  => "Republiche\ dominicane",
    'dz'  => 'Alzerie',
    'ea'  => "Ceuta\ e\ Melilla",
    'ec'  => 'Ecuador',
    'ee'  => 'Estonie',
    'eg'  => 'Egjit',
    'eh'  => "Sahara\ ocidentâl",
    'er'  => 'Eritree',
    'es'  => 'Spagne',
    'et'  => 'Etiopie',
    'eu'  => "Union\ europeane",
    'fi'  => 'Finlandie',
    'fj'  => 'Fizi',
    'fk'  => "Isulis\ Falkland\ \[Isulis\ Malvinas\]",
    'fm'  => 'Micronesie',
    'fo'  => "Isulis\ Faroe",
    'fq'  => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'  => 'France',
    'fx'  => "Metropolitan\ France",
    'ga'  => 'Gabon',
    'gb'  => "Ream\ unît",
    'gd'  => 'Grenada',
    'ge'  => 'Gjeorgjie',
    'gf'  => "Guiana\ francês",
    'gg'  => 'Guernsey',
    'gh'  => 'Ghana',
    'gi'  => 'Gjibraltar',
    'gl'  => 'Groenlande',
    'gm'  => 'Gambia',
    'gn'  => 'Guinee',
    'gp'  => 'Guadalupe',
    'gq'  => "Guinee\ ecuatoriâl",
    'gr'  => 'Grecie',
    'gs'  => "Georgia\ dal\ Sud\ e\ Isulis\ Sandwich\ dal\ Sud",
    'gt'  => 'Guatemala',
    'gu'  => 'Guam',
    'gw'  => "Guinea\-Bissau",
    'gy'  => 'Guyana',
    'hk'  => "Hong\ Kong",
    'hm'  => "Isule\ Heard\ e\ Isulis\ McDonald",
    'hn'  => 'Honduras',
    'hr'  => 'Cravuazie',
    'ht'  => 'Haiti',
    'hu'  => 'Ongjarie',
    'ic'  => "Isulis\ Canariis",
    'id'  => 'Indonesie',
    'ie'  => 'Irlande',
    'il'  => 'Israêl',
    'im'  => "Isule\ di\ Man",
    'in'  => 'India',
    'io'  => "Teritori\ britanic\ dal\ Ocean\ Indian",
    'iq'  => 'Iraq',
    'ir'  => 'Iran',
    'is'  => 'Islande',
    'it'  => 'Italie',
    'je'  => 'Jersey',
    'jm'  => 'Gjamaiche',
    'jo'  => 'Jordanie',
    'jp'  => 'Gjapon',
    'jt'  => "Johnston\ Island",
    'ke'  => 'Kenya',
    'kg'  => 'Kirghizstan',
    'kh'  => 'Camboze',
    'ki'  => 'Kiribati',
    'km'  => 'Comoris',
    'kn'  => "San\ Kitts\ e\ Nevis",
    'kp'  => "Coree\ dal\ nord",
    'kr'  => "Coree\ dal\ sud",
    'kw'  => 'Kuwait',
    'ky'  => "Isulis\ Cayman",
    'kz'  => 'Kazachistan',
    'la'  => 'Laos',
    'lb'  => 'Liban',
    'lc'  => "Sante\ Lusie",
    'li'  => 'Liechtenstein',
    'lk'  => "Sri\ Lanka",
    'lr'  => 'Liberie',
    'ls'  => 'Lesotho',
    'lt'  => 'Lituanie',
    'lu'  => 'Lussemburc',
    'lv'  => 'Letonie',
    'ly'  => 'Libie',
    'ma'  => 'Maroc',
    'mc'  => 'Monaco',
    'md'  => 'Moldavie',
    'me'  => 'Montenegro',
    'mf'  => "Sant\ Martin",
    'mg'  => 'Madagascar',
    'mh'  => "Isulis\ Marshall",
    'mi'  => "Midway\ Islands",
    'mk'  => "Macedonie\ \[FYROM\]",
    'ml'  => 'Mali',
    'mm'  => 'Birmanie',
    'mn'  => 'Mongolie',
    'mo'  => 'Macao',
    'mp'  => "Isulis\ Mariana\ dal\ Nord",
    'mq'  => 'Martiniche',
    'mr'  => 'Mauritanie',
    'ms'  => 'Montserrat',
    'mt'  => 'Malta',
    'mu'  => 'Maurizi',
    'mv'  => 'Maldivis',
    'mw'  => 'Malawi',
    'mx'  => 'Messic',
    'my'  => 'Malaysia',
    'mz'  => 'Mozambic',
    'na'  => 'Namibie',
    'nc'  => "Gnove\ Caledonie",
    'ne'  => 'Niger',
    'nf'  => "Isole\ Norfolk",
    'ng'  => 'Nigerie',
    'ni'  => 'Nicaragua',
    'nl'  => "Paîs\ bas",
    'no'  => 'Norvegje',
    'np'  => 'Nepal',
    'nq'  => "Dronning\ Maud\ Land",
    'nr'  => 'Nauru',
    'nt'  => "Neutral\ Zone",
    'nu'  => 'Niue',
    'nz'  => "Gnove\ Zelande",
    'om'  => 'Oman',
    'pa'  => 'Panamà',
    'pc'  => "Pacific\ Islands\ Trust\ Territory",
    'pe'  => 'Perù',
    'pf'  => "Polinesie\ francês",
    'pg'  => "Papue\ Gnove\ Guinee",
    'ph'  => 'Filipinis',
    'pk'  => 'Pakistan',
    'pl'  => 'Polonie',
    'pm'  => "San\ Pierre\ e\ Miquelon",
    'pn'  => 'Pitcairn',
    'pr'  => "Porto\ Rico",
    'ps'  => "Teritoris\ palestinês",
    'pt'  => 'Portugal',
    'pu'  => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'  => 'Palau',
    'py'  => 'Paraguay',
    'pz'  => "Panama\ Canal\ Zone",
    'qa'  => 'Qatar',
    'qo'  => "Oceanie\ periferiche",
    're'  => 'Reunion',
    'ro'  => 'Romanie',
    'rs'  => 'Serbie',
    'ru'  => 'Russie',
    'rw'  => 'Ruande',
    'sa'  => "Arabie\ Saudide",
    'sb'  => "Isulis\ Salomon",
    'sc'  => 'Seychelles',
    'sd'  => 'Sudan',
    'se'  => 'Svezie',
    'sg'  => 'Singapore',
    'sh'  => "Sante\ Eline",
    'si'  => 'Slovenie',
    'sj'  => "Svalbard\ e\ Jan\ Mayen",
    'sk'  => 'Slovachie',
    'sl'  => "Sierra\ Leone",
    'sm'  => "San\ Marin",
    'sn'  => 'Senegal',
    'so'  => 'Somalie',
    'sr'  => 'Suriname',
    'st'  => "Sao\ Tomè\ e\ Principe",
    'su'  => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'  => "El\ Salvador",
    'sy'  => 'Sirie',
    'sz'  => 'Swaziland',
    'ta'  => "Tristan\ da\ Cunha",
    'tc'  => "Isulis\ Turks\ e\ Caicos",
    'td'  => 'Çad',
    'tf'  => "Teritoris\ meridionâi\ francês",
    'tg'  => 'Togo',
    'th'  => 'Tailandie',
    'tj'  => 'Tazikistan',
    'tk'  => 'Tokelau',
    'tl'  => "Timor\ orientâl",
    'tm'  => 'Turkmenistan',
    'tn'  => 'Tunisie',
    'to'  => 'Tonga',
    'tr'  => 'Turchie',
    'tt'  => "Trinidad\ e\ Tobago",
    'tv'  => 'Tuvalu',
    'tw'  => 'Taiwan',
    'tz'  => 'Tanzanie',
    'ua'  => 'Ucraine',
    'ug'  => 'Uganda',
    'um'  => "Isulis\ periferichis\ minôrs\ dai\ Stâts\ Unîts",
    'us'  => "Stâts\ Unîts",
    'uy'  => 'Uruguay',
    'uz'  => 'Uzbechistan',
    'va'  => 'Vatican',
    'vc'  => "San\ Vincent\ e\ lis\ Grenadinis",
    'vd'  => "North\ Vietnam",
    've'  => 'Venezuela',
    'vg'  => "Isulis\ vergjinis\ britanichis",
    'vi'  => "Isulis\ vergjinis\ americanis",
    'vn'  => 'Vietnam',
    'vu'  => 'Vanuatu',
    'wf'  => "Wallis\ e\ Futuna",
    'wk'  => "Wake\ Island",
    'ws'  => 'Samoa',
    'yd'  => "People\â\\s\ Democratic\ Republic\ of\ Yemen",
    'ye'  => 'Yemen',
    'yt'  => 'Mayotte',
    'za'  => "Sud\ Afriche",
    'zm'  => 'Zambia',
    'zw'  => 'Zimbabwe',
    'zz'  => "Regjon\ no\ cognossude\ o\ no\ valide",
);

%Locales::DB::Territory::fur::name_to_code = (
    'afghanistan'                               => 'af',
    'afriche'                                   => '002',
    'africhedimieç'                            => '017',
    'africhemeridionâl'                        => '018',
    'africheocidentâl'                         => '011',
    'africheorientâl'                          => '014',
    'africhesetentrionâl'                      => '015',
    'albanie'                                   => 'al',
    'alzerie'                                   => 'dz',
    'americhecentrâl'                          => '013',
    'americhedalnord'                           => '003',
    'americhelatineecaraibiche'                 => 419,
    'americhemeridionâl'                       => '005',
    'americhesetentrionâl'                     => '021',
    'americhis'                                 => '019',
    'andorra'                                   => 'ad',
    'angola'                                    => 'ao',
    'anguilla'                                  => 'ai',
    'antartic'                                  => 'aq',
    'antiguaebarbuda'                           => 'ag',
    'antilisolandesis'                          => 'an',
    'arabiesaudide'                             => 'sa',
    'argjentine'                                => 'ar',
    'armenie'                                   => 'am',
    'aruba'                                     => 'aw',
    'ascensionisland'                           => 'ac',
    'asie'                                      => 142,
    'asiecentrâl'                              => 143,
    'asiemeridionâl'                           => '034',
    'asieocidentâl'                            => 145,
    'asieorientâl'                             => '030',
    'asiesudorientâl'                          => '035',
    'australie'                                 => 'au',
    'australieegnovezelande'                    => '053',
    'austrie'                                   => 'at',
    'azerbaigian'                               => 'az',
    'bahamas'                                   => 'bs',
    'bahrain'                                   => 'bh',
    'bangladesh'                                => 'bd',
    'barbados'                                  => 'bb',
    'belgjiche'                                 => 'be',
    'belize'                                    => 'bz',
    'benin'                                     => 'bj',
    'bermuda'                                   => 'bm',
    'bhutan'                                    => 'bt',
    'bielorussie'                               => 'by',
    'birmanie'                                  => 'mm',
    'bolivie'                                   => 'bo',
    'bosnieeercegovine'                         => 'ba',
    'botswana'                                  => 'bw',
    'brasîl'                                   => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brunei'                                    => 'bn',
    'bulgarie'                                  => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'camboze'                                   => 'kh',
    'camerun'                                   => 'cm',
    'canade'                                    => 'ca',
    'cantonandenderburyislands'                 => 'ct',
    'caraibic'                                  => '029',
    'ceutaemelilla'                             => 'ea',
    'channelislands'                            => 830,
    'cile'                                      => 'cl',
    'cine'                                      => 'cn',
    'cipri'                                     => 'cy',
    'cjâfvert'                                 => 'cv',
    'colombie'                                  => 'co',
    'commonwealthdaistâtsindipendents'         => 172,
    'comoris'                                   => 'km',
    'congordc'                                  => 'cd',
    'congorepubliche'                           => 'cg',
    'coreedalnord'                              => 'kp',
    'coreedalsud'                               => 'kr',
    'costarica'                                 => 'cr',
    'cravuazie'                                 => 'hr',
    'cuba'                                      => 'cu',
    'cuestediavoli'                             => 'ci',
    'czechoslovakia'                            => 200,
    'danimarcje'                                => 'dk',
    'diegogarcia'                               => 'dg',
    'dominiche'                                 => 'dm',
    'dronningmaudland'                          => 'nq',
    'eastgermany'                               => 'dd',
    'ecuador'                                   => 'ec',
    'egjit'                                     => 'eg',
    'elsalvador'                                => 'sv',
    'emirâtsarapsunîts'                       => 'ae',
    'eritree'                                   => 'er',
    'estonie'                                   => 'ee',
    'etiopie'                                   => 'et',
    'europe'                                    => 150,
    'europemeridionâl'                         => '039',
    'europeocidentâl'                          => 155,
    'europeorientâl'                           => 151,
    'europesetentrionâl'                       => 154,
    'filipinis'                                 => 'ph',
    'finlandie'                                 => 'fi',
    'fizi'                                      => 'fj',
    'france'                                    => 'fr',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabon'                                     => 'ga',
    'gambia'                                    => 'gm',
    'georgiadalsudeisulissandwichdalsud'        => 'gs',
    'ghana'                                     => 'gh',
    'gibuti'                                    => 'dj',
    'gjamaiche'                                 => 'jm',
    'gjapon'                                    => 'jp',
    'gjeorgjie'                                 => 'ge',
    'gjermanie'                                 => 'de',
    'gjibraltar'                                => 'gi',
    'gnovecaledonie'                            => 'nc',
    'gnovezelande'                              => 'nz',
    'grecie'                                    => 'gr',
    'grenada'                                   => 'gd',
    'groenlande'                                => 'gl',
    'guadalupe'                                 => 'gp',
    'guam'                                      => 'gu',
    'guatemala'                                 => 'gt',
    'guernsey'                                  => 'gg',
    'guianafrancês'                            => 'gf',
    'guineabissau'                              => 'gw',
    'guinee'                                    => 'gn',
    'guineeecuatoriâl'                         => 'gq',
    'guyana'                                    => 'gy',
    'haiti'                                     => 'ht',
    'honduras'                                  => 'hn',
    'hongkong'                                  => 'hk',
    'india'                                     => 'in',
    'indonesie'                                 => 'id',
    'iran'                                      => 'ir',
    'iraq'                                      => 'iq',
    'irlande'                                   => 'ie',
    'islande'                                   => 'is',
    'isolenorfolk'                              => 'nf',
    'israêl'                                   => 'il',
    'isulebouvet'                               => 'bv',
    'isulechristmas'                            => 'cx',
    'isuleclipperton'                           => 'cp',
    'isulediman'                                => 'im',
    'isuleheardeisulismcdonald'                 => 'hm',
    'isulisaland'                               => 'ax',
    'isuliscanariis'                            => 'ic',
    'isuliscayman'                              => 'ky',
    'isuliscocos'                               => 'cc',
    'isuliscook'                                => 'ck',
    'isulisfalklandisulismalvinas'              => 'fk',
    'isulisfaroe'                               => 'fo',
    'isulismarianadalnord'                      => 'mp',
    'isulismarshall'                            => 'mh',
    'isulisperiferichisminôrsdaistâtsunîts'  => 'um',
    'isulissalomon'                             => 'sb',
    'isulisturksecaicos'                        => 'tc',
    'isulisvergjinisamericanis'                 => 'vi',
    'isulisvergjinisbritanichis'                => 'vg',
    'italie'                                    => 'it',
    'jersey'                                    => 'je',
    'johnstonisland'                            => 'jt',
    'jordanie'                                  => 'jo',
    'kazachistan'                               => 'kz',
    'kenya'                                     => 'ke',
    'kirghizstan'                               => 'kg',
    'kiribati'                                  => 'ki',
    'kuwait'                                    => 'kw',
    'laos'                                      => 'la',
    'lesotho'                                   => 'ls',
    'letonie'                                   => 'lv',
    'liban'                                     => 'lb',
    'liberie'                                   => 'lr',
    'libie'                                     => 'ly',
    'liechtenstein'                             => 'li',
    'lituanie'                                  => 'lt',
    'lussemburc'                                => 'lu',
    'macao'                                     => 'mo',
    'macedoniefyrom'                            => 'mk',
    'madagascar'                                => 'mg',
    'malawi'                                    => 'mw',
    'malaysia'                                  => 'my',
    'maldivis'                                  => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'maroc'                                     => 'ma',
    'martiniche'                                => 'mq',
    'mauritanie'                                => 'mr',
    'maurizi'                                   => 'mu',
    'mayotte'                                   => 'yt',
    'melanesie'                                 => '054',
    'messic'                                    => 'mx',
    'metropolitanfrance'                        => 'fx',
    'micronesie'                                => 'fm',
    'midwayislands'                             => 'mi',
    'moldavie'                                  => 'md',
    'monaco'                                    => 'mc',
    'mongolie'                                  => 'mn',
    'mont'                                      => '001',
    'montenegro'                                => 'me',
    'montserrat'                                => 'ms',
    'mozambic'                                  => 'mz',
    'namibie'                                   => 'na',
    'nauru'                                     => 'nr',
    'nepal'                                     => 'np',
    'neutralzone'                               => 'nt',
    'nicaragua'                                 => 'ni',
    'niger'                                     => 'ne',
    'nigerie'                                   => 'ng',
    'niue'                                      => 'nu',
    'northvietnam'                              => 'vd',
    'norvegje'                                  => 'no',
    'oceanie'                                   => '009',
    'oceanieperiferiche'                        => 'qo',
    'oman'                                      => 'om',
    'ongjarie'                                  => 'hu',
    'pacificislandstrustterritory'              => 'pc',
    'pakistan'                                  => 'pk',
    'palau'                                     => 'pw',
    'panamacanalzone'                           => 'pz',
    'panamà'                                   => 'pa',
    'papuegnoveguinee'                          => 'pg',
    'paraguay'                                  => 'py',
    'paîsbas'                                  => 'nl',
    "people\â\\sdemocraticrepublicofyemen" => 'yd',
    'perù'                                     => 'pe',
    'pitcairn'                                  => 'pn',
    'polinesie'                                 => '061',
    'polinesiefrancês'                         => 'pf',
    'polonie'                                   => 'pl',
    'portorico'                                 => 'pr',
    'portugal'                                  => 'pt',
    'qatar'                                     => 'qa',
    'reamunît'                                 => 'gb',
    'regjondemicronesie'                        => '057',
    'regjonnocognossudeonovalide'               => 'zz',
    'republicheceche'                           => 'cz',
    'republichecentriafricane'                  => 'cf',
    'republichedominicane'                      => 'do',
    'reunion'                                   => 're',
    'romanie'                                   => 'ro',
    'ruande'                                    => 'rw',
    'russie'                                    => 'ru',
    'saharaocidentâl'                          => 'eh',
    'samoa'                                     => 'ws',
    'samoamerecanis'                            => 'as',
    'sankittsenevis'                            => 'kn',
    'sanmarin'                                  => 'sm',
    'sanpierreemiquelon'                        => 'pm',
    'santbarthélemy'                           => 'bl',
    'santeeline'                                => 'sh',
    'santelusie'                                => 'lc',
    'santmartin'                                => 'mf',
    'sanvincentelisgrenadinis'                  => 'vc',
    'saotomèeprincipe'                         => 'st',
    'senegal'                                   => 'sn',
    'serbie'                                    => 'rs',
    'serbieemontenegro'                         => 'cs',
    'seychelles'                                => 'sc',
    'sierraleone'                               => 'sl',
    'singapore'                                 => 'sg',
    'sirie'                                     => 'sy',
    'slovachie'                                 => 'sk',
    'slovenie'                                  => 'si',
    'somalie'                                   => 'so',
    'southcentralasia'                          => '062',
    'spagne'                                    => 'es',
    'srilanka'                                  => 'lk',
    'stâtsunîts'                              => 'us',
    'sudafriche'                                => 'za',
    'sudan'                                     => 'sd',
    'suriname'                                  => 'sr',
    'svalbardejanmayen'                         => 'sj',
    'svezie'                                    => 'se',
    'svuizare'                                  => 'ch',
    'swaziland'                                 => 'sz',
    'tailandie'                                 => 'th',
    'taiwan'                                    => 'tw',
    'tanzanie'                                  => 'tz',
    'tazikistan'                                => 'tj',
    'teritoribritanicdaloceanindian'            => 'io',
    'teritorismeridionâifrancês'              => 'tf',
    'teritorispalestinês'                      => 'ps',
    'timororientâl'                            => 'tl',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidadetobago'                           => 'tt',
    'tristandacunha'                            => 'ta',
    'tunisie'                                   => 'tn',
    'turchie'                                   => 'tr',
    'turkmenistan'                              => 'tm',
    'tuvalu'                                    => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'ucraine'                                   => 'ua',
    'uganda'                                    => 'ug',
    'unioneuropeane'                            => 'eu',
    'unionofsovietsocialistrepublics'           => 'su',
    'uruguay'                                   => 'uy',
    'uzbechistan'                               => 'uz',
    'vanuatu'                                   => 'vu',
    'vatican'                                   => 'va',
    'venezuela'                                 => 've',
    'vietnam'                                   => 'vn',
    'wakeisland'                                => 'wk',
    'wallisefutuna'                             => 'wf',
    'yemen'                                     => 'ye',
    'zambia'                                    => 'zm',
    'zimbabwe'                                  => 'zw',
    'Çad'                                      => 'td',
);

1;

